@@ -97,7 +97,7 @@ void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b)
 
 //-----------------------------------------------------------------------------
 void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b,
-                unsigned char a)
+                      unsigned char a)
 {
   this->Color[0] = r;
   this->Color[1] = g;
@@ -105,6 +105,11 @@ void vtkPen::SetColor(unsigned char r, unsigned char g, unsigned char b,
   this->Color[3] = a;
 }
 
+void vtkPen::SetColor(const vtkColor4ub &color)
+{
+  this->PenColor = color;
+}
+
 //-----------------------------------------------------------------------------
 void vtkPen::SetOpacity(unsigned char a)
 {
@@ -129,6 +134,11 @@ void vtkPen::GetColor(unsigned char color[3])
     }
 }
 
+vtkColor4ub vtkPen::GetColorObject()
+{
+  return this->PenColor;
+}
+
 //-----------------------------------------------------------------------------
 unsigned char vtkPen::GetOpacity()
 {
