@@ -2,7 +2,7 @@
 
   Program:   Visualization Toolkit
   Module:    vtkArrayCoordinates.h
-  
+
 -------------------------------------------------------------------------
   Copyright 2008 Sandia Corporation.
   Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
@@ -22,11 +22,12 @@
 // .NAME vtkArrayCoordinates - Stores coordinate into an N-way array.
 //
 // .SECTION Description
-// vtkArrayCoordinates stores a collection of coordinates that can be used to
-// access values in a vtkArray containing an arbitrary number of dimensions.
+// vtkArrayCoordinates stores a collection of coordinates that can be
+// used to access values in a vtkArray containing an arbitrary number of
+// dimensions.
 //
-// Convenience constructors are provided for working with one, two, and three
-// dimensions.  For higher dimensions, use the default constructor, 
+// Convenience constructors are provided for working with one, two, and
+// three dimensions.  For higher dimensions, use the default constructor,
 // SetDimensions() and operator[] to assign a coordinate value along each
 // dimension.
 //
@@ -34,65 +35,70 @@
 // vtkArray, vtkArrayExtents
 //
 // .SECTION Thanks
-// Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories.
+// Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National
+// Laboratories.
 
 #ifndef __vtkArrayCoordinates_h
 #define __vtkArrayCoordinates_h
 
 #include "vtkSystemIncludes.h"
-#include <vtksys/stl/vector>
+#include <vector>
 
 class VTK_COMMON_EXPORT vtkArrayCoordinates
 {
 public:
+  typedef vtkIdType CoordinateT;
+  typedef vtkIdType DimensionT;
+
   // Description:
-  // Create an empty set of coordinates.  Use SetDimensions() and operator[]
-  // to populate the coordinates.
+  // Create an empty set of coordinates.  Use SetDimensions() and
+  // operator[] to populate the coordinates.
   vtkArrayCoordinates();
-  
+
   // Description:
   // Create coordinates for a one-dimensional array.
-  explicit vtkArrayCoordinates(vtkIdType i);
-  
+  explicit vtkArrayCoordinates(CoordinateT i);
+
   // Description:
   // Create coordinates for a two-dimensional array.
-  vtkArrayCoordinates(vtkIdType i, vtkIdType j);
-  
+  vtkArrayCoordinates(CoordinateT i, CoordinateT j);
+
   // Description:
   // Create coordinates for a three-dimensional array.
-  vtkArrayCoordinates(vtkIdType i, vtkIdType j, vtkIdType k);
+  vtkArrayCoordinates(CoordinateT i, CoordinateT j, CoordinateT k);
 
   // Description:
   // Return the number of dimensions contained in the coordinates.
-  vtkIdType GetDimensions() const;
+  DimensionT GetDimensions() const;
 
   // Description:
-  // Set the number of dimensions.  Note that this method resets the coordinate
-  // along each dimension to zero, so you must set every coordinate explicitly
-  // using operator[] after calling SetDimensions().
-  void SetDimensions(vtkIdType dimensions);
-  
+  // Set the number of dimensions.  Note that this method resets the
+  // coordinate along each dimension to zero, so you must set every
+  // coordinate explicitly using operator[] after calling SetDimensions().
+  void SetDimensions(DimensionT dimensions);
+
   // Description:
   // Returns the index of the i-th dimension.
-  vtkIdType& operator[](vtkIdType i);
-  
+  CoordinateT& operator[](DimensionT i);
+
   // Description:
   // Returns the index of the i-th dimension.
-  const vtkIdType& operator[](vtkIdType i) const;  
+  const CoordinateT& operator[](DimensionT i) const;
 
-  
   // Description:
   // Equality comparison
   bool operator==(const vtkArrayCoordinates& rhs) const;
-  
+
   // Description:
   // Inequality comparison
   bool operator!=(const vtkArrayCoordinates& rhs) const;
   VTK_COMMON_EXPORT friend ostream& operator<<(
     ostream& stream, const vtkArrayCoordinates& rhs);
-  
+
 private:
-  vtkstd::vector<vtkIdType> Storage;
+  //BTX
+  std::vector<CoordinateT> Storage;
+  //ETX
 };
 
 #endif
