@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCommand.h,v $
+  Module:    vtkCommand.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -76,12 +76,12 @@
 //  - Views/vtkView returns NULL
 //  - Views/vtkDataRepresentation returns a pointer to a vtkSelection
 //  - Rendering/vtkInteractorStyleRubberBand2D returns an array of 5 unsigned
-// int values (startPosition[2],endPosition[2], and selection type
-// {SELECT_UNION|SELECT_NORMAL})
-//  - Rendering/vtkInteractorStyleRubberBand3D returns an array of 5 unsigned
-// int values (startPosition[2],endPosition[2], and selection type
-// {SELECT_UNION|SELECT_NORMAL})
-//  - Graphics/vtkSelectionLink returns NULL
+// integers (p1x, p1y, p2x, p2y, mode), where mode is
+// vtkInteractorStyleRubberBand2D::SELECT_UNION or
+// vtkInteractorStyleRubberBand2D::SELECT_NORMAL
+// - vtkCommand::AnnotationChangedEvent
+//  - GUISupport/Qt/vtkQtAnnotationView returns a pointer to a
+// vtkAnnotationLayers
 // - vtkCommand::PlacePointEvent
 //  - Widgets/vtkSeedWidget returns a pointer to an int, being the current
 // handle number
@@ -158,6 +158,10 @@
 //  - Rendering/vtkRenderer returns a pointer to itself
 // - vtkCommand::ResetCameraClippingRangeEvent
 //  - Rendering/vtkRenderer returns a pointer to itself
+// - vtkCommand::ActiveCameraEvent
+//  - Rendering/vtkRenderer returns a pointer to the active camera
+// - vtkCommand::CreateCameraEvent
+//  - Rendering/vtkRenderer returns a pointer to the created camera
 // - vtkCommand::EnterEvent
 //  - most of the objects return NULL
 //  - GUISupport/Qt/QVTKWidget returns a QEvent*
@@ -166,6 +170,8 @@
 //  - GUISupport/Qt/QVTKWidget returns a QEvent*
 // - vtkCommand::RenderWindowMessageEvent
 //  - Rendering/vtkWin32OpenGLRenderWindow return a pointer to a UINT message
+// - vtkCommand::ComputeVisiblePropBoundsEvent
+//  - Rendering/vtkRenderer returns a pointer to itself
 // - QVTKWidget::ContextMenuEvent
 //  - GUISupport/Qt/QVTKWidget returns a QContextMenuEvent*
 // - QVTKWidget::DragEnterEvent
@@ -182,6 +188,12 @@
 //  - A pointer to a double value between 0.0 and 1.0
 // - vtkCommand::VolumeMapperComputeGradientsProgressEvent
 //  - A pointer to a double value between 0.0 and 1.0
+// - vtkCommand::TDxMotionEvent (TDx=3DConnexion)
+//  - A vtkTDxMotionEventInfo*
+// - vtkCommand::TDxButtonPressEvent
+//  - A int* being the number of the button
+// - vtkCommand::TDxButtonReleaseEvent
+//  - A int* being the number of the button
 //
 // .SECTION See Also
 // vtkObject vtkCallbackCommand vtkOldStyleCallbackCommand
@@ -191,21 +203,22 @@
 #define __vtkCommand_h
 
 #include "vtkObjectBase.h"
-
-class vtkObject;
+#include "vtkObject.h" // Need vtkTypeMacro
 
 // The superclass that all commands should be subclasses of
 class VTK_COMMON_EXPORT vtkCommand : public vtkObjectBase
 {
 public:
+  vtkTypeMacro(vtkCommand,vtkObjectBase);
+
   // Description:
   // Decrease the reference count (release by another object). This has
   // the same effect as invoking Delete() (i.e., it reduces the reference
   // count by 1).
   void UnRegister();
-  virtual void UnRegister(vtkObjectBase *) 
+  virtual void UnRegister(vtkObjectBase *)
     { this->UnRegister(); }
-  
+
   // Description:
   // All derived classes of vtkCommand must implement this
   // method. This is the method that actually does the work of the
@@ -217,7 +230,7 @@ public:
   // but the user can package data and pass it this
   // way. Alternatively, a derived class of vtkCommand can be used to
   // pass data.)
-  virtual void Execute(vtkObject *caller, unsigned long eventId, 
+  virtual void Execute(vtkObject *caller, unsigned long eventId,
                        void *callData) = 0;
 
   // Description:
@@ -229,29 +242,29 @@ public:
   // Description:
   // Set/Get the abort flag. If this is set to true no further
   // commands are executed.
-  void SetAbortFlag(int f)  
+  void SetAbortFlag(int f)
     { this->AbortFlag = f; }
-  int GetAbortFlag() 
+  int GetAbortFlag()
     { return this->AbortFlag; }
-  void AbortFlagOn() 
+  void AbortFlagOn()
     { this->SetAbortFlag(1); }
-  void AbortFlagOff() 
+  void AbortFlagOff()
     { this->SetAbortFlag(0); }
-  
+
   // Description:
   // Set/Get the passive observer flag. If this is set to true, this
   // indicates that this command does not change the state of the
   // system in any way. Passive observers are processed first, and
   // are not called even when another command has focus.
-  void SetPassiveObserver(int f)  
+  void SetPassiveObserver(int f)
     { this->PassiveObserver = f; }
-  int GetPassiveObserver() 
+  int GetPassiveObserver()
     { return this->PassiveObserver; }
-  void PassiveObserverOn() 
+  void PassiveObserverOn()
     { this->SetPassiveObserver(1); }
-  void PassiveObserverOff() 
+  void PassiveObserverOff()
     { this->SetPassiveObserver(0); }
-  
+
 //BTX
   // Description:
   // All the currently defined events are listed here.  Developers can
@@ -288,6 +301,8 @@ public:
     MouseMoveEvent,
     MouseWheelForwardEvent,
     MouseWheelBackwardEvent,
+    ActiveCameraEvent,
+    CreateCameraEvent,
     ResetCameraEvent,
     ResetCameraClippingRangeEvent,
     ModifiedEvent,
@@ -323,7 +338,7 @@ public:
     WidgetModifiedEvent,
     WidgetValueChangedEvent,
     WidgetActivateEvent,
-    ConnectionCreatedEvent, 
+    ConnectionCreatedEvent,
     ConnectionClosedEvent,
     DomainModifiedEvent,
     PropertyModifiedEvent,
@@ -331,11 +346,26 @@ public:
     RegisterEvent,
     UnRegisterEvent,
     UpdateInformationEvent,
+    AnnotationChangedEvent,
     SelectionChangedEvent,
     UpdatePropertyEvent,
     ViewProgressEvent,
     UpdateDataEvent,
     CurrentChangedEvent,
+    ComputeVisiblePropBoundsEvent,
+    TDxMotionEvent, // 3D Connexion device event
+    TDxButtonPressEvent, // 3D Connexion device event
+    TDxButtonReleaseEvent, // 3D Connexion device event
+    HoverEvent,
+    LoadStateEvent,
+    SaveStateEvent,
+    StateChangedEvent,
+    WindowMakeCurrentEvent,
+    WindowIsCurrentEvent,
+    WindowFrameEvent,
+    HighlightEvent,
+    WindowSupportsOpenGLEvent,
+    WindowIsDirectEvent,
     UserEvent = 1000
   };
 //ETX
@@ -355,4 +385,4 @@ protected:
 };
 
 #endif /* __vtkCommand_h */
- 
+
