@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCriticalSection.h,v $
+  Module:    vtkCriticalSection.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -109,7 +109,7 @@ class VTK_COMMON_EXPORT vtkCriticalSection : public vtkObject
 public:
   static vtkCriticalSection *New();
 
-  vtkTypeRevisionMacro(vtkCriticalSection,vtkObject);
+  vtkTypeMacro(vtkCriticalSection,vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
   
   // Description:
