@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkIdListCollection.h,v $
+  Module:    vtkIdListCollection.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,7 +28,7 @@ class VTK_COMMON_EXPORT vtkIdListCollection : public vtkCollection
 {
 public:
   static vtkIdListCollection *New();
-  vtkTypeRevisionMacro(vtkIdListCollection,vtkCollection);
+  vtkTypeMacro(vtkIdListCollection,vtkCollection);
 
   // Description:
   // Add a dataset to the list.
