@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLookupTable.cxx,v $
+  Module:    vtkLookupTable.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -18,7 +18,6 @@
 #include "vtkMath.h"
 #include <assert.h>
 
-vtkCxxRevisionMacro(vtkLookupTable, "$Revision: 1.110 $");
 vtkStandardNewMacro(vtkLookupTable);
 
 // Construct with range=(0,1); and hsv ranges set up for rainbow color table 
@@ -45,6 +44,11 @@ vtkLookupTable::vtkLookupTable(int sze, int ext)
   this->AlphaRange[1] = 1.0;
   this->Alpha = 1.0;
 
+  this->NanColor[0] = 0.5;
+  this->NanColor[1] = 0.0;
+  this->NanColor[2] = 0.0;
+  this->NanColor[3] = 1.0;
+
   this->TableRange[0] = 0.0;
   this->TableRange[1] = 1.0;
 
@@ -70,6 +74,7 @@ int vtkLookupTable::IsOpaque()
   if(this->OpaqueFlagBuildTime<this->GetMTime())
     {
     int opaque=1;
+    if (this->NanColor[3] < 1.0) { opaque = 0; }
     int size=this->Table->GetNumberOfTuples();
     int i=0;
     unsigned char *ptr=this->Table->GetPointer(0);
@@ -346,27 +351,33 @@ inline double vtkApplyLogScale(double v, const double range[2],
       }
     }
   return v;
-}                 
+}
 
 //----------------------------------------------------------------------------
 // Apply shift/scale to the scalar value v and do table lookup.
-inline unsigned char *vtkLinearLookup(double v,   
+inline unsigned char *vtkLinearLookup(double v,
                                       unsigned char *table,
                                       double maxIndex,
-                                      double shift, double scale)
+                                      double shift, double scale,
+                                      unsigned char *nanColor)
 {
-  double findx = (v + shift)*scale;
-  if (findx < 0)
+  if (vtkMath::IsNan(v))
     {
-    findx = 0;
+    return nanColor;
     }
-  if (findx > maxIndex)
+
+  double findx = (v + shift)*scale;
+  if (findx < 0.0)
+    {
+    findx = 0.0;
+    }
+  else if (findx > maxIndex)
     {
     findx = maxIndex;
     }
-  return &table[4*static_cast<int>(findx)];
+  return &table[4*static_cast<unsigned int>(findx)];
   /* round
-  return &table[4*(int)(findx + 0.5f)];
+  return &table[4*(unsigned int)(findx + 0.5f)];
   */
 }
 
@@ -486,6 +497,12 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
   unsigned char *cptr;
   double alpha;
 
+  unsigned char nanColor[4];
+  for (int c = 0; c < 4; c++)
+    {
+    nanColor[c] = static_cast<unsigned char>(self->GetNanColor()[c]*255.0);
+    }
+
   if ( (alpha=self->GetAlpha()) >= 1.0 ) //no blending required 
     {
     if (self->GetScale() == VTK_SCALE_LOG10)
@@ -509,7 +526,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -522,7 +539,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -534,7 +551,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           *output++ = cptr[3];
@@ -546,7 +563,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           input += inIncr;
@@ -572,7 +589,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -584,7 +602,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -595,7 +614,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           *output++ = cptr[3];
@@ -606,7 +626,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           input += inIncr;
@@ -638,7 +659,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -651,7 +672,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -663,7 +684,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           *output++ = static_cast<unsigned char>(alpha*cptr[3]);
@@ -675,7 +696,7 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         while (--i >= 0) 
           {
           val = vtkApplyLogScale(*input, range, logRange);
-          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           input += inIncr;
@@ -701,7 +722,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -713,7 +735,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = *cptr++;
           *output++ = *cptr++;
           *output++ = *cptr++;
@@ -724,7 +747,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           *output++ = static_cast<unsigned char>(cptr[3]*alpha);
@@ -735,7 +759,8 @@ void vtkLookupTableMapData(vtkLookupTable *self, T *input,
         {
         while (--i >= 0) 
           {
-          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale); 
+          cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
+                                 nanColor);
           *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 + 
                                                  cptr[2]*0.11 + 0.5);
           input += inIncr;
@@ -935,6 +960,9 @@ void vtkLookupTable::PrintSelf(ostream& os, vtkIndent indent)
      << this->ValueRange[1] << ")\n";
   os << indent << "AlphaRange: (" << this->AlphaRange[0] << ", "
      << this->AlphaRange[1] << ")\n";
+  os << indent << "NanColor: (" << this->NanColor[0] << ", "
+     << this->NanColor[1] << ", " << this->NanColor[2] << ", "
+     << this->NanColor[3] << ")\n";
   os << indent << "NumberOfTableValues: "
      << this->GetNumberOfTableValues() << "\n";
   os << indent << "NumberOfColors: " << this->NumberOfColors << "\n";
@@ -983,3 +1011,8 @@ void vtkLookupTable::DeepCopy(vtkLookupTable *lut)
   this->Table->DeepCopy(lut->Table);
 }
 
+//----------------------------------------------------------------------------
+vtkIdType vtkLookupTable::GetNumberOfAvailableColors()
+{
+  return this->Table->GetNumberOfTuples();
+}
