@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPlaneCollection.cxx,v $
+  Module:    vtkPlaneCollection.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -15,7 +15,6 @@
 #include "vtkPlaneCollection.h"
 #include "vtkObjectFactory.h"
 
-vtkCxxRevisionMacro(vtkPlaneCollection, "$Revision: 1.8 $");
 vtkStandardNewMacro(vtkPlaneCollection);
 
 vtkPlane *vtkPlaneCollection::GetNextPlane(
