@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkProcessStatistics.h,v $
+  Module:    vtkProcessStatistics.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -27,7 +27,7 @@ public:
   // Construct the ProcessStatistics with eight points.
   static vtkProcessStatistics *New();
 
-  vtkTypeRevisionMacro(vtkProcessStatistics,vtkObject);
+  vtkTypeMacro(vtkProcessStatistics,vtkObject);
 
   int    GetProcessSizeInBytes();
   double GetProcessCPUTimeInMilliseconds();
