@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkSmartPointer.h,v $
+  Module:    vtkSmartPointer.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -21,7 +21,6 @@
 #define __vtkSmartPointer_h
 
 #include "vtkSmartPointerBase.h"
-#include <vtksys/Configure.hxx> // need check for member template support
 
 template <class T>
 class vtkSmartPointer: public vtkSmartPointerBase
@@ -39,13 +38,9 @@ public:
   // Description:
   // Initialize smart pointer with a new reference to the same object
   // referenced by given smart pointer.
-#ifdef vtksys_CXX_HAS_MEMBER_TEMPLATES
   template <class U>
   vtkSmartPointer(const vtkSmartPointer<U>& r):
     vtkSmartPointerBase(CheckType(r.GetPointer())) {}
-#else
-  vtkSmartPointer(const vtkSmartPointerBase& r): vtkSmartPointerBase(r) {}
-#endif
 
   // Description:
   // Assign object to reference.  This removes any reference to an old
@@ -59,20 +54,12 @@ public:
   // Description:
   // Assign object to reference.  This removes any reference to an old
   // object.
-#ifdef vtksys_CXX_HAS_MEMBER_TEMPLATES
   template <class U>
   vtkSmartPointer& operator=(const vtkSmartPointer<U>& r)
     {
     this->vtkSmartPointerBase::operator=(CheckType(r.GetPointer()));
     return *this;
     }
-#else
-  vtkSmartPointer& operator=(const vtkSmartPointerBase& r)
-    {
-    this->vtkSmartPointerBase::operator=(r);
-    return *this;
-    }
-#endif
 
   // Description:
   // Get the contained pointer.
