@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTransformCollection.h,v $
+  Module:    vtkTransformCollection.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,7 @@
 class VTK_COMMON_EXPORT vtkTransformCollection : public vtkCollection
 {
 public:
-  vtkTypeRevisionMacro(vtkTransformCollection,vtkCollection);
+  vtkTypeMacro(vtkTransformCollection,vtkCollection);
   static vtkTransformCollection *New();
 
   // Description:
