@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkUnsignedLongLongArray.h,v $
+  Module:    vtkUnsignedLongLongArray.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -36,7 +36,7 @@ class VTK_COMMON_EXPORT vtkUnsignedLongLongArray : public vtkDataArray
 {
 public:
   static vtkUnsignedLongLongArray* New();
-  vtkTypeRevisionMacro(vtkUnsignedLongLongArray,vtkDataArray);
+  vtkTypeMacro(vtkUnsignedLongLongArray,vtkDataArray);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -93,6 +93,34 @@ public:
   vtkIdType InsertNextValue(unsigned long long f)
     { return this->RealSuperclass::InsertNextValue(f); }
 
+  // Description:
+  // Get the range of array values for the given component in the
+  // native data type.
+  unsigned long long *GetValueRange(int comp)
+    { return this->RealSuperclass::GetValueRange(comp); }
+//BTX
+  void GetValueRange(unsigned long long range[2], int comp)
+    { this->RealSuperclass::GetValueRange(range, comp); }
+//ETX
+
+  // Description:
+  // Get the range of array values for the 0th component in the
+  // native data type.
+  unsigned long long *GetValueRange()
+    { return this->RealSuperclass::GetValueRange(0); }
+//BTX
+  void GetValueRange(unsigned long long range[2])
+    { this->RealSuperclass::GetValueRange(range, 0); }
+//ETX
+
+  // Description:
+  // Get the minimum data value in its native type.
+  static unsigned long long GetDataTypeValueMin() {return VTK_UNSIGNED_LONG_LONG_MIN;}
+
+  // Description:
+  // Get the maximum data value in its native type.
+  static unsigned long long GetDataTypeValueMax() {return VTK_UNSIGNED_LONG_LONG_MAX;}
+
   // Description:
   // Get the address of a particular data index. Make sure data is allocated
   // for the number of items requested. Set MaxId according to the number of
@@ -112,7 +140,7 @@ public:
   // the array supplied by the user.  Set save to 1 to keep the class
   // from deleting the array when it cleans up or reallocates memory.
   // The class uses the actual array provided; it does not copy the data
-  // from the suppled array. 
+  // from the suppled array.
   void SetArray(unsigned long long* array, vtkIdType size, int save)
     { this->RealSuperclass::SetArray(array, size, save); }
   void SetArray(unsigned long long* array, vtkIdType size, int save, int deleteMethod)
