@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkVariantArray.cxx,v $
+  Module:    vtkVariantArray.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -76,7 +76,6 @@ public:
 // Standard functions
 //
 
-vtkCxxRevisionMacro(vtkVariantArray, "$Revision: 1.17 $");
 vtkStandardNewMacro(vtkVariantArray);
 //----------------------------------------------------------------------------
 void vtkVariantArray::PrintSelf(ostream& os, vtkIndent indent)
@@ -558,9 +557,9 @@ void vtkVariantArray::InsertValue(vtkIdType id, vtkVariant value)
 }
 
 //----------------------------------------------------------------------------
-void vtkVariantArray::InsertVariantValue(vtkIdType id, vtkVariant value)
+void vtkVariantArray::SetVariantValue(vtkIdType id, vtkVariant value)
 {
-  this->InsertValue(id, value);
+  this->SetValue(id, value);
 }
 
 //----------------------------------------------------------------------------
