@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkWin32Header.h,v $
+  Module:    vtkWin32Header.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -45,7 +45,7 @@ Do_not_include_vtkWin32Header_directly__vtkSystemIncludes_includes_it;
 
 //
 // Windows specific stuff------------------------------------------
-#if defined(_WIN32) || defined(WIN32) || defined(__CYGWIN__)
+#if defined(_WIN32) || defined(WIN32)
 
 // define strict header for windows
 #ifndef STRICT
@@ -85,7 +85,9 @@ Do_not_include_vtkWin32Header_directly__vtkSystemIncludes_includes_it;
 # endif
   // Enable workaround for windows header name mangling.
   // See VTK/Utilities/Upgrading/README.WindowsMangling.txt for details.
+#if !defined(__WRAP__)
 # define VTK_WORKAROUND_WINDOWS_MANGLE
+#endif
 
 #if ( _MSC_VER >= 1300 ) // Visual studio .NET
 #pragma warning ( disable : 4311 )
