@@ -23,10 +23,9 @@ theme.SetLineWidth(4)
 view.ApplyViewTheme(theme)
 theme.FastDelete()
 
-window = vtkRenderWindow()
-window.SetSize(600, 600)
-view.SetupRenderWindow(window)
-view.GetRenderer().ResetCamera()
+view.GetRenderWindow().SetSize(600, 600)
+view.ResetCamera()
+view.Render()
 
-window.GetInteractor().Start()
+view.GetInteractor().Start()
 
