@@ -8,7 +8,6 @@ reader3 = vtkXMLTreeReader()
 reader3.SetFileName("vtklibrary.xml")
 reader3.Update()
 
-dummy = vtkIcicleView()
 view2 = vtkIcicleView()
 view2.SetRepresentationFromInput(reader2.GetOutput())
 view2.SetAreaSizeArrayName("size")
@@ -37,14 +36,11 @@ view2.ApplyViewTheme(theme)
 view3.ApplyViewTheme(theme)
 theme.FastDelete()
 
-win2 = vtkRenderWindow()
-win3 = vtkRenderWindow()
-dummy.SetupRenderWindow(win2)
-view2.SetupRenderWindow(win2)
-view3.SetupRenderWindow(win3)
-view2.GetRenderer().ResetCamera()
-view3.GetRenderer().ResetCamera()
+view2.ResetCamera()
+view3.ResetCamera()
+view2.Render()
+view3.Render()
 
-win2.GetInteractor().Initialize()
-win3.GetInteractor().Initialize()
-win2.GetInteractor().Start()
+view2.GetInteractor().Initialize()
+view3.GetInteractor().Initialize()
+view2.GetInteractor().Start()
