@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: GPURenderDemo.cxx,v $
+  Module:    GPURenderDemo.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -30,13 +30,11 @@
 #include "vtkVolume.h"
 #include "vtkVolumeProperty.h"
 #include "vtkXMLImageDataReader.h"
-#include "vtkGPUVolumeRayCastMapper.h"
+#include "vtkSmartVolumeMapper.h"
 
 #define VTI_FILETYPE 1
 #define MHA_FILETYPE 2
 
-// FB: comment for testing svn
-
 // Callback for moving the planes from the box widget to the mapper
 class vtkBoxWidgetCallback : public vtkCommand
 {
@@ -54,14 +52,14 @@ public:
         planes->Delete();
         }
     }
-  void SetMapper(vtkGPUVolumeRayCastMapper* m) 
+  void SetMapper(vtkSmartVolumeMapper* m) 
     { this->Mapper = m; }
 
 protected:
   vtkBoxWidgetCallback() 
     { this->Mapper = 0; }
 
-  vtkGPUVolumeRayCastMapper *Mapper;
+  vtkSmartVolumeMapper *Mapper;
 };
 
 void PrintUsage()
@@ -316,7 +314,7 @@ int main(int argc, char *argv[])
   
   // Create our volume and mapper
   vtkVolume *volume = vtkVolume::New();
-  vtkGPUVolumeRayCastMapper *mapper = vtkGPUVolumeRayCastMapper::New();
+  vtkSmartVolumeMapper *mapper = vtkSmartVolumeMapper::New();
   
   // Add a box widget if the clip option was selected
   vtkBoxWidget *box = vtkBoxWidget::New();
@@ -522,13 +520,6 @@ int main(int argc, char *argv[])
   renWin->SetSize(600,600);
   renWin->Render();
 
-  if ( !mapper->IsRenderSupported(renWin, property) )
-    {
-      cout << "This mapper is unsupported on this platform" << endl;
-      exit(EXIT_FAILURE);
-    }
-  
-
   // Add the volume to the scene
   renderer->AddVolume( volume );
 
