@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkArrayData.cxx,v $
+  Module:    vtkArrayData.cxx
   
 -------------------------------------------------------------------------
   Copyright 2008 Sandia Corporation.
@@ -32,7 +32,6 @@
 // Standard functions
 //
 
-vtkCxxRevisionMacro(vtkArrayData, "$Revision: 1.13 $");
 vtkStandardNewMacro(vtkArrayData);
 
 class vtkArrayData::implementation
