@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkArrayData.h,v $
+  Module:    vtkArrayData.h
   
 -------------------------------------------------------------------------
   Copyright 2008 Sandia Corporation.
@@ -19,14 +19,6 @@
 
 =========================================================================*/
 
-#ifndef __vtkArrayData_h
-#define __vtkArrayData_h
-
-#include "vtkArray.h"
-#include "vtkDataObject.h"
-
-class vtkArray;
-
 // .NAME vtkArrayData - Pipeline data object that contains multiple vtkArray objects.
 //
 // .SECTION Description
@@ -42,11 +34,19 @@ class vtkArray;
 // .SECTION Thanks
 // Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories.
 
+#ifndef __vtkArrayData_h
+#define __vtkArrayData_h
+
+#include "vtkArray.h"
+#include "vtkDataObject.h"
+
+class vtkArray;
+
 class VTK_FILTERING_EXPORT vtkArrayData : public vtkDataObject
 {
 public:
   static vtkArrayData* New();
-  vtkTypeRevisionMacro(vtkArrayData, vtkDataObject);
+  vtkTypeMacro(vtkArrayData, vtkDataObject);
   void PrintSelf(ostream &os, vtkIndent indent);
 
   static vtkArrayData* GetData(vtkInformation* info);
