@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkBiQuadraticQuadraticHexahedron.h,v $
+  Module:    vtkBiQuadraticQuadraticHexahedron.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -78,7 +78,7 @@ class VTK_FILTERING_EXPORT vtkBiQuadraticQuadraticHexahedron : public vtkNonLine
 {
 public:
   static vtkBiQuadraticQuadraticHexahedron *New();
-  vtkTypeRevisionMacro(vtkBiQuadraticQuadraticHexahedron,vtkNonLinearCell);
+  vtkTypeMacro(vtkBiQuadraticQuadraticHexahedron,vtkNonLinearCell);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
