@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCardinalSpline.cxx,v $
+  Module:    vtkCardinalSpline.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -18,7 +18,6 @@
 #include "vtkPiecewiseFunction.h"
 #include <assert.h>
 
-vtkCxxRevisionMacro(vtkCardinalSpline, "$Revision: 1.31 $");
 vtkStandardNewMacro(vtkCardinalSpline);
 
 //----------------------------------------------------------------------------
