@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkColorTransferFunction.cxx,v $
+  Module:    vtkColorTransferFunction.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,9 +22,10 @@
 #include <vtkstd/iterator>
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkColorTransferFunction, "$Revision: 1.80 $");
 vtkStandardNewMacro(vtkColorTransferFunction);
 
+#define MY_MAX(x, y) ((x) > (y) ? (x) : (y))
+
 //=============================================================================
 class vtkCTFNode
 {
@@ -181,14 +182,16 @@ inline void vtkColorTransferFunctionInterpolateDiverging(double s,
     {
     // Insert the white midpoint by setting one end to white and adjusting the
     // scalar value.
+    double Mmid = MY_MAX(msh1[0], msh2[0]);
+    Mmid = MY_MAX(88.0, Mmid);
     if (s < 0.5)
       {
-      msh2[0] = 95.0;  msh2[1] = 0.0;  msh2[2] = 0.0;
+      msh2[0] = Mmid;  msh2[1] = 0.0;  msh2[2] = 0.0;
       s = 2.0*s;
       }
     else
       {
-      msh1[0] = 95.0;  msh1[1] = 0.0;  msh1[2] = 0.0;
+      msh1[0] = Mmid;  msh1[1] = 0.0;  msh1[2] = 0.0;
       s = 2.0*s - 1.0;
       }
     }
@@ -233,6 +236,10 @@ vtkColorTransferFunction::vtkColorTransferFunction()
   this->HSVWrap = 1; //By default HSV will be wrap
 
   this->Scale = VTK_CTF_LINEAR;
+
+  this->NanColor[0] = 0.5;
+  this->NanColor[1] = 0.0;
+  this->NanColor[2] = 0.0;
   
   this->Function = NULL;
 
@@ -618,6 +625,23 @@ void vtkColorTransferFunction::GetTable( double xStart, double xEnd,
                                          int size, double* table )
 {
   int i, j;
+
+  // Special case: If either the start or end is a NaN, then all any
+  // interpolation done on them is also a NaN.  Therefore, fill the table with
+  // the NaN color.
+  if (vtkMath::IsNan(xStart) || vtkMath::IsNan(xEnd))
+    {
+    double *tableEntry = table;
+    for (i = 0; i < size; i++)
+      {
+      tableEntry[0] = this->NanColor[0];
+      tableEntry[1] = this->NanColor[1];
+      tableEntry[2] = this->NanColor[2];
+      tableEntry += 3;
+      }
+    return;
+    }
+
   int idx = 0;
   int numNodes = static_cast<int>(this->Internal->Nodes.size());
   
@@ -1434,6 +1458,19 @@ void vtkColorTransferFunction::MapScalarsThroughTable2(void *input,
     }
 }
 
+//----------------------------------------------------------------------------
+vtkIdType vtkColorTransferFunction::GetNumberOfAvailableColors()
+{
+  if(this->Table)
+    {
+    // Not sure if this is correct since it is only set if
+    // "const unsigned char *::GetTable( double xStart, double xEnd,int size)"
+    // has been called.
+    return static_cast<vtkIdType>(this->TableSize);
+    }
+  return 16777216;  //2^24
+}
+
 //----------------------------------------------------------------------------
 void vtkColorTransferFunction::FillFromDataPointer(int nb, double *ptr)
 {
@@ -1565,6 +1602,10 @@ void vtkColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "AllowDuplicateScalars: " << this->AllowDuplicateScalars << endl;
 
+  os << indent << "NanColor: "
+     << this->NanColor[0] << ", " << this->NanColor[1] << ", "
+     << this->NanColor[2] << endl;
+
   unsigned int i;
   for( i = 0; i < this->Internal->Nodes.size(); i++ )
     {
