@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCompositeDataPipeline.h,v $
+  Module:    vtkCompositeDataPipeline.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -55,7 +55,7 @@ class VTK_FILTERING_EXPORT vtkCompositeDataPipeline : public vtkStreamingDemandD
 {
 public:
   static vtkCompositeDataPipeline* New();
-  vtkTypeRevisionMacro(vtkCompositeDataPipeline,vtkStreamingDemandDrivenPipeline);
+  vtkTypeMacro(vtkCompositeDataPipeline,vtkStreamingDemandDrivenPipeline);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -108,6 +108,14 @@ public:
   // *** THIS IS AN EXPERIMENTAL FEATURE. IT MAY CHANGE WITHOUT NOTICE ***
   static vtkInformationIntegerVectorKey* COMPOSITE_INDICES();
 
+  // Description:
+  // COMPOSITE_INDEX() is added to the leaf nodes of the meta-data composite
+  // dataset (COMPOSITE_DATA_META_DATA) during REQUEST_INFORMATION(). Filters
+  // downstream can use this index to request specific datasets when
+  // creating UPDATE_COMPOSITE_INDICES().
+  // *** THIS IS AN EXPERIMENTAL FEATURE. IT MAY CHANGE WITHOUT NOTICE ***
+  static vtkInformationIntegerKey* COMPOSITE_INDEX();
+
 protected:
   vtkCompositeDataPipeline();
   ~vtkCompositeDataPipeline();
