@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExecutionScheduler.cxx,v $
+  Module:    vtkExecutionScheduler.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -50,7 +50,6 @@
 #include <vtksys/hash_set.hxx>
 
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkExecutionScheduler, "$Revision: 1.19 $");
 vtkStandardNewMacro(vtkExecutionScheduler);
 
 vtkInformationKeyMacro(vtkExecutionScheduler, TASK_PRIORITY, Integer);
@@ -750,6 +749,22 @@ void vtkExecutionScheduler::RescheduleNetwork(vtkExecutive *sink)
   this->RescheduleFrom(sink, this->Resources);
 }
 
+//----------------------------------------------------------------------------
+void vtkExecutionScheduler::ClassInitialize()
+{
+  // Currently empty - initialize late when required.
+}
+
+//----------------------------------------------------------------------------
+void vtkExecutionScheduler::ClassFinalize()
+{
+  // Clean up our singleton (if it was ever initalized).
+  if (globalScheduler)
+    {
+    globalScheduler->FastDelete();
+    }
+}
+
 //----------------------------------------------------------------------------
 typedef struct 
 {
