@@ -48,6 +48,9 @@ public:
   int IsLinear();
   int RequiresInitialization();
   void Initialize();
+  int RequiresExplicitFaceRepresentation();
+  void SetFaces(vtkIdType *faces);
+  vtkIdType *GetFaces();
   int GetNumberOfEdges();
   int GetNumberOfFaces();
   vtkCell *GetEdge(int edgeId);
@@ -107,6 +110,7 @@ public:
   void SetCellTypeToPyramid() {this->SetCellType(VTK_PYRAMID);}
   void SetCellTypeToPentagonalPrism() {this->SetCellType(VTK_PENTAGONAL_PRISM);}
   void SetCellTypeToHexagonalPrism() {this->SetCellType(VTK_HEXAGONAL_PRISM);}
+  void SetCellTypeToPolyhedron() {this->SetCellType(VTK_POLYHEDRON);}
   void SetCellTypeToConvexPointSet() {this->SetCellType(VTK_CONVEX_POINT_SET);}
   void SetCellTypeToQuadraticEdge() {this->SetCellType(VTK_QUADRATIC_EDGE);}
   void SetCellTypeToCubicLine() {this->SetCellType(VTK_CUBIC_LINE);}
