@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPolyLine.h,v $
+  Module:    vtkPolyLine.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -33,7 +33,7 @@ class VTK_FILTERING_EXPORT vtkPolyLine : public vtkCell
 {
 public:
   static vtkPolyLine *New();
-  vtkTypeRevisionMacro(vtkPolyLine,vtkCell);
+  vtkTypeMacro(vtkPolyLine,vtkCell);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
