@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQuad.cxx,v $
+  Module:    vtkQuad.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,10 +22,9 @@
 #include "vtkMath.h"
 #include "vtkPlane.h"
 #include "vtkPointData.h"
-#include "vtkPointLocator.h"
+#include "vtkIncrementalPointLocator.h"
 #include "vtkPoints.h"
 
-vtkCxxRevisionMacro(vtkQuad, "$Revision: 1.3.12.1 $");
 vtkStandardNewMacro(vtkQuad);
 
 static const double VTK_DIVERGED = 1.e6;
@@ -400,9 +399,15 @@ static LINE_CASES lineCases[] = {
   {{-1, -1, -1, -1, -1}}
 };
 
+//----------------------------------------------------------------------------
+int *vtkQuad::GetEdgeArray(int edgeId)
+{
+  return edges[edgeId];
+}
+
 //----------------------------------------------------------------------------
 void vtkQuad::Contour(double value, vtkDataArray *cellScalars, 
-                      vtkPointLocator *locator, 
+                      vtkIncrementalPointLocator *locator,
                       vtkCellArray *verts, 
                       vtkCellArray *lines, 
                       vtkCellArray *vtkNotUsed(polys), 
@@ -795,7 +800,7 @@ static QUAD_CASES quadCasesComplement[] = {
 // Clip this quad using scalar value provided. Like contouring, except
 // that it cuts the quad to produce other quads and/or triangles.
 void vtkQuad::Clip(double value, vtkDataArray *cellScalars, 
-                   vtkPointLocator *locator, vtkCellArray *polys,
+                   vtkIncrementalPointLocator *locator, vtkCellArray *polys,
                    vtkPointData *inPd, vtkPointData *outPd,
                    vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd,
                    int insideOut)
