@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkSmoothErrorMetric.cxx,v $
+  Module:    vtkSmoothErrorMetric.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkMath.h"
 #include <assert.h>
 
-vtkCxxRevisionMacro(vtkSmoothErrorMetric,"$Revision: 1.2 $");
 vtkStandardNewMacro(vtkSmoothErrorMetric);
 
 //-----------------------------------------------------------------------------
