@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkUndirectedGraph.h,v $
+  Module:    vtkUndirectedGraph.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -45,7 +45,7 @@ class VTK_FILTERING_EXPORT vtkUndirectedGraph : public vtkGraph
 {
 public:
   static vtkUndirectedGraph *New();
-  vtkTypeRevisionMacro(vtkUndirectedGraph, vtkGraph);
+  vtkTypeMacro(vtkUndirectedGraph, vtkGraph);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -84,15 +84,16 @@ public:
   virtual void GetInEdges(vtkIdType v, vtkInEdgeIterator *it)
     { Superclass::GetInEdges(v, it); }
 
+  // Description:
+  // Check the structure, and accept it if it is a valid
+  // undirected graph. This is public to allow
+  // the ToDirected/UndirectedGraph to work.
+  virtual bool IsStructureValid(vtkGraph *g);
+
 protected:
   vtkUndirectedGraph();
   ~vtkUndirectedGraph();
 
-  // Description:
-  // Check the structure, and accept it if it is a valid
-  // undirected graph.
-  virtual bool IsStructureValid(vtkGraph *g);
-
   //BTX
   // Description:
   // For iterators, returns the same edge list as GetOutEdges().
