@@ -61,11 +61,7 @@ void vtkEventQtSlotConnect::Connect(
   vtkObject* vtk_obj, unsigned long event,
   const QObject* qt_obj, const char* slot, 
   void* client_data, float priority
-#if QT_VERSION >= 0x040000
   , Qt::ConnectionType type)
-#else
-  )
-#endif
 {
   if (!vtk_obj || !qt_obj)
     {
@@ -75,11 +71,7 @@ void vtkEventQtSlotConnect::Connect(
   vtkQtConnection* connection = new vtkQtConnection(this);
   connection->SetConnection(
     vtk_obj, event, qt_obj, slot, client_data, priority
-#if QT_VERSION >= 0x040000
     , type);
-#else
-    );
-#endif
   Connections->push_back(connection);
 }
 
