@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQtChartView.cxx,v $
+  Module:    vtkQtChartView.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -107,7 +107,6 @@ private:
 };
 
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkQtChartView, "$Revision: 1.3 $");
 
 //----------------------------------------------------------------------------
 vtkQtChartView::vtkQtChartView()
