@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQtStackedChartView.h,v $
+  Module:    vtkQtStackedChartView.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -34,7 +34,7 @@ Q_OBJECT
 
 public:
   static vtkQtStackedChartView *New();
-  vtkTypeRevisionMacro(vtkQtStackedChartView, vtkQtChartView);
+  vtkTypeMacro(vtkQtStackedChartView, vtkQtChartView);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -53,7 +53,6 @@ public:
   // Sets whether or not the stacked chart is drawn with a gradient.
   void SetGradientDisplayed(bool gradient);
 
-  //BTX
   // Description:
   // Adds stacked chart selection handlers to the mouse selection.
   virtual void AddChartSelectionHandlers(vtkQtChartMouseSelection* selector);
@@ -69,7 +68,6 @@ public:
   // Description:
   // Gets the stacked chart series options.
   virtual vtkQtChartSeriesOptions* GetChartSeriesOptions(int series);
-  //ETX
 
 protected:
   vtkQtStackedChartView();
