@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQtTableRepresentation.h,v $
+  Module:    vtkQtTableRepresentation.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -61,7 +61,7 @@ class vtkQtTableModelAdapter;
 class QVTK_EXPORT vtkQtTableRepresentation : public vtkDataRepresentation
 {
 public:
-  vtkTypeRevisionMacro(vtkQtTableRepresentation, vtkDataRepresentation);
+  vtkTypeMacro(vtkQtTableRepresentation, vtkDataRepresentation);
   void PrintSelf(ostream &os, vtkIndent indent);
 
   // Description:
