@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkBridgeDataSet.h,v $
+  Module:    vtkBridgeDataSet.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -29,7 +29,7 @@ class VTK_BRIDGE_EXPORT vtkBridgeDataSet : public vtkGenericDataSet
 {
 public:
   static vtkBridgeDataSet *New();
-  vtkTypeRevisionMacro(vtkBridgeDataSet,vtkGenericDataSet);
+  vtkTypeMacro(vtkBridgeDataSet,vtkGenericDataSet);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
