@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGenericContourFilter.cxx,v $
+  Module:    vtkGenericContourFilter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -34,11 +34,11 @@
 #include "vtkGenericAttributeCollection.h"
 #include "vtkGenericAttribute.h"
 #include "vtkGenericCellTessellator.h"
+#include "vtkIncrementalPointLocator.h"
 
-vtkCxxRevisionMacro(vtkGenericContourFilter, "$Revision: 1.9 $");
 vtkStandardNewMacro(vtkGenericContourFilter);
 
-vtkCxxSetObjectMacro(vtkGenericContourFilter,Locator,vtkPointLocator);
+vtkCxxSetObjectMacro(vtkGenericContourFilter,Locator,vtkIncrementalPointLocator);
 
 // Construct object with initial range (0,1) and single contour value
 // of 0.0.
