@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGeoView.h,v $
+  Module:    vtkGeoView.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -56,7 +56,7 @@ class VTK_GEOVIS_EXPORT vtkGeoView : public vtkRenderView
 {
 public:
   static vtkGeoView *New();
-  vtkTypeRevisionMacro(vtkGeoView, vtkRenderView);
+  vtkTypeMacro(vtkGeoView, vtkRenderView);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -100,8 +100,6 @@ protected:
   vtkGeoView();
   ~vtkGeoView();
 
-  bool HasMesa();
-
   vtkGlobeSource*    LowResEarthSource;
   vtkPolyDataMapper* LowResEarthMapper;
   vtkActor*          LowResEarthActor;
