@@ -10,8 +10,11 @@ vtkRenderWindowInteractor iren
     iren SetRenderWindow renWin
 
 vtkGenericEnSightReader reader
+# Make sure all algorithms use the composite data pipeline
+vtkCompositeDataPipeline cdp
+reader SetDefaultExecutivePrototype cdp
+cdp Delete
     reader SetCaseFileName "$VTK_DATA_ROOT/Data/EnSight/elements6.case"
-    reader Update
 
 vtkGeometryFilter geom
     geom SetInputConnection [reader GetOutputPort]
@@ -25,7 +28,7 @@ vtkArrayCalculator calc
     calc AddVectorArrayName "pointCVectors_i" 0 1 2
     calc SetResultArrayName "test"
 
-vtkPolyDataMapper mapper
+vtkHierarchicalPolyDataMapper mapper
     mapper SetInputConnection [calc GetOutputPort]
     mapper SetColorModeToMapScalars
     mapper SetScalarModeToUsePointFieldData
@@ -47,3 +50,4 @@ renWin Render
 # prevent the tk window from showing up then start the event loop
 wm withdraw .
 
+reader SetDefaultExecutivePrototype {}
