@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkArrowSource.cxx,v $
+  Module:    vtkArrowSource.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,6 @@
 #include "vtkTransform.h"
 #include "vtkTransformFilter.h"
 
-vtkCxxRevisionMacro(vtkArrowSource, "$Revision: 1.8 $");
 vtkStandardNewMacro(vtkArrowSource);
 
 vtkArrowSource::vtkArrowSource()
