@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkArrowSource.h,v $
+  Module:    vtkArrowSource.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -35,7 +35,7 @@ public:
   // Construct cone with angle of 45 degrees.
   static vtkArrowSource *New();
 
-  vtkTypeRevisionMacro(vtkArrowSource,vtkPolyDataAlgorithm);
+  vtkTypeMacro(vtkArrowSource,vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
     
   // Description:
