@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkContourFilter.h,v $
+  Module:    vtkContourFilter.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -48,7 +48,7 @@
 
 #include "vtkContourValues.h" // Needed for inline methods
 
-class vtkPointLocator;
+class vtkIncrementalPointLocator;
 class vtkScalarTree;
 class vtkSynchronizedTemplates2D;
 class vtkSynchronizedTemplates3D;
@@ -58,7 +58,7 @@ class vtkRectilinearSynchronizedTemplates;
 class VTK_GRAPHICS_EXPORT vtkContourFilter : public vtkPolyDataAlgorithm
 {
 public:
-  vtkTypeRevisionMacro(vtkContourFilter,vtkPolyDataAlgorithm);
+  vtkTypeMacro(vtkContourFilter,vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -121,8 +121,8 @@ public:
   // Description:
   // Set / get a spatial locator for merging points. By default, 
   // an instance of vtkMergePoints is used.
-  void SetLocator(vtkPointLocator *locator);
-  vtkGetObjectMacro(Locator,vtkPointLocator);
+  void SetLocator(vtkIncrementalPointLocator *locator);
+  vtkGetObjectMacro(Locator,vtkIncrementalPointLocator);
 
   // Description:
   // Create default locator. Used to create one when none is
@@ -159,7 +159,7 @@ protected:
   int ComputeNormals;
   int ComputeGradients;
   int ComputeScalars;
-  vtkPointLocator *Locator;
+  vtkIncrementalPointLocator *Locator;
   int UseScalarTree;
   vtkScalarTree *ScalarTree;
   
