@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkConvertSelection.cxx,v $
+  Module:    vtkConvertSelection.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -55,7 +55,6 @@
 
 vtkCxxSetObjectMacro(vtkConvertSelection, ArrayNames, vtkStringArray);
 
-vtkCxxRevisionMacro(vtkConvertSelection, "$Revision: 1.23 $");
 vtkStandardNewMacro(vtkConvertSelection);
 //----------------------------------------------------------------------------
 vtkConvertSelection::vtkConvertSelection()
@@ -64,6 +63,7 @@ vtkConvertSelection::vtkConvertSelection()
   this->OutputType = vtkSelectionNode::INDICES;
   this->ArrayNames = 0;
   this->InputFieldType = -1;
+  this->MatchAnyValues = false;
 }
 
 //----------------------------------------------------------------------------
@@ -72,6 +72,25 @@ vtkConvertSelection::~vtkConvertSelection()
   this->SetArrayNames(0);
 }
 
+//----------------------------------------------------------------------------
+void vtkConvertSelection::AddArrayName(const char* name)
+{
+  if (!this->ArrayNames)
+    {
+    this->ArrayNames = vtkStringArray::New();
+    }
+  this->ArrayNames->InsertNextValue(name);
+}
+
+//----------------------------------------------------------------------------
+void vtkConvertSelection::ClearArrayNames()
+{
+  if (this->ArrayNames)
+    {
+    this->ArrayNames->Initialize();
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkConvertSelection::SetArrayName(const char* name)
 {
@@ -211,7 +230,7 @@ int vtkConvertSelection::ConvertToBlockSelection(
   vtkstd::set<unsigned int> indices;
   for (unsigned int n = 0; n < input->GetNumberOfNodes(); ++n)
     {
-    vtkSelectionNode* inputNode = input->GetNode(n);
+    vtkSmartPointer<vtkSelectionNode> inputNode = input->GetNode(n);
     if (inputNode->GetContentType() == vtkSelectionNode::GLOBALIDS)
       {
       // global id selection does not have COMPOSITE_INDEX() key, so we convert
@@ -502,18 +521,13 @@ int vtkConvertSelection::Convert(
     else if (vtkTable::SafeDownCast(data))
       {
       if (!inputNode->GetProperties()->Has(vtkSelectionNode::FIELD_TYPE()) ||
-          inputNode->GetFieldType() == vtkSelectionNode::ROW)
+          inputNode->GetFieldType() != vtkSelectionNode::FIELD)
         {
         dsa = vtkTable::SafeDownCast(data)->GetRowData();
         }
-      else if (inputNode->GetFieldType() == vtkSelectionNode::FIELD)
-        {
-        fd = data->GetFieldData();
-        }
       else
         {
-        vtkErrorMacro("Inappropriate selection type for a vtkTable");
-        return 0;
+        fd = data->GetFieldData();
         }
       }
     else
@@ -678,7 +692,11 @@ int vtkConvertSelection::Convert(
             }
           }
         }
-      else
+      // If no domain array, the name of the selection and data arrays
+      // must match (if they exist).
+      else if (inputNode->GetContentType() != vtkSelectionNode::PEDIGREEIDS ||
+               !selArr->GetName() || !dataArr->GetName() ||
+               !strcmp(selArr->GetName(), dataArr->GetName()))
         {
         // Perform the lookup
         vtkIdType numTuples = selArr->GetNumberOfTuples();
@@ -800,38 +818,55 @@ int vtkConvertSelection::Convert(
         }
     
       // Check array existence.
-      if (!outputDataArr)
+      if (outputDataArr)
         {
-        vtkErrorMacro("Output selection array does not exist in input dataset.");
-        return 0;
-        }
-
-      // Put the array's values into the selection.
-      vtkAbstractArray* outputArr = vtkAbstractArray::CreateArray(outputDataArr->GetDataType());
-      outputArr->SetName(outputDataArr->GetName());
-      vtkIdType numTuples = outputDataArr->GetNumberOfTuples();
-      vtkIdType numIndices = indices->GetNumberOfTuples();
-      for (vtkIdType i = 0; i < numIndices; ++i)
-        {
-        vtkIdType index = indices->GetValue(i);
-        if (index < numTuples)
+        // Put the array's values into the selection.
+        vtkAbstractArray* outputArr = vtkAbstractArray::CreateArray(outputDataArr->GetDataType());
+        outputArr->SetName(outputDataArr->GetName());
+        vtkIdType numTuples = outputDataArr->GetNumberOfTuples();
+        vtkIdType numIndices = indices->GetNumberOfTuples();
+        for (vtkIdType i = 0; i < numIndices; ++i)
           {
-          outputArr->InsertNextTuple(index, outputDataArr);
+          vtkIdType index = indices->GetValue(i);
+          if (index < numTuples)
+            {
+            outputArr->InsertNextTuple(index, outputDataArr);
+            }
+          if (i % 1000 == 0)
+            {
+            progress = 0.8 + (0.2 * (ind*numIndices + i)) / (numOutputArrays*numIndices);
+            this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
+            }
+          }
+
+        if(this->MatchAnyValues)
+          {
+          vtkSmartPointer<vtkSelectionNode> outNode =
+            vtkSmartPointer<vtkSelectionNode>::New();
+          outNode->ShallowCopy(inputNode);
+          outNode->SetContentType(this->OutputType);
+          outNode->SetSelectionList(outputArr);
+          output->AddNode(outNode);
           }
         else
           {
-          // TODO: Make this a silent warning when we are done debugging
-          vtkWarningMacro("Attempting to select an index outside the array range.");
-          }
-        if (i % 1000 == 0)
-          {
-          progress = 0.8 + (0.2 * (ind*numIndices + i)) / (numOutputArrays*numIndices);
-          this->InvokeEvent(vtkCommand::ProgressEvent, &progress);
+          outputData->AddArray(outputArr);
           }
+
+        outputArr->Delete();
         }
-      outputData->AddArray(outputArr);
-      outputArr->Delete();
       }
+
+    // If there are no output arrays, just add a dummy one so
+    // that the selection list is not null.
+    if (outputData->GetNumberOfArrays() == 0)
+      {
+      vtkSmartPointer<vtkIdTypeArray> arr =
+        vtkSmartPointer<vtkIdTypeArray>::New();
+      arr->SetName("Empty");
+      outputData->AddArray(arr);
+      }
+
     outputNode->SetSelectionData(outputData);
     output->Union(outputNode);
     }
@@ -924,6 +959,7 @@ void vtkConvertSelection::GetSelectedItems(
         }
       }
     }
+  indexSel->Delete();
 }
 
 //----------------------------------------------------------------------------
@@ -1020,16 +1056,23 @@ vtkSelection* vtkConvertSelection::ToSelectionType(
   vtkSelection* input, 
   vtkDataObject* data, 
   int type, 
-  vtkStringArray* arrayNames)
+  vtkStringArray* arrayNames,
+  int inputFieldType)
 {
   VTK_CREATE(vtkConvertSelection, convert);
-  convert->SetInput(0, input);
-  convert->SetInput(1, data);
+  vtkDataObject* dataCopy = data->NewInstance();
+  dataCopy->ShallowCopy(data);
+  VTK_CREATE(vtkSelection, inputCopy);
+  inputCopy->ShallowCopy(input);
+  convert->SetInput(0, inputCopy);
+  convert->SetInput(1, dataCopy);
   convert->SetOutputType(type);
   convert->SetArrayNames(arrayNames);
+  convert->SetInputFieldType(inputFieldType);
   convert->Update();
   vtkSelection* output = convert->GetOutput();
   output->Register(0);
+  dataCopy->Delete();
   return output;
 }
 
@@ -1039,6 +1082,7 @@ void vtkConvertSelection::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "InputFieldType: " << this->InputFieldType << endl;
   os << indent << "OutputType: " << this->OutputType << endl;
+  os << indent << "MatchAnyValues: " << (this->MatchAnyValues ? "true" : "false") << endl;
   os << indent << "ArrayNames: " << (this->ArrayNames ? "" : "(null)") << endl;
   if (this->ArrayNames)
     {
