@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCutter.cxx,v $
+  Module:    vtkCutter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,6 +28,7 @@
 #include "vtkInformationVector.h"
 #include "vtkMergePoints.h"
 #include "vtkObjectFactory.h"
+#include "vtkPlane.h"
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkRectilinearGrid.h"
@@ -37,13 +38,14 @@
 #include "vtkSynchronizedTemplates3D.h"
 #include "vtkSynchronizedTemplatesCutter3D.h"
 #include "vtkUnstructuredGrid.h"
+#include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkIncrementalPointLocator.h"
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkCutter, "$Revision: 1.88 $");
 vtkStandardNewMacro(vtkCutter);
 vtkCxxSetObjectMacro(vtkCutter,CutFunction,vtkImplicitFunction);
-vtkCxxSetObjectMacro(vtkCutter,Locator,vtkPointLocator)
+vtkCxxSetObjectMacro(vtkCutter,Locator,vtkIncrementalPointLocator)
 
 //----------------------------------------------------------------------------
 // Construct with user-specified implicit function; initial value of 0.0; and
@@ -60,6 +62,9 @@ vtkCutter::vtkCutter(vtkImplicitFunction *cf)
   this->SynchronizedTemplatesCutter3D = vtkSynchronizedTemplatesCutter3D::New();
   this->GridSynchronizedTemplates = vtkGridSynchronizedTemplates3D::New();
   this->RectilinearSynchronizedTemplates = vtkRectilinearSynchronizedTemplates::New();
+
+  this->GetInformation()->Set(vtkAlgorithm::PRESERVES_RANGES(), 1);
+  this->GetInformation()->Set(vtkAlgorithm::PRESERVES_BOUNDS(), 1);
 }
 
 //----------------------------------------------------------------------------
@@ -92,12 +97,6 @@ unsigned long vtkCutter::GetMTime()
     mTime = ( time > mTime ? time : mTime );
     }
 
-  if ( this->Locator != NULL )
-    {
-    time = this->Locator->GetMTime();
-    mTime = ( time > mTime ? time : mTime );
-    }
-
   return mTime;
 }
 
@@ -317,7 +316,7 @@ int vtkCutter::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkDataSet *input = vtkDataSet::SafeDownCast(
     inInfo->Get(vtkDataObject::DATA_OBJECT()));
   vtkPolyData *output = vtkPolyData::SafeDownCast(
@@ -391,6 +390,7 @@ void vtkCutter::GetCellTypeDimensions(unsigned char* cellTypeDimensions)
   cellTypeDimensions[VTK_VERTEX] = 0;
   cellTypeDimensions[VTK_POLY_VERTEX] = 0;
   cellTypeDimensions[VTK_LINE] = 1;
+  cellTypeDimensions[VTK_CUBIC_LINE]=1;
   cellTypeDimensions[VTK_POLY_LINE] = 1;
   cellTypeDimensions[VTK_QUADRATIC_EDGE] = 1;
   cellTypeDimensions[VTK_PARAMETRIC_CURVE] = 1;
@@ -401,6 +401,7 @@ void vtkCutter::GetCellTypeDimensions(unsigned char* cellTypeDimensions)
   cellTypeDimensions[VTK_PIXEL] = 2;
   cellTypeDimensions[VTK_QUAD] = 2;
   cellTypeDimensions[VTK_QUADRATIC_TRIANGLE] = 2;
+  cellTypeDimensions[VTK_BIQUADRATIC_TRIANGLE] = 2;
   cellTypeDimensions[VTK_QUADRATIC_QUAD] = 2;
   cellTypeDimensions[VTK_QUADRATIC_LINEAR_QUAD] = 2;
   cellTypeDimensions[VTK_BIQUADRATIC_QUAD] = 2;
@@ -993,3 +994,130 @@ void vtkCutter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Generate Cut Scalars: "
      << (this->GenerateCutScalars ? "On\n" : "Off\n");
 }
+
+//-----------------------------------------------------------------------
+
+int vtkCutter::ProcessRequest(vtkInformation* request,
+                              vtkInformationVector** inputVector,
+                              vtkInformationVector* outputVector)
+{
+  if(request->Has(vtkStreamingDemandDrivenPipeline::
+     REQUEST_UPDATE_EXTENT_INFORMATION()))
+    {
+    // compute the priority for this UpdateExtent
+    vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
+    if (!inInfo)
+      {
+      return 1;
+      }
+
+    double inPrior = 1;
+    if (inInfo->Has(vtkStreamingDemandDrivenPipeline::PRIORITY()))
+      {
+      inPrior = inInfo->Get(vtkStreamingDemandDrivenPipeline::
+                            PRIORITY());
+      }
+
+    // Get bounds and evaluate implicit function. If all bounds
+    // evaluate to a value smaller than input value, this piece
+    // has priority set to 0.
+
+    static double bounds[] = {-1.0,1.0, -1.0,1.0, -1.0,1.0};
+    double prior = 1;
+
+    // determine geometric bounds of this piece
+    double *wBBox =
+      inInfo->
+        Get(vtkStreamingDemandDrivenPipeline::PIECE_BOUNDING_BOX());
+
+    if (!wBBox)
+      {
+      wBBox =
+        inInfo->
+        Get(vtkStreamingDemandDrivenPipeline::WHOLE_BOUNDING_BOX());      
+      }
+    if (wBBox)
+      {
+      bounds[0] = wBBox[0];
+      bounds[1] = wBBox[1];
+      bounds[2] = wBBox[2];
+      bounds[3] = wBBox[3];
+      bounds[4] = wBBox[4];
+      bounds[5] = wBBox[5];
+      }
+    else
+      {
+      //try to figure out geometric bounds
+      double *origin = inInfo->Get(vtkDataObject::ORIGIN());
+      double *spacing = inInfo->Get(vtkDataObject::SPACING());
+      int *subExtent = inInfo->Get(
+        vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT());
+      if (origin && spacing && subExtent)
+        {
+        bounds[0] = origin[0]+subExtent[0]*spacing[0];
+        bounds[1] = origin[0]+subExtent[1]*spacing[0];
+        bounds[2] = origin[1]+subExtent[2]*spacing[1];
+        bounds[3] = origin[1]+subExtent[3]*spacing[1];
+        bounds[4] = origin[2]+subExtent[4]*spacing[2];
+        bounds[5] = origin[2]+subExtent[5]*spacing[2];
+        }
+      else
+        {
+        //cerr << "Need geometric bounds meta information to evaluate priority" << endl;
+        outputVector->GetInformationObject(0)->
+          Set(vtkStreamingDemandDrivenPipeline::PRIORITY(),inPrior);
+        return 1;
+        }
+      }
+
+    vtkPlane* fPtr = vtkPlane::SafeDownCast(this->GetCutFunction());
+    if (!fPtr)
+      {
+      //cerr << "Can not evaluate priority for that clip type" << endl;
+      outputVector->GetInformationObject(0)->
+        Set(vtkStreamingDemandDrivenPipeline::PRIORITY(),inPrior);
+      return 1;
+      }
+    
+    static double fVal[8];
+    fVal[0] = fPtr->EvaluateFunction(bounds[0],bounds[2],bounds[4]);
+    fVal[1] = fPtr->EvaluateFunction(bounds[0],bounds[2],bounds[5]);
+    fVal[2] = fPtr->EvaluateFunction(bounds[0],bounds[3],bounds[4]);
+    fVal[3] = fPtr->EvaluateFunction(bounds[0],bounds[3],bounds[5]);
+    fVal[4] = fPtr->EvaluateFunction(bounds[1],bounds[2],bounds[4]);
+    fVal[5] = fPtr->EvaluateFunction(bounds[1],bounds[2],bounds[5]);
+    fVal[6] = fPtr->EvaluateFunction(bounds[1],bounds[3],bounds[4]);
+    fVal[7] = fPtr->EvaluateFunction(bounds[1],bounds[3],bounds[5]);
+
+    prior = 0;
+    int numOffsets = this->ContourValues->GetNumberOfContours();
+    for (int c=0; c < numOffsets; c++)
+      {      
+      double value = this->ContourValues->GetValue(c);
+      int i;
+      bool less = fVal[0]<value;
+      for (i=1; i<8;i++)
+        {
+        if ((fVal[i]<=value) != less)
+          {
+          //this corner is on different side than first, piece 
+          //intersects and cannot be rejected
+          prior = inPrior;
+          c = numOffsets;
+          break;
+          }
+        }
+      }
+    if (prior != inPrior)
+      {
+      //cerr << "rejected something!" << endl;
+      }
+    outputVector->GetInformationObject(0)->
+      Set(vtkStreamingDemandDrivenPipeline::PRIORITY(),prior);
+    return 1;
+    }
+
+  //all other requests handled by superclass
+  return this->Superclass::ProcessRequest(request, inputVector,
+                                          outputVector);
+}
