@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkDensifyPolyData.cxx,v $
+  Module:    vtkDensifyPolyData.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -348,7 +348,6 @@ private:
 
 
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkDensifyPolyData, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkDensifyPolyData);
 
 //----------------------------------------------------------------------------
