@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExtractSelectedIds.cxx,v $
+  Module:    vtkExtractSelectedIds.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -34,7 +34,6 @@
 #include "vtkStringArray.h"
 #include "vtkUnstructuredGrid.h"
 
-vtkCxxRevisionMacro(vtkExtractSelectedIds, "$Revision: 1.31 $");
 vtkStandardNewMacro(vtkExtractSelectedIds);
 
 //----------------------------------------------------------------------------
@@ -192,10 +191,22 @@ void vtkExtractSelectedIdsCopyCells(vtkDataSet* input, T* output,
     {
     if (inArray[i] > 0)
       {
-      input->GetCellPoints(i, ptIds);
-      for (j = 0; j < ptIds->GetNumberOfIds(); j++)
+      // special handling for polyhedron cells
+      if (vtkUnstructuredGrid::SafeDownCast(input) &&
+          vtkUnstructuredGrid::SafeDownCast(output) &&
+          input->GetCellType(i) == VTK_POLYHEDRON)
         {
-        ptIds->SetId(j, pointMap[ptIds->GetId(j)]);
+        ptIds->Reset();
+        vtkUnstructuredGrid::SafeDownCast(input)->GetFaceStream(i, ptIds);
+        vtkUnstructuredGrid::ConvertFaceStreamPointIds(ptIds, pointMap);
+        }
+      else
+        {
+        input->GetCellPoints(i, ptIds);
+        for (j = 0; j < ptIds->GetNumberOfIds(); j++)
+          {
+          ptIds->SetId(j, pointMap[ptIds->GetId(j)]);
+          }
         }
       output->InsertNextCell(input->GetCellType(i), ptIds);
       outCD->CopyData(inCD, i, newId++);
