@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExtractSelectedThresholds.cxx,v $
+  Module:    vtkExtractSelectedThresholds.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,6 @@
 #include "vtkDoubleArray.h"
 #include "vtkSignedCharArray.h"
 
-vtkCxxRevisionMacro(vtkExtractSelectedThresholds, "$Revision: 1.18 $");
 vtkStandardNewMacro(vtkExtractSelectedThresholds);
 
 //----------------------------------------------------------------------------
@@ -144,7 +143,7 @@ int vtkExtractSelectedThresholds::ExtractCells(
     return 1;
     }
 
-  //find out what array we are suppose to threshold in
+  //find out what array we are supposed to threshold in
   vtkDataArray *inScalars = NULL;
   bool use_ids = false;
   if (usePointScalars)
@@ -414,7 +413,7 @@ int vtkExtractSelectedThresholds::ExtractPoints(
     return 1;
     }
 
-  //find out what array we are suppose to threshold in
+  //find out what array we are supposed to threshold in
   vtkDataArray *inScalars = NULL;
   bool use_ids = false;
   if (sel->GetSelectionList()->GetName())
