@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExtractTemporalFieldData.cxx,v $
+  Module:    vtkExtractTemporalFieldData.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -33,7 +33,6 @@
 
 
 
-vtkCxxRevisionMacro(vtkExtractTemporalFieldData, "$Revision: 1.7 $");
 vtkStandardNewMacro(vtkExtractTemporalFieldData);
 
 //----------------------------------------------------------------------------
