@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkFrustumSource.cxx,v $
+  Module:    vtkFrustumSource.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkInformationVector.h"
 #include "vtkCellArray.h"
 
-vtkCxxRevisionMacro(vtkFrustumSource, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkFrustumSource);
 vtkCxxSetObjectMacro(vtkFrustumSource,Planes,vtkPlanes);
 
