@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkHyperOctreeDepth.cxx,v $
+  Module:    vtkHyperOctreeDepth.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,6 @@
 #include "vtkCellData.h"
 #include "vtkIntArray.h"
 
-vtkCxxRevisionMacro(vtkHyperOctreeDepth, "$Revision: 1.3 $");
 vtkStandardNewMacro(vtkHyperOctreeDepth);
 
 //----------------------------------------------------------------------------
