@@ -123,7 +123,6 @@ int vtkImageMarchingCubes::RequestData(
   // multiply by the area of each slice
   temp *= extent[1] - extent[0] + 1;
   temp *= extent[3] - extent[2] + 1;
-  temp = temp;
   // temp holds memory per image. (+1 to avoid dividing by zero)
   this->NumberOfSlicesPerChunk = this->InputMemoryLimit * 1024 / (temp + 1);
   if (this->NumberOfSlicesPerChunk < minSlicesPerChunk)
@@ -310,7 +309,7 @@ void vtkImageMarchingCubesComputePointGradient(T *ptr, double *g,
 
 
 //----------------------------------------------------------------------------
-// This method interpolates verticies to make a new point.
+// This method interpolates vertices to make a new point.
 template <class T>
 int vtkImageMarchingCubesMakeNewPoint(vtkImageMarchingCubes *self,
                                       int idx0, int idx1, int idx2,
@@ -662,7 +661,7 @@ void vtkImageMarchingCubes::March(vtkImageData *inData,
 
 
 //============================================================================
-// These method act as the point locator so verticies will be shared.
+// These method act as the point locator so vertices will be shared.
 // One 2d array of cubes is stored. (z dimension is ignored).
 // Points are indexed by their cube and edge.
 // Shared edges are only represented once.  Cubes are responsible for
@@ -784,7 +783,7 @@ int *vtkImageMarchingCubes::GetLocatorPointer(int cellX,int cellY,int edge)
   cellY -= this->LocatorMinY;
 
   // compute new indexes for edges (0 to 4) 
-  // must be compatable with LocatorIncrementZ.
+  // must be compatible with LocatorIncrementZ.
   if (edge == 7)
     {
     edge = 1;
