@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkMarchingSquares.cxx,v $
+  Module:    vtkMarchingSquares.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -37,7 +37,6 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkMarchingSquares, "$Revision: 1.3 $");
 vtkStandardNewMacro(vtkMarchingSquares);
 
 // Description:
