@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkMergeCells.cxx,v $
+  Module:    vtkMergeCells.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -41,7 +41,6 @@
 #include <vtkstd/map>
 #include <vtkstd/algorithm>
 
-vtkCxxRevisionMacro(vtkMergeCells, "$Revision: 1.9 $");
 vtkStandardNewMacro(vtkMergeCells);
 
 vtkCxxSetObjectMacro(vtkMergeCells, UnstructuredGrid, vtkUnstructuredGrid);
@@ -723,7 +722,18 @@ vtkIdType *vtkMergeCells::MapPointsToIdsUsingLocator(vtkDataSet *set)
     if (npoints0 > 0)
       {
       double tmpbounds[6];
-      grid->GetBounds(tmpbounds);
+      
+      // Prior to MapPointsToIdsUsingLocator(), points0->SetNumberOfPoints()
+      // has been called to set the number of points to the upper bound on the
+      // points TO BE merged and now points0->GetNumberOfPoints() does not
+      // refer to the number of the points merged so far. Thus we need to 
+      // temporarily set the number to the latter such that grid->GetBounds()
+      // is able to return the correct bounding information. This is a fix to 
+      // bug #0009626.
+      
+      points0->GetData()->SetNumberOfTuples( npoints0 );
+      grid->GetBounds( tmpbounds ); // safe to call GetBounds() for real info
+      points0->GetData()->SetNumberOfTuples( this->TotalNumberOfPoints );
 
       bounds[0] = ((tmpbounds[0] < bounds[0]) ? tmpbounds[0] : bounds[0]);
       bounds[2] = ((tmpbounds[2] < bounds[2]) ? tmpbounds[2] : bounds[2]);
