@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkModelMetadata.h,v $
+  Module:    vtkModelMetadata.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -18,26 +18,26 @@
 ----------------------------------------------------------------------------*/
 
 // .NAME vtkModelMetadata - This class encapsulates the metadata
-//   that appear in mesh-based file formats but do not appear in 
+//   that appear in mesh-based file formats but do not appear in
 //   vtkUnstructuredGrid.  It can pack itself into the field
 //   arrays of a vtkUnstructuredGrid, and be unpacked by metadata
 //   aware filters and writers later on.
 //
 // .SECTION Description
 //   This class is inspired by the Exodus II file format, but
-//   because this class does not depend on the Exodus library, it 
-//   should be possible to use it to represent metadata for other 
+//   because this class does not depend on the Exodus library, it
+//   should be possible to use it to represent metadata for other
 //   dataset file formats.  Sandia Labs uses it in their Exodus II
 //   reader, their Exodus II writer and their EnSight writer.
 //   vtkDistributedDataFilter looks for metadata attached to
 //   it's input and redistributes the metadata with the grid.
-//  
+//
 //   The fields in this class are those described in the document
 //   "EXODUS II: A Finite Element Data Model", SAND92-2137, November 1995.
 //
 //   Element and node IDs stored in this object must be global IDs,
 //   in the event that the original dataset was partitioned across
-//   many files.  
+//   many files.
 //
 //   One way to initialize this object is by using vtkExodusModel
 //   (a Sandia class used by the Sandia Exodus reader).
@@ -45,19 +45,19 @@
 //   vtkUnstructuredGrid drawn from it and will set the required fields.
 //
 //   Alternatively, you can use all the Set*
-//   methods to set the individual fields. This class does not 
-//   copy the data, it simply uses your pointer. This 
-//   class will free the storage associated with your pointer 
+//   methods to set the individual fields. This class does not
+//   copy the data, it simply uses your pointer. This
+//   class will free the storage associated with your pointer
 //   when the class is deleted.  Most fields have sensible defaults.
 //   The only requirement is that if you are using this ModelMetadata
-//   to write out an Exodus or EnSight file in parallel, you must 
-//   SetBlockIds and SetBlockIdArrayName.  Your vtkUnstructuredGrid must 
+//   to write out an Exodus or EnSight file in parallel, you must
+//   SetBlockIds and SetBlockIdArrayName.  Your vtkUnstructuredGrid must
 //   have a cell array giving the block ID for each cell.
 //
 // .SECTION Caveats
-//   The Exodus II library supports an optimized element order map 
-//   (section 3.7 in the SAND document).  It contains all the element 
-//   IDs, listed in the order in which a solver should process them.  
+//   The Exodus II library supports an optimized element order map
+//   (section 3.7 in the SAND document).  It contains all the element
+//   IDs, listed in the order in which a solver should process them.
 //   We don't include this, and won't unless there is a request.
 //
 //   There is an assumption in some classes that the name of the cell
@@ -73,21 +73,18 @@
 
 #include "vtkObject.h"
 
-#define myVtkGetMacro(name, type) virtual type Get##name() const { return this->name; }
-
-#define myVtkGetStringMacro(name) virtual char* Get##name () const { return this->name; }
-
 class vtkDataSet;
 class vtkCharArray;
+class vtkIdTypeArray;
 class vtkIntArray;
 class vtkFloatArray;
 class vtkIntArray;
 class vtkModelMetadataSTLCloak;
 
 class VTK_GRAPHICS_EXPORT vtkModelMetadata : public vtkObject
-{ 
+{
 public:
-  vtkTypeRevisionMacro(vtkModelMetadata, vtkObject);
+  vtkTypeMacro(vtkModelMetadata, vtkObject);
   virtual void PrintSelf(ostream &os, vtkIndent indent);
   static vtkModelMetadata *New();
 
@@ -108,7 +105,7 @@ public:
   //    VERBOSE_TESTING is defined in your execution environment,
   //    this method will print more than mere counts, and actually
   //    print a few of the IDs, distribution factors and so on.  If
-  //    VERY_VERBOSE_TESTING is defined, it will print out 
+  //    VERY_VERBOSE_TESTING is defined, it will print out
   //    all ID lists, distribution factor lists, and so on.
 
   virtual void PrintLocalInformation();
@@ -116,14 +113,14 @@ public:
   // Description:
   //   The title of the dataset.
   vtkSetStringMacro(Title);
-  myVtkGetStringMacro(Title);
+  const char *GetTitle() const {return this->Title;}
 
   // Description:
-  //   Set the information lines. 
+  //   Set the information lines.
   void SetInformationLines(int numLines, char **lines);
-  
+
   // Description:
-  //   Add an information line. 
+  //   Add an information line.
   void AddInformationLine(char *info);
 
   // Description:
@@ -133,14 +130,15 @@ public:
 
   // Description:
   //   Get the number of information lines.
-  myVtkGetMacro(NumberOfInformationLines, int);
+  int GetNumberOfInformationLines() const {
+    return this->NumberOfInformationLines;}
 
   // Description:
   //   Set the list of QA records.  If there was already a
   //   a list, it will be replaced with this one.  We use your
   //   pointer and delete the records when done.
-  void SetQARecords(int numberOfRecords, char *QARecords[][4]); 
-  
+  void SetQARecords(int numberOfRecords, char *QARecords[][4]);
+
   // Description:
   //   Add a QA record.  They fields are:
   //    The code name
@@ -151,12 +149,12 @@ public:
 
   // Description:
   //   Get a pointer to the 4 fields of a QA record
-  void GetQARecord(int which, 
-          char **name, char **version, char **date, char **time) const;
+  void GetQARecord(int which, char **name, char **version,
+                   char **date, char **time) const;
 
   // Description:
   //   Get the number of QA records
-  myVtkGetMacro(NumberOfQARecords, int);
+  int GetNumberOfQARecords() const {return this->NumberOfQARecords;}
 
   // Description:
   //    Set the index of the time step represented by the results
@@ -164,14 +162,14 @@ public:
   //    step indices start at 0 in this file, they start at 1 in
   //    an Exodus file.
   vtkSetMacro(TimeStepIndex, int);
-  myVtkGetMacro(TimeStepIndex, int);
+  int GetTimeStepIndex() const {return this->TimeStepIndex;}
 
   // Description:
   //    Set the total number of time steps in the file,
   //    and the value at each time step.  We use your time
   //    step value array and delete it when we're done.
   void SetTimeSteps(int numberOfTimeSteps, float *timeStepValues);
-  myVtkGetMacro(NumberOfTimeSteps, int);
+  int GetNumberOfTimeSteps() const {return this->NumberOfTimeSteps;}
 
   // Description:
   //    Get the time step values
@@ -185,13 +183,13 @@ public:
   // Description:
   //   Get the dimension of the model.  This is also the number
   //   of coordinate names.
-  myVtkGetMacro(Dimension, int);
+  int GetDimension() const {return this->Dimension;}
 
   // Description:
   //   The number of blocks in the file.  Set this before setting
   //   any of the block arrays.
   vtkSetMacro(NumberOfBlocks, int);
-  myVtkGetMacro(NumberOfBlocks, int);
+  int GetNumberOfBlocks() const {return this->NumberOfBlocks;}
 
   // Description:
   //   An arbitrary integer ID for each block.
@@ -200,7 +198,7 @@ public:
   int *GetBlockIds() const {return this->BlockIds;}
 
   // Description:
-  //   Element type for each block - a name that means 
+  //   Element type for each block - a name that means
   //   something to person who created the file.
   //   We use your pointers, and free the memory when the object is freed.
   void SetBlockElementType(char **);
@@ -222,19 +220,19 @@ public:
 
   // Description:
   //   Set or get a pointer to a list global element IDs for the
-  //   elements in each block. 
+  //   elements in each block.
   //   We use your pointers, and free the memory when the object is freed.
   void SetBlockElementIdList(int *);
   int *GetBlockElementIdList() const {return this->BlockElementIdList;}
 
   // Description:
-  //    Get the length of the list of elements in every block. 
-  myVtkGetMacro(SumElementsPerBlock, int);                                         
+  //    Get the length of the list of elements in every block.
+  int GetSumElementsPerBlock() const {return this->SumElementsPerBlock;}
 
   // Description:
   //   Get a list of the index into the BlockElementIdList of the
   //   start of each block's elements.
-  int *GetBlockElementIdListIndex()const {return this->BlockElementIdListIndex;} 
+  int *GetBlockElementIdListIndex()const {return this->BlockElementIdListIndex;}
 
   // Description:
   //   Set or get a pointer to a list of the number of attributes
@@ -253,31 +251,32 @@ public:
 
   // Description:
   //    Get the length of the list of floating point block attributes.
-  myVtkGetMacro(SizeBlockAttributeArray, int);
+  int GetSizeBlockAttributeArray() const {
+    return this->SizeBlockAttributeArray;}
 
   // Description:
   //   Get a list of the index into the BlockAttributes of the
   //   start of each block's element attribute list.
-  int *GetBlockAttributesIndex()const {return this->BlockAttributesIndex;};
+  int *GetBlockAttributesIndex() const {return this->BlockAttributesIndex;}
 
   // Description:
   //   The number of node sets in the file.  Set this value before
   //   setting the various node set arrays.
   vtkSetMacro(NumberOfNodeSets, int);
-  myVtkGetMacro(NumberOfNodeSets, int);
+  int GetNumberOfNodeSets() const {return this->NumberOfNodeSets;}
 
   // Description:
   //   Set or get the list the IDs for each node set.
   //   Length of list is the number of node sets.
   //   We use your pointer, and free the memory when the object is freed.
   void SetNodeSetIds(int *);
-  int *GetNodeSetIds()const {return this->NodeSetIds;}
+  int *GetNodeSetIds() const {return this->NodeSetIds;}
 
   // Description:
   //   Set or get a pointer to a list of the number of nodes in each node set.
   //   We use your pointer, and free the memory when the object is freed.
   int SetNodeSetSize(int *);
-  int *GetNodeSetSize()const {return this->NodeSetSize;}
+  int *GetNodeSetSize() const {return this->NodeSetSize;}
 
   // Description:
   //   Set or get a pointer to a concatenated list of the
@@ -285,59 +284,63 @@ public:
   //   node set 0, then all IDs in node set 1, and so on.
   //   We use your pointer, and free the memory when the object is freed.
   void SetNodeSetNodeIdList(int *);
-  int *GetNodeSetNodeIdList()const {return this->NodeSetNodeIdList;}
+  int *GetNodeSetNodeIdList() const {return this->NodeSetNodeIdList;}
 
   // Description:
   //   Set or get a list of the number of distribution factors stored
   //   by each node set.  This is either 0 or equal to the number of
-  //   nodes in the node set. 
+  //   nodes in the node set.
   //   Length of list is number of node sets.
   //   We use your pointer, and free the memory when the object is freed.
   int SetNodeSetNumberOfDistributionFactors(int *);
-  int *GetNodeSetNumberOfDistributionFactors()const {return this->NodeSetNumberOfDistributionFactors;}
+  int *GetNodeSetNumberOfDistributionFactors() const
+    {return this->NodeSetNumberOfDistributionFactors;}
 
   // Description:
   //   Set or get a list of the distribution factors for the node sets.
   //   The list is organized by node set, and within node set by node.
   //   We use your pointer, and free the memory when the object is freed.
   void SetNodeSetDistributionFactors(float *);
-  float *GetNodeSetDistributionFactors()const {return this->NodeSetDistributionFactors;}
+  float *GetNodeSetDistributionFactors() const {
+    return this->NodeSetDistributionFactors;}
 
   // Description:
   //   Get the total number of nodes in all node sets
-  myVtkGetMacro(SumNodesPerNodeSet, int);     
+  int GetSumNodesPerNodeSet() const {return this->SumNodesPerNodeSet;}
 
   // Description:
   //   Get the total number of distribution factors stored for all node sets
-  myVtkGetMacro(SumDistFactPerNodeSet, int);
+  int GetSumDistFactPerNodeSet() const {return this->SumDistFactPerNodeSet;}
 
   // Description:
   //   Get a list of the index of the starting entry for each node set
   //   in the list of node set node IDs.
-  int *GetNodeSetNodeIdListIndex() const {return this->NodeSetNodeIdListIndex;}
+  int *GetNodeSetNodeIdListIndex() const {
+    return this->NodeSetNodeIdListIndex;}
 
   // Description:
   //   Get a list of the index of the starting entry for each node set
   //   in the list of node set distribution factors.
-  int *GetNodeSetDistributionFactorIndex() const {return this->NodeSetDistributionFactorIndex;}
+  int *GetNodeSetDistributionFactorIndex() const {
+    return this->NodeSetDistributionFactorIndex;}
 
   // Description:
   //   Set or get the number of side sets.  Set this value before
   //   setting any of the other side set arrays.
   vtkSetMacro(NumberOfSideSets, int);
-  myVtkGetMacro(NumberOfSideSets, int);
+  int GetNumberOfSideSets() const {return this->NumberOfSideSets;}
 
   // Description:
-  //   Set or get a pointer to a list giving the ID of each side set. 
+  //   Set or get a pointer to a list giving the ID of each side set.
   //   We use your pointer, and free the memory when the object is freed.
   void SetSideSetIds(int *);
-  int *GetSideSetIds()const {return this->SideSetIds;}
+  int *GetSideSetIds() const {return this->SideSetIds;}
 
   // Description:
   //   Set or get a pointer to a list of the number of sides  in each side set.
   //   We use your pointer, and free the memory when the object is freed.
   int SetSideSetSize(int *sizes);
-  int *GetSideSetSize()const {return this->SideSetSize;}
+  int *GetSideSetSize() const {return this->SideSetSize;}
 
   // Description:
   //   Set or get a pointer to a list of the number of distribution
@@ -345,7 +348,8 @@ public:
   //   no distribution factors, or 1 per node in the side set.
   //   We use your pointer, and free the memory when the object is freed.
   int SetSideSetNumberOfDistributionFactors(int *df);
-  int *GetSideSetNumberOfDistributionFactors()const {return this->SideSetNumberOfDistributionFactors;}
+  int *GetSideSetNumberOfDistributionFactors() const {
+    return this->SideSetNumberOfDistributionFactors;}
 
   // Description:
   //   Set or get a pointer to a list of the elements containing each
@@ -353,7 +357,7 @@ public:
   //   within side set by element.
   //   We use your pointer, and free the memory when the object is freed.
   void SetSideSetElementList(int *);
-  int *GetSideSetElementList()const {return this->SideSetElementList;}
+  int *GetSideSetElementList() const {return this->SideSetElementList;}
 
   // Description:
   //   Set or get a pointer to the element side for each side in the side set.
@@ -361,8 +365,8 @@ public:
   //   types of cells.)  Side Ids are arranged by side set and within
   //   side set by side, and correspond to the SideSetElementList.
   //   We use your pointer, and free the memory when the object is freed.
-  void SetSideSetSideList( int *);
-  int *GetSideSetSideList()const {return this->SideSetSideList;}
+  void SetSideSetSideList(int *);
+  int *GetSideSetSideList() const {return this->SideSetSideList;}
 
   // Description:
   //   Set or get a pointer to a list of the number of nodes in each
@@ -370,7 +374,7 @@ public:
   //   within side set by side.
   //   We use your pointer, and free the memory when the object is freed.
   void SetSideSetNumDFPerSide(int *numNodes);
-  int *GetSideSetNumDFPerSide()const {return this->SideSetNumDFPerSide;}
+  int *GetSideSetNumDFPerSide() const {return this->SideSetNumDFPerSide;}
 
   // Description:
   //   Set or get a pointer to a list of all the distribution factors.
@@ -383,88 +387,94 @@ public:
   //   by side set, by node.
   //   We use your pointer, and free the memory when the object is freed.
   void SetSideSetDistributionFactors(float *);
-  float *GetSideSetDistributionFactors()const {return this->SideSetDistributionFactors;}
+  float *GetSideSetDistributionFactors() const {
+    return this->SideSetDistributionFactors;}
 
   // Description:
   //   Get the total number of sides in all side sets
-  myVtkGetMacro(SumSidesPerSideSet, int);
+  int GetSumSidesPerSideSet() const {return this->SumSidesPerSideSet;}
 
   // Description:
   //   Get the total number of distribution factors stored for all side sets
-  myVtkGetMacro(SumDistFactPerSideSet, int);
+  int GetSumDistFactPerSideSet() const {return this->SumDistFactPerSideSet;}
 
   // Description:
   //   Get a list of the index of the starting entry for each side set
   //   in the list of side set side IDs.
-  int *GetSideSetListIndex()const {return this->SideSetListIndex;}
+  int *GetSideSetListIndex() const {return this->SideSetListIndex;}
 
   // Description:
   //   Get a list of the index of the starting entry for each side set
   //   in the list of side set distribution factors.
-  int *GetSideSetDistributionFactorIndex()const {return this->SideSetDistributionFactorIndex;}
+  int *GetSideSetDistributionFactorIndex() const {
+    return this->SideSetDistributionFactorIndex;}
 
   // Description:
   //   The number of block properties (global variables)
-  myVtkGetMacro(NumberOfBlockProperties, int);
+  int GetNumberOfBlockProperties() const {
+    return this->NumberOfBlockProperties;}
 
   // Description:
-  //   Set or get the names of the block properties.  
+  //   Set or get the names of the block properties.
   void SetBlockPropertyNames(int numProp, char **names);
-  char **GetBlockPropertyNames()const {return this->BlockPropertyNames;}
+  char **GetBlockPropertyNames() const {return this->BlockPropertyNames;}
 
   // Description:
   //   Set or get value for each variable for each block.  List
   //   the integer values in order by variable and within variable
   //   by block.
   void SetBlockPropertyValue(int *);
-  int *GetBlockPropertyValue()const {return this->BlockPropertyValue;}
+  int *GetBlockPropertyValue() const {return this->BlockPropertyValue;}
 
   // Description:
   //   The number of node set properties (global variables)
-  myVtkGetMacro(NumberOfNodeSetProperties, int);
+  int GetNumberOfNodeSetProperties() const {
+    return this->NumberOfNodeSetProperties;}
 
   // Description:
-  //   Set or get the names of the node setproperties.  
+  //   Set or get the names of the node setproperties.
   void SetNodeSetPropertyNames(int numProp, char **names);
-  char **GetNodeSetPropertyNames()const {return this->NodeSetPropertyNames;}
+  char **GetNodeSetPropertyNames() const {return this->NodeSetPropertyNames;}
 
   // Description:
   //   Set or get value for each variable for each node set.  List
   //   the integer values in order by variable and within variable
   //   by node set.
   void SetNodeSetPropertyValue(int *);
-  int *GetNodeSetPropertyValue()const {return this->NodeSetPropertyValue;}
+  int *GetNodeSetPropertyValue() const {return this->NodeSetPropertyValue;}
 
   // Description:
   //   The number of side set properties (global variables)
-  myVtkGetMacro(NumberOfSideSetProperties, int);
+  int GetNumberOfSideSetProperties() const {
+    return this->NumberOfSideSetProperties;}
 
   // Description:
-  //   Set or get the names of the side set properties.  
+  //   Set or get the names of the side set properties.
   void SetSideSetPropertyNames(int numProp, char **names);
-  char **GetSideSetPropertyNames()const {return this->SideSetPropertyNames;}
+  char **GetSideSetPropertyNames() const {return this->SideSetPropertyNames;}
 
   // Description:
   //   Set or get value for each variable for each side set.  List
   //   the integer values in order by variable and within variable
   //   by side set.
   void SetSideSetPropertyValue(int *);
-  int *GetSideSetPropertyValue()const {return this->SideSetPropertyValue;}
+  int *GetSideSetPropertyValue() const {return this->SideSetPropertyValue;}
 
   // Description:
   //   Get the number of global variables per time step
-  myVtkGetMacro(NumberOfGlobalVariables, int);
+  int GetNumberOfGlobalVariables() const {
+    return this->NumberOfGlobalVariables;}
 
   // Description:
   //  Set or get the names of the global variables
   void SetGlobalVariableNames(int numVarNames, char **n);
-  char **GetGlobalVariableNames()const {return this->GlobalVariableNames;}
+  char **GetGlobalVariableNames() const {return this->GlobalVariableNames;}
 
   // Description:
   //   Set or get the values of the global variables at the current
   //   time step.
   void SetGlobalVariableValue(float *f);
-  float *GetGlobalVariableValue()const {return this->GlobalVariableValue;}
+  float *GetGlobalVariableValue() const {return this->GlobalVariableValue;}
 
   // Description:
   //   The ModelMetadata maintains a list of the element variables that
@@ -478,7 +488,8 @@ public:
   //   the variable in the list of original names that represents it's
   //   first component.
   void SetElementVariableInfo(int numOrigNames, char **origNames,
-            int numNames, char **names,  int *numComp, int *map);
+                              int numNames, char **names, int *numComp,
+                              int *map);
 
   // Description:
   //   The ModelMetadata maintains a list of the node variables that
@@ -492,7 +503,8 @@ public:
   //   the variable in the list of original names that represents it's
   //   first component.
   void SetNodeVariableInfo(int numOrigNames, char **origNames,
-            int numNames, char **names,  int *numComp, int *map);
+                           int numNames, char **names,  int *numComp,
+                           int *map);
 
   // Description:
   //   A truth table indicating which element variables are
@@ -500,15 +512,17 @@ public:
   //   element variables that were in the file.
   //   The table is by block ID and within block ID by variable.
   void SetElementVariableTruthTable(int *);
-  int *GetElementVariableTruthTable()const {return this->ElementVariableTruthTable;}
+  int *GetElementVariableTruthTable() const {
+    return this->ElementVariableTruthTable;}
 
   // Description:
   //   Instead of a truth table of all "1"s, you can set this
   //   instance variable to indicate that all variables are
   //   defined in all blocks.
   vtkSetMacro(AllVariablesDefinedInAllBlocks, int);
-  myVtkGetMacro(AllVariablesDefinedInAllBlocks, int);
   vtkBooleanMacro(AllVariablesDefinedInAllBlocks, int);
+  int GetAllVariablesDefinedInAllBlocks() const {
+    return this->AllVariablesDefinedInAllBlocks;}
 
   // Description:
   //   If the element variable named is defined for the block Id
@@ -533,27 +547,39 @@ public:
   //   These methods return names of the original variables, the names
   //   of the grid variables, a list of the number of components in
   //   each grid variable, and a list of the index into the list of
-  //   original variable names where the original name of the first 
+  //   original variable names where the original name of the first
   //   component of a grid variable may be found.  The names of subsequent
   //   components would immediately follow the name of the the first
   //   component.
-  myVtkGetMacro(OriginalNumberOfElementVariables, int);
-  char **GetOriginalElementVariableNames()const {return this->OriginalElementVariableNames;}
-  myVtkGetMacro(NumberOfElementVariables, int);
-  char **GetElementVariableNames()const {return this->ElementVariableNames;}
-  int *GetElementVariableNumberOfComponents()const {return this->ElementVariableNumberOfComponents;}
-  int *GetMapToOriginalElementVariableNames()const {return this->MapToOriginalElementVariableNames;}
+  int GetOriginalNumberOfElementVariables() const {
+    return this->OriginalNumberOfElementVariables;}
+  char **GetOriginalElementVariableNames() const {
+    return this->OriginalElementVariableNames;}
+  int GetNumberOfElementVariables() const {
+    return this->NumberOfElementVariables;}
+  char **GetElementVariableNames() const {
+    return this->ElementVariableNames;}
+  int *GetElementVariableNumberOfComponents() const {
+    return this->ElementVariableNumberOfComponents;}
+  int *GetMapToOriginalElementVariableNames() const {
+    return this->MapToOriginalElementVariableNames;}
 
-  myVtkGetMacro(OriginalNumberOfNodeVariables, int);
-  char **GetOriginalNodeVariableNames()const {return this->OriginalNodeVariableNames;}
-  myVtkGetMacro(NumberOfNodeVariables, int);
-  char **GetNodeVariableNames()const {return this->NodeVariableNames;}
-  int *GetNodeVariableNumberOfComponents()const {return this->NodeVariableNumberOfComponents;}
-  int *GetMapToOriginalNodeVariableNames()const {return this->MapToOriginalNodeVariableNames;}
+  int GetOriginalNumberOfNodeVariables() const {
+    return this->OriginalNumberOfNodeVariables;}
+  char **GetOriginalNodeVariableNames() const {
+    return this->OriginalNodeVariableNames;}
+  int GetNumberOfNodeVariables() const {
+    return this->NumberOfNodeVariables;}
+  char **GetNodeVariableNames() const {
+    return this->NodeVariableNames;}
+  int *GetNodeVariableNumberOfComponents() const {
+    return this->NodeVariableNumberOfComponents;}
+  int *GetMapToOriginalNodeVariableNames() const {
+    return this->MapToOriginalNodeVariableNames;}
 
   // Description:
   //   Given the name of an element variable the vtkUnstructuredGrid
-  //   described by this ModelMetadata, and a component number, give 
+  //   described by this ModelMetadata, and a component number, give
   //   the name of the scalar array in the original
   //   file that turned into that component when the file was
   //   read into VTK.
@@ -561,7 +587,7 @@ public:
 
   // Description:
   //   Given the name of an node variable the vtkUnstructuredGrid
-  //   described by this ModelMetadata, and a component number, give 
+  //   described by this ModelMetadata, and a component number, give
   //   the name of the scalar array in the original
   //   file that turned into that component when the file was
   //   read into VTK.
@@ -612,14 +638,14 @@ public:
   // Description:
   //   In VTK we take vtkUnstructuredGrids and perform
   //   operations on them, including subsetting and merging
-  //   grids.  We need to modify the metadata object 
+  //   grids.  We need to modify the metadata object
   //   when this happens.  MergeModelMetadata merges the supplied
-  //   model (both global and local metadata) into this model.  
+  //   model (both global and local metadata) into this model.
   //   The models must be from the same file set.
   //
   //   MergeModelMetadata assumes that no element in one metadata
   //   object appears in the other.  (It doesn't test for duplicate
-  //   elements when merging the two metadata objects.) 
+  //   elements when merging the two metadata objects.)
   int MergeModelMetadata(const vtkModelMetadata *em);
 
   // Description:
@@ -635,14 +661,12 @@ public:
   //   We need the grid containing the cells so we can find point
   //   Ids as well, and also the name of the global cell ID array
   //   and the name of the global point ID array.
-  vtkModelMetadata *ExtractModelMetadata(vtkIntArray *globalCellIdList,
-                                     vtkDataSet *grid,
-                                     const char *globalCellIdArrayName,
-                                     const char *globalNodeIdArrayName);
+  vtkModelMetadata *ExtractModelMetadata(vtkIdTypeArray *globalCellIdList,
+                                         vtkDataSet *grid);
 
   // Description:
   //   Create and return a new metadata object containing only the
-  //   global metadata of this metadata object.  
+  //   global metadata of this metadata object.
   vtkModelMetadata *ExtractGlobalMetadata();
 
   // Description:
@@ -701,7 +725,7 @@ private:
   vtkIntArray *PackSizeArray(int maxStr, int maxLine);
   int InitializeFromIntArray(vtkModelMetadata *sizes, vtkIntArray *ia);
   vtkIntArray *PackIntArray();
-  int InitializeFromCharArray(vtkModelMetadata *sizes, 
+  int InitializeFromCharArray(vtkModelMetadata *sizes,
                    vtkCharArray *uca, int maxStr, int maxLine);
   vtkCharArray *PackCharArray(int maxStr, int maxLine);
   int InitializeFromFloatArray(vtkFloatArray *fa);
@@ -710,7 +734,7 @@ private:
   static char *StrDupWithNew(const char *s);
 
   static char *WriteLines(char *p, int maxLines, int maxLen, char **lines);
-  static char *ReadLines(char ***to, int maxLines, 
+  static char *ReadLines(char ***to, int maxLines,
                             int maxLen, char *from);
   static char **CopyLines(char **lines, int num);
   static int *CopyInts(int *vals, int num);
@@ -735,11 +759,11 @@ private:
     int *id2, int *id2Idx, int id2Len,
     int **idNew, int **idNewIdx, int *idNewLen);
 
-  void ExtractCellsFromBlockData(vtkModelMetadataSTLCloak *idset, 
+  void ExtractCellsFromBlockData(vtkModelMetadataSTLCloak *idset,
                                  vtkModelMetadata *mmd);
-  void ExtractNodesFromNodeSetData(vtkModelMetadataSTLCloak *idset, 
+  void ExtractNodesFromNodeSetData(vtkModelMetadataSTLCloak *idset,
                                    vtkModelMetadata *mmd);
-  void ExtractSidesFromSideSetData(vtkModelMetadataSTLCloak *idset, 
+  void ExtractSidesFromSideSetData(vtkModelMetadataSTLCloak *idset,
                                    vtkModelMetadata *mmd);
 
   void ShowFloats(const char *what, int num, float *f);
@@ -783,7 +807,7 @@ private:
 
   // Time steps
 
-  int TimeStepIndex;     // starting at 0 (Exodus file starts at 1) 
+  int TimeStepIndex;     // starting at 0 (Exodus file starts at 1)
   int NumberOfTimeSteps; // (G)
   float *TimeStepValues; // (G)
 
@@ -801,10 +825,10 @@ private:
 
   // Block information - values that we calculate
 
-  int SumElementsPerBlock;                                         
+  int SumElementsPerBlock;
   int SizeBlockAttributeArray;
 
-  int *BlockElementIdListIndex;          // NumberOfBlocks         
+  int *BlockElementIdListIndex;          // NumberOfBlocks
   int *BlockAttributesIndex;             // NumberOfBlocks
 
   vtkModelMetadataSTLCloak *BlockIdIndex;    // computed map
@@ -830,7 +854,7 @@ private:
   // Side Sets - input to class with Set*
 
   int NumberOfSideSets; // (G)
-  
+
   int *SideSetIds;                          // NumberOfSideSets (G)
   int *SideSetSize;                         // NumberOfSideSets (L)
   int *SideSetNumberOfDistributionFactors;  // NSS (L) (SSNDF[i] = 0 or NumNodesInSide)
