@@ -81,6 +81,15 @@ public:
   void SetSource(vtkPolyData *source);
   vtkPolyData *GetSource();
 
+  // Description:
+  // Signature definition for programmable method callbacks. Methods passed to
+  // SetGlyphMethod or SetGlyphMethodArgDelete must conform to this signature.
+  // The presence of this typedef is useful for reference and for external
+  // analysis tools, but it cannot be used in the method signatures in these
+  // header files themselves because it prevents the internal VTK wrapper
+  // generators from wrapping these methods.
+  typedef void (*ProgrammableMethodCallbackType)(void *arg);
+
   // Description:
   // Specify function to be called for each input point.
   void SetGlyphMethod(void (*f)(void *), void *arg);
@@ -128,8 +137,8 @@ protected:
   vtkPointData *PointData;
   int ColorMode;
   
-  void (*GlyphMethod)(void *); // Support GlyphMethod
-  void (*GlyphMethodArgDelete)(void *);
+  ProgrammableMethodCallbackType GlyphMethod; // Support GlyphMethod
+  ProgrammableMethodCallbackType GlyphMethodArgDelete;
   void *GlyphMethodArg;
   
 private:
