@@ -2,7 +2,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTemporalStatistics.cxx,v $
+  Module:    vtkTemporalStatistics.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -44,7 +44,6 @@
 #include <vtkstd/algorithm>
 
 //=============================================================================
-vtkCxxRevisionMacro(vtkTemporalStatistics, "$Revision: 1.6 $");
 vtkStandardNewMacro(vtkTemporalStatistics);
 
 //=============================================================================
@@ -459,7 +458,10 @@ void vtkTemporalStatistics::InitializeArray(vtkDataArray *array,
                           vtkAbstractArray::CreateArray(array->GetDataType())));
     newArray->SetName(vtkTemporalStatisticsMangleName(array->GetName(),
                                                     STANDARD_DEVIATION_SUFFIX));
-    newArray->SetNumberOfComponents(array->GetNumberOfComponents());
+        
+    newArray->SetNumberOfComponents(array->GetNumberOfComponents());   
+    newArray->CopyComponentNames( array );    
+    
     newArray->SetNumberOfTuples(array->GetNumberOfTuples());
     switch (array->GetDataType())
       {
