@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTessellatedBoxSource.cxx,v $
+  Module:    vtkTessellatedBoxSource.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -21,7 +21,6 @@
 
 #include <assert.h>
 
-vtkCxxRevisionMacro(vtkTessellatedBoxSource, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkTessellatedBoxSource);
 
 // ----------------------------------------------------------------------------
