@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkWarpScalar.cxx,v $
+  Module:    vtkWarpScalar.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,9 +24,9 @@
 #include "vtkPointSet.h"
 #include "vtkPoints.h"
 
-vtkCxxRevisionMacro(vtkWarpScalar, "$Revision: 1.51 $");
 vtkStandardNewMacro(vtkWarpScalar);
 
+//----------------------------------------------------------------------------
 vtkWarpScalar::vtkWarpScalar()
 {
   this->ScaleFactor = 1.0;
@@ -41,21 +41,25 @@ vtkWarpScalar::vtkWarpScalar()
                                vtkDataSetAttributes::SCALARS);
 }
 
+//----------------------------------------------------------------------------
 vtkWarpScalar::~vtkWarpScalar()
 {
 }
 
+//----------------------------------------------------------------------------
 double *vtkWarpScalar::DataNormal(vtkIdType id, vtkDataArray *normals)
 {
   return normals->GetTuple(id);
 }
 
+//----------------------------------------------------------------------------
 double *vtkWarpScalar::InstanceNormal(vtkIdType vtkNotUsed(id), 
                                      vtkDataArray *vtkNotUsed(normals))
 {
   return this->Normal;
 }
 
+//----------------------------------------------------------------------------
 double *vtkWarpScalar::ZNormal(vtkIdType vtkNotUsed(id), 
                               vtkDataArray *vtkNotUsed(normals))
 {
@@ -63,6 +67,7 @@ double *vtkWarpScalar::ZNormal(vtkIdType vtkNotUsed(id),
   return zNormal;
 }
 
+//----------------------------------------------------------------------------
 int vtkWarpScalar::RequestData(
   vtkInformation *vtkNotUsed(request),
   vtkInformationVector **inputVector,
@@ -167,6 +172,7 @@ int vtkWarpScalar::RequestData(
   return 1;
 }
 
+//----------------------------------------------------------------------------
 void vtkWarpScalar::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
