@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkDSPFilterGroup.h,v $
+  Module:    vtkDSPFilterGroup.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -41,7 +41,7 @@ class VTK_HYBRID_EXPORT vtkDSPFilterGroup : public vtkObject
 {
 public:
   static vtkDSPFilterGroup *New();
-  vtkTypeRevisionMacro(vtkDSPFilterGroup,vtkObject);
+  vtkTypeMacro(vtkDSPFilterGroup,vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 
