@@ -17,7 +17,7 @@ class vtkMultiProcessController;
 #include <vtkstd/map>
 #include <vtkstd/vector>
 
-#include "exodusII.h"
+#include "vtk_exodusII.h"
 
 class vtkExodusIIReaderParser;
 class vtkMutableDirectedGraph;
@@ -30,7 +30,7 @@ class vtkExodusIIReaderPrivate : public vtkObject
 public:
   static vtkExodusIIReaderPrivate* New();
   void PrintData( ostream& os, vtkIndent indent );
-  vtkTypeRevisionMacro(vtkExodusIIReaderPrivate,vtkObject);
+  vtkTypeMacro(vtkExodusIIReaderPrivate,vtkObject);
   //virtual void Modified();
 
   /// Open an ExodusII file for reading. Returns 0 on success.
@@ -230,6 +230,14 @@ public:
   vtkGetMacro(GenerateGlobalNodeIdArray,int);
   static const char* GetGlobalNodeIdArrayName() { return "GlobalNodeId"; }  
 
+  vtkSetMacro(GenerateImplicitElementIdArray,int);
+  vtkGetMacro(GenerateImplicitElementIdArray,int);
+  static const char* GetImplicitElementIdArrayName() { return "ImplicitElementId"; }  
+
+  vtkSetMacro(GenerateImplicitNodeIdArray,int);
+  vtkGetMacro(GenerateImplicitNodeIdArray,int);
+  static const char* GetImplicitNodeIdArrayName() { return "ImplicitNodeId"; }  
+
   /** Should we generate an array defined over all cells
     * (whether they are members of blocks or sets) indicating the source file?
     */
@@ -258,6 +266,9 @@ public:
   vtkSetMacro(ModeShapeTime,double);
   vtkGetMacro(ModeShapeTime,double);
 
+  vtkSetMacro(AnimateModeShapes, int);
+  vtkGetMacro(AnimateModeShapes, int);
+
   vtkDataArray* FindDisplacementVectors( int timeStep );
 
   vtkSetMacro(EdgeFieldDecorations,int);
@@ -346,7 +357,9 @@ public:
     /// Cached cell connectivity arrays for mesh
     vtkUnstructuredGrid* CachedConnectivity;
 
-    BlockSetInfoType() { this->CachedConnectivity = 0; }
+    BlockSetInfoType(){this->CachedConnectivity=0;}
+    BlockSetInfoType(const BlockSetInfoType& block);
+    ~BlockSetInfoType();
   };
 
   /// A struct to hold information about Exodus blocks
@@ -363,7 +376,7 @@ public:
     int CellType; 
     // Number of points per cell as used by VTK 
     // -- not what's in the file (i.e., BdsPerEntry[0] >= PointsPerCell)
-    int PointsPerCell; 
+    int PointsPerCell;
   };
 
   /// A struct to hold information about Exodus blocks
@@ -408,6 +421,7 @@ public:
   vtkTimeStamp InformationTimeStamp;
  
   friend class vtkExodusIIReader;
+  friend class vtkPExodusIIReader;
 
   virtual void SetParser( vtkExodusIIReaderParser* );
   vtkGetObjectMacro(Parser,vtkExodusIIReaderParser);
@@ -480,6 +494,8 @@ public:
 
   int UpdateTimeInformation();
 
+  bool ProducedFastPathOutput;
+
 protected:
   vtkExodusIIReaderPrivate();
   ~vtkExodusIIReaderPrivate();
@@ -775,6 +791,8 @@ protected:
   int GenerateFileIdArray;
   int GenerateGlobalElementIdArray;
   int GenerateGlobalNodeIdArray;
+  int GenerateImplicitElementIdArray;
+  int GenerateImplicitNodeIdArray;
 
   /** Defaults to 0. Set by vtkPExodusIIReader on each entry of ReaderList.
     * Used to generate the file ID array over all output cells.
@@ -787,6 +805,7 @@ protected:
   int ApplyDisplacements;
   float DisplacementMagnitude;
   int HasModeShapes;
+  int AnimateModeShapes;
 
   // Specify how to decorate edge and face variables.
   int EdgeFieldDecorations;
