@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExodusReader.h,v $
+  Module:    vtkExodusReader.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -56,7 +56,7 @@ class VTK_HYBRID_EXPORT vtkExodusReader : public vtkUnstructuredGridAlgorithm
 {
 public:
   static vtkExodusReader *New();
-  vtkTypeRevisionMacro(vtkExodusReader,vtkUnstructuredGridAlgorithm);
+  vtkTypeMacro(vtkExodusReader,vtkUnstructuredGridAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
   
   // Description:
