@@ -17,11 +17,15 @@
 #include "vtkActor.h"
 #include "vtkCellArray.h"
 #include "vtkDoubleArray.h"
+#include "vtkImageData.h"
 #include "vtkObjectFactory.h"
+#include "vtkPlaneSource.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
 #include "vtkPolyDataMapper2D.h"
 #include "vtkProperty2D.h"
+#include "vtkProperty.h"
+#include "vtkTexturedActor2D.h"
 #include "vtkTextMapper.h"
 #include "vtkTextProperty.h"
 #include "vtkTransform.h"
@@ -38,12 +42,12 @@ vtkLegendBoxActor::vtkLegendBoxActor()
   // Positioning information
   this->PositionCoordinate->SetCoordinateSystemToNormalizedViewport();
   this->PositionCoordinate->SetValue(0.75, 0.75);
-  
+
   this->Position2Coordinate->SetValue(0.2, 0.2);
 
   this->LockBorder = 0;
   this->ScalarVisibility = 1;
-  
+
   // Control font properties
   this->EntryTextProperty = vtkTextProperty::New();
   this->EntryTextProperty->SetBold(0);
@@ -56,7 +60,7 @@ vtkLegendBoxActor::vtkLegendBoxActor()
   this->Border = 1;
   this->Box = 0;
   this->Padding = 3;
-  
+
   // Symbols and text strings
   this->NumberOfEntries = 0;
   this->Size = 0;
@@ -69,6 +73,13 @@ vtkLegendBoxActor::vtkLegendBoxActor()
   this->TextMapper = NULL;
   this->TextActor = NULL;
 
+  this->Icon = NULL;
+  this->IconActor = NULL;
+  this->IconMapper = NULL;
+  this->IconTransformFilter = NULL;
+  this->IconTransform = NULL;
+  this->IconImage = NULL;
+
   // Construct the border
   this->BorderPolyData = vtkPolyData::New();
   vtkPoints *points = vtkPoints::New();
@@ -85,7 +96,7 @@ vtkLegendBoxActor::vtkLegendBoxActor()
 
   this->BorderMapper = vtkPolyDataMapper2D::New();
   this->BorderMapper->SetInput(this->BorderPolyData);
-  
+
   this->BorderActor = vtkActor2D::New();
   this->BorderActor->SetMapper(this->BorderMapper);
 
@@ -102,9 +113,18 @@ vtkLegendBoxActor::vtkLegendBoxActor()
 
   this->BoxMapper = vtkPolyDataMapper2D::New();
   this->BoxMapper->SetInput(this->BoxPolyData);
-  
+
   this->BoxActor = vtkActor2D::New();
   this->BoxActor->SetMapper(this->BoxMapper);
+
+  // Background.
+  this->UseBackground = 0;
+  this->BackgroundOpacity = 1.0;
+  this->BackgroundColor[0] =  this->BackgroundColor[1] = this->BackgroundColor[2] = 0.3;
+  this->Background = vtkPlaneSource::New();
+  this->BackgroundActor = vtkTexturedActor2D::New();
+  this->BackgroundMapper = vtkPolyDataMapper2D::New();
+  this->BackgroundActor->SetMapper(this->BackgroundMapper);
 }
 
 //----------------------------------------------------------------------------
@@ -126,6 +146,13 @@ vtkLegendBoxActor::~vtkLegendBoxActor()
     this->BoxPolyData->Delete();
     }
 
+  if ( this->BackgroundActor )
+    {
+    this->BackgroundActor->Delete();
+    this->BackgroundMapper->Delete();
+    this->Background->Delete();
+    }
+
   this->SetEntryTextProperty(NULL);
 }
 
@@ -152,6 +179,17 @@ void vtkLegendBoxActor::InitializeEntries()
         this->TextMapper[i]->Delete();
         this->TextActor[i]->Delete();
         }
+
+      if( this->IconImage[i] )
+        {
+        this->IconImage[i]->Delete();
+        }
+
+      this->Icon[i]->Delete();
+      this->IconTransform[i]->Delete();
+      this->IconTransformFilter[i]->Delete();
+      this->IconMapper[i]->Delete();
+      this->IconActor[i]->Delete();
       }//for all entries
     delete [] this->Symbol; this->Symbol = NULL;
     delete [] this->Transform; this->Transform = NULL;
@@ -160,9 +198,16 @@ void vtkLegendBoxActor::InitializeEntries()
     delete [] this->SymbolActor; this->SymbolActor = NULL;
     delete [] this->TextMapper; this->TextMapper = NULL;
     delete [] this->TextActor; this->TextActor = NULL;
+
+    delete [] this->IconImage; this->IconImage = NULL;
+    delete [] this->Icon; this->Icon = NULL;
+    delete [] this->IconActor; this->IconActor = NULL;
+    delete [] this->IconMapper; this->IconMapper = NULL;
+    delete [] this->IconTransform; this->IconTransform = NULL;
+    delete [] this->IconTransformFilter; this->IconTransformFilter = NULL;
     }//if entries have been defined
 }
-  
+
 //----------------------------------------------------------------------------
 void vtkLegendBoxActor::SetNumberOfEntries(int num)
 {
@@ -175,7 +220,7 @@ void vtkLegendBoxActor::SetNumberOfEntries(int num)
     {
     this->NumberOfEntries = num;
     }
-  
+
   else //allocate space
     {
     int i;
@@ -186,12 +231,24 @@ void vtkLegendBoxActor::SetNumberOfEntries(int num)
     colors->SetNumberOfTuples(num);
     vtkTextMapper **textMapper= new vtkTextMapper* [num];
     vtkActor2D **textActor = new vtkActor2D* [num];
+
+    // Symbol
     vtkPolyData **symbol = new vtkPolyData* [num];
     vtkTransform **transform= new vtkTransform* [num];
-    vtkTransformPolyDataFilter **symbolTransform = 
+    vtkTransformPolyDataFilter **symbolTransform =
                                  new vtkTransformPolyDataFilter* [num];
     vtkPolyDataMapper2D **symbolMapper = new vtkPolyDataMapper2D* [num];
     vtkActor2D **symbolActor = new vtkActor2D* [num];
+
+    // Icon.
+    vtkPlaneSource **icon = new vtkPlaneSource* [num];
+    vtkTransform **iconTransform= new vtkTransform* [num];
+    vtkTransformPolyDataFilter **iconTransformFilter =
+                                 new vtkTransformPolyDataFilter* [num];
+    vtkPolyDataMapper2D **iconMapper = new vtkPolyDataMapper2D* [num];
+    vtkTexturedActor2D **iconActor = new vtkTexturedActor2D* [num];
+    vtkImageData **iconImage = new vtkImageData* [num];
+
     //copy old values
     for (i=0; i<this->NumberOfEntries; i++)
       {
@@ -200,20 +257,49 @@ void vtkLegendBoxActor::SetNumberOfEntries(int num)
       textMapper[i]->Register(this);
       textActor[i] = this->TextActor[i];
       textActor[i]->Register(this);
+
+      // Symbol.
       symbol[i] = this->Symbol[i];
       if ( symbol[i] )
         {
         symbol[i]->Register(this);
         }
+
       transform[i] = this->Transform[i];
       transform[i]->Register(this);
+
       symbolTransform[i] = this->SymbolTransform[i];
       symbolTransform[i]->Register(this);
+
       symbolMapper[i] = this->SymbolMapper[i];
       symbolMapper[i]->Register(this);
+
       symbolActor[i] = this->SymbolActor[i];
       symbolActor[i]->Register(this);
+
+      // Icon.
+      icon[i] = this->Icon[i];
+      icon[i]->Register(this);
+
+      iconTransform[i] = this->IconTransform[i];
+      iconTransform[i]->Register(this);
+
+      iconTransformFilter[i] = this->IconTransformFilter[i];
+      iconTransformFilter[i]->Register(this);
+
+      iconMapper[i] = this->IconMapper[i];
+      iconMapper[i]->Register(this);
+
+      iconActor[i] = this->IconActor[i];
+      iconActor[i]->Register(this);
+
+      iconImage[i] = this->IconImage[i];
+      if( iconImage[i] )
+        {
+        iconImage[i]->Register(this);
+        }
       }
+
     //initialize data values
     static double color[3]={-1.0,-1.0,-1.0};
     for (i=this->NumberOfEntries; i<num; i++) //initialize
@@ -222,6 +308,8 @@ void vtkLegendBoxActor::SetNumberOfEntries(int num)
       textMapper[i] = vtkTextMapper::New();
       textActor[i] = vtkActor2D::New();
       textActor[i]->SetMapper(textMapper[i]);
+
+      // Symbol.
       symbol[i] = NULL;
       transform[i] = vtkTransform::New();
       symbolTransform[i] = vtkTransformPolyDataFilter::New();
@@ -230,23 +318,51 @@ void vtkLegendBoxActor::SetNumberOfEntries(int num)
       symbolMapper[i]->SetInput(symbolTransform[i]->GetOutput());
       symbolActor[i] = vtkActor2D::New();
       symbolActor[i]->SetMapper(symbolMapper[i]);
+
+      // Icon.
+      iconImage[i] = NULL;
+
+      icon[i] = vtkPlaneSource::New();
+      icon[i]->SetPoint1(1.0, 0.0, 0.0);
+      icon[i]->SetPoint2(0, 1.0, 0.0);
+      icon[i]->SetOrigin(0.0, 0.0, 0.0);
+      icon[i]->SetResolution(1, 1);
+
+      iconTransform[i] = vtkTransform::New();
+
+      iconTransformFilter[i] = vtkTransformPolyDataFilter::New();
+      iconTransformFilter[i]->SetTransform(iconTransform[i]);
+
+      iconMapper[i] = vtkPolyDataMapper2D::New();
+      iconMapper[i]->SetInput(iconTransformFilter[i]->GetOutput());
+
+      iconActor[i] = vtkTexturedActor2D::New();
+      iconActor[i]->SetMapper(iconMapper[i]);
       }
 
     //Clear out the old stuff
     this->InitializeEntries();
-    
+
     //Bring everything up to date
     this->NumberOfEntries = this->Size = num;
     this->Colors = colors;
     this->TextMapper = textMapper;
     this->TextActor = textActor;
+
     this->Symbol = symbol;
     this->Transform = transform;
     this->SymbolTransform = symbolTransform;
     this->SymbolMapper = symbolMapper;
     this->SymbolActor = symbolActor;
+
+    this->Icon = icon;
+    this->IconTransform = iconTransform;
+    this->IconTransformFilter = iconTransformFilter;
+    this->IconMapper = iconMapper;
+    this->IconActor = iconActor;
+    this->IconImage = iconImage;
     }
-  
+
   this->Modified();
   return;
 }
@@ -261,7 +377,34 @@ void vtkLegendBoxActor::SetEntry(int i, vtkPolyData *symbol, const char* string,
     this->SetEntryString(i,string);
     this->SetEntryColor(i,color);
     }
-  
+
+  return;
+}
+
+//----------------------------------------------------------------------------
+void vtkLegendBoxActor::SetEntry(int i, vtkImageData *icon, const char* string, double color[3])
+{
+  if ( i >= 0 && i < this->NumberOfEntries )
+    {
+    this->SetEntryIcon(i,icon);
+    this->SetEntryString(i,string);
+    this->SetEntryColor(i,color);
+    }
+
+  return;
+}
+
+
+//----------------------------------------------------------------------------
+void vtkLegendBoxActor::SetEntry(int i, vtkPolyData *symbol, vtkImageData *icon,
+                                 const char* string, double color[3])
+{
+  if ( i >= 0 && i < this->NumberOfEntries )
+    {
+    this->SetEntry(i, symbol, string, color);
+    this->SetEntryIcon(i, icon);
+    }
+
   return;
 }
 
@@ -287,18 +430,40 @@ void vtkLegendBoxActor::SetEntrySymbol(int i, vtkPolyData *symbol)
     }
 }
 
+//----------------------------------------------------------------------------
+void vtkLegendBoxActor::SetEntryIcon(int i, vtkImageData *icon)
+{
+  if ( i >= 0 && i < this->NumberOfEntries )
+    {
+    if ( this->IconImage[i] == icon )
+      {
+      return;
+      }
+    if ( this->IconImage[i] )
+      {
+      this->IconImage[i]->Delete();
+      }
+    this->IconImage[i] = icon;
+    if ( this->IconImage[i] )
+      {
+      this->IconImage[i]->Register(this);
+      }
+    this->Modified();
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkLegendBoxActor::SetEntryString(int i, const char* string)
 {
   if ( i >= 0 && i < this->NumberOfEntries )
     {
-    if ( this->TextMapper[i]->GetInput() && string 
-         && (!strcmp(this->TextMapper[i]->GetInput(),string))) 
+    if ( this->TextMapper[i]->GetInput() && string
+         && (!strcmp(this->TextMapper[i]->GetInput(),string)))
       {
       return;
       }
     this->TextMapper[i]->SetInput(string);
-    this->Modified(); 
+    this->Modified();
     }
 }
 
@@ -309,12 +474,12 @@ void vtkLegendBoxActor::SetEntryColor(int i, double color[3])
     {
     double oldColor[3];
     this->Colors->GetTuple(i, oldColor);
-    
-    if ( oldColor[0] != color[0] || oldColor[1] != color[1] || 
+
+    if ( oldColor[0] != color[0] || oldColor[1] != color[1] ||
          oldColor[2] != color[2] )
       {
       this->Colors->SetTuple3(i,color[0],color[1],color[2]);
-      this->Modified(); 
+      this->Modified();
       }
     }
 }
@@ -340,6 +505,19 @@ vtkPolyData *vtkLegendBoxActor::GetEntrySymbol(int i)
     }
 }
 
+//----------------------------------------------------------------------------
+vtkImageData* vtkLegendBoxActor::GetEntryIcon(int i)
+{
+  if ( i < 0 || i >= this->NumberOfEntries )
+    {
+    return NULL;
+    }
+  else
+    {
+    return this->IconImage[i];
+    }
+}
+
 //----------------------------------------------------------------------------
 const char* vtkLegendBoxActor::GetEntryString(int i)
 {
@@ -372,21 +550,22 @@ double* vtkLegendBoxActor::GetEntryColor(int i)
 // resources to release.
 void vtkLegendBoxActor::ReleaseGraphicsResources(vtkWindow *win)
 {
-  if ( this->BorderActor ) 
-     { 
-     this->BorderActor->ReleaseGraphicsResources(win); 
-     } 
+  if ( this->BorderActor )
+     {
+     this->BorderActor->ReleaseGraphicsResources(win);
+     }
 
-  if ( this->BoxActor ) 
-     { 
-     this->BoxActor->ReleaseGraphicsResources(win); 
-     } 
+  if ( this->BoxActor )
+     {
+     this->BoxActor->ReleaseGraphicsResources(win);
+     }
 
-  for (int i=0; i < this->Size; i++) 
-    { 
-    this->TextActor[i]->ReleaseGraphicsResources(win); 
-    this->SymbolActor[i]->ReleaseGraphicsResources(win); 
-    } 
+  for (int i=0; i < this->Size; i++)
+    {
+    this->TextActor[i]->ReleaseGraphicsResources(win);
+    this->SymbolActor[i]->ReleaseGraphicsResources(win);
+    this->IconActor[i]->ReleaseGraphicsResources(win);
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -398,6 +577,11 @@ int vtkLegendBoxActor::RenderOverlay(vtkViewport *viewport)
     }
 
   int renderedSomething = 0;
+  if ( this->BackgroundActor && this->UseBackground )
+    {
+    this->BackgroundActor->RenderOverlay(viewport);
+    }
+
   if ( this->Border )
     {
     renderedSomething += this->BorderActor->RenderOverlay(viewport);
@@ -416,10 +600,15 @@ int vtkLegendBoxActor::RenderOverlay(vtkViewport *viewport)
         {
         renderedSomething += this->SymbolActor[i]->RenderOverlay(viewport);
         }
+      if ( this->IconImage[i] )
+        {
+        renderedSomething += this->IconActor[i]->RenderOverlay(viewport);
+        }
+
       renderedSomething += this->TextActor[i]->RenderOverlay(viewport);
       }
     }
-  
+
   return renderedSomething;
 }
 
@@ -480,6 +669,9 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
     int tempi[2], fontSize;
     double sf, twr, swr;
     double *bounds;
+    bool iconExists   (false);
+    bool symbolExists (false);
+
     for (swr=0.0, maxLength=i=0; i<this->NumberOfEntries; i++)
       {
       str = this->TextMapper[i]->GetInput();
@@ -495,6 +687,7 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
 
       if ( this->Symbol[i] ) //if there is a symbol
         {
+        symbolExists = true;
         this->Symbol[i]->Update();
         bounds = this->Symbol[i]->GetBounds();
         if ( (bounds[3]-bounds[2]) == 0.0 )
@@ -510,13 +703,34 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
           swr = sf;
           }
         }//if symbol defined
+
+        // We pick the one with highest ratio if both symbol and icon
+        // exists.
+        if(this->IconImage[i])
+          {
+          iconExists = true;
+
+          bounds = this->IconImage[i]->GetBounds();
+          if ( (bounds[3]-bounds[2]) == 0.0 )
+            {
+            sf = 1.0;
+            }
+          else
+            {
+            sf = (bounds[1]-bounds[0]) / (bounds[3]-bounds[2]);
+            }
+          if ( sf > swr )
+            {
+            swr = sf;
+            }
+          } // if icon defined.
       }
 
     //Compute the final proportion (symbol width to text width)
     fontSize = 12;
     this->TextMapper[maxTextMapper]->GetTextProperty()->SetFontSize(fontSize);
     this->TextMapper[maxTextMapper]->GetSize(viewport,tempi);
-    
+
     if(maxLength>0) // make sure that tempi is not 0, to avoid a
       // divide-by-zero floating-point exception.
       {
@@ -528,6 +742,11 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
       symbolSize=0;
       }
 
+    if(iconExists && symbolExists)
+      {
+      symbolSize *= 2;
+      }
+
     //Okay, now that the proportions are okay, let's size everything
     //First the text
     int size[2];
@@ -547,7 +766,7 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
       {
       this->LegendEntriesVisible = 0;
       }
-    
+
     //Border and box - may adjust spacing based on font size relationship
     //to the proportions relative to the border
     //
@@ -556,7 +775,7 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
       //adjust the border/box placement if too much whitespace
       if ( !this->LockBorder && tempi[0] < size[0] )
         {
-        p2[0] = p1[0] + 2.0*this->Padding + 
+        p2[0] = p1[0] + 2.0*this->Padding +
                 symbolSize*(p2[0] - p1[0] - 2.0*this->Padding) + tempi[0];
         }
       vtkPoints *pts = this->BorderPolyData->GetPoints();
@@ -566,6 +785,17 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
       pts->SetPoint(3, p1[0],p2[1],0.0);
       }
 
+    if (this->UseBackground)
+      {
+      this->Background->SetOrigin(p1[0], p1[1], 0.0);
+      this->Background->SetPoint1(p2[0], p1[1], 0.0);
+      this->Background->SetPoint2(p1[0], p2[1], 0.0);
+
+      this->BackgroundMapper->SetInput(this->Background->GetOutput());
+      this->BackgroundActor->GetProperty()->SetOpacity(this->BackgroundOpacity);
+      this->BackgroundActor->GetProperty()->SetColor(this->BackgroundColor);
+      }
+
     if (this->Border)
       {
       this->BorderActor->SetProperty(this->GetProperty());
@@ -574,7 +804,7 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
     //Place text strings
     double color[3];
     double posY;
-    double posX = p1[0] + this->Padding + 
+    double posX = p1[0] + this->Padding +
                  symbolSize*(p2[0] - p1[0] - 2.0*this->Padding);
     for (i=0; i<this->NumberOfEntries; i++)
       {
@@ -590,13 +820,34 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
                                                          color[2]);
         }
       }
-    
+
+    double sizeFraction = 1.0;
+
+    double symbolsPositionFraction = 0.5;
+    double iconsPositionFraction   = 0.0;
+
+    if(symbolExists && iconExists)
+      {
+      symbolsPositionFraction = 0.25;
+      iconsPositionFraction   = 0.625;
+
+      sizeFraction = 0.5;
+      }
+    else if(iconExists)
+      {
+      iconsPositionFraction = 0.5;
+      }
+    else
+      {
+      // Do nothing.
+      }
+
     //Place symbols
     //
     //Find the x-y bounds of the symbols...we'll be scaling these as well
-    size[0] = (int)(symbolSize*(p2[0] - p1[0] - 2.0*this->Padding));
-    posX = p1[0] + this->Padding + 
-                 0.5*symbolSize*(p2[0] - p1[0] - 2.0*this->Padding);
+    size[0] = (int)(sizeFraction * symbolSize*(p2[0] - p1[0] - 2.0*this->Padding));
+    posX = p1[0] + this->Padding +
+                 symbolsPositionFraction * symbolSize*(p2[0] - p1[0] - 2.0*this->Padding);
     for (i=0; i<this->NumberOfEntries; i++)
       {
       if ( this->Symbol[i] )
@@ -604,18 +855,18 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
         this->SymbolTransform[i]->SetInput(this->Symbol[i]);
         bounds = this->Symbol[i]->GetBounds();
 
-        if ( (bounds[1]-bounds[0]) == 0.0 ) 
-          { 
-          sf = VTK_DOUBLE_MAX; 
+        if ( (bounds[1]-bounds[0]) == 0.0 )
+          {
+          sf = VTK_DOUBLE_MAX;
           }
-        else 
-          { 
-          sf = size[0]/(bounds[1]-bounds[0]); 
+        else
+          {
+          sf = size[0]/(bounds[1]-bounds[0]);
           }
-        
+
         if ( (bounds[3]-bounds[2]) == 0.0 )
           {
-          if ( sf >= VTK_DOUBLE_MAX )          
+          if ( sf >= VTK_DOUBLE_MAX )
             {
             sf = 1.0;
             }
@@ -640,14 +891,69 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
                                                         color[2]);
           }
         }//if symbol defined
-      }//for all entries
+      else
+        {
+        std::cout << "Symbol is not defined: " << std::endl;
+        }
+      }
 
+      // Place icons.
+      size[0] = (int)(sizeFraction * symbolSize*(p2[0] - p1[0] - 2.0*this->Padding));
+      posX = p1[0] + this->Padding +
+                   iconsPositionFraction * symbolSize*(p2[0] - p1[0] - 2.0*this->Padding);
+      for (i=0; i<this->NumberOfEntries; i++)
+        {
+        if ( this->IconImage[i] )
+          {
+          vtkTexture *texture (vtkTexture::New());
+          texture->SetInput(this->IconImage[i]);
+          this->IconActor[i]->SetTexture(texture);
+          texture->Delete();
+          this->Icon[i]->Update();
+          this->IconTransformFilter[i]->SetInput(this->Icon[i]->GetOutput());
+          this->IconTransformFilter[i]->Update();
+          bounds = this->Icon[i]->GetOutput(0)->GetBounds();
+
+          if ( (bounds[1]-bounds[0]) == 0.0 )
+            {
+            sf = VTK_DOUBLE_MAX;
+            }
+          else
+            {
+            sf = size[0]/(bounds[1]-bounds[0]);
+            }
+
+          if ( (bounds[3]-bounds[2]) == 0.0 )
+            {
+            if ( sf >= VTK_DOUBLE_MAX )
+              {
+              sf = 1.0;
+              }
+            }
+          else if ( (size[1]/(bounds[3]-bounds[2])) < sf )
+            {
+            sf = size[1]/(bounds[3]-bounds[2]);
+            }
+
+          posY = p2[1] - this->Padding - (double)i*size[1] - 0.5*size[1] -
+                         0.25*tempi[1];
+          this->IconTransform[i]->Identity();
+          this->IconTransform[i]->Translate(posX, posY, 0.0);
+          this->IconTransform[i]->Scale(0.5 * sf, 0.5 * sf, 1);
+          this->IconMapper[i]->SetScalarVisibility(this->ScalarVisibility);
+          }// If icon is defined.
+        }
     this->BuildTime.Modified();
     }//rebuild legend box
 
   //Okay, now we're ready to render something
   //Border
   int renderedSomething = 0;
+  if ( this->BackgroundActor && this->UseBackground )
+    {
+    this->BackgroundActor->RenderOpaqueGeometry(viewport);
+    }
+
   if ( this->Border )
     {
     renderedSomething += this->BorderActor->RenderOpaqueGeometry(viewport);
@@ -666,6 +972,10 @@ int vtkLegendBoxActor::RenderOpaqueGeometry(vtkViewport *viewport)
         {
         renderedSomething += this->SymbolActor[i]->RenderOpaqueGeometry(viewport);
         }
+      if( this->IconImage[i])
+        {
+        renderedSomething += this->IconActor[i]->RenderOpaqueGeometry(viewport);
+        }
       renderedSomething += this->TextActor[i]->RenderOpaqueGeometry(viewport);
       }
     }
@@ -698,12 +1008,18 @@ void vtkLegendBoxActor::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Number Of Entries: " << this->NumberOfEntries << "\n";
 
-  os << indent << "Scalar Visibility: " 
+  os << indent << "Scalar Visibility: "
      << (this->ScalarVisibility ? "On\n" : "Off\n");
   os << indent << "Padding: " << this->Padding << "\n";
   os << indent << "Border: " << (this->Border ? "On\n" : "Off\n");
   os << indent << "Box: " << (this->Box ? "On\n" : "Off\n");
   os << indent << "LockBorder: " << (this->LockBorder ? "On\n" : "Off\n");
+
+  os << indent << "UseBackgroud: " << (this->UseBackground ? "On\n" : "Off\n");
+  os << indent << "BackgroundOpacity: " << this->BackgroundOpacity << "\n";
+
+  os << indent << "BackgroundColor: (" << this->BackgroundColor[0] << ", "
+    << this->BackgroundColor[1] << ", " << this->BackgroundColor[2] << ")\n";
 }
 
 //----------------------------------------------------------------------------
