@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPolyDataToImageStencil.cxx,v $
+  Module:    vtkPolyDataToImageStencil.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -49,10 +49,8 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkImageStencilData.h"
 #include "vtkObjectFactory.h"
 
-// don't need all of these
-#include "vtkLine.h"
+#include "vtkMath.h"
 #include "vtkCellArray.h"
-#include "vtkDataArray.h"
 #include "vtkDoubleArray.h"
 #include "vtkSignedCharArray.h"
 #include "vtkMergePoints.h"
@@ -60,7 +58,6 @@ POSSIBILITY OF SUCH DAMAGES.
 #include "vtkPointData.h"
 #include "vtkCellData.h"
 #include "vtkGenericCell.h"
-#include "vtkLine.h"
 #include "vtkImageData.h"
 #include "vtkPolyData.h"
 #include "vtkInformation.h"
@@ -69,52 +66,18 @@ POSSIBILITY OF SUCH DAMAGES.
 
 #include <math.h>
 
-#include <vtkstd/vector>
-#include <vtkstd/algorithm>
 
-
-vtkCxxRevisionMacro(vtkPolyDataToImageStencil, "$Revision: 1.32 $");
 vtkStandardNewMacro(vtkPolyDataToImageStencil);
-vtkCxxSetObjectMacro(vtkPolyDataToImageStencil, InformationInput,
-                     vtkImageData);
 
 //----------------------------------------------------------------------------
 vtkPolyDataToImageStencil::vtkPolyDataToImageStencil()
 {
-  // InformationInput is an input used only for its information.
-  // The vtkImageStencilSource produces a structured data
-  // set with a specific "Spacing" and "Origin", and the
-  // InformationInput is a source of this information.
-  this->InformationInput = NULL;
-
-  // If no InformationInput is set, then the Spacing and Origin
-  // for the output must be set directly.
-  this->OutputOrigin[0] = 0;
-  this->OutputOrigin[1] = 0;
-  this->OutputOrigin[2] = 0;
-  this->OutputSpacing[0] = 1;
-  this->OutputSpacing[1] = 1;
-  this->OutputSpacing[2] = 1;
-
-  // The default output extent is essentially infinite, which allows
-  // this filter to produce any requested size.  This would not be a
-  // great source to connect to some sort of writer or viewer, it
-  // should only be connected to multiple-input filters that take
-  // compute their output extent from one of the other inputs.
-  this->OutputWholeExtent[0] = 0;
-  this->OutputWholeExtent[1] = VTK_LARGE_INTEGER >> 2;
-  this->OutputWholeExtent[2] = 0;
-  this->OutputWholeExtent[3] = VTK_LARGE_INTEGER >> 2;
-  this->OutputWholeExtent[4] = 0;
-  this->OutputWholeExtent[5] = VTK_LARGE_INTEGER >> 2;
-
   this->Tolerance = 1e-3;
 }
 
 //----------------------------------------------------------------------------
 vtkPolyDataToImageStencil::~vtkPolyDataToImageStencil()
 {
-  this->SetInformationInput(NULL);
 }
 
 //----------------------------------------------------------------------------
@@ -148,227 +111,98 @@ void vtkPolyDataToImageStencil::PrintSelf(ostream& os,
 {
   this->Superclass::PrintSelf(os,indent);
 
-    os << indent << "InformationInput: " << this->InformationInput << "\n";
-  os << indent << "OutputSpacing: " << this->OutputSpacing[0] << " " <<
-    this->OutputSpacing[1] << " " << this->OutputSpacing[2] << "\n";
-  os << indent << "OutputOrigin: " << this->OutputOrigin[0] << " " <<
-    this->OutputOrigin[1] << " " << this->OutputOrigin[2] << "\n";
-  os << indent << "OutputWholeExtent: " << this->OutputWholeExtent[0] << " " <<
-    this->OutputWholeExtent[1] << " " << this->OutputWholeExtent[2] << " " <<
-    this->OutputWholeExtent[3] << " " << this->OutputWholeExtent[4] << " " <<
-    this->OutputWholeExtent[5] << "\n";
   os << indent << "Input: " << this->GetInput() << "\n";
   os << indent << "Tolerance: " << this->Tolerance << "\n";
 }
 
 //----------------------------------------------------------------------------
 // This method was taken from vtkCutter and slightly modified
-void vtkPolyDataToImageStencil::DataSetCutter(
-  vtkDataSet *input, vtkPolyData *output, double z, vtkMergePoints *locator)
+void vtkPolyDataToImageStencil::PolyDataCutter(
+  vtkPolyData *input, vtkPolyData *output, double z, double thickness,
+  vtkMergePoints *locator)
 {
-  vtkIdType cellId, i;
-  vtkPoints *cellPts;
-  vtkDoubleArray *cellScalars;
-  vtkGenericCell *cell;
-  vtkCellArray *newVerts, *newLines, *newPolys;
-  vtkPoints *newPoints;
-  double s;
-  vtkIdType estimatedSize, numCells=input->GetNumberOfCells();
-  int numCellPts;
-  vtkPointData *inPD, *outPD;
-  vtkCellData *inCD=input->GetCellData(), *outCD=output->GetCellData();
-  vtkIdList *cellIds;
-  
-  cellScalars=vtkDoubleArray::New();
+  vtkCellData *inCD = input->GetCellData();
+  vtkCellData *outCD = output->GetCellData();
+  vtkDoubleArray *cellScalars = vtkDoubleArray::New();
 
-  // Create objects to hold output of contour operation
-  estimatedSize = (vtkIdType) pow ((double) numCells, .75);
-  estimatedSize = estimatedSize / 1024 * 1024; //multiple of 1024
-  if (estimatedSize < 1024)
-    {
-    estimatedSize = 1024;
-    }
+  // For the new points and lines
+  vtkPoints *newPoints = vtkPoints::New();
+  newPoints->Allocate(333);
+  vtkCellArray *newLines = vtkCellArray::New();
+  newLines->Allocate(1000);
 
-  newPoints = vtkPoints::New();
-  newPoints->Allocate(estimatedSize,estimatedSize/2);
-  newVerts = vtkCellArray::New();
-  newVerts->Allocate(estimatedSize,estimatedSize/2);
-  newLines = vtkCellArray::New();
-  newLines->Allocate(estimatedSize,estimatedSize/2);
-  newPolys = vtkCellArray::New();
-  newPolys->Allocate(estimatedSize,estimatedSize/2);
+  // No verts or polys are expected
+  vtkCellArray *newVerts = vtkCellArray::New();
+  vtkCellArray *newPolys = vtkCellArray::New();
 
-  // Interpolate data along edge.
-  inPD = input->GetPointData();
-  outPD = output->GetPointData();
-  outPD->InterpolateAllocate(inPD,estimatedSize,estimatedSize/2);
-  outCD->CopyAllocate(inCD,estimatedSize,estimatedSize/2);
+  // Allocate space for the cell data
+  outCD->CopyAllocate(inCD, 1000);
     
   // locator used to merge potentially duplicate points
-  //
-  locator->InitPointInsertion (newPoints, input->GetBounds());
+  locator->InitPointInsertion(newPoints, input->GetBounds());
 
   // Compute some information for progress methods
-  //
-  cell = vtkGenericCell::New();
+  vtkGenericCell *cell = vtkGenericCell::New();
   
   // Loop over all cells; get scalar values for all cell points
   // and process each cell.
-  //
-  for (cellId=0; cellId < numCells; cellId++)
+  vtkIdType numCells = input->GetNumberOfCells();
+  for (vtkIdType cellId = 0; cellId < numCells; cellId++)
     {
-    input->GetCell(cellId,cell);
-    cellPts = cell->GetPoints();
-    cellIds = cell->GetPointIds();
+    input->GetCell(cellId, cell);
+    vtkPoints *cellPts = cell->GetPoints();
+    vtkIdList *cellIds = cell->GetPointIds();
 
-    numCellPts = cellPts->GetNumberOfPoints();
-    cellScalars->SetNumberOfTuples(numCellPts);
-    for (i=0; i < numCellPts; i++)
+    if (cell->GetCellDimension() == 1 && input->GetNumberOfPolys() == 0)
       {
-      // scalar value is distance from the specified z plane
-      s = input->GetPoint(cellIds->GetId(i))[2] - z;
-      cellScalars->SetTuple(i,&s);
+      double *bounds = cell->GetBounds();
+      if (bounds[4] >= z - 0.5*thickness && bounds[5] < z + 0.5*thickness)
+        {
+        vtkIdType numCellPts = cellPts->GetNumberOfPoints();
+        newLines->InsertNextCell(numCellPts);
+        for (vtkIdType i = 0; i < numCellPts; i++)
+          {
+          vtkIdType ptId;
+          locator->InsertUniquePoint(cellPts->GetPoint(i), ptId);
+          newLines->InsertCellPoint(ptId);
+          }
+        outCD->CopyData(inCD, cellId, newLines->GetNumberOfCells()-1);
+        }
       }
+    else if (cell->GetCellDimension() == 2)
+      {
+      vtkIdType numCellPts = cellPts->GetNumberOfPoints();
+      cellScalars->SetNumberOfTuples(numCellPts);
+      for (vtkIdType i = 0; i < numCellPts; i++)
+        {
+        // scalar value is distance from the specified z plane
+        cellScalars->SetValue(i, input->GetPoint(cellIds->GetId(i))[2]);
+        }
 
-    cell->Contour(0.0, cellScalars, locator, 
-                  newVerts, newLines, newPolys, inPD, outPD,
-                  inCD, cellId, outCD);
+      cell->Contour(z, cellScalars, locator,
+                    newVerts, newLines, newPolys, NULL, NULL,
+                    inCD, cellId, outCD);
+      }
     }
 
   // Update ourselves.  Because we don't know upfront how many verts, lines,
   // polys we've created, take care to reclaim memory. 
-  //
   cell->Delete();
   cellScalars->Delete();
 
   output->SetPoints(newPoints);
   newPoints->Delete();
 
-  if (newVerts->GetNumberOfCells())
-    {
-    output->SetVerts(newVerts);
-    }
-  newVerts->Delete();
-
   if (newLines->GetNumberOfCells())
     {
     output->SetLines(newLines);
     }
   newLines->Delete();
-
-  if (newPolys->GetNumberOfCells())
-    {
-    output->SetPolys(newPolys);
-    }
+  newVerts->Delete();
   newPolys->Delete();
 
-  locator->Initialize();//release any extra memory
-  output->Squeeze();
-}
-
-//----------------------------------------------------------------------------
-inline int vtkPolyDataToImageStencilFloor(double x)
-{
-#if defined i386 || defined _M_IX86 || defined _M_X64
-  // This code assumes IEEE 754 64-bit double.
-  // It uses a denormalizer to round the double at the
-  // 2^(-16) position, or around 1e-5, and then extracts
-  // the integer portion.  So, essentially, it is a floor()
-  // operation that is accurate to within 1e-5.
-  // We use it because it is many, many times
-  // faster than the floor() function.
-  union { vtkTypeFloat64 d; vtkTypeUInt32 i[2]; } dual;
-  dual.d = x + 103079215104.0;  // (2**(52-16))*1.5
-  return static_cast<int>((dual.i[1]<<16)|(dual.i[0]>>16));
-#else
-  // This doesn't assume IEEE 754 and is a good, fast
-  // floor() approximation on most architectures
-  x += 2147483648.0;
-  vtkTypeUInt32 i = static_cast<unsigned int>(x);
-  return static_cast<int>(i - 2147483648U);
-#endif
-}
-
-//----------------------------------------------------------------------------
-static void vtkFloatingEndPointScanConvertLine2D(
-  double pt1[2], double pt2[2], int inflection1, int inflection2,
-  double tolerance, int z, int extent[6],
-  vtkstd::vector< vtkstd::vector<double> >& zyBucket)
-{
-  double x1 = pt1[0];
-  double x2 = pt2[0];
-  double y1 = pt1[1];
-  double y2 = pt2[1];
-
-  // swap end points if necessary
-  if (y1 > y2)
-    {
-    x1 = pt2[0];
-    x2 = pt1[0];
-    y1 = pt2[1];
-    y2 = pt1[1];
-    }
-
-  // find min and max of x values
-  double xmin = x1;
-  double xmax = x2;
-  if (x1 > x2)
-    {
-    xmin = x2;
-    xmax = x1;
-    }
-
-  // check for parallel to the x-axis
-  if (y1 == y2)
-    {
-    return;
-    }
-  
-  // Integer y values for start and end of line
-  int Ay, By;
-
-  double ymin = y1;
-  double ymax = y2;
-  if (inflection1 < 0 || inflection2 < 0)
-    {
-    // if this is a lower inflection point, include a tolerance
-    ymin -= tolerance;
-    }
-  if (inflection1 > 0 || inflection2 > 0)
-    {
-    // likewise, if upper inflection, add tolerance at top
-    ymax += tolerance;
-    }
-
-  // The "+1" is important, it means that if we have two polygons
-  // that share a line, and make a stencil from each, the produced
-  // regions are guaranteed not to overlap if tolerance=0.
-  Ay = vtkPolyDataToImageStencilFloor(ymin) + 1;
-  By = vtkPolyDataToImageStencilFloor(ymax);
-
-  // Precompute values for a Bresenham-like line algorithm
-  double grad = (x2 - x1)/(y2 - y1);
-  double delta = (Ay - y1)*grad;
-
-  // Take z coordinate and extents into account for bucket index
-  int idx0 = (z - extent[4])*(extent[3] - extent[2] + 1) - extent[2];
-
-  // Go along y and place each x in the proper (y,z) bucket.
-  for( int y = Ay; y <= By; y++ )
-    {
-    delta += grad;
-    double x = x1 + delta;
-    // clamp x (because of tolerance, it might not be in range)
-    if (x < xmin)
-      {
-      x = xmin;
-      }
-    else if (x > xmax)
-      {
-      x = xmax;
-      }
-    zyBucket[idx0 + y].push_back( x );
-    }
+  //release any extra memory
+  locator->Initialize();
 }
 
 //----------------------------------------------------------------------------
@@ -383,8 +217,8 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
   //    (if the input polydata is closed, there will be no loose ends) 
   // 3) go through all line segments, and for each integer y value on
   //    a line segment, store the x value at that point in a bucket
-  // 4) for each (y,z) integer index, find all the stored x values
-  //    and use them to create the vtkStencilData
+  // 4) for each z integer index, find all the stored x values
+  //    and use them to create one z slice of the vtkStencilData
     
   // the spacing and origin of the generated stencil
   double *spacing = data->GetSpacing();
@@ -413,19 +247,19 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
   // the output produced by cutting the polydata with the Z plane
   vtkPolyData *slice = vtkPolyData::New();
 
-  // Determine data dimensions
-  int dims[3];
-  dims[0] = (extent[1] - extent[0]) + 1;
-  dims[1] = (extent[3] - extent[2]) + 1;
-  dims[2] = (extent[5] - extent[4]) + 1;
+  // This raster stores all line segments by recording all "x"
+  // positions on the surface for each y integer position.
+  vtkImageStencilRaster raster(&extent[2]);
+  raster.SetTolerance(tolerance);
 
-  // This vector stores all line segments by recording all "x"
-  // positions on the surface for each (y,z) integer position.
-  vtkstd::vector< vtkstd::vector<double> > zyBucket(dims[1]*dims[2]);
+  // The extent for one slice of the image
+  int sliceExtent[6];
+  sliceExtent[0] = extent[0]; sliceExtent[1] = extent[1];
+  sliceExtent[2] = extent[2]; sliceExtent[3] = extent[3];
+  sliceExtent[4] = extent[4]; sliceExtent[5] = extent[4];
 
   // Loop through the slices
-  int idxY, idxZ;
-  for (idxZ = extent[4]; idxZ <= extent[5]; idxZ++)
+  for (int idxZ = extent[4]; idxZ <= extent[5]; idxZ++)
     {
     if (threadId == 0)
       {
@@ -435,9 +269,10 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
     double z = idxZ*spacing[2] + origin[2];
 
     slice->PrepareForNewData();
+    raster.PrepareForNewData();
 
     // Step 1: Cut the data into slices
-    this->DataSetCutter(input, slice, z, locator);
+    this->PolyDataCutter(input, slice, z, spacing[2], locator);
     
     if (!slice->GetNumberOfLines())
       {
@@ -466,7 +301,7 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
     vtkSignedCharArray *inflectionPointList = vtkSignedCharArray::New();
     
     // find all points with just a single adjacent point,
-    // also look for lower inflection points
+    // also look for inflection points i.e. where the y direction changes
     for (vtkIdType i = 0; i < numberOfPoints; i++)
       {
       double yval = points->GetPoint(i)[1];
@@ -523,17 +358,8 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
         looseEndIdList->InsertNextId( i );
         looseEndNeighborList->InsertNextId( neighborId );
         }
-      // mark lower inflection points
-      int inflection = 0;
-      if (bottomPoint)
-        {
-        inflection = -1;
-        }
-      else if (topPoint)
-        {
-        inflection = 1;
-        }
-      inflectionPointList->InsertNextValue( inflection );
+      // mark inflection points
+      inflectionPointList->InsertNextValue( bottomPoint | topPoint );
       }
 
     while (looseEndIdList->GetNumberOfIds() >= 2)
@@ -591,11 +417,25 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
       lines->InsertNextCell( 2 );
       lines->InsertCellPoint( firstLooseEndId );
       lines->InsertCellPoint( secondLooseEndId );
+
+      // check if the new vertices are vertical inflection points
+      slice->GetPoint( secondLooseEndId, secondLooseEnd );
+      vtkIdType secondNeighborId = looseEndNeighborList->GetId(0);
+      double secondNeighbor[3];
+      slice->GetPoint( secondNeighborId, secondNeighbor);
+
+      inflectionPointList->SetValue(firstLooseEndId,
+        ((firstLooseEnd[1] - neighbor[1])*
+        (secondLooseEnd[1] - firstLooseEnd[1]) <= 0));
+
+      inflectionPointList->SetValue(secondLooseEndId,
+        ((secondLooseEnd[1] - firstLooseEnd[1])*
+         (secondNeighbor[1] - secondLooseEnd[1]) <= 0));
       }
 
     // Step 3: Go through all the line segments for this slice,
     // and for each integer y position on the line segment,
-    // drop the corresponding x position into the (y,z) bucket.
+    // drop the corresponding x position into the y raster line.
     lines->InitTraversal();
     vtkIdType *pts = 0;
     vtkIdType npts = 0;
@@ -608,71 +448,22 @@ void vtkPolyDataToImageStencil::ThreadedExecute(
         points->GetPoint(pts[j-1], point1);
         points->GetPoint(pts[j], point2);
         // check to see if line contains a lower inflection point
-        int inflection1 = inflectionPointList->GetValue(pts[j-1]);
-        int inflection2 = inflectionPointList->GetValue(pts[j]);
+        bool inflection1 = (inflectionPointList->GetValue(pts[j-1]) != 0);
+        bool inflection2 = (inflectionPointList->GetValue(pts[j]) != 0);
       
-        vtkFloatingEndPointScanConvertLine2D(point1, point2,
-                                             inflection1, inflection2,
-                                             tolerance, idxZ,
-                                             extent, zyBucket);
+        raster.InsertLine(point1, point2, inflection1, inflection2);
         }
       }
 
     looseEndIdList->Delete();
     looseEndNeighborList->Delete();
     inflectionPointList->Delete();
-    }
 
-  // Step 4: The final part of the algorithm is to fill in the
-  // stencil, i.e. rasterization of the polyhedron.
-  int r1, r2, lastr2;
-  for (idxZ = extent[4]; idxZ <= extent[5]; idxZ++)
-    {
-    for (idxY = extent[2]; idxY <= extent[3]; idxY++)
-      {
-      vtkstd::vector<double>& xList =
-        zyBucket[(idxZ - extent[4])*dims[1] + (idxY - extent[2])];
-
-      if (xList.empty())
-        {
-        continue;
-        }
-      
-      // handle pairs
-      lastr2 = extent[0] - 1;
-      if (xList.size() % 2 == 0)
-        {
-        vtkstd::sort(xList.begin(), xList.end());
-
-        vtkstd::vector<double>::iterator xIter = xList.begin();
-        while (xIter != xList.end())
-          {
-          double x1 = *xIter++;
-          double x2 = *xIter++;
-          // Use floor()+1 instead of ceil() to ensure that, if
-          // tolerance is zero and there are neighboring extents,
-          // there will be no overlap.
-          r1 = vtkPolyDataToImageStencilFloor(x1 - tolerance) + 1;
-          // Take floor() of second value in pair
-          r2 = vtkPolyDataToImageStencilFloor(x2 + tolerance);
-
-          // extents are not allowed to overlap
-          if (r1 <= lastr2)
-            {
-            r1 = lastr2 + 1;
-            // eliminate empty extents
-            if (r1 > r2)
-              {
-              continue;
-              }
-            }
-
-          data->InsertNextExtent(r1, r2, idxY, idxZ);
-
-          lastr2 = r2;
-          }
-        }
-      }
+    // Step 4: Use the x values stored in the xy raster to create
+    // one z slice of the vtkStencilData
+    sliceExtent[4] = idxZ;
+    sliceExtent[5] = idxZ;
+    raster.FillStencilData(data, sliceExtent);
     }
 
   slice->Delete();
@@ -701,44 +492,6 @@ int vtkPolyDataToImageStencil::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkPolyDataToImageStencil::RequestInformation(
-  vtkInformation *,
-  vtkInformationVector **,
-  vtkInformationVector *outputVector)
-{
-  vtkInformation *outInfo = outputVector->GetInformationObject(0);
-  
-  int wholeExtent[6];
-  double spacing[3];
-  double origin[3];
-
-  for (int i = 0; i < 3; i++)
-    {
-    wholeExtent[2*i] = this->OutputWholeExtent[2*i];
-    wholeExtent[2*i+1] = this->OutputWholeExtent[2*i+1];
-    spacing[i] = this->OutputSpacing[i];
-    origin[i] = this->OutputOrigin[i];
-    }
-
-  // If InformationInput is set, then get the spacing,
-  // origin, and whole extent from it.
-  if (this->InformationInput)
-    {
-    this->InformationInput->UpdateInformation();
-    this->InformationInput->GetWholeExtent(wholeExtent);
-    this->InformationInput->GetSpacing(spacing);
-    this->InformationInput->GetOrigin(origin);
-    }
-
-  outInfo->Set(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
-               wholeExtent, 6);
-  outInfo->Set(vtkDataObject::SPACING(), spacing, 3);
-  outInfo->Set(vtkDataObject::ORIGIN(), origin, 3);
-
-  return 1;
-}
-
 //----------------------------------------------------------------------------
 int vtkPolyDataToImageStencil::FillInputPortInformation(
   int,
