@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: TestPostgreSQLDatabase.cxx,v $
+  Module:    TestPostgreSQLDatabase.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -87,7 +87,7 @@ int TestPostgreSQLDatabase( int /*argc*/, char* /*argv*/[] )
   query->SetQuery( dropQuery.c_str() );
   if ( ! query->Execute() )
     {
-    cout << "Drop query did not succeed (this result was expected). The last message: " << endl;
+    cout << "Drop query did not succeed (this result *** was *** expected). The last message: " << endl;
     cout << "   " << query->GetLastErrorText() << endl;
     }
   else
