@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkDICOMImageReader.cxx,v $
+  Module:    vtkDICOMImageReader.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -19,6 +19,7 @@
 #include "vtkImageData.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
+#include "vtkErrorCode.h"
 
 #include <vtkstd/vector>
 #include <vtkstd/string>
@@ -28,7 +29,6 @@
 #include "DICOMAppHelper.h"
 #include "DICOMParser.h"
 
-vtkCxxRevisionMacro(vtkDICOMImageReader, "$Revision: 1.38 $");
 vtkStandardNewMacro(vtkDICOMImageReader);
 
 class vtkDICOMImageReaderVector : public vtkstd::vector<vtkstd::string>
@@ -104,7 +104,7 @@ void vtkDICOMImageReader::PrintSelf(ostream& os, vtkIndent indent)
 //----------------------------------------------------------------------------
 int vtkDICOMImageReader::CanReadFile(const char* fname)
 {
-  bool canOpen = this->Parser->OpenFile((char*) fname);
+  bool canOpen = this->Parser->OpenFile((const char*) fname);
   if (!canOpen)
     {
     vtkErrorMacro("DICOMParser couldn't open : " << fname);
@@ -197,7 +197,7 @@ void vtkDICOMImageReader::ExecuteInformation()
          iter != this->DICOMFileNames->end();
          iter++)
       {
-      char* fn = (char*) (*iter).c_str();
+      const char* fn = iter->c_str();
       vtkDebugMacro( << "Trying : " << fn);
 
       bool couldOpen = this->Parser->OpenFile(fn);
@@ -254,6 +254,7 @@ void vtkDICOMImageReader::ExecuteData(vtkDataObject *output)
   if (!this->FileName && this->DICOMFileNames->size() == 0)
     {
     vtkErrorMacro( << "Either a filename was not specified or the specified directory does not contain any DICOM images.");
+    this->SetErrorCode( vtkErrorCode::NoFileNameError );
     return;
     }
 
@@ -277,6 +278,12 @@ void vtkDICOMImageReader::ExecuteData(vtkDataObject *output)
     unsigned long imageDataLength;
 
     this->AppHelper->GetImageData(imgData, dataType, imageDataLength);
+    if( !imageDataLength )
+      {
+      vtkErrorMacro( << "There was a problem retrieving data from: " << this->FileName );
+      this->SetErrorCode( vtkErrorCode::FileFormatError );
+      return;
+      }
 
     void* buffer = data->GetScalarPointer();
     if (buffer == NULL)
@@ -324,8 +331,9 @@ void vtkDICOMImageReader::ExecuteData(vtkDataObject *output)
          fiter++)
       {
       count++;
-      vtkDebugMacro( << "File : " << (*fiter).c_str());
-      this->Parser->OpenFile((char*)(*fiter).c_str());
+      const char *file = fiter->c_str();
+      vtkDebugMacro( << "File : " << file );
+      this->Parser->OpenFile( file );
       this->Parser->ReadHeader();
 
       void* imgData = NULL;
@@ -333,6 +341,12 @@ void vtkDICOMImageReader::ExecuteData(vtkDataObject *output)
       unsigned long imageDataLengthInBytes;
 
       this->AppHelper->GetImageData(imgData, dataType, imageDataLengthInBytes);
+      if( !imageDataLengthInBytes )
+        {
+        vtkErrorMacro( << "There was a problem retrieving data from: " << file );
+        this->SetErrorCode( vtkErrorCode::FileFormatError );
+        return;
+        }
 
       // DICOM stores the upper left pixel as the first pixel in an
       // image. VTK stores the lower left pixel as the first pixel in
@@ -351,9 +365,9 @@ void vtkDICOMImageReader::ExecuteData(vtkDataObject *output)
       buffer = ((char*) buffer) + imageDataLengthInBytes;
 
       this->UpdateProgress(float(count)/float(numFiles));
-      int len = static_cast<int> (strlen((char*) (*fiter).c_str()));
+      int len = static_cast<int> (strlen((const char*) (*fiter).c_str()));
       char* filename = new char[len+1];
-      strcpy(filename, (char*) (*fiter).c_str());
+      strcpy(filename, (const char*) (*fiter).c_str());
       this->SetProgressText(filename);
       delete[] filename;
       }
