@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkEnSight6BinaryReader.cxx,v $
+  Module:    vtkEnSight6BinaryReader.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -33,7 +33,6 @@
 #include <ctype.h>
 #include <vtkstd/string>
 
-vtkCxxRevisionMacro(vtkEnSight6BinaryReader, "$Revision: 1.58 $");
 vtkStandardNewMacro(vtkEnSight6BinaryReader);
 
 //----------------------------------------------------------------------------
@@ -859,10 +858,12 @@ int vtkEnSight6BinaryReader::ReadMeasuredGeometryFile(
    }
   else
     {
+    vtkIdType id;
     for (i = 0; i < this->NumberOfMeasuredPoints; i++)
       {
+      id = pointIds[i];
       points->InsertNextPoint(coords[3*i], coords[3*i+1], coords[3*i+2]);
-      pd->InsertNextCell(VTK_VERTEX, 1, (vtkIdType*)&pointIds[i]);
+      pd->InsertNextCell(VTK_VERTEX, 1, &id);
       }
     }
 
