@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageWriter.cxx,v $
+  Module:    vtkImageWriter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,7 +25,6 @@
 
 #include <vtksys/SystemTools.hxx>
 
-vtkCxxRevisionMacro(vtkImageWriter, "$Revision: 1.61 $");
 vtkStandardNewMacro(vtkImageWriter);
 
 //----------------------------------------------------------------------------
