@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkOpenFOAMReader.h,v $
+  Module:    vtkOpenFOAMReader.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -53,7 +53,7 @@ class VTK_IO_EXPORT vtkOpenFOAMReader : public vtkMultiBlockDataSetAlgorithm
 {
 public:
   static vtkOpenFOAMReader *New();
-  vtkTypeRevisionMacro(vtkOpenFOAMReader, vtkMultiBlockDataSetAlgorithm);
+  vtkTypeMacro(vtkOpenFOAMReader, vtkMultiBlockDataSetAlgorithm);
   void PrintSelf(ostream &, vtkIndent);
 
   // Description:
@@ -221,9 +221,7 @@ public:
   void SetRefresh() { this->Refresh = true; this->Modified(); }
 
   void SetParent(vtkOpenFOAMReader *parent) { this->Parent = parent; }
-  //BTX
   int MakeInformationVector(vtkInformationVector *, const vtkStdString &);
-  //ETX
   bool SetTimeValue(const double);
   vtkDoubleArray *GetTimeValues();
   int MakeMetaDataAtTimeStep(const bool);
