@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPostgreSQLDatabase.cxx,v $
+  Module:    vtkPostgreSQLDatabase.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -37,14 +37,13 @@
 #include <assert.h>
 
 vtkStandardNewMacro(vtkPostgreSQLDatabase);
-vtkCxxRevisionMacro(vtkPostgreSQLDatabase, "$Revision: 1.34 $");
 
 // ----------------------------------------------------------------------
 vtkPostgreSQLDatabase::vtkPostgreSQLDatabase()
 {
   this->Connection = 0;
   this->ConnectionMTime = this->MTime;
-  
+
   this->DatabaseType = 0;
   this->SetDatabaseType("psql");
   this->HostName = 0;
@@ -54,6 +53,9 @@ vtkPostgreSQLDatabase::vtkPostgreSQLDatabase()
   this->ServerPort = -1;
   this->ConnectOptions = 0;
   this->LastErrorText = 0;
+  this->Tables = vtkStringArray::New();
+  this->Tables->Register(this);
+  this->Tables->Delete();
 }
 
 // ----------------------------------------------------------------------
@@ -70,6 +72,7 @@ vtkPostgreSQLDatabase::~vtkPostgreSQLDatabase()
   this->SetConnectOptions( 0 );
   this->SetDatabaseType( 0 );
   this->SetLastErrorText( 0 );
+  this->Tables->UnRegister(this);
 }
 
 // ----------------------------------------------------------------------
@@ -103,48 +106,48 @@ vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
   queryStr << schema->GetColumnNameFromHandle( tblHandle, colHandle );
 
   // Figure out column type
-  int colType = schema->GetColumnTypeFromHandle( tblHandle, colHandle ); 
+  int colType = schema->GetColumnTypeFromHandle( tblHandle, colHandle );
   vtkStdString colTypeStr;
   switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
     {
-    case vtkSQLDatabaseSchema::SERIAL:    
+    case vtkSQLDatabaseSchema::SERIAL:
       colTypeStr = "SERIAL";
       break;
-    case vtkSQLDatabaseSchema::SMALLINT:  
+    case vtkSQLDatabaseSchema::SMALLINT:
       colTypeStr = "SMALLINT";
       break;
-    case vtkSQLDatabaseSchema::INTEGER:   
+    case vtkSQLDatabaseSchema::INTEGER:
       colTypeStr = "INTEGER";
       break;
-    case vtkSQLDatabaseSchema::BIGINT:    
+    case vtkSQLDatabaseSchema::BIGINT:
       colTypeStr = "BIGINT";
       break;
-    case vtkSQLDatabaseSchema::VARCHAR:   
+    case vtkSQLDatabaseSchema::VARCHAR:
       colTypeStr = "VARCHAR";
       break;
-    case vtkSQLDatabaseSchema::TEXT:      
+    case vtkSQLDatabaseSchema::TEXT:
       colTypeStr = "TEXT";
       break;
-    case vtkSQLDatabaseSchema::REAL:      
+    case vtkSQLDatabaseSchema::REAL:
       colTypeStr = "REAL";
       break;
-    case vtkSQLDatabaseSchema::DOUBLE:    
+    case vtkSQLDatabaseSchema::DOUBLE:
       colTypeStr = "DOUBLE PRECISION";
       break;
-    case vtkSQLDatabaseSchema::BLOB:      
+    case vtkSQLDatabaseSchema::BLOB:
       colTypeStr = "BYTEA";
       break;
-    case vtkSQLDatabaseSchema::TIME:      
+    case vtkSQLDatabaseSchema::TIME:
       colTypeStr = "TIME";
       break;
-    case vtkSQLDatabaseSchema::DATE:      
+    case vtkSQLDatabaseSchema::DATE:
       colTypeStr = "DATE";
       break;
-    case vtkSQLDatabaseSchema::TIMESTAMP: 
+    case vtkSQLDatabaseSchema::TIMESTAMP:
       colTypeStr = "TIMESTAMP WITH TIME ZONE";
       break;
     }
-  
+
   if ( colTypeStr.size() )
     {
     queryStr << " " << colTypeStr;
@@ -154,45 +157,45 @@ vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
     vtkGenericWarningMacro( "Unable to get column specification: unsupported data type " << colType );
     return vtkStdString();
     }
-  
+
   // Decide whether size is allowed, required, or unused
   int colSizeType = 0;
   switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
     {
-    case vtkSQLDatabaseSchema::SERIAL:    
+    case vtkSQLDatabaseSchema::SERIAL:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::SMALLINT:  
+    case vtkSQLDatabaseSchema::SMALLINT:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::INTEGER:   
+    case vtkSQLDatabaseSchema::INTEGER:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::BIGINT:    
+    case vtkSQLDatabaseSchema::BIGINT:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::VARCHAR:   
+    case vtkSQLDatabaseSchema::VARCHAR:
       colSizeType = -1;
       break;
-    case vtkSQLDatabaseSchema::TEXT:      
+    case vtkSQLDatabaseSchema::TEXT:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::REAL:      
+    case vtkSQLDatabaseSchema::REAL:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::DOUBLE:    
+    case vtkSQLDatabaseSchema::DOUBLE:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::BLOB:      
+    case vtkSQLDatabaseSchema::BLOB:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::TIME:      
+    case vtkSQLDatabaseSchema::TIME:
       colSizeType =  1;
       break;
-    case vtkSQLDatabaseSchema::DATE:      
+    case vtkSQLDatabaseSchema::DATE:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::TIMESTAMP: 
+    case vtkSQLDatabaseSchema::TIMESTAMP:
       colSizeType =  0;
       break;
     }
@@ -201,14 +204,14 @@ vtkStdString vtkPostgreSQLDatabase::GetColumnSpecification(
   if ( colSizeType )
     {
     int colSize = schema->GetColumnSizeFromHandle( tblHandle, colHandle );
-    // IF size is provided but absurd, 
+    // IF size is provided but absurd,
     // OR, if size is required but not provided OR absurd,
     // THEN assign the default size.
     if ( ( colSize < 0 ) || ( colSizeType == -1 && colSize < 1 ) )
       {
       colSize = VTK_SQL_DEFAULT_COLUMN_SIZE;
       }
-    
+
     // At this point, we have either a valid size if required, or a possibly null valid size
     // if not required. Thus, skip sizing in the latter case.
     if ( colSize > 0 )
@@ -261,10 +264,18 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
     options += " user=";
     options += this->User;
     }
-  if ( password && strlen( password ) > 0 )
+  if ( password && this->Password != password )
+    {
+    if ( this->Password )
+      {
+      delete [] this->Password;
+      }
+    this->Password = password ? vtksys::SystemTools::DuplicateString( password ) : 0;
+    }
+  if ( this->Password && strlen( this->Password ) > 0 )
     {
     options += " password=";
-    options += password;
+    options += this->Password;
     }
   if ( this->ConnectOptions && strlen( this->ConnectOptions ) > 0 )
     {
@@ -279,14 +290,6 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
     if ( this->OpenInternal( options.c_str() ) )
       {
       this->SetLastErrorText( 0 );
-      if ( this->Password != password )
-        {
-        if ( this->Password )
-          {
-          delete [] this->Password;
-          }
-        this->Password = password ? vtksys::SystemTools::DuplicateString( password ) : 0;
-        }
       return true;
       }
     }
@@ -296,14 +299,6 @@ bool vtkPostgreSQLDatabase::Open( const char* password )
   if ( this->OpenInternal( options.c_str() ) )
     {
     this->SetLastErrorText( 0 );
-    if ( this->Password != password )
-      {
-      if ( this->Password )
-        {
-        delete this->Password;
-        }
-      this->Password = password ? vtksys::SystemTools::DuplicateString( password ) : 0;
-      }
     return true;
     }
 
@@ -348,14 +343,14 @@ bool vtkPostgreSQLDatabase::HasError()
     }
   else
     {
-    return false; 
+    return false;
     }
 }
 
 // ----------------------------------------------------------------------
 const char* vtkPostgreSQLDatabase::GetLastErrorText()
 {
-  return this->LastErrorText; 
+  return this->LastErrorText;
 }
 
 // ----------------------------------------------------------------------
@@ -380,24 +375,26 @@ vtkStdString vtkPostgreSQLDatabase::GetURL()
 // ----------------------------------------------------------------------
 bool vtkPostgreSQLDatabase::ParseURL( const char* URL )
 {
+  vtkstd::string urlstr( URL ? URL : "" );
   vtkstd::string protocol;
-  vtkstd::string username; 
-  vtkstd::string unused;
-  vtkstd::string hostname; 
-  vtkstd::string dataport; 
+  vtkstd::string username;
+  vtkstd::string password;
+  vtkstd::string hostname;
+  vtkstd::string dataport;
   vtkstd::string database;
 
   // Okay now for all the other database types get more detailed info
   if ( ! vtksys::SystemTools::ParseURL(
-      URL, protocol, username, unused, hostname, dataport, database) )
+      urlstr, protocol, username, password, hostname, dataport, database) )
     {
-    vtkErrorMacro( "Invalid URL: " << URL );
+    vtkErrorMacro( "Invalid URL: \"" << urlstr.c_str() << "\"" );
     return false;
     }
 
   if ( protocol == "psql" )
     {
     this->SetUser( username.empty() ? 0 : username.c_str() );
+    this->SetPassword( password.empty() ? 0 : password.c_str() );
     this->SetHostName( hostname.empty() ? 0 : hostname.c_str() );
     this->SetServerPort( atoi( dataport.c_str() ) );
     this->SetDatabaseName( database.empty() ? 0 : database.c_str() );
@@ -410,10 +407,11 @@ bool vtkPostgreSQLDatabase::ParseURL( const char* URL )
 // ----------------------------------------------------------------------
 vtkStringArray* vtkPostgreSQLDatabase::GetTables()
 {
+  this->Tables->Resize(0);
   if ( ! this->Connection )
     {
     vtkErrorMacro(<< this->GetLastErrorText());
-    return 0;
+    return this->Tables;
     }
 
   // NB: Other columns of interest include table_catalog, table_schema, table_type,
@@ -431,17 +429,16 @@ vtkStringArray* vtkPostgreSQLDatabase::GetTables()
     vtkErrorMacro(<< "Database returned error: " << query->GetLastErrorText());
     this->SetLastErrorText(query->GetLastErrorText());
     query->Delete();
-    return 0;
+    return this->Tables;
     }
   vtkDebugMacro(<< "GetTables(): SQL query succeeded.");
-  vtkStringArray* results = vtkStringArray::New();
   while ( query->NextRow() )
     {
-    results->InsertNextValue( query->DataValue( 0 ).ToString() );
+    this->Tables->InsertNextValue( query->DataValue( 0 ).ToString() );
     }
   query->Delete();
   this->SetLastErrorText(NULL);
-  return results;
+  return this->Tables;
 }
 
 // ----------------------------------------------------------------------
@@ -472,7 +469,7 @@ vtkStringArray* vtkPostgreSQLDatabase::GetRecord( const char* table )
   // Each row in the results that come back from this query
   // describes a single column in the table.
   vtkStringArray* results = vtkStringArray::New();
-    
+
   while ( query->NextRow() )
     {
     results->InsertNextValue( query->DataValue( 0 ).ToString() );
@@ -644,10 +641,9 @@ bool vtkPostgreSQLDatabase::DropDatabase( const char* dbName )
       }
     }
 
-  vtkstd::string qstr( "DROP DATABASE \"" );
+  vtkstd::string qstr( "DROP DATABASE IF EXISTS \"" );
   qstr += dbName;
   qstr += "\"";
-  //qstr += " IF EXISTS";
   vtkSQLQuery *query = this->GetQueryInstance();
   query->SetQuery(qstr.c_str());
   if (query->Execute() == false)
@@ -705,7 +701,7 @@ void vtkPostgreSQLDatabase::UpdateDataTypeMap()
     {
     return;
     }
-  
+
   this->Connection->DataTypeMap.clear();
 
   vtkSQLQuery *typeQuery = this->GetQueryInstance();
@@ -770,5 +766,5 @@ void vtkPostgreSQLDatabase::UpdateDataTypeMap()
       } // done looping over rows
     } // done with "query is successful"
   typeQuery->Delete();
-} 
-      
+}
+
