@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkSQLDatabase.cxx,v $
+Module:    vtkSQLDatabase.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -19,6 +19,7 @@ PURPOSE.  See the above copyright notice for more information.
 -------------------------------------------------------------------------*/
 
 #include "vtkToolkits.h"
+#include "vtkInformationObjectBaseKey.h"
 #include "vtkSQLDatabase.h"
 #include "vtkSQLQuery.h"
 
@@ -38,6 +39,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkODBCDatabase.h"
 #endif // VTK_USE_ODBC
 
+#include "vtkCriticalSection.h"
 #include "vtkObjectFactory.h"
 #include "vtkStdString.h"
 
@@ -45,7 +47,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include <vtksys/ios/sstream>
 
 
-class vtkSQLDatabase::vtkCallbackVector : 
+class vtkSQLDatabase::vtkCallbackVector :
   public vtkstd::vector<vtkSQLDatabase::CreateFunction>
 {
 public:
@@ -78,10 +80,11 @@ public:
     }
 };
 
-// Used to clean up the Callbacks 
+// Used to clean up the Callbacks
 static vtkSQLDatabaseCleanup vtkCleanupSQLDatabaseGlobal;
 
-vtkCxxRevisionMacro(vtkSQLDatabase, "$Revision: 1.49 $");
+vtkInformationKeyMacro(vtkSQLDatabase, DATABASE, ObjectBase);
+
 // ----------------------------------------------------------------------
 vtkSQLDatabase::vtkSQLDatabase()
 {
@@ -145,48 +148,48 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification( vtkSQLDatabaseSchema* schem
   queryStr << schema->GetColumnNameFromHandle( tblHandle, colHandle );
 
   // Figure out column type
-  int colType = schema->GetColumnTypeFromHandle( tblHandle, colHandle ); 
+  int colType = schema->GetColumnTypeFromHandle( tblHandle, colHandle );
   vtkStdString colTypeStr;
   switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
     {
-    case vtkSQLDatabaseSchema::SERIAL:    
+    case vtkSQLDatabaseSchema::SERIAL:
       colTypeStr = "INTEGER";
       break;
-    case vtkSQLDatabaseSchema::SMALLINT:  
+    case vtkSQLDatabaseSchema::SMALLINT:
       colTypeStr = "INTEGER";
       break;
-    case vtkSQLDatabaseSchema::INTEGER:   
+    case vtkSQLDatabaseSchema::INTEGER:
       colTypeStr = "INTEGER";
       break;
-    case vtkSQLDatabaseSchema::BIGINT:    
+    case vtkSQLDatabaseSchema::BIGINT:
       colTypeStr = "INTEGER";
       break;
-    case vtkSQLDatabaseSchema::VARCHAR:   
+    case vtkSQLDatabaseSchema::VARCHAR:
       colTypeStr = "VARCHAR";
       break;
-    case vtkSQLDatabaseSchema::TEXT:      
+    case vtkSQLDatabaseSchema::TEXT:
       colTypeStr = "VARCHAR";
       break;
-    case vtkSQLDatabaseSchema::REAL:      
+    case vtkSQLDatabaseSchema::REAL:
       colTypeStr = "FLOAT";
       break;
-    case vtkSQLDatabaseSchema::DOUBLE:    
+    case vtkSQLDatabaseSchema::DOUBLE:
       colTypeStr = "DOUBLE";
       break;
-    case vtkSQLDatabaseSchema::BLOB:      
+    case vtkSQLDatabaseSchema::BLOB:
       colTypeStr = "";
       break;
-    case vtkSQLDatabaseSchema::TIME:      
+    case vtkSQLDatabaseSchema::TIME:
       colTypeStr = "TIME";
       break;
-    case vtkSQLDatabaseSchema::DATE:      
+    case vtkSQLDatabaseSchema::DATE:
       colTypeStr = "DATE";
       break;
-    case vtkSQLDatabaseSchema::TIMESTAMP: 
+    case vtkSQLDatabaseSchema::TIMESTAMP:
       colTypeStr = "TIMESTAMP";
       break;
     }
-  
+
   if ( colTypeStr.size() )
     {
     queryStr << " " << colTypeStr;
@@ -196,45 +199,45 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification( vtkSQLDatabaseSchema* schem
     vtkGenericWarningMacro( "Unable to get column specification: unsupported data type " << colType );
     return vtkStdString();
     }
-  
+
   // Decide whether size is allowed, required, or unused
   int colSizeType = 0;
   switch ( static_cast<vtkSQLDatabaseSchema::DatabaseColumnType>( colType ) )
     {
-    case vtkSQLDatabaseSchema::SERIAL:    
+    case vtkSQLDatabaseSchema::SERIAL:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::SMALLINT:  
+    case vtkSQLDatabaseSchema::SMALLINT:
       colSizeType =  1;
       break;
-    case vtkSQLDatabaseSchema::INTEGER:   
+    case vtkSQLDatabaseSchema::INTEGER:
       colSizeType =  1;
       break;
-    case vtkSQLDatabaseSchema::BIGINT:    
+    case vtkSQLDatabaseSchema::BIGINT:
       colSizeType =  1;
       break;
-    case vtkSQLDatabaseSchema::VARCHAR:   
+    case vtkSQLDatabaseSchema::VARCHAR:
       colSizeType = -1;
       break;
-    case vtkSQLDatabaseSchema::TEXT:      
+    case vtkSQLDatabaseSchema::TEXT:
       colSizeType = -1;
       break;
-    case vtkSQLDatabaseSchema::REAL:      
+    case vtkSQLDatabaseSchema::REAL:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::DOUBLE:    
+    case vtkSQLDatabaseSchema::DOUBLE:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::BLOB:      
+    case vtkSQLDatabaseSchema::BLOB:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::TIME:      
+    case vtkSQLDatabaseSchema::TIME:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::DATE:      
+    case vtkSQLDatabaseSchema::DATE:
       colSizeType =  0;
       break;
-    case vtkSQLDatabaseSchema::TIMESTAMP: 
+    case vtkSQLDatabaseSchema::TIMESTAMP:
       colSizeType =  0;
       break;
     }
@@ -243,14 +246,14 @@ vtkStdString vtkSQLDatabase::GetColumnSpecification( vtkSQLDatabaseSchema* schem
   if ( colSizeType )
     {
     int colSize = schema->GetColumnSizeFromHandle( tblHandle, colHandle );
-    // IF size is provided but absurd, 
+    // IF size is provided but absurd,
     // OR, if size is required but not provided OR absurd,
     // THEN assign the default size.
     if ( ( colSize < 0 ) || ( colSizeType == -1 && colSize < 1 ) )
       {
       colSize = VTK_SQL_DEFAULT_COLUMN_SIZE;
       }
-    
+
     // At this point, we have either a valid size if required, or a possibly null valid size
     // if not required. Thus, skip sizing in the latter case.
     if ( colSize > 0 )
@@ -288,7 +291,7 @@ vtkStdString vtkSQLDatabase::GetIndexSpecification( vtkSQLDatabaseSchema* schema
       skipped = false;
       break;
     case vtkSQLDatabaseSchema::INDEX:
-      // Not supported within a CREATE TABLE statement by all SQL backends: 
+      // Not supported within a CREATE TABLE statement by all SQL backends:
       // must be created later with a CREATE INDEX statement
       queryStr = "CREATE INDEX ";
       skipped = true;
@@ -296,7 +299,7 @@ vtkStdString vtkSQLDatabase::GetIndexSpecification( vtkSQLDatabaseSchema* schema
     default:
       return vtkStdString();
     }
-  
+
   // No index_name for PRIMARY KEYs nor UNIQUEs
   if ( skipped )
     {
@@ -311,7 +314,7 @@ vtkStdString vtkSQLDatabase::GetIndexSpecification( vtkSQLDatabaseSchema* schema
     }
 
   queryStr += " (";
-        
+
   // Loop over all column names of the index
   int numCnm = schema->GetNumberOfColumnNamesInIndex( tblHandle, idxHandle );
   if ( numCnm < 0 )
@@ -379,45 +382,52 @@ vtkStdString vtkSQLDatabase::GetTriggerSpecification( vtkSQLDatabaseSchema* sche
 
   return queryStr;
 }
- 
+
 // ----------------------------------------------------------------------
 vtkSQLDatabase* vtkSQLDatabase::CreateFromURL( const char* URL )
 {
+  vtkstd::string urlstr( URL ? URL : "" );
   vtkstd::string protocol;
-  vtkstd::string username; 
+  vtkstd::string username;
   vtkstd::string unused;
-  vtkstd::string hostname; 
-  vtkstd::string dataport; 
+  vtkstd::string hostname;
+  vtkstd::string dataport;
   vtkstd::string database;
   vtkstd::string dataglom;
   vtkSQLDatabase* db = 0;
-  
+
+  static vtkSimpleCriticalSection dbURLCritSec;
+  dbURLCritSec.Lock();
+
   // SQLite is a bit special so lets get that out of the way :)
-  if ( ! vtksys::SystemTools::ParseURLProtocol( URL, protocol, dataglom ))
+  if ( ! vtksys::SystemTools::ParseURLProtocol( urlstr, protocol, dataglom ))
     {
-    vtkGenericWarningMacro( "Invalid URL (no protocol found): " << URL );
+    vtkGenericWarningMacro( "Invalid URL (no protocol found): \"" << urlstr.c_str() << "\"" );
+    dbURLCritSec.Unlock();
     return 0;
     }
   if ( protocol == "sqlite" )
     {
     db = vtkSQLiteDatabase::New();
-    db->ParseURL(URL);
+    db->ParseURL( URL );
+    dbURLCritSec.Unlock();
     return db;
     }
-    
+
   // Okay now for all the other database types get more detailed info
-  if ( ! vtksys::SystemTools::ParseURL( URL, protocol, username,
+  if ( ! vtksys::SystemTools::ParseURL( urlstr, protocol, username,
                                         unused, hostname, dataport, database) )
     {
-    vtkGenericWarningMacro( "Invalid URL (other components missing): " << URL );
+    vtkGenericWarningMacro( "Invalid URL (other components missing): \"" << urlstr.c_str() << "\"" );
+    dbURLCritSec.Unlock();
     return 0;
     }
-  
+
 #ifdef VTK_USE_POSTGRES
   if ( protocol == "psql" )
     {
     db = vtkPostgreSQLDatabase::New();
-    db->ParseURL(URL);
+    db->ParseURL( URL );
     }
 #endif // VTK_USE_POSTGRES
 
@@ -425,7 +435,7 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL( const char* URL )
   if ( protocol == "mysql" )
     {
     db = vtkMySQLDatabase::New();
-    db->ParseURL(URL);
+    db->ParseURL( URL );
     }
 #endif // VTK_USE_MYSQL
 
@@ -433,7 +443,7 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL( const char* URL )
   if ( protocol == "odbc" )
     {
     db = vtkODBCDatabase::New();
-    db->ParseURL(URL);
+    db->ParseURL( URL );
     }
 #endif // VTK_USE_ODBC
 
@@ -441,13 +451,14 @@ vtkSQLDatabase* vtkSQLDatabase::CreateFromURL( const char* URL )
   // provide us with the required implementation.
   if (!db && vtkSQLDatabase::Callbacks)
     {
-    db = vtkSQLDatabase::Callbacks->CreateFromURL(URL);
+    db = vtkSQLDatabase::Callbacks->CreateFromURL( URL );
     }
 
-  if (!db)
+  if ( ! db )
     {
     vtkGenericWarningMacro( "Unsupported protocol: " << protocol.c_str() );
     }
+  dbURLCritSec.Unlock();
   return db;
 }
 
@@ -467,7 +478,7 @@ bool vtkSQLDatabase::EffectSchema( vtkSQLDatabaseSchema* schema, bool dropIfExis
     vtkGenericWarningMacro( "Unable to effect the schema: unable to begin transaction" );
     return false;
     }
- 
+
   // Loop over preamble statements of the schema and execute them only if they are relevant
   int numPre = schema->GetNumberOfPreambles();
   for ( int preHandle = 0; preHandle < numPre; ++ preHandle )
@@ -576,6 +587,25 @@ bool vtkSQLDatabase::EffectSchema( vtkSQLDatabaseSchema* schema, bool dropIfExis
       }
     queryStr += ")";
 
+    // Add options to the end of the CREATE TABLE statement
+    int numOpt = schema->GetNumberOfOptionsInTable( tblHandle );
+    if ( numOpt < 0 )
+      {
+      query->RollbackTransaction();
+      query->Delete();
+      return false;
+      }
+    for ( int optHandle = 0; optHandle < numOpt; ++ optHandle )
+      {
+      vtkStdString optBackend = schema->GetOptionBackendFromHandle( tblHandle, optHandle );
+      if ( strcmp( optBackend, VTK_SQL_ALLBACKENDS ) && strcmp( optBackend, this->GetClassName() ) )
+        {
+        continue;
+        }
+      queryStr += " ";
+      queryStr += schema->GetOptionTextFromHandle( tblHandle, optHandle );
+      }
+
     // Execute the CREATE TABLE query
     query->SetQuery( queryStr );
     if ( ! query->Execute() )
@@ -601,7 +631,7 @@ bool vtkSQLDatabase::EffectSchema( vtkSQLDatabaseSchema* schema, bool dropIfExis
         return false;
         }
       }
- 
+
     // Check out number of triggers
     int numTrg = schema->GetNumberOfTriggersInTable( tblHandle );
     if ( numTrg < 0 )
@@ -650,7 +680,7 @@ bool vtkSQLDatabase::EffectSchema( vtkSQLDatabaseSchema* schema, bool dropIfExis
       }
 
     // If triggers are specified but not supported, don't quit, but let the user know it
-    else if ( numTrg ) 
+    else if ( numTrg )
       {
       vtkGenericWarningMacro( "Triggers are not supported by this SQL backend; ignoring them." );
       }
