@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkSQLiteQuery.cxx,v $
+  Module:    vtkSQLiteQuery.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -36,7 +36,6 @@
 #define COMMIT_TRANSACTION "COMMIT"
 #define ROLLBACK_TRANSACTION "ROLLBACK"
 
-vtkCxxRevisionMacro(vtkSQLiteQuery, "$Revision: 1.19 $");
 vtkStandardNewMacro(vtkSQLiteQuery);
 
 // ----------------------------------------------------------------------
@@ -44,6 +43,7 @@ vtkSQLiteQuery::vtkSQLiteQuery()
 {
   this->Statement = NULL;
   this->InitialFetch = true;
+  this->InitialFetchResult=VTK_SQLITE_DONE;
   this->LastErrorText = NULL;
   this->TransactionInProgress = false;
 }
@@ -81,9 +81,10 @@ void vtkSQLiteQuery::PrintSelf(ostream  &os, vtkIndent indent)
     {
     os << "(null)" << "\n";
     }
-  os << indent << "InitialFetch: " << InitialFetch << "\n";
-  os << indent << "InitialFetchResult: " << InitialFetchResult << "\n";
-  os << indent << "TransactionInProgress: " << TransactionInProgress << "\n";
+  os << indent << "InitialFetch: " << this->InitialFetch << "\n";
+  os << indent << "InitialFetchResult: " << this->InitialFetchResult << "\n";
+  os << indent << "TransactionInProgress: " << this->TransactionInProgress
+     << "\n";
   os << indent << "LastErrorText: "
     << (this->LastErrorText ? this->LastErrorText : "(null)") << endl;
 }
