@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkXMLWriter.cxx,v $
+  Module:    vtkXMLWriter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -53,6 +53,9 @@
 #include <ctype.h> // isalnum is defined here for some versions of Borland
 #endif
 
+#include <locale> // C++ locale
+
+
 //*****************************************************************************
 // Friend class to enable access for  template functions to the protected
 // writer methods.
@@ -211,7 +214,6 @@ int vtkXMLWriterWriteBinaryDataBlocks(vtkXMLWriter* writer,
 }
 //*****************************************************************************
 
-vtkCxxRevisionMacro(vtkXMLWriter, "$Revision: 1.74 $");
 vtkCxxSetObjectMacro(vtkXMLWriter, Compressor, vtkDataCompressor);
 //----------------------------------------------------------------------------
 vtkXMLWriter::vtkXMLWriter()
@@ -277,6 +279,33 @@ vtkXMLWriter::~vtkXMLWriter()
   delete[] this->NumberOfTimeValues;
 }
 
+//----------------------------------------------------------------------------
+void vtkXMLWriter::SetCompressorType(int compressorType)
+{
+  if (compressorType == NONE)
+    {
+    if (this->Compressor)
+      {
+      this->Compressor->Delete();
+      this->Compressor = 0;
+      this->Modified();
+      }
+    return;
+    }
+
+  if (compressorType == ZLIB)
+    {
+    if (this->Compressor && !this->Compressor->IsTypeOf("vtkZLibDataCompressor"))
+      {
+      this->Compressor->Delete();
+      }
+
+    this->Compressor = vtkZLibDataCompressor::New();
+    this->Modified();
+    return;
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkXMLWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -616,6 +645,8 @@ int vtkXMLWriter::WriteInternal()
     return 0;
     }
 
+  (*this->Stream).imbue(vtkstd::locale::classic());
+  
   // Tell the subclass to write the data.
   int result = this->WriteData();
 
@@ -658,6 +689,8 @@ int vtkXMLWriter::StartFile()
     os << "<?xml version=\"1.0\"?>\n";
     }
 
+  os.imbue(vtkstd::locale::classic());
+  
   // Open the document-level element.  This will contain the rest of
   // the elements.
   os << "<VTKFile";
@@ -1706,6 +1739,7 @@ void vtkXMLWriter::WriteArrayAppended(
     offs.GetRangeMinPosition(timestep) = -1;
     offs.GetRangeMaxPosition(timestep) = -1;
     }
+
   //
   offs.GetPosition(timestep) = this->ReserveAttributeSpace("offset");
   // Write information in the recognized keys associated with this array.
@@ -1768,8 +1802,26 @@ void vtkXMLWriter::WriteArrayHeader(vtkAbstractArray* a,  vtkIndent indent,
   if(a->GetNumberOfComponents() > 1)
     {
     this->WriteScalarAttribute("NumberOfComponents",
-      a->GetNumberOfComponents());
+      a->GetNumberOfComponents()); 
     }
+  
+  //always write out component names, even if only 1 component
+  vtksys_ios::ostringstream buff;    
+  const char* compName = NULL;
+  for ( int i=0; i < a->GetNumberOfComponents(); ++i )
+    {
+    //get the component names    
+    buff << "ComponentName" << i;      
+    compName = a->GetComponentName( i );
+    if ( compName )
+      {
+      this->WriteStringAttribute( buff.str().c_str(), compName );
+      compName = NULL;
+      }
+    buff.str("");
+    buff.clear();
+    }
+    
   if(this->NumberOfTimeSteps > 1)
     {
     this->WriteScalarAttribute("TimeStep", timestep);
@@ -1864,7 +1916,7 @@ void vtkXMLWriter::WriteArrayInline(
     key->SaveState(info,eKey);
     eKey->PrintXML(os,indent);
     eKey->Delete();
-    }
+    }  
   // Write the inline data.
   this->WriteInlineData(a, indent.GetNextIndent());
   // Close tag.
