@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageAnisotropicDiffusion3D.cxx,v $
+  Module:    vtkImageAnisotropicDiffusion3D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkImageAnisotropicDiffusion3D, "$Revision: 1.43 $");
 vtkStandardNewMacro(vtkImageAnisotropicDiffusion3D);
 
 //----------------------------------------------------------------------------
@@ -171,7 +170,7 @@ void vtkImageAnisotropicDiffusion3D::ThreadedRequestData(
     {
     if (!id)
       {
-      this->UpdateProgress((double)(this->NumberOfIterations - idx)
+      this->UpdateProgress(static_cast<double>(this->NumberOfIterations - idx)
                            /this->NumberOfIterations);
       }
     this->Iterate(in, out, ar[0], ar[1], ar[2], outExt, idx);
@@ -287,14 +286,15 @@ void vtkImageAnisotropicDiffusion3D::Iterate(vtkImageData *inData,
   << min0 << ", " << max0 << ", " << min1 << ", " << max1 << ", " 
   << min2 << ", " << max2 << ")");
   
-  // I apologize for explicitely diffusing each neighbor, but it is the easiest
+  // I apologize for explicitly diffusing each neighbor, but it is the easiest
   // way to deal with the boundary conditions.  Besides it is fast.
   // (Are you sure every one is correct?!!!)
 
   for (idxC = 0; idxC < maxC; idxC++)
     {
-    inPtr2 = (double *)(inData->GetScalarPointer(min0, min1, min2));
-    outPtr2 = (double *)(outData->GetScalarPointer(min0, min1, min2));
+    inPtr2 = static_cast<double *>(inData->GetScalarPointer(min0, min1, min2));
+    outPtr2 =
+      static_cast<double *>(outData->GetScalarPointer(min0, min1, min2));
     inPtr2 += idxC;
     outPtr2 += idxC;
     
