@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageHybridMedian2D.cxx,v $
+  Module:    vtkImageHybridMedian2D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -23,7 +23,6 @@
 #include <vtkstd/algorithm>
 #include <vtkstd/numeric>
 
-vtkCxxRevisionMacro(vtkImageHybridMedian2D, "$Revision: 1.29 $");
 vtkStandardNewMacro(vtkImageHybridMedian2D);
 
 //----------------------------------------------------------------------------
@@ -58,8 +57,6 @@ void vtkImageHybridMedian2DExecute(vtkImageHybridMedian2D *self,
   unsigned long count = 0;
   unsigned long target;
 
-  id = id;
-
   inData->GetIncrements(inInc0, inInc1, inInc2);
   inInfo->Get(vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(), wholeExt);
   wholeMin0 = wholeExt[0];
