@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageImport.cxx,v $
+  Module:    vtkImageImport.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -27,7 +27,6 @@
 #include <ctype.h>
 #include <vtkstd/exception>
 
-vtkCxxRevisionMacro(vtkImageImport, "$Revision: 1.51 $");
 vtkStandardNewMacro(vtkImageImport);
 
 
@@ -84,6 +83,9 @@ vtkImageImport::vtkImageImport()
   vtkExecutive *exec = vtkImageImportExecutive::New();
   this->SetExecutive(exec);
   exec->Delete();
+
+  this->ScalarArrayName=0;
+  this->SetScalarArrayName("scalars");
 }
 
 //----------------------------------------------------------------------------
@@ -93,6 +95,7 @@ vtkImageImport::~vtkImageImport()
     {
     delete [] static_cast<char *>(this->ImportVoidPointer);
     }
+  this->SetScalarArrayName(NULL);
 }
 
 //----------------------------------------------------------------------------
@@ -173,6 +176,16 @@ void vtkImageImport::PrintSelf(ostream& os, vtkIndent indent)
   
   os << indent << "BufferPointerCallback: "
      << (this->BufferPointerCallback? "Set" : "Not Set") << "\n";
+
+  os << indent << "ScalarArrayName: ";
+  if(this->ScalarArrayName!=0)
+    {
+      os  << this->ScalarArrayName << endl;
+    }
+  else
+    {
+      os  << "(none)" << endl;
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -244,6 +257,7 @@ void vtkImageImport::ExecuteData(vtkDataObject *output)
 
   data->SetExtent(this->DataExtent);
   data->GetPointData()->GetScalars()->SetVoidArray(ptr,size,1);
+  data->GetPointData()->GetScalars()->SetName(this->ScalarArrayName);
 }
 
 //----------------------------------------------------------------------------
