@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageStencilData.cxx,v $
+  Module:    vtkImageStencilData.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,8 +24,8 @@
 #include "vtkMath.h"
 
 #include <math.h>
+#include <vtkstd/algorithm>
 
-vtkCxxRevisionMacro(vtkImageStencilData, "$Revision: 1.33 $");
 vtkStandardNewMacro(vtkImageStencilData);
 
 //----------------------------------------------------------------------------
@@ -43,11 +43,15 @@ vtkImageStencilData::vtkImageStencilData()
   this->ExtentLists = NULL;
   this->ExtentListLengths = NULL;
 
+  this->Extent[0] = 0;
+  this->Extent[1] = -1;
+  this->Extent[2] = 0;
+  this->Extent[3] = -1;
+  this->Extent[4] = 0;
+  this->Extent[5] = -1;
+
   this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_3D_EXTENT);
   this->Information->Set(vtkDataObject::DATA_EXTENT(), this->Extent, 6);
-
-  int extent[6] = {0, -1, 0, -1, 0, -1};
-  memcpy(this->Extent, extent, 6*sizeof(int));
 }
 
 //----------------------------------------------------------------------------
@@ -294,8 +298,10 @@ void vtkImageStencilData::AllocateExtents()
 {
   int extent[6];
   this->GetExtent(extent);
-  int numEntries = (extent[3] - extent[2] + 1)*(extent[5] - extent[4] + 1);
+  int ySize = (extent[3] - extent[2] + 1);
+  int zSize = (extent[5] - extent[4] + 1);
 
+  int numEntries = ySize*zSize;
   if (numEntries != this->NumberOfExtentEntries)
     {
     if (this->NumberOfExtentEntries != 0)
@@ -353,12 +359,10 @@ int vtkImageStencilData::GetNextExtent(int &r1, int &r2,
                                        int rmin, int rmax,
                                        int yIdx, int zIdx, int &iter)
 {
-  int extent[6];
-  this->GetExtent(extent);
-  int yExt = extent[3] - extent[2] + 1;
-  int zExt = extent[5] - extent[4] + 1;
-  yIdx -= extent[2];
-  zIdx -= extent[4];
+  int yExt = this->Extent[3] - this->Extent[2] + 1;
+  int zExt = this->Extent[5] - this->Extent[4] + 1;
+  yIdx -= this->Extent[2];
+  zIdx -= this->Extent[4];
 
   // initialize r1, r2 to defaults
   r1 = rmax + 1;
@@ -482,43 +486,43 @@ void vtkImageStencilData::Fill( void )
 void vtkImageStencilData::InsertNextExtent(int r1, int r2, int yIdx, int zIdx)
 {
   // calculate the index into the extent array
-  int extent[6];
-  this->GetExtent(extent);
-  int yExt = extent[3] - extent[2] + 1;
-  int incr = (zIdx - extent[4])*yExt + (yIdx - extent[2]);
+  int yMin = this->Extent[2];
+  int yMax = this->Extent[3];
+  int zMin = this->Extent[4];
+  int incr = (yMax - yMin + 1)*(zIdx - zMin) + (yIdx - yMin);
 
   int &clistlen = this->ExtentListLengths[incr];
   int *&clist = this->ExtentLists[incr];
 
+  // no space has been allocated yet
   if (clistlen == 0)
-    { // no space has been allocated yet
+    {
     clist = new int[2];
     }
-  else
-    { // check whether more space is needed
+  // this extent continues the previous extent
+  else if (r1 == clist[clistlen-1]+1)
+    {
+    clist[clistlen-1] = r2;
+    return;
+    }
+  // check if clistlen is a power of two
+  else if ((clistlen & (clistlen-1)) == 0)
+    {
     // the allocated space is always the smallest power of two
     // that is not less than the number of stored items, therefore
     // we need to allocate space when clistlen is a power of two
-    int clistmaxlen = 2;
-    while (clistlen > clistmaxlen)
+    int *newclist = new int[2*clistlen];
+    for (int k = 0; k < clistlen; k++)
       {
-      clistmaxlen *= 2;
-      }
-    if (clistmaxlen == clistlen)
-      { // need to allocate more space
-      clistmaxlen *= 2;
-      int *newclist = new int[clistmaxlen];
-      for (int k = 0; k < clistlen; k++)
-        {
-        newclist[k] = clist[k];
-        }
-      delete [] clist;
-      clist = newclist;
+      newclist[k] = clist[k];
       }
+    delete [] clist;
+    clist = newclist;
     }
 
-  clist[clistlen++] = r1;
-  clist[clistlen++] = r2 + 1;
+  clist[clistlen] = r1;
+  clist[clistlen + 1] = r2 + 1;
+  clistlen += 2;
 }
 
 //----------------------------------------------------------------------------
@@ -526,10 +530,10 @@ void vtkImageStencilData::InsertAndMergeExtent(int r1, int r2,
                                                int yIdx, int zIdx)
 {
   // calculate the index into the extent array
-  int extent[6];
-  this->GetExtent(extent);
-  int yExt = extent[3] - extent[2] + 1;
-  int incr = (zIdx - extent[4])*yExt + (yIdx - extent[2]);
+  int yMin = this->Extent[2];
+  int yMax = this->Extent[3];
+  int zMin = this->Extent[4];
+  int incr = (yMax - yMin + 1)*(zIdx - zMin) + (yIdx - yMin);
 
   int &clistlen = this->ExtentListLengths[incr];
   int *&clist = this->ExtentLists[incr];
@@ -537,20 +541,21 @@ void vtkImageStencilData::InsertAndMergeExtent(int r1, int r2,
   if (clistlen == 0)
     { // no space has been allocated yet
     clist = new int[2];
-    clist[clistlen++] = r1;
-    clist[clistlen++] = r2 + 1;
+    clist[clistlen] = r1;
+    clist[clistlen + 1] = r2 + 1;
+    clistlen += 2;
     return;
     }
   
   for (int k = 0; k < clistlen; k+=2)
     {
     if ((r1 >= clist[k] && r1 < clist[k+1]) || 
-      (r2 >= clist[k] && r2 < clist[k+1]))
+        (r2 >= clist[k] && r2 < clist[k+1]))
       {
       // An intersecting extent is already present. Merge with that one.
       if (r1 < clist[k])
         {
-        clist[k]   = r1;
+        clist[k] = r1;
         }
       else if (r2 >= clist[k+1])
         {
@@ -574,36 +579,29 @@ void vtkImageStencilData::InsertAndMergeExtent(int r1, int r2,
   // the allocated space is always the smallest power of two
   // that is not less than the number of stored items, therefore
   // we need to allocate space when clistlen is a power of two
-  int clistmaxlen = 2;
-  while (clistlen > clistmaxlen)
+  if ((clistlen & (clistlen-1)) == 0)
     {
-    clistmaxlen *= 2;
-    }
-  int insertIndex = clistlen, offset = 0;
-  if (clistmaxlen == clistlen || r1 < clist[clistlen-1])
-    { // need to allocate more space or rearrange
-    if (clistmaxlen == clistlen)
+    int *newclist = new int[2*clistlen];
+    for (int k = 0; k < clistlen; k++)
       {
-      clistmaxlen *= 2;
-      }
-    int *newclist = new int[clistmaxlen];
-    for (int k = 0; k < clistlen; k+=2)
-      {
-      if (offset == 0 && r1 < clist[k])
-        {
-        insertIndex = k;
-        offset = 2;
-        }
-      newclist[k+offset] = clist[k];
-      newclist[k+1+offset] = clist[k+1];
+      newclist[k] = clist[k];
       }
     delete [] clist;
     clist = newclist;
     }
 
+  // shift to make room for the insertion
+  int insertIndex = clistlen;
+  clistlen += 2;
+  while (r1 < clist[insertIndex-1])
+    {
+    clist[insertIndex] = clist[insertIndex-2];
+    clist[insertIndex+1] = clist[insertIndex-1];
+    insertIndex -= 2;
+    }
+
   clist[insertIndex] = r1;
   clist[insertIndex+1] = r2 + 1;
-  clistlen += 2;
 }
 
 
@@ -648,17 +646,20 @@ void vtkImageStencilData::CollapseAdditionalIntersections(int r2, int idx,
 //----------------------------------------------------------------------------
 void vtkImageStencilData::RemoveExtent(int r1, int r2, int yIdx, int zIdx)
 {
-  if (zIdx < this->Extent[4] || zIdx > this->Extent[5] || 
-      yIdx < this->Extent[2] || yIdx > this->Extent[3] )
+  int xMin = this->Extent[0];
+  int xMax = this->Extent[1];
+  int yMin = this->Extent[2];
+  int yMax = this->Extent[3];
+  int zMin = this->Extent[4];
+  int zMax = this->Extent[5];
+
+  if (zIdx < zMin || zIdx > zMax || yIdx < yMin || yIdx > yMax )
     {
     return;
     }
   
   // calculate the index into the extent array
-  int extent[6];
-  this->GetExtent(extent);
-  int yExt = extent[3] - extent[2] + 1;
-  int incr = (zIdx - extent[4])*yExt + (yIdx - extent[2]);
+  int incr = (yMax - yMin + 1)*(zIdx - zMin) + (yIdx - yMin);
 
   int &clistlen = this->ExtentListLengths[incr];
   int *&clist = this->ExtentLists[incr];
@@ -668,7 +669,7 @@ void vtkImageStencilData::RemoveExtent(int r1, int r2, int yIdx, int zIdx)
     return;
     }
 
-  if (r1 <= extent[0] && r2 >= extent[1])
+  if (r1 <= xMin && r2 >= xMax)
     {
     // remove the whole row.
     clistlen = 0;
@@ -740,15 +741,9 @@ void vtkImageStencilData::RemoveExtent(int r1, int r2, int yIdx, int zIdx)
           // the allocated space is always the smallest power of two
           // that is not less than the number of stored items, therefore
           // we need to allocate space when clistlen is a power of two
-          int clistmaxlen = 2;
-          while (clistlen > clistmaxlen)
+          if ((clistlen & (clistlen-1)) == 0)
             {
-            clistmaxlen *= 2;
-            }
-          if (clistmaxlen == clistlen)
-            { // need to allocate more space
-            clistmaxlen *= 2;
-            int *newclist = new int[clistmaxlen];
+            int *newclist = new int[2*clistlen];
             for (int m = 0; m < clistlen; m++)
               {
               newclist[m] = clist[m];
@@ -756,8 +751,9 @@ void vtkImageStencilData::RemoveExtent(int r1, int r2, int yIdx, int zIdx)
             delete [] clist;
             clist = newclist;
             }
-          clist[clistlen++] = r2+1;
-          clist[clistlen++] = tmp;
+          clist[clistlen] = r2+1;
+          clist[clistlen+1] = tmp;
+          clistlen += 2;
           }
         }
       else
@@ -1048,3 +1044,427 @@ int vtkImageStencilData::Clip( int extent[6] )
   return (removed ? 1 : 0);
 }
 
+//----------------------------------------------------------------------------
+// tolerance for float-to-int conversion in stencil operations
+
+#define VTK_STENCIL_TOL 7.62939453125e-06
+
+//----------------------------------------------------------------------------
+vtkImageStencilRaster::vtkImageStencilRaster(const int extent[2])
+{
+  int rsize = extent[1] - extent[0] + 1;
+
+  // the "raster" is a sequence of pointer-pairs, where the first pointer
+  // points to the first value in the raster line, and the second pointer
+  // points to one location past the last vale in the raster line.  The
+  // difference is the number of x values stored in the raster line.
+  this->Raster = new double*[2*static_cast<size_t>(rsize)];
+
+  // the extent is the range of y values (one line per y)
+  this->Extent[0] = extent[0];
+  this->Extent[1] = extent[1];
+
+  // tolerance should be larger than expected roundoff errors
+  this->Tolerance = VTK_STENCIL_TOL;
+
+  // no extent is used initially
+  this->UsedExtent[0] = 0;
+  this->UsedExtent[1] = -1;
+}
+
+//----------------------------------------------------------------------------
+vtkImageStencilRaster::~vtkImageStencilRaster()
+{
+  if (this->UsedExtent[1] >= this->UsedExtent[0])
+    {
+    size_t i = 2*static_cast<size_t>(this->UsedExtent[0] - this->Extent[0]);
+    size_t imax = 2*static_cast<size_t>(this->UsedExtent[1] - this->Extent[0]);
+
+    do
+      {
+      if (this->Raster[i])
+        {
+        delete [] this->Raster[i];
+        }
+      i += 2;
+      }
+    while (i <= imax);
+    }
+  delete [] this->Raster;
+}
+
+//----------------------------------------------------------------------------
+void vtkImageStencilRaster::PrepareForNewData(const int allocateExtent[2])
+{
+  if (this->UsedExtent[1] >= this->UsedExtent[0])
+    {
+    // reset and re-use the allocated raster lines
+    size_t i = 2*static_cast<size_t>(this->UsedExtent[0]-this->Extent[0]);
+    size_t imax=2*static_cast<size_t>(this->UsedExtent[1]-this->Extent[0]);
+    do
+      {
+      this->Raster[i+1] = this->Raster[i];
+      i += 2;
+      }
+    while (i <= imax);
+    }
+
+  if (allocateExtent && allocateExtent[1] >= allocateExtent[1])
+    {
+    this->PrepareExtent(allocateExtent[0], allocateExtent[1]);
+    }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageStencilRaster::PrepareExtent(int ymin, int ymax)
+{
+  // this does not do any allocation, it just initializes any
+  // raster lines are not already part of the UsedExtent, and
+  // then expands the UsedExtent to include [ymin, ymax]
+
+  if (this->UsedExtent[1] < this->UsedExtent[0])
+    {
+    size_t i = 2*static_cast<size_t>(ymin - this->Extent[0]);
+    size_t imax = 2*static_cast<size_t>(ymax - this->Extent[0]);
+
+    do
+      {
+      this->Raster[i] = 0;
+      }
+    while (++i <= imax);
+
+    this->UsedExtent[0] = ymin;
+    this->UsedExtent[1] = ymax;
+
+    return;
+    }
+
+  if (ymin < this->UsedExtent[0])
+    {
+    size_t i = 2*static_cast<size_t>(ymin - this->Extent[0]);
+    size_t imax = 2*static_cast<size_t>(this->UsedExtent[0]-this->Extent[0]-1);
+
+    do
+      {
+      this->Raster[i] = 0;
+      }
+    while (++i <= imax);
+
+    this->UsedExtent[0] = ymin;
+    }
+
+  if (ymax > this->UsedExtent[1])
+    {
+    size_t i = 2*static_cast<size_t>(this->UsedExtent[1]+1 - this->Extent[0]);
+    size_t imax = 2*static_cast<size_t>(ymax - this->Extent[0]);
+
+    do
+      {
+      this->Raster[i] = 0;
+      }
+    while (++i <= imax);
+
+    this->UsedExtent[1] = ymax;
+    }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageStencilRaster::InsertPoint(int y, double x)
+{
+  size_t pos = 2*static_cast<size_t>(y - this->Extent[0]);
+  double* &rhead = this->Raster[pos];
+  double* &rtail = this->Raster[pos+1];
+
+  // current size is the diff between the tail and the head
+  size_t n = rtail - rhead;
+
+  // no allocation on this raster line yet
+  if (rhead == 0)
+    {
+    rhead = new double[2];
+    rtail = rhead;
+    }
+  // grow whenever size reaches a power of two
+  else if (n > 1 && (n & (n-1)) == 0)
+    {
+    double *ptr = new double[2*n];
+    for (size_t i = 0; i < n; i++)
+      {
+      ptr[i] = rhead[i];
+      }
+    delete [] rhead;
+    rhead = ptr;
+    rtail = ptr + n;
+    }
+
+  // insert the value
+  *rtail++ = x;
+}
+
+//----------------------------------------------------------------------------
+void vtkImageStencilRaster::InsertLine(
+  const double pt1[2], const double pt2[2],
+  bool inflection1, bool inflection2)
+{
+  double x1 = pt1[0];
+  double x2 = pt2[0];
+  double y1 = pt1[1];
+  double y2 = pt2[1];
+
+  // swap end points if necessary
+  if (y1 > y2)
+    {
+    x1 = pt2[0];
+    x2 = pt1[0];
+    y1 = pt2[1];
+    y2 = pt1[1];
+    bool tmp = inflection1;
+    inflection1 = inflection2;
+    inflection2 = tmp;
+    }
+
+  // find min and max of x values
+  double xmin = x1;
+  double xmax = x2;
+  if (x1 > x2)
+    {
+    xmin = x2;
+    xmax = x1;
+    }
+
+  // check for parallel to the x-axis
+  if (y1 == y2)
+    {
+    return;
+    }
+
+  double ymin = y1;
+  double ymax = y2;
+
+  // if an end is an inflection point, include a tolerance
+  ymin -= inflection1*this->Tolerance;
+  ymax += inflection2*this->Tolerance;
+
+  // Integer y values for start and end of line
+  int iy1, iy2;
+  iy1 = this->Extent[0];
+  iy2 = this->Extent[1];
+
+  // Check for out of bounds
+  if (ymax < iy1 || ymin >= iy2)
+    {
+    return;
+    }
+
+  // Guard against extentY
+  if (ymin >= iy1)
+    {
+    iy1 = vtkMath::Floor(ymin) + 1;
+    }
+  if (ymax < iy2)
+    {
+    iy2 = vtkMath::Floor(ymax);
+    }
+
+  // Expand allocated extent if necessary
+  if (iy1 < this->UsedExtent[0] ||
+      iy2 > this->UsedExtent[1])
+    {
+    this->PrepareExtent(iy1, iy2);
+    }
+
+  // Precompute values for a Bresenham-like line algorithm
+  double grad = (x2 - x1)/(y2 - y1);
+  double delta = (iy1 - y1)*grad;
+
+  // Go along y and place each x in the proper raster line
+  for (int y = iy1; y <= iy2; y++)
+    {
+    double x = x1 + delta;
+    // incrementing delta has less roundoff error than incrementing x,
+    // since delta will typically be smaller than x
+    delta += grad;
+
+    // clamp x (because of tolerance, it might not be in range)
+    if (x < xmin)
+      {
+      x = xmin;
+      }
+    else if (x > xmax)
+      {
+      x = xmax;
+      }
+
+    this->InsertPoint(y, x);
+    }
+}
+
+//----------------------------------------------------------------------------
+void vtkImageStencilRaster::FillStencilData(
+  vtkImageStencilData *data, const int extent[6], int xj, int yj)
+{
+  if (xj != 0)
+    {
+    // slices are stacked in the x direction
+    int xmin = extent[2*xj];
+    int xmax = extent[2*xj+1];
+    int ymin = this->UsedExtent[0];
+    int ymax = this->UsedExtent[1];
+    int zmin = extent[0];
+    int zmax = extent[1];
+
+    for (int idY = ymin; idY <= ymax; idY++)
+      {
+      size_t pos = 2*static_cast<size_t>(idY - this->Extent[0]);
+      double *rline = this->Raster[pos];
+      double *rlineEnd = this->Raster[pos+1];
+
+      if (rline == 0)
+        {
+        continue;
+        }
+
+      vtkstd::sort(rline, rlineEnd);
+
+      int xy[2];
+      xy[2-xj] = idY;
+
+      int lastr = VTK_INT_MIN;
+
+      size_t l = rlineEnd - rline;
+      l = l - (l & 1); // force l to be an even number
+      for (size_t k = 0; k < l; k += 2)
+        {
+        double x1 = rline[k] - this->Tolerance;
+        double x2 = rline[k+1] + this->Tolerance;
+
+        // make sure one of the ends is in bounds
+        if (x2 < xmin || x1 >= xmax)
+          {
+          continue;
+          }
+
+        // clip the line segment with the bounds
+        int r1 = xmin;
+        int r2 = xmax;
+
+        if (x1 >= xmin)
+          {
+          r1 = vtkMath::Floor(x1) + 1;
+          }
+        if (x2 < xmax)
+          {
+          r2 = vtkMath::Floor(x2);
+          }
+
+        // ensure no overlap occurs with previous
+        if (r1 <= lastr)
+          {
+          r1 = lastr + 1;
+          }
+        lastr = r2;
+
+        for (int idX = r1; idX <= r2; idX++)
+          {
+          xy[xj-1] = idX;
+          data->InsertNextExtent(zmin, zmax, xy[0], xy[1]);
+          }
+        }
+      }
+    }
+  else
+    {
+    // slices stacked in the y or z direction
+    int zj = 3 - yj;
+    int xmin = extent[0];
+    int xmax = extent[1];
+    int ymin = this->UsedExtent[0];
+    int ymax = this->UsedExtent[1];
+    int zmin = extent[2*zj];
+    int zmax = extent[2*zj+1];
+
+    // convert each raster line into extents for the stencil
+    for (int idY = ymin; idY <= ymax; idY++)
+      {
+      size_t pos = 2*static_cast<size_t>(idY - this->Extent[0]);
+      double *rline = this->Raster[pos];
+      double *rlineEnd = this->Raster[pos+1];
+
+      if (rline == 0)
+        {
+        continue;
+        }
+
+      vtkstd::sort(rline, rlineEnd);
+
+      int lastr = VTK_INT_MIN;
+
+      // go through each raster line and fill the stencil
+      size_t l = rlineEnd - rline;
+      l = l - (l & 1); // force l to be an even number
+      for (size_t k = 0; k < l; k += 2)
+        {
+        int yz[2];
+
+        yz[yj-1] = idY;
+        yz[2-yj] = zmin;
+
+        double x1 = rline[k] - this->Tolerance;
+        double x2 = rline[k+1] + this->Tolerance;
+
+        if (x2 < xmin || x1 >= xmax)
+          {
+          continue;
+          }
+
+        int r1 = xmin;
+        int r2 = xmax;
+
+        if (x1 >= xmin)
+          {
+          r1 = vtkMath::Floor(x1) + 1;
+          }
+        if (x2 < xmax)
+          {
+          r2 = vtkMath::Floor(x2);
+          }
+
+        // ensure no overlap occurs between extents
+        if (r1 <= lastr)
+          {
+          r1 = lastr + 1;
+          }
+        lastr = r2;
+
+        if (r2 >= r1)
+          {
+          data->InsertNextExtent(r1, r2, yz[0], yz[1]);
+          }
+        }
+      }
+
+    // copy the result to all other slices
+    if (zmin < zmax)
+      {
+      for (int idY = ymin; idY <= ymax; idY++)
+        {
+        int r1, r2;
+        int yz[2];
+
+        yz[yj-1] = idY;
+        yz[2-yj] = zmin;
+
+        int iter = 0;
+        while (data->GetNextExtent(r1, r2, xmin, xmax, yz[0], yz[1], iter))
+          {
+          for (int idZ = zmin + 1; idZ <= zmax; idZ++)
+            {
+            yz[2-yj] = idZ;
+            data->InsertNextExtent(r1, r2, yz[0], yz[1]);
+            }
+          yz[2-yj] = zmin;
+          }
+        }
+      }
+   }
+}
