@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkBoostGraphAdapter.h,v $
+  Module:    vtkBoostGraphAdapter.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -43,7 +43,8 @@
 #include "vtkTree.h"
 #include "vtkUndirectedGraph.h"
 #include "vtkVariant.h"
-#include <stddef.h> // for ptrdiff_t
+
+#include <boost/version.hpp>
 
 namespace boost {
   //===========================================================================
@@ -52,8 +53,8 @@ namespace boost {
 
   // Forward declarations are required here, so that we aren't forced
   // to include boost/property_map.hpp.
-  template<typename> class property_traits;
-  class read_write_property_map_tag;
+  template<typename> struct property_traits;
+  struct read_write_property_map_tag;
 
 #define vtkPropertyMapMacro(T, V)                       \
   template <>                                           \
@@ -86,7 +87,7 @@ namespace boost {
   vtkPropertyMapMacro(vtkIdTypeArray, vtkIdType)
   vtkPropertyMapMacro(vtkDoubleArray, double)
   vtkPropertyMapMacro(vtkFloatArray, float)
-  
+
   // vtkDataArray
   template<>
   struct property_traits<vtkDataArray*>
@@ -97,11 +98,11 @@ namespace boost {
     typedef read_write_property_map_tag category;
   };
 
-  inline double 
+  inline double
   get(vtkDataArray * const& arr, vtkIdType key)
   {
     return arr->GetTuple1(key);
-  }                     
+  }
 
   inline void
   put(vtkDataArray *arr, vtkIdType key, const double& value)
@@ -119,11 +120,11 @@ namespace boost {
     typedef read_write_property_map_tag category;
   };
 
-  inline vtkVariant 
+  inline vtkVariant
   get(vtkAbstractArray * const& arr, vtkIdType key)
   {
     return arr->GetVariantValue(key);
-  }                     
+  }
 
   inline void
   put(vtkAbstractArray *arr, vtkIdType key, const vtkVariant& value)
@@ -132,7 +133,7 @@ namespace boost {
   }
 }
 
-#include <vtksys/stl/utility>
+#include <vtksys/stl/utility> // STL Header
 
 #include <boost/config.hpp>
 #include <boost/iterator/iterator_facade.hpp>
@@ -141,12 +142,12 @@ namespace boost {
 #include <boost/graph/adjacency_iterator.hpp>
 
 // The functions and classes in this file allows the user to
-// treat a vtkDirectedGraph or vtkUndirectedGraph object 
+// treat a vtkDirectedGraph or vtkUndirectedGraph object
 // as a boost graph "as is".
 
 namespace boost {
 
-  class vtk_vertex_iterator : 
+  class vtk_vertex_iterator :
     public iterator_facade<vtk_vertex_iterator,
                            vtkIdType,
                            bidirectional_traversal_tag,
@@ -169,8 +170,8 @@ namespace boost {
 
       friend class iterator_core_access;
     };
-    
-  class vtk_edge_iterator : 
+
+  class vtk_edge_iterator :
     public iterator_facade<vtk_edge_iterator,
                            vtkEdgeType,
                            forward_traversal_tag,
@@ -186,8 +187,8 @@ namespace boost {
           lastVertex = graph->GetNumberOfVertices();
           }
 
-        vtkIdType myRank = -1;  
-        vtkDistributedGraphHelper *helper 
+        vtkIdType myRank = -1;
+        vtkDistributedGraphHelper *helper
           = this->graph? this->graph->GetDistributedGraphHelper() : 0;
         if (helper)
           {
@@ -195,7 +196,7 @@ namespace boost {
           vertex = helper->MakeDistributedId(myRank, vertex);
           lastVertex = helper->MakeDistributedId(myRank, lastVertex);
           }
-          
+
         if (graph != 0)
           {
           directed = (vtkDirectedGraph::SafeDownCast(graph) != 0);
@@ -218,12 +219,12 @@ namespace boost {
                     && (// Skip non-local edges
                         (helper && helper->GetEdgeOwner(iter->Id) != myRank)
                         // Skip entirely-local edges where Source > Target
-                        || (((helper 
+                        || (((helper
                               && myRank == helper->GetVertexOwner(iter->Target))
                              || !helper)
                             && vertex > iter->Target)))
                 {
-                this->inc();  
+                this->inc();
                 }
               }
             }
@@ -246,15 +247,15 @@ namespace boost {
         inc();
         if (!directed)
           {
-          vtkIdType myRank = -1;  
-          vtkDistributedGraphHelper *helper 
+          vtkIdType myRank = -1;
+          vtkDistributedGraphHelper *helper
             = this->graph? this->graph->GetDistributedGraphHelper() : 0;
           if (helper)
             {
             myRank = this->graph->GetInformation()->Get(vtkDataObject::DATA_PIECE_NUMBER());
             }
-          
-          while (iter != 0 
+
+          while (iter != 0
                  && (// Skip non-local edges
                      (helper && helper->GetEdgeOwner(iter->Id) != myRank)
                      // Skip entirely-local edges where Source > Target
@@ -302,8 +303,8 @@ namespace boost {
 
       friend class iterator_core_access;
     };
-    
-  class vtk_out_edge_pointer_iterator : 
+
+  class vtk_out_edge_pointer_iterator :
     public iterator_facade<vtk_out_edge_pointer_iterator,
                            vtkEdgeType,
                            bidirectional_traversal_tag,
@@ -339,8 +340,8 @@ namespace boost {
 
       friend class iterator_core_access;
     };
-    
-  class vtk_in_edge_pointer_iterator : 
+
+  class vtk_in_edge_pointer_iterator :
     public iterator_facade<vtk_in_edge_pointer_iterator,
                            vtkEdgeType,
                            bidirectional_traversal_tag,
@@ -376,19 +377,19 @@ namespace boost {
 
       friend class iterator_core_access;
     };
-    
+
   //===========================================================================
   // vtkGraph
   // VertexAndEdgeListGraphConcept
   // BidirectionalGraphConcept
   // AdjacencyGraphConcept
-    
-  struct vtkGraph_traversal_category : 
+
+  struct vtkGraph_traversal_category :
     public virtual bidirectional_graph_tag,
     public virtual edge_list_graph_tag,
     public virtual vertex_list_graph_tag,
     public virtual adjacency_graph_tag { };
-      
+
   template <>
   struct graph_traits<vtkGraph*> {
     typedef vtkIdType vertex_descriptor;
@@ -407,10 +408,17 @@ namespace boost {
     typedef vtkIdType edges_size_type;
     typedef vtkIdType degree_size_type;
 
-    typedef adjacency_iterator_generator<vtkGraph*, 
+    typedef adjacency_iterator_generator<vtkGraph*,
       vertex_descriptor, out_edge_iterator>::type adjacency_iterator;
   };
 
+#if BOOST_VERSION >= 104500
+  template<>
+  struct graph_property_type< vtkGraph* > {
+    typedef no_property type;
+  };
+#endif
+
   template<>
   struct vertex_property_type< vtkGraph* > {
     typedef no_property type;
@@ -421,6 +429,41 @@ namespace boost {
     typedef no_property type;
   };
 
+#if BOOST_VERSION >= 104500
+  template<>
+  struct graph_bundle_type< vtkGraph* > {
+    typedef no_property type;
+  };
+#endif
+
+  template<>
+  struct vertex_bundle_type< vtkGraph* > {
+    typedef no_property type;
+  };
+
+  template<>
+  struct edge_bundle_type< vtkGraph* > {
+    typedef no_property type;
+  };
+
+  inline bool has_no_edges(vtkGraph* g)
+    {
+      return ((g->GetNumberOfEdges() > 0) ? false : true);
+    }
+
+  inline void remove_edge(graph_traits<vtkGraph*>::edge_descriptor e,
+                          vtkGraph* g)
+    {
+    if(vtkMutableDirectedGraph::SafeDownCast(g))
+      {
+      vtkMutableDirectedGraph::SafeDownCast(g)->RemoveEdge(e.Id);
+      }
+    else if(vtkMutableUndirectedGraph::SafeDownCast(g))
+      {
+      vtkMutableUndirectedGraph::SafeDownCast(g)->RemoveEdge(e.Id);
+      }
+    }
+
   //===========================================================================
   // vtkDirectedGraph
 
@@ -438,26 +481,70 @@ namespace boost {
   template <>
   struct graph_traits<vtkDirectedGraph* const> : graph_traits<vtkDirectedGraph*> { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkDirectedGraph* >
+    : graph_property_type< vtkGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkDirectedGraph* const >
+    : graph_property_type< vtkGraph* > { };
+#endif
+
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkDirectedGraph* > 
+  struct vertex_property_type< vtkDirectedGraph* >
     : vertex_property_type< vtkGraph* > { };
 
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkDirectedGraph* const > 
+  struct vertex_property_type< vtkDirectedGraph* const >
     : vertex_property_type< vtkGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkDirectedGraph* > 
+  struct edge_property_type< vtkDirectedGraph* >
     : edge_property_type< vtkGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkDirectedGraph* const > 
+  struct edge_property_type< vtkDirectedGraph* const >
     : edge_property_type< vtkGraph* > { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkDirectedGraph* >
+    : graph_bundle_type< vtkGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkDirectedGraph* const >
+    : graph_bundle_type< vtkGraph* > { };
+#endif
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkDirectedGraph* >
+    : vertex_bundle_type< vtkGraph* > { };
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkDirectedGraph* const >
+    : vertex_bundle_type< vtkGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkDirectedGraph* >
+    : edge_bundle_type< vtkGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkDirectedGraph* const >
+    : edge_bundle_type< vtkGraph* > { };
+
   //===========================================================================
   // vtkTree
 
@@ -488,26 +575,70 @@ namespace boost {
   template <>
   struct graph_traits<vtkUndirectedGraph* const> : graph_traits<vtkUndirectedGraph*> { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkUndirectedGraph* >
+    : graph_property_type< vtkGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkUndirectedGraph* const >
+    : graph_property_type< vtkGraph* > { };
+#endif
+
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkUndirectedGraph* > 
+  struct vertex_property_type< vtkUndirectedGraph* >
     : vertex_property_type< vtkGraph* > { };
 
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkUndirectedGraph* const > 
+  struct vertex_property_type< vtkUndirectedGraph* const >
     : vertex_property_type< vtkGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkUndirectedGraph* > 
+  struct edge_property_type< vtkUndirectedGraph* >
     : edge_property_type< vtkGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkUndirectedGraph* const > 
+  struct edge_property_type< vtkUndirectedGraph* const >
     : edge_property_type< vtkGraph* > { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkUndirectedGraph* >
+    : graph_bundle_type< vtkGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkUndirectedGraph* const >
+    : graph_bundle_type< vtkGraph* > { };
+#endif
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkUndirectedGraph* >
+    : vertex_bundle_type< vtkGraph* > { };
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkUndirectedGraph* const >
+    : vertex_bundle_type< vtkGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkUndirectedGraph* >
+    : edge_bundle_type< vtkGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkUndirectedGraph* const >
+    : edge_bundle_type< vtkGraph* > { };
+
   //===========================================================================
   // vtkMutableDirectedGraph
 
@@ -522,26 +653,70 @@ namespace boost {
   template <>
   struct graph_traits<vtkMutableDirectedGraph* const> : graph_traits<vtkMutableDirectedGraph*> { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkMutableDirectedGraph* >
+    : graph_property_type< vtkDirectedGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkMutableDirectedGraph* const >
+    : graph_property_type< vtkDirectedGraph* > { };
+#endif
+
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkMutableDirectedGraph* > 
+  struct vertex_property_type< vtkMutableDirectedGraph* >
     : vertex_property_type< vtkDirectedGraph* > { };
 
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkMutableDirectedGraph* const > 
+  struct vertex_property_type< vtkMutableDirectedGraph* const >
     : vertex_property_type< vtkDirectedGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkMutableDirectedGraph* > 
+  struct edge_property_type< vtkMutableDirectedGraph* >
     : edge_property_type< vtkDirectedGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkMutableDirectedGraph* const > 
+  struct edge_property_type< vtkMutableDirectedGraph* const >
     : edge_property_type< vtkDirectedGraph* > { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkMutableDirectedGraph* >
+    : graph_bundle_type< vtkDirectedGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkMutableDirectedGraph* const >
+    : graph_bundle_type< vtkDirectedGraph* > { };
+#endif
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkMutableDirectedGraph* >
+    : vertex_bundle_type< vtkDirectedGraph* > { };
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkMutableDirectedGraph* const >
+    : vertex_bundle_type< vtkDirectedGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkMutableDirectedGraph* >
+    : edge_bundle_type< vtkDirectedGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkMutableDirectedGraph* const >
+    : edge_bundle_type< vtkDirectedGraph* > { };
+
   //===========================================================================
   // vtkMutableUndirectedGraph
 
@@ -556,26 +731,70 @@ namespace boost {
   template <>
   struct graph_traits<vtkMutableUndirectedGraph* const> : graph_traits<vtkMutableUndirectedGraph*> { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkMutableUndirectedGraph* >
+    : graph_property_type< vtkUndirectedGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_property_type< vtkMutableUndirectedGraph* const >
+    : graph_property_type< vtkUndirectedGraph* > { };
+#endif
+
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkMutableUndirectedGraph* > 
+  struct vertex_property_type< vtkMutableUndirectedGraph* >
     : vertex_property_type< vtkUndirectedGraph* > { };
 
   // Internal vertex properties
   template<>
-  struct vertex_property_type< vtkMutableUndirectedGraph* const > 
+  struct vertex_property_type< vtkMutableUndirectedGraph* const >
     : vertex_property_type< vtkUndirectedGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkMutableUndirectedGraph* > 
+  struct edge_property_type< vtkMutableUndirectedGraph* >
     : edge_property_type< vtkUndirectedGraph* > { };
 
   // Internal edge properties
   template<>
-  struct edge_property_type< vtkMutableUndirectedGraph* const > 
+  struct edge_property_type< vtkMutableUndirectedGraph* const >
     : edge_property_type< vtkUndirectedGraph* > { };
 
+#if BOOST_VERSION >= 104500
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkMutableUndirectedGraph* >
+    : graph_bundle_type< vtkUndirectedGraph* > { };
+
+  // Internal graph properties
+  template<>
+  struct graph_bundle_type< vtkMutableUndirectedGraph* const >
+    : graph_bundle_type< vtkUndirectedGraph* > { };
+#endif
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkMutableUndirectedGraph* >
+    : vertex_bundle_type< vtkUndirectedGraph* > { };
+
+  // Internal vertex properties
+  template<>
+  struct vertex_bundle_type< vtkMutableUndirectedGraph* const >
+    : vertex_bundle_type< vtkUndirectedGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkMutableUndirectedGraph* >
+    : edge_bundle_type< vtkUndirectedGraph* > { };
+
+  // Internal edge properties
+  template<>
+  struct edge_bundle_type< vtkMutableUndirectedGraph* const >
+    : edge_bundle_type< vtkUndirectedGraph* > { };
+
   //===========================================================================
   // API implementation
   template <>
@@ -607,25 +826,25 @@ target(boost::graph_traits< vtkGraph* >::edge_descriptor e,
 
 inline vtksys_stl::pair<
   boost::graph_traits< vtkGraph* >::vertex_iterator,
-  boost::graph_traits< vtkGraph* >::vertex_iterator >  
+  boost::graph_traits< vtkGraph* >::vertex_iterator >
 vertices(vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::vertex_iterator Iter;
   vtkIdType start = 0;
   if (vtkDistributedGraphHelper *helper = g->GetDistributedGraphHelper())
     {
-    int rank = 
+    int rank =
       g->GetInformation()->Get(vtkDataObject::DATA_PIECE_NUMBER());
     start = helper->MakeDistributedId(rank, start);
     }
 
-  return vtksys_stl::make_pair( Iter(start), 
+  return vtksys_stl::make_pair( Iter(start),
                                 Iter(start + g->GetNumberOfVertices()) );
 }
 
 inline vtksys_stl::pair<
   boost::graph_traits< vtkGraph* >::edge_iterator,
-  boost::graph_traits< vtkGraph* >::edge_iterator >  
+  boost::graph_traits< vtkGraph* >::edge_iterator >
 edges(vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::edge_iterator Iter;
@@ -634,9 +853,9 @@ edges(vtkGraph *g)
 
 inline vtksys_stl::pair<
   boost::graph_traits< vtkGraph* >::out_edge_iterator,
-  boost::graph_traits< vtkGraph* >::out_edge_iterator >  
+  boost::graph_traits< vtkGraph* >::out_edge_iterator >
 out_edges(
-  boost::graph_traits< vtkGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkGraph* >::vertex_descriptor u,
   vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::out_edge_iterator Iter;
@@ -646,9 +865,9 @@ out_edges(
 
 inline vtksys_stl::pair<
   boost::graph_traits< vtkGraph* >::in_edge_iterator,
-  boost::graph_traits< vtkGraph* >::in_edge_iterator >  
+  boost::graph_traits< vtkGraph* >::in_edge_iterator >
 in_edges(
-  boost::graph_traits< vtkGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkGraph* >::vertex_descriptor u,
   vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::in_edge_iterator Iter;
@@ -660,7 +879,7 @@ inline vtksys_stl::pair<
   boost::graph_traits< vtkGraph* >::adjacency_iterator,
   boost::graph_traits< vtkGraph* >::adjacency_iterator >
 adjacent_vertices(
-  boost::graph_traits< vtkGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkGraph* >::vertex_descriptor u,
   vtkGraph *g)
 {
   typedef boost::graph_traits< vtkGraph* >::adjacency_iterator Iter;
@@ -679,11 +898,11 @@ inline boost::graph_traits< vtkGraph* >::edges_size_type
 num_edges(vtkGraph *g)
 {
   return g->GetNumberOfEdges();
-}  
+}
 
 inline boost::graph_traits< vtkGraph* >::degree_size_type
 out_degree(
-  boost::graph_traits< vtkGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkGraph* >::vertex_descriptor u,
   vtkGraph *g)
 {
   return g->GetOutDegree(u);
@@ -691,7 +910,7 @@ out_degree(
 
 inline boost::graph_traits< vtkDirectedGraph* >::degree_size_type
 in_degree(
-  boost::graph_traits< vtkDirectedGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkDirectedGraph* >::vertex_descriptor u,
   vtkDirectedGraph *g)
 {
   return g->GetInDegree(u);
@@ -699,7 +918,7 @@ in_degree(
 
 inline boost::graph_traits< vtkGraph* >::degree_size_type
 degree(
-  boost::graph_traits< vtkGraph* >::vertex_descriptor u, 
+  boost::graph_traits< vtkGraph* >::vertex_descriptor u,
   vtkGraph *g)
 {
   return g->GetDegree(u);
@@ -759,7 +978,7 @@ namespace boost {
 
   inline property_traits<vtkGraphEdgeMap>::reference
   get(
-    vtkGraphEdgeMap vtkNotUsed(arr), 
+    vtkGraphEdgeMap vtkNotUsed(arr),
     property_traits<vtkGraphEdgeMap>::key_type key)
   {
     return key.Id;
@@ -788,7 +1007,7 @@ namespace boost {
     vtkEdgeType key)
   {
     return get(helper.pmap, key.Id);
-  } 
+  }
 
   template<typename PMap>
   inline void
@@ -817,12 +1036,12 @@ namespace boost {
 
   inline property_traits<vtkGraphIndexMap>::reference
   get(
-    vtkGraphIndexMap vtkNotUsed(arr), 
+    vtkGraphIndexMap vtkNotUsed(arr),
     property_traits<vtkGraphIndexMap>::key_type key)
   {
     return key;
   }
-  
+
   //===========================================================================
   // Helper for vtkGraph property maps
   // Automatically multiplies the property value by some value (default 1)
@@ -846,7 +1065,7 @@ namespace boost {
     const typename property_traits<PMap>::key_type key)
   {
     return multi.multiplier * get(multi.pmap, key);
-  } 
+  }
 
   template<typename PMap>
   inline void
@@ -910,8 +1129,13 @@ namespace boost {
   template<>
   struct property_map<vtkUndirectedGraph* const, edge_index_t>
     : property_map<vtkUndirectedGraph*, edge_index_t> { };
-
 } // namespace boost
 
+#if BOOST_VERSION > 104000
+#include <boost/property_map/vector_property_map.hpp>
+#else
+#include <boost/vector_property_map.hpp>
+#endif
+
 
 #endif // __vtkBoostGraphAdapter_h
