@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkDescriptiveStatistics.h,v $
+Module:    vtkDescriptiveStatistics.h
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -13,7 +13,7 @@ PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
 /*-------------------------------------------------------------------------
-  Copyright 2008 Sandia Corporation.
+  Copyright 2010 Sandia Corporation.
   Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
   the U.S. Government retains certain rights in this software.
   -------------------------------------------------------------------------*/
@@ -21,19 +21,22 @@ PURPOSE.  See the above copyright notice for more information.
 //
 // .SECTION Description
 // Given a selection of columns of interest in an input data table, this 
-// class provides the following functionalities, depending on the
-// execution mode it is executed in:
-// * Learn: calculate extremal values, arithmetic mean, unbiased variance 
-//   estimator, skewness estimator, and both sample and G2 estimation of the 
-//   kurtosis excess. More precisely, Learn calculates the sums; if
-//   \p finalize is set to true (default), the final statistics are calculated
-//   with CalculateFromSums. Otherwise, only raw sums are output; this 
-//   option is made for efficient parallel calculations.
-//   Note that CalculateFromSums is a static function, so that it can be used
-//   directly with no need to instantiate a vtkDescriptiveStatistics object.
-// * Assess: given an input data set in port INPUT_DATA, and a reference value x along
-//   with an acceptable deviation d>0, assess all entries in the data set which
-//   are outside of [x-d,x+d].
+// class provides the following functionalities, depending on the chosen
+// execution options:
+// * Learn: calculate extremal values, sample mean, and M2, M3, and M4 aggregates
+//   (cf. P. Pebay, Formulas for robust, one-pass parallel computation of covariances
+//   and Arbitrary-Order Statistical Moments, Sandia Report SAND2008-6212, Sep 2008,
+//   http://infoserve.sandia.gov/sand_doc/2008/086212.pdf for details)
+// * Derive: calculate unbiased variance estimator, standard deviation estimator,
+//   two skewness estimators, and two kurtosis excess estimators.
+// * Assess: given an input data set, a reference value and a non-negative deviation,
+//   mark each datum with corresponding relative deviation (1-dimensional Mahlanobis
+//   distance). If the deviation is zero, then mark each datum which are equal to the
+//   reference value with 0, and all others with 1. By default, the reference value
+//   and the deviation are, respectively, the mean and the standard deviation of the
+//   input model.
+// * Test: calculate Jarque-Bera statistic and, if VTK to R interface is available,
+//   retrieve corresponding p-value for normality testing.
 //
 // .SECTION Thanks
 // Thanks to Philippe Pebay and David Thompson from Sandia National Laboratories 
@@ -44,6 +47,7 @@ PURPOSE.  See the above copyright notice for more information.
 
 #include "vtkUnivariateStatisticsAlgorithm.h"
 
+class vtkMultiBlockDataSet;
 class vtkStringArray;
 class vtkTable;
 class vtkVariant;
@@ -51,7 +55,7 @@ class vtkVariant;
 class VTK_INFOVIS_EXPORT vtkDescriptiveStatistics : public vtkUnivariateStatisticsAlgorithm
 {
 public:
-  vtkTypeRevisionMacro(vtkDescriptiveStatistics, vtkUnivariateStatisticsAlgorithm);
+  vtkTypeMacro(vtkDescriptiveStatistics, vtkUnivariateStatisticsAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
   static vtkDescriptiveStatistics* New();
 
@@ -63,6 +67,22 @@ public:
   vtkGetMacro(UnbiasedVariance,int);
   vtkBooleanMacro(UnbiasedVariance,int);
 
+  // Description:
+  // Set/get whether the G1 estimator for the skewness should be used, or if
+  // the g1 skewness will be calculated.
+  // The default is that the g1 skewness estimator will be used.
+  vtkSetMacro(G1Skewness,int);
+  vtkGetMacro(G1Skewness,int);
+  vtkBooleanMacro(G1Skewness,int);
+
+  // Description:
+  // Set/get whether the G2 estimator for the kurtosis should be used, or if
+  // the g2 kurtosis will be calculated.
+  // The default is that the g2 kurtosis estimator will be used.
+  vtkSetMacro(G2Kurtosis,int);
+  vtkGetMacro(G2Kurtosis,int);
+  vtkBooleanMacro(G2Kurtosis,int);
+
   // Description:
   // Set/get whether the deviations returned should be signed, or should
   // only have their magnitude reported.
@@ -84,7 +104,7 @@ public:
   // Description:
   // Given a collection of models, calculate aggregate model
   virtual void Aggregate( vtkDataObjectCollection*,
-                          vtkDataObject* );
+                          vtkMultiBlockDataSet* );
 
 protected:
   vtkDescriptiveStatistics();
@@ -95,19 +115,21 @@ protected:
   // NB: input parameters are unused.
   virtual void Learn( vtkTable* inData,
                       vtkTable* inParameters,
-                      vtkDataObject* outMeta );
+                      vtkMultiBlockDataSet* outMeta );
 
   // Description:
   // Execute the calculations required by the Derive option.
-  virtual void Derive( vtkDataObject* );
+  virtual void Derive( vtkMultiBlockDataSet* );
 
   // Description:
   // Execute the calculations required by the Test option.
   virtual void Test( vtkTable* inData,
-                     vtkDataObject* inMeta,
-                     vtkDataObject* outMeta ); 
+                     vtkMultiBlockDataSet* inMeta,
+                     vtkTable* outMeta ); 
 
   int UnbiasedVariance;
+  int G1Skewness;
+  int G2Kurtosis;
   int SignedDeviations;
 
 //BTX  
