@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGraphHierarchicalBundle.cxx,v $
+  Module:    vtkGraphHierarchicalBundle.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -58,7 +58,6 @@ static vtkVariant vtkGetVariantValue(vtkAbstractArray* arr, vtkIdType i)
 }
 
 
-vtkCxxRevisionMacro(vtkGraphHierarchicalBundle, "$Revision: 1.12 $");
 vtkStandardNewMacro(vtkGraphHierarchicalBundle);
 
 vtkGraphHierarchicalBundle::vtkGraphHierarchicalBundle()
@@ -93,7 +92,7 @@ int vtkGraphHierarchicalBundle::RequestData(
   vtkInformation *treeInfo = inputVector[1]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkGraph *graph = vtkGraph::SafeDownCast(
     graphInfo->Get(vtkDataObject::DATA_OBJECT()));
   vtkTree *tree = vtkTree::SafeDownCast(
