@@ -2,6 +2,7 @@
 #include "vtkMultiCorrelativeStatisticsAssessFunctor.h"
 
 #include "vtkDataObject.h"
+#include "vtkDataObjectCollection.h"
 #include "vtkDoubleArray.h"
 #include "vtkInformation.h"
 #include "vtkMultiBlockDataSet.h"
@@ -11,8 +12,8 @@
 #include "vtkTable.h"
 #include "vtkVariantArray.h"
 
-#include <vtkstd/map>
-#include <vtkstd/vector>
+#include <vtksys/stl/map>
+#include <vtksys/stl/vector>
 #include <vtksys/ios/sstream>
 
 #define VTK_MULTICORRELATIVE_KEYCOLUMN1 "Column1"
@@ -21,7 +22,6 @@
 #define VTK_MULTICORRELATIVE_AVERAGECOL "Mean"
 #define VTK_MULTICORRELATIVE_COLUMNAMES "Column"
 
-vtkCxxRevisionMacro(vtkMultiCorrelativeStatistics,"$Revision: 1.10 $");
 vtkStandardNewMacro(vtkMultiCorrelativeStatistics);
 
 // ----------------------------------------------------------------------
@@ -43,7 +43,7 @@ void vtkMultiCorrelativeStatistics::PrintSelf( ostream& os, vtkIndent indent )
 }
 
 // ----------------------------------------------------------------------
-void vtkMultiCorrelativeInvertCholesky( vtkstd::vector<double*>& chol, vtkstd::vector<double>& inv )
+void vtkMultiCorrelativeInvertCholesky( vtksys_stl::vector<double*>& chol, vtksys_stl::vector<double>& inv )
 {
   vtkIdType m = static_cast<vtkIdType>( chol.size() );
   inv.resize( m * ( m + 1 ) / 2 );
@@ -72,9 +72,9 @@ void vtkMultiCorrelativeInvertCholesky( vtkstd::vector<double*>& chol, vtkstd::v
 }
 
 // ----------------------------------------------------------------------
-void vtkMultiCorrelativeTransposeTriangular( vtkstd::vector<double>& a, vtkIdType m )
+void vtkMultiCorrelativeTransposeTriangular( vtksys_stl::vector<double>& a, vtkIdType m )
 {
-  vtkstd::vector<double> b( a.begin(), a.end() );
+  vtksys_stl::vector<double> b( a.begin(), a.end() );
   double* bp = &b[0];
   vtkIdType i, j;
   a.clear();
@@ -101,83 +101,6 @@ void vtkMultiCorrelativeTransposeTriangular( vtkstd::vector<double>& a, vtkIdTyp
   //                                 J                            G H I J
 }
 
-// ======================================================== vtkMultiCorrelativeAssessFunctor
-vtkMultiCorrelativeAssessFunctor* vtkMultiCorrelativeAssessFunctor::New()
-{
-  return new vtkMultiCorrelativeAssessFunctor;
-}
-
-bool vtkMultiCorrelativeAssessFunctor::Initialize( vtkTable* inData, vtkTable* reqModel, bool cholesky )
-{
-  vtkDoubleArray* avgs = vtkDoubleArray::SafeDownCast( reqModel->GetColumnByName( VTK_MULTICORRELATIVE_AVERAGECOL ) );
-  if ( ! avgs )
-    {
-    vtkGenericWarningMacro( "Multicorrelative request without a \"" VTK_MULTICORRELATIVE_AVERAGECOL "\" column" );
-    return false;
-    }
-  vtkStringArray* name = vtkStringArray::SafeDownCast( reqModel->GetColumnByName( VTK_MULTICORRELATIVE_COLUMNAMES ) );
-  if ( ! name )
-    {
-    vtkGenericWarningMacro( "Multicorrelative request without a \"" VTK_MULTICORRELATIVE_COLUMNAMES "\" column" );
-    return false;
-    }
-
-  vtkstd::vector<vtkDataArray*> cols; // input data columns
-  vtkstd::vector<double*> chol; // Cholesky matrix columns. Only the lower triangle is significant.
-  vtkIdType m = reqModel->GetNumberOfColumns() - 2;
-  vtkIdType i;
-  for ( i = 0; i < m ; ++ i )
-    {
-    vtkStdString colname( name->GetValue( i ) );
-    vtkDataArray* arr = vtkDataArray::SafeDownCast( inData->GetColumnByName( colname.c_str() ) );
-    if ( ! arr )
-      {
-      vtkGenericWarningMacro( "Multicorrelative input data needs a \"" << colname.c_str() << "\" column" );
-      return false;
-      }
-    cols.push_back( arr );
-    vtkDoubleArray* dar = vtkDoubleArray::SafeDownCast( reqModel->GetColumnByName( colname.c_str() ) );
-    if ( ! dar )
-      {
-      vtkGenericWarningMacro( "Multicorrelative request needs a \"" << colname.c_str() << "\" column" );
-      return false;
-      }
-    chol.push_back( dar->GetPointer( 1 ) );
-    }
-
-  // OK, if we made it this far, we will succeed
-  this->Columns = cols;
-  this->Center = avgs->GetPointer( 0 );
-  this->Tuple.resize( m );
-  this->EmptyTuple = vtkstd::vector<double>( m, 0. );
-  if ( cholesky )
-    {
-    vtkMultiCorrelativeInvertCholesky( chol, this->Factor ); // store the inverse of chol in this->Factor, F
-    vtkMultiCorrelativeTransposeTriangular( this->Factor, m ); // transposing F makes it easier to use in the () operator.
-    }
-#if 0
-  // Compute the normalization factor to turn X * F * F' * X' into a cumulance.
-  if ( m % 2 == 0 )
-    {
-    this->Normalization = 1.0;
-    for ( i = m / 2 - 1; i > 1; -- i )
-      {
-      this->Normalization *= i;
-      }
-    }
-  else
-    {
-    this->Normalization = sqrt( 3.141592653589793 ) / ( 1 << ( m / 2 ) );
-    for ( i = m - 2; i > 1; i -= 2 )
-      {
-      this->Normalization *= i;
-      }
-    }
-#endif // 0
-
-  return true;
-}
-
 // ----------------------------------------------------------------------
 void vtkMultiCorrelativeAssessFunctor::operator () ( vtkVariantArray* result, vtkIdType row )
 {
@@ -211,56 +134,172 @@ void vtkMultiCorrelativeAssessFunctor::operator () ( vtkVariantArray* result, vt
 }
 
 // ----------------------------------------------------------------------
-int vtkMultiCorrelativeStatistics::FillInputPortInformation( int port, vtkInformation* info )
+void vtkMultiCorrelativeStatistics::Aggregate( vtkDataObjectCollection* inMetaColl,
+                                               vtkMultiBlockDataSet* outMeta )
 {
-  // Override the parent class for port 1 (Learn)
-  int stat; // = this->Superclass::FillInputPortInformation( port, info );
-  if ( port == 1 )
-    {
-    info->Set( vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkMultiBlockDataSet" );
-    info->Set( vtkAlgorithm::INPUT_IS_OPTIONAL(), 1 );
-    stat = 1;
+  if ( ! outMeta ) 
+    { 
+    return; 
+    } 
+
+  // Get hold of the first model (data object) in the collection
+  vtkCollectionSimpleIterator it;
+  inMetaColl->InitTraversal( it );
+  vtkDataObject *inMetaDO = inMetaColl->GetNextDataObject( it );
+
+  // Verify that the first input model is indeed contained in a multiblock data set
+  vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
+  if ( ! inMeta ) 
+    { 
+    return; 
     }
-  else
+
+  // Verify that the first covariance matrix is indeed contained in a table
+  vtkTable* inCov = vtkTable::SafeDownCast( inMeta->GetBlock( 0 ) );
+  if ( ! inCov )
     {
-    stat = this->Superclass::FillInputPortInformation( port, info );
+    return;
     }
-  return stat;
+
+  vtkIdType nRow = inCov->GetNumberOfRows();
+  if ( ! nRow )
+    {
+    // No statistics were calculated.
+    return;
+    }
+
+  // Use this first model to initialize the aggregated one
+  vtkTable* outCov = vtkTable::New();
+  outCov->DeepCopy( inCov );
+
+  // Now, loop over all remaining models and update aggregated each time
+  while ( ( inMetaDO = inMetaColl->GetNextDataObject( it ) ) )
+    {
+    // Verify that the current model is indeed contained in a multiblock data set
+    inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
+    if ( ! inMeta ) 
+      {
+      outCov->Delete();
+
+      return; 
+      }
+
+    // Verify that the current covariance matrix is indeed contained in a table
+    inCov = vtkTable::SafeDownCast( inMeta->GetBlock( 0 ) );
+    if ( ! inCov )
+      {
+      outCov->Delete();
+
+      return;
+      }
+
+    if ( inCov->GetNumberOfRows() != nRow )
+      {
+      // Models do not match
+      outCov->Delete();
+
+      return;
+      }
+
+    // Iterate over all model rows
+    int inN, outN;
+    double muFactor = 0.;
+    double covFactor = 0.;
+    vtkstd::vector<double> inMu, outMu;
+    int j = 0;
+    int k = 0;
+    for ( int r = 0; r < nRow; ++ r )
+      {
+      // Verify that variable names match each other
+      if ( inCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN1 ) != outCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN1 )
+           || inCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN2 ) != outCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN2 ) )
+        {
+        // Models do not match
+        outCov->Delete();
+
+        return;
+        }
+
+      // Update each model parameter
+      if ( inCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN1 ).ToString() == "Cardinality" )
+        {
+        // Cardinality
+        inN = inCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToInt();
+        outN = outCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToInt();
+        int totN = inN + outN;
+        outCov->SetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL, totN );
+        muFactor = static_cast<double>( inN ) / totN;
+        covFactor = static_cast<double>( inN ) * outN / totN;
+        }
+      else if ( inCov->GetValueByName( r, VTK_MULTICORRELATIVE_KEYCOLUMN2 ).ToString() == "" )
+        {
+        // Mean
+        inMu.push_back( inCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToDouble() );
+        outMu.push_back( outCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToDouble() );
+        outCov->SetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL, outMu.back() + ( inMu.back() - outMu.back() ) * muFactor );
+        }
+      else
+        {
+        // M XY
+        double inCovEntry = inCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToDouble();
+        double outCovEntry = outCov->GetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL ).ToDouble();
+        outCov->SetValueByName( r, VTK_MULTICORRELATIVE_ENTRIESCOL, inCovEntry + outCovEntry + ( inMu[j] - outMu[j] ) * ( inMu[k] - outMu[k] ) * covFactor );
+        ++ k;
+        if ( k > j )
+          {
+          ++ j;
+          k = 0;
+          }
+        }
+      }
+    }
+  
+  // Replace covariance block of output model with updated one
+  outMeta->SetBlock( 0, outCov );
+
+  // Clean up
+  outCov->Delete();
 }
 
 // ----------------------------------------------------------------------
-int vtkMultiCorrelativeStatistics::FillOutputPortInformation( int port, vtkInformation* info )
+void vtkMultiCorrelativeStatistics::Learn( vtkTable* inData, 
+                                           vtkTable* vtkNotUsed( inParameters ),
+                                           vtkMultiBlockDataSet* outMeta )
 {
-  // Override the parent class for port 1 (Learn)
-  int stat = this->Superclass::FillOutputPortInformation( port, info );
-  if ( port == 1 )
+  if ( ! inData )
     {
-    info->Set( vtkDataObject::DATA_TYPE_NAME(), "vtkMultiBlockDataSet" );
+    return;
     }
-  return stat;
-}
 
-// ----------------------------------------------------------------------
-void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData, 
-                                                  vtkDataObject* outMetaDO )
-{
-  vtkMultiBlockDataSet* outMeta = vtkMultiBlockDataSet::SafeDownCast( outMetaDO );
   if ( ! outMeta )
     {
     return;
     }
 
-  vtkstd::set<vtkstd::set<vtkStdString> >::iterator reqIt;
-  vtkstd::set<vtkStdString>::iterator colIt;
-  vtkstd::set<vtkstd::pair<vtkStdString,vtkDataArray*> > allColumns;
-  vtkstd::map<vtkstd::pair<vtkIdType,vtkIdType>,vtkIdType> colPairs;
-  vtkstd::map<vtkstd::pair<vtkIdType,vtkIdType>,vtkIdType>::iterator cpIt;
-  vtkstd::map<vtkStdString,vtkIdType> colNameToIdx;
-  vtkstd::vector<vtkDataArray*> colPtrs;
+  vtkTable* sparseCov = vtkTable::New();
+
   vtkStringArray* ocol1 = vtkStringArray::New();
-  vtkStringArray* ocol2 = vtkStringArray::New();
   ocol1->SetName( VTK_MULTICORRELATIVE_KEYCOLUMN1 );
+  sparseCov->AddColumn( ocol1 );
+  ocol1->Delete();
+
+  vtkStringArray* ocol2 = vtkStringArray::New();
   ocol2->SetName( VTK_MULTICORRELATIVE_KEYCOLUMN2 );
+  sparseCov->AddColumn( ocol2 );
+  ocol2->Delete();
+
+  vtkDoubleArray* mucov = vtkDoubleArray::New();
+  mucov->SetName( VTK_MULTICORRELATIVE_ENTRIESCOL );
+  sparseCov->AddColumn( mucov );
+  mucov->Delete();
+
+  vtksys_stl::set<vtksys_stl::set<vtkStdString> >::const_iterator reqIt;
+  vtksys_stl::set<vtkStdString>::const_iterator colIt;
+  vtksys_stl::set<vtksys_stl::pair<vtkStdString,vtkDataArray*> > allColumns;
+  vtksys_stl::map<vtksys_stl::pair<vtkIdType,vtkIdType>,vtkIdType> colPairs;
+  vtksys_stl::map<vtksys_stl::pair<vtkIdType,vtkIdType>,vtkIdType>::iterator cpIt;
+  vtksys_stl::map<vtkStdString,vtkIdType> colNameToIdx;
+  vtksys_stl::vector<vtkDataArray*> colPtrs;
 
   // Populate a vector with pointers to columns of interest (i.e., columns from the input dataset
   // which have some statistics requested) and create a map from column names into this vector.
@@ -273,14 +312,14 @@ void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData,
       vtkDataArray* arr = vtkDataArray::SafeDownCast( inData->GetColumnByName( colIt->c_str() ) );
       if ( arr )
         {
-        allColumns.insert( vtkstd::pair<vtkStdString,vtkDataArray*>( *colIt, arr ) );
+        allColumns.insert( vtksys_stl::pair<vtkStdString,vtkDataArray*>( *colIt, arr ) );
         }
       }
     }
   // Now make a map from input column name to output column index (colNameToIdx):
   vtkIdType i = 0;
   vtkIdType m = static_cast<vtkIdType>( allColumns.size() );
-  vtkstd::set<vtkstd::pair<vtkStdString,vtkDataArray*> >::iterator acIt;
+  vtksys_stl::set<vtksys_stl::pair<vtkStdString,vtkDataArray*> >::const_iterator acIt;
   vtkStdString empty;
   ocol1->InsertNextValue( "Cardinality" );
   ocol2->InsertNextValue( empty );
@@ -296,26 +335,28 @@ void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData,
   // This keeps us from computing the same covariance entry multiple times if several requests
   // contain common pairs of columns.
   i = m;
-  // For each request:
+
+  // Loop over requests
+  vtkIdType nRow = inData->GetNumberOfRows();
   for ( reqIt = this->Internals->Requests.begin(); reqIt != this->Internals->Requests.end(); ++ reqIt )
     {
     // For each column in the request:
     for ( colIt = reqIt->begin(); colIt != reqIt->end(); ++ colIt )
       {
-      vtkstd::map<vtkStdString,vtkIdType>::iterator idxIt = colNameToIdx.find( *colIt );
+      vtksys_stl::map<vtkStdString,vtkIdType>::iterator idxIt = colNameToIdx.find( *colIt );
       // Ignore invalid column names
       if ( idxIt != colNameToIdx.end() )
         {
         vtkIdType colA = idxIt->second;
         vtkStdString colAName = idxIt->first;
-        vtkstd::set<vtkStdString>::iterator colIt2;
+        vtksys_stl::set<vtkStdString>::const_iterator colIt2;
         for ( colIt2 = colIt; colIt2 != reqIt->end(); ++ colIt2 )
           {
           idxIt = colNameToIdx.find( *colIt2 );
           // Ignore invalid column names
           if ( idxIt != colNameToIdx.end() )
             { // Note that other requests may have inserted this entry.
-            vtkstd::pair<vtkIdType,vtkIdType> entry( colA, idxIt->second );
+            vtksys_stl::pair<vtkIdType,vtkIdType> entry( colA, idxIt->second );
             if ( colPairs.find( entry ) == colPairs.end() )
               { // point to the offset in mucov (below) for this column-pair sum:
               //cout << "Pair (" << colAName.c_str() << ", " << idxIt->first.c_str() << "): " << colPairs[entry] << "\n";
@@ -338,18 +379,15 @@ void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData,
   // Now (finally!) compute the covariance and column sums.
   // This uses the on-line algorithms for computing centered
   // moments and covariances from Philippe's SAND2008-6212 report.
-  vtkIdType n = inData->GetNumberOfRows();
   double* x;
-  vtkstd::vector<double> v( m, 0. ); // Values (v) for one observation
-  //vtkstd::vector<double> mucov( m + colPairs.size(), 0. ); // mean (mu) followed by covariance (cov) values
-  vtkDoubleArray* mucov = vtkDoubleArray::New();
-  mucov->SetName( VTK_MULTICORRELATIVE_ENTRIESCOL );
+  vtksys_stl::vector<double> v( m, 0. ); // Values (v) for one observation
+  //vtksys_stl::vector<double> mucov( m + colPairs.size(), 0. ); // mean (mu) followed by covariance (cov) values
   mucov->SetNumberOfTuples( 1 + m + colPairs.size() ); // sample size followed by mean (mu) followed by covariance (cov) values
   mucov->FillComponent( 0, 0. );
   double* rv = mucov->GetPointer( 0 );
-  *rv = static_cast<double>( n );
+  *rv = static_cast<double>( nRow );
   ++ rv; // skip Cardinality entry
-  for ( i = 0; i < n; ++ i )
+  for ( i = 0; i < nRow; ++ i )
     {
     // First fetch column values
     for ( vtkIdType j = 0; j < m; ++ j )
@@ -377,13 +415,6 @@ void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData,
       }
     }
 
-  vtkTable* sparseCov = vtkTable::New();
-  sparseCov->AddColumn( ocol1 );
-  sparseCov->AddColumn( ocol2 );
-  sparseCov->AddColumn( mucov );
-  ocol1->Delete();
-  ocol2->Delete();
-  mucov->Delete();
   outMeta->SetNumberOfBlocks( 1 );
   outMeta->SetBlock( 0, sparseCov );
   outMeta->GetMetaData( static_cast<unsigned>( 0 ) )->Set( vtkCompositeDataSet::NAME(), "Raw Sparse Covariance Data" );
@@ -391,7 +422,7 @@ void vtkMultiCorrelativeStatistics::ExecuteLearn( vtkTable* inData,
 }
 
 // ----------------------------------------------------------------------
-void vtkMultiCorrelativeCholesky( vtkstd::vector<double*>& a, vtkIdType m )
+void vtkMultiCorrelativeCholesky( vtksys_stl::vector<double*>& a, vtkIdType m )
 {
   // Some macros to make the Cholevsky decomposition algorithm legible:
 #ifdef A
@@ -426,15 +457,14 @@ void vtkMultiCorrelativeCholesky( vtkstd::vector<double*>& a, vtkIdType m )
 }
 
 // ----------------------------------------------------------------------
-void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
+void vtkMultiCorrelativeStatistics::Derive( vtkMultiBlockDataSet* outMeta )
 {
-  vtkMultiBlockDataSet* outMeta = vtkMultiBlockDataSet::SafeDownCast( outMetaDO );
   vtkTable* sparseCov;
   vtkStringArray* ocol1;
   vtkStringArray* ocol2;
   vtkDoubleArray* mucov;
   if (
-    ! outMeta || outMeta->GetNumberOfBlocks() < 1 ||
+    ! outMeta ||
     ! ( sparseCov = vtkTable::SafeDownCast( outMeta->GetBlock( 0 ) ) ) ||
     ! ( ocol1 = vtkStringArray::SafeDownCast( sparseCov->GetColumnByName( VTK_MULTICORRELATIVE_KEYCOLUMN1 ) ) ) ||
     ! ( ocol2 = vtkStringArray::SafeDownCast( sparseCov->GetColumnByName( VTK_MULTICORRELATIVE_KEYCOLUMN2 ) ) ) ||
@@ -444,13 +474,13 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
     return;
     }
 
-  vtkstd::set<vtkstd::set<vtkStdString> >::iterator reqIt;
-  vtkstd::set<vtkStdString>::iterator colIt;
-  vtkstd::set<vtkstd::pair<vtkStdString,vtkDataArray*> > allColumns;
-  vtkstd::map<vtkstd::pair<vtkIdType,vtkIdType>,vtkIdType> colPairs;
-  vtkstd::map<vtkstd::pair<vtkIdType,vtkIdType>,vtkIdType>::iterator cpIt;
-  vtkstd::map<vtkStdString,vtkIdType> colNameToIdx;
-  vtkstd::vector<vtkDataArray*> colPtrs;
+  vtksys_stl::set<vtksys_stl::set<vtkStdString> >::const_iterator reqIt;
+  vtksys_stl::set<vtkStdString>::const_iterator colIt;
+  vtksys_stl::set<vtksys_stl::pair<vtkStdString,vtkDataArray*> > allColumns;
+  vtksys_stl::map<vtksys_stl::pair<vtkIdType,vtkIdType>,vtkIdType> colPairs;
+  vtksys_stl::map<vtksys_stl::pair<vtkIdType,vtkIdType>,vtkIdType>::iterator cpIt;
+  vtksys_stl::map<vtkStdString,vtkIdType> colNameToIdx;
+  vtksys_stl::vector<vtkDataArray*> colPtrs;
   // Reconstruct information about the computed sums from the raw data.
   // The first entry is always the sample size
   double n = mucov->GetValue( 0 );
@@ -463,14 +493,14 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
     }
   for ( ; i < nmucov; ++ i )
     {
-    vtkstd::pair<vtkIdType,vtkIdType> idxs( colNameToIdx[ocol1->GetValue(i)], colNameToIdx[ocol2->GetValue(i)] );
+    vtksys_stl::pair<vtkIdType,vtkIdType> idxs( colNameToIdx[ocol1->GetValue(i)], colNameToIdx[ocol2->GetValue(i)] );
     colPairs[idxs] = i - 1;
     }
   double* rv = mucov->GetPointer( 0 ) + 1;
   double* x = rv;
 
   // Create an output table for each request and fill it in using the mucov array (the first table in
-  // outMeta and which is presumed to exist upon entry to ExecuteDerive).
+  // outMeta and which is presumed to exist upon entry to Derive).
   // Note that these tables are normalized by the number of samples.
   outMeta->SetNumberOfBlocks( 1 + static_cast<int>( this->Internals->Requests.size() ) );
   // For each request:
@@ -482,15 +512,15 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
     colNames->SetName( VTK_MULTICORRELATIVE_COLUMNAMES );
     vtkDoubleArray* colAvgs = vtkDoubleArray::New();
     colAvgs->SetName( VTK_MULTICORRELATIVE_AVERAGECOL );
-    vtkstd::vector<vtkDoubleArray*> covCols;
-    vtkstd::vector<double*> covPtrs;
-    vtkstd::vector<int> covIdxs;
+    vtksys_stl::vector<vtkDoubleArray*> covCols;
+    vtksys_stl::vector<double*> covPtrs;
+    vtksys_stl::vector<int> covIdxs;
     vtksys_ios::ostringstream reqNameStr;
     reqNameStr << "Cov(";
     // For each column in the request:
     for ( colIt = reqIt->begin(); colIt != reqIt->end(); ++ colIt )
       {
-      vtkstd::map<vtkStdString,vtkIdType>::iterator idxIt = colNameToIdx.find( *colIt );
+      vtksys_stl::map<vtkStdString,vtkIdType>::iterator idxIt = colNameToIdx.find( *colIt );
       // Ignore invalid column names
       if ( idxIt != colNameToIdx.end() )
         {
@@ -528,7 +558,7 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
     colAvgs->Delete();
 
     vtkIdType j = 0;
-    for ( vtkstd::vector<vtkDoubleArray*>::iterator arrIt = covCols.begin(); arrIt != covCols.end(); ++ arrIt, ++ j )
+    for ( vtksys_stl::vector<vtkDoubleArray*>::iterator arrIt = covCols.begin(); arrIt != covCols.end(); ++ arrIt, ++ j )
       {
       (*arrIt)->SetNumberOfTuples( reqCovSize );
       (*arrIt)->FillComponent( 0, 0. );
@@ -540,7 +570,7 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
         (*arrIt)->Delete();
         for ( vtkIdType k = 0; k <= j; ++ k, ++ x )
           {
-          *x = rv[colPairs[vtkstd::pair<vtkIdType,vtkIdType>( covIdxs[k], covIdxs[j] )]] * scale;
+          *x = rv[colPairs[vtksys_stl::pair<vtkIdType,vtkIdType>( covIdxs[k], covIdxs[j] )]] * scale;
           }
         }
       else
@@ -557,24 +587,16 @@ void vtkMultiCorrelativeStatistics::ExecuteDerive( vtkDataObject* outMetaDO )
 }
 
 // ----------------------------------------------------------------------
-void vtkMultiCorrelativeStatistics::ExecuteAssess( vtkTable* inData, 
-                                                   vtkDataObject* inMetaDO, 
-                                                   vtkTable* outData, 
-                                                   vtkDataObject* vtkNotUsed(outMetaDO) )
+void vtkMultiCorrelativeStatistics::Assess( vtkTable* inData, 
+                                            vtkMultiBlockDataSet* inMeta, 
+                                            vtkTable* outData )
 {
-  vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
-  if ( ! inMeta || ! outData )
+  if ( ! inData )
     {
     return;
     }
 
-  if ( inData->GetNumberOfColumns() <= 0 )
-    {
-    return;
-    }
-
-  vtkIdType nsamples = inData->GetNumberOfRows();
-  if ( nsamples <= 0 )
+  if ( ! inMeta )
     {
     return;
     }
@@ -583,6 +605,7 @@ void vtkMultiCorrelativeStatistics::ExecuteAssess( vtkTable* inData,
   // Column names of the metadata and input data are assumed to match (no mapping using AssessNames or AssessParameters is done).
   // The output columns will be named "this->AssessNames->GetValue(0)(A,B,C)" where "A", "B", and "C" are the column names specified in the
   // per-request metadata tables.
+  vtkIdType nRow = inData->GetNumberOfRows();
   int nb = static_cast<int>( inMeta->GetNumberOfBlocks() );
   AssessFunctor* dfunc = 0;
   for ( int req = 1; req < nb; ++ req )
@@ -628,17 +651,17 @@ void vtkMultiCorrelativeStatistics::ExecuteAssess( vtkTable* inData,
         }
       assessColName << ")";
 
-      vtkVariantArray* assessValues = vtkVariantArray::New();
+      vtkDoubleArray* assessValues = vtkDoubleArray::New();
       names[v] = assessColName.str().c_str(); // Storing names to be able to use SetValueByName which is faster than SetValue
       assessValues->SetName( names[v] );
-      assessValues->SetNumberOfTuples( nsamples );
+      assessValues->SetNumberOfTuples( nRow );
       outData->AddColumn( assessValues );
       assessValues->Delete();
       }
 
     // Assess each entry of the column
     vtkVariantArray* assessResult = vtkVariantArray::New();
-    for ( vtkIdType r = 0; r < nsamples; ++ r )
+    for ( vtkIdType r = 0; r < nRow; ++ r )
       {
       (*dfunc)( assessResult, r );
       for ( int v = 0; v < nv; ++ v )
@@ -654,14 +677,92 @@ void vtkMultiCorrelativeStatistics::ExecuteAssess( vtkTable* inData,
     }
 }
 
+// ----------------------------------------------------------------------
+vtkMultiCorrelativeAssessFunctor* vtkMultiCorrelativeAssessFunctor::New()
+{
+  return new vtkMultiCorrelativeAssessFunctor;
+}
+
+// ----------------------------------------------------------------------
+bool vtkMultiCorrelativeAssessFunctor::Initialize( vtkTable* inData, 
+                                                   vtkTable* reqModel, 
+                                                   bool cholesky )
+{
+  vtkDoubleArray* avgs = vtkDoubleArray::SafeDownCast( reqModel->GetColumnByName( VTK_MULTICORRELATIVE_AVERAGECOL ) );
+  if ( ! avgs )
+    {
+    vtkGenericWarningMacro( "Multicorrelative request without a \"" VTK_MULTICORRELATIVE_AVERAGECOL "\" column" );
+    return false;
+    }
+  vtkStringArray* name = vtkStringArray::SafeDownCast( reqModel->GetColumnByName( VTK_MULTICORRELATIVE_COLUMNAMES ) );
+  if ( ! name )
+    {
+    vtkGenericWarningMacro( "Multicorrelative request without a \"" VTK_MULTICORRELATIVE_COLUMNAMES "\" column" );
+    return false;
+    }
+
+  vtksys_stl::vector<vtkDataArray*> cols; // input data columns
+  vtksys_stl::vector<double*> chol; // Cholesky matrix columns. Only the lower triangle is significant.
+  vtkIdType m = reqModel->GetNumberOfColumns() - 2;
+  vtkIdType i;
+  for ( i = 0; i < m ; ++ i )
+    {
+    vtkStdString colname( name->GetValue( i ) );
+    vtkDataArray* arr = vtkDataArray::SafeDownCast( inData->GetColumnByName( colname.c_str() ) );
+    if ( ! arr )
+      {
+      vtkGenericWarningMacro( "Multicorrelative input data needs a \"" << colname.c_str() << "\" column" );
+      return false;
+      }
+    cols.push_back( arr );
+    vtkDoubleArray* dar = vtkDoubleArray::SafeDownCast( reqModel->GetColumnByName( colname.c_str() ) );
+    if ( ! dar )
+      {
+      vtkGenericWarningMacro( "Multicorrelative request needs a \"" << colname.c_str() << "\" column" );
+      return false;
+      }
+    chol.push_back( dar->GetPointer( 1 ) );
+    }
+
+  // OK, if we made it this far, we will succeed
+  this->Columns = cols;
+  this->Center = avgs->GetPointer( 0 );
+  this->Tuple.resize( m );
+  this->EmptyTuple = vtksys_stl::vector<double>( m, 0. );
+  if ( cholesky )
+    {
+    vtkMultiCorrelativeInvertCholesky( chol, this->Factor ); // store the inverse of chol in this->Factor, F
+    vtkMultiCorrelativeTransposeTriangular( this->Factor, m ); // transposing F makes it easier to use in the () operator.
+    }
+#if 0
+  // Compute the normalization factor to turn X * F * F' * X' into a cumulance.
+  if ( m % 2 == 0 )
+    {
+    this->Normalization = 1.0;
+    for ( i = m / 2 - 1; i > 1; -- i )
+      {
+      this->Normalization *= i;
+      }
+    }
+  else
+    {
+    this->Normalization = sqrt( 3.141592653589793 ) / ( 1 << ( m / 2 ) );
+    for ( i = m - 2; i > 1; i -= 2 )
+      {
+      this->Normalization *= i;
+      }
+    }
+#endif // 0
+
+  return true;
+}
+
 // ----------------------------------------------------------------------
 void vtkMultiCorrelativeStatistics::SelectAssessFunctor( vtkTable* inData, 
                                                          vtkDataObject* inMetaDO,
                                                          vtkStringArray* vtkNotUsed(rowNames), 
                                                          AssessFunctor*& dfunc )
 {
-  (void)inData;
-
   dfunc = 0;
   vtkTable* reqModel = vtkTable::SafeDownCast( inMetaDO );
   if ( ! reqModel )
