@@ -1,10 +1,16 @@
 #include "vtkPCAStatistics.h"
 
 #include "vtkDoubleArray.h"
+#include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkMultiBlockDataSet.h"
 #include "vtkMultiCorrelativeStatisticsAssessFunctor.h"
 #include "vtkObjectFactory.h"
+#ifdef VTK_USE_GNU_R
+#include <vtkRInterface.h>
+#endif // VTK_USE_GNU_R
+#include "vtkSmartPointer.h"
+#include "vtkStringArray.h"
 #include "vtkTable.h"
 #include "vtkVariantArray.h"
 
@@ -17,13 +23,11 @@
 // To Do:
 // - Add option to pre-multiply EigenVectors by normalization coeffs
 // - In vtkPCAAssessFunctor, pre-multiply EigenVectors by normalization coeffs (if req)
-// - 
+// -
 
 #define VTK_PCA_NORMCOLUMN "PCA Cov Norm"
 #define VTK_PCA_COMPCOLUMN "PCA"
 
-
-vtkCxxRevisionMacro(vtkPCAStatistics,"$Revision: 1.12 $");
 vtkStandardNewMacro(vtkPCAStatistics);
 
 const char* vtkPCAStatistics::NormalizationSchemeEnumNames[NUM_NORMALIZATION_SCHEMES + 1] =
@@ -43,6 +47,154 @@ const char* vtkPCAStatistics::BasisSchemeEnumNames[NUM_BASIS_SCHEMES + 1] =
   "InvalidBasisScheme"
 };
 
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvalues(int request, vtkDoubleArray* eigenvalues)
+{
+  vtkSmartPointer<vtkMultiBlockDataSet> outputMetaDS =
+      vtkMultiBlockDataSet::SafeDownCast(
+        this->GetOutputDataObject( vtkStatisticsAlgorithm::OUTPUT_MODEL ) );
+
+  if(!outputMetaDS)
+    {
+    vtkErrorMacro(<<"NULL dataset pointer!");
+    }
+
+  vtkSmartPointer<vtkTable> outputMeta =
+    vtkTable::SafeDownCast( outputMetaDS->GetBlock( request + 1 ) );
+
+  if(!outputMetaDS)
+    {
+    vtkErrorMacro(<<"NULL table pointer!");
+    }
+
+  vtkDoubleArray* meanCol = vtkDoubleArray::SafeDownCast(outputMeta->GetColumnByName("Mean"));
+  vtkStringArray* rowNames = vtkStringArray::SafeDownCast(outputMeta->GetColumnByName("Column"));
+
+  eigenvalues->SetNumberOfComponents(1);
+
+  // Get values
+  int eval = 0;
+  for(vtkIdType i = 0; i < meanCol->GetNumberOfTuples(); i++)
+    {
+    std::stringstream ss;
+    ss << "PCA " << eval;
+
+    std::string rowName = rowNames->GetValue(i);
+    if(rowName.compare(ss.str()) == 0)
+      {
+      eigenvalues->InsertNextValue(meanCol->GetValue(i));
+      eval++;
+      }
+    }
+
+}
+
+// ----------------------------------------------------------------------
+double vtkPCAStatistics::GetEigenvalue(int request, int i)
+{
+  vtkSmartPointer<vtkDoubleArray> eigenvalues =
+    vtkSmartPointer<vtkDoubleArray>::New();
+  this->GetEigenvalues(request, eigenvalues);
+  return eigenvalues->GetValue(i);
+}
+
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvalues(vtkDoubleArray* eigenvalues)
+{
+  this->GetEigenvalues(0, eigenvalues);
+}
+
+// ----------------------------------------------------------------------
+double vtkPCAStatistics::GetEigenvalue(int i)
+{
+  return this->GetEigenvalue(0,i);
+}
+
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvectors(int request, vtkDoubleArray* eigenvectors)
+{
+  // Count eigenvalues
+  vtkSmartPointer<vtkDoubleArray> eigenvalues =
+    vtkSmartPointer<vtkDoubleArray>::New();
+  this->GetEigenvalues(request, eigenvalues);
+  vtkIdType numberOfEigenvalues = eigenvalues->GetNumberOfTuples();
+
+  vtkSmartPointer<vtkMultiBlockDataSet> outputMetaDS =
+      vtkMultiBlockDataSet::SafeDownCast(
+        this->GetOutputDataObject( vtkStatisticsAlgorithm::OUTPUT_MODEL ) );
+
+  if(!outputMetaDS)
+    {
+    vtkErrorMacro(<<"NULL dataset pointer!");
+    }
+
+  vtkSmartPointer<vtkTable> outputMeta =
+    vtkTable::SafeDownCast( outputMetaDS->GetBlock( request + 1 ) );
+
+  if(!outputMeta)
+    {
+    vtkErrorMacro(<<"NULL table pointer!");
+    }
+
+  vtkDoubleArray* meanCol = vtkDoubleArray::SafeDownCast(outputMeta->GetColumnByName("Mean"));
+  vtkStringArray* rowNames = vtkStringArray::SafeDownCast(outputMeta->GetColumnByName("Column"));
+
+  eigenvectors->SetNumberOfComponents(numberOfEigenvalues);
+
+  // Get vectors
+  int eval = 0;
+  for(vtkIdType i = 0; i < meanCol->GetNumberOfTuples(); i++)
+    {
+    std::stringstream ss;
+    ss << "PCA " << eval;
+
+    std::string rowName = rowNames->GetValue(i);
+    if(rowName.compare(ss.str()) == 0)
+      {
+      std::vector<double> eigenvector;
+      for(int val = 0; val < numberOfEigenvalues; val++)
+        {
+        // The first two columns will always be "Column" and "Mean", so start with the next one
+        vtkDoubleArray* currentCol = vtkDoubleArray::SafeDownCast(outputMeta->GetColumn(val+2));
+        eigenvector.push_back(currentCol->GetValue(i));
+        }
+
+      eigenvectors->InsertNextTupleValue(&eigenvector.front());
+      eval++;
+      }
+    }
+
+}
+
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvectors(vtkDoubleArray* eigenvectors)
+{
+  this->GetEigenvectors(0, eigenvectors);
+}
+
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvector(int request, int i, vtkDoubleArray* eigenvector)
+{
+  vtkSmartPointer<vtkDoubleArray> eigenvectors =
+    vtkSmartPointer<vtkDoubleArray>::New();
+  this->GetEigenvectors(request, eigenvectors);
+
+  double* evec = new double[eigenvectors->GetNumberOfComponents()];
+  eigenvectors->GetTupleValue(i, evec);
+
+  eigenvector->Reset();
+  eigenvector->Squeeze();
+  eigenvector->SetNumberOfComponents(eigenvectors->GetNumberOfComponents());
+  eigenvector->InsertNextTupleValue(evec);
+  delete evec;
+}
+
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::GetEigenvector(int i, vtkDoubleArray* eigenvector)
+{
+  this->GetEigenvector(0, i, eigenvector);
+}
+
 // ======================================================== vtkPCAAssessFunctor
 class vtkPCAAssessFunctor : public vtkMultiCorrelativeAssessFunctor
 {
@@ -62,21 +214,27 @@ public:
   vtkIdType BasisSize;
 };
 
+// ----------------------------------------------------------------------
 vtkPCAAssessFunctor* vtkPCAAssessFunctor::New()
 {
   return new vtkPCAAssessFunctor;
 }
 
-bool vtkPCAAssessFunctor::InitializePCA(
-                                        vtkTable* inData, vtkTable* reqModel,
-                                        int normScheme, int basisScheme, int fixedBasisSize, double fixedBasisEnergy )
+// ----------------------------------------------------------------------
+bool vtkPCAAssessFunctor::InitializePCA( vtkTable* inData,
+                                         vtkTable* reqModel,
+                                         int normScheme,
+                                         int basisScheme,
+                                         int fixedBasisSize,
+                                         double fixedBasisEnergy )
 {
-  if ( ! this->vtkMultiCorrelativeAssessFunctor::Initialize(
-                                                            inData, reqModel, false /* no Cholesky decomp */ ) )
+  if ( ! this->vtkMultiCorrelativeAssessFunctor::Initialize( inData,
+                                                             reqModel,
+                                                             false /* no Cholesky decomp */ ) )
     {
     return false;
     }
-  
+
   // Put the PCA basis into a matrix form we can use.
   vtkIdType m = reqModel->GetNumberOfColumns() - 2;
   vtkDoubleArray* evalm = vtkDoubleArray::SafeDownCast( reqModel->GetColumnByName( VTK_MULTICORRELATIVE_AVERAGECOL ) );
@@ -85,39 +243,41 @@ bool vtkPCAAssessFunctor::InitializePCA(
     vtkGenericWarningMacro( "No \"" VTK_MULTICORRELATIVE_AVERAGECOL "\" column in request." );
     return false;
     }
+
   // Check that the derived model includes additional rows specifying the
   // normalization as required.
   vtkIdType mrmr = reqModel->GetNumberOfRows(); // actual number of rows
   vtkIdType ermr; // expected number of rows
   switch ( normScheme )
     {
-  case vtkPCAStatistics::NONE:
-    // m+1 covariance/Cholesky rows, m eigenvector rows, no normalization factors
-    ermr = 2 * m + 1;
-    break;
-  case vtkPCAStatistics::DIAGONAL_SPECIFIED:
-  case vtkPCAStatistics::DIAGONAL_VARIANCE:
-    // m+1 covariance/Cholesky rows, m eigenvector rows, 1 normalization factor row
-    ermr = 2 * m + 2;
-    break;
-  case vtkPCAStatistics::TRIANGLE_SPECIFIED:
-    // m+1 covariance/Cholesky rows, m eigenvector rows, m normalization factor rows
-    ermr = 3 * m + 1;
-    break;
-  case vtkPCAStatistics::NUM_NORMALIZATION_SCHEMES:
-  default:
+    case vtkPCAStatistics::NONE:
+      // m+1 covariance/Cholesky rows, m eigenvector rows, no normalization factors
+      ermr = 2 * m + 1;
+      break;
+    case vtkPCAStatistics::DIAGONAL_SPECIFIED:
+    case vtkPCAStatistics::DIAGONAL_VARIANCE:
+      // m+1 covariance/Cholesky rows, m eigenvector rows, 1 normalization factor row
+      ermr = 2 * m + 2;
+      break;
+    case vtkPCAStatistics::TRIANGLE_SPECIFIED:
+      // m+1 covariance/Cholesky rows, m eigenvector rows, m normalization factor rows
+      ermr = 3 * m + 1;
+      break;
+    case vtkPCAStatistics::NUM_NORMALIZATION_SCHEMES:
+    default:
       {
       vtkGenericWarningMacro( "The normalization scheme specified (" << normScheme << ") is invalid." );
       return false;
       }
-    break;
+      break;
     }
+
   // Allow derived classes to add rows, but never allow fewer than required.
   if ( mrmr < ermr )
     {
     vtkGenericWarningMacro(
-      "Expected " << ( 2 * m + 1 ) << " or more columns in request but found "
-      << reqModel->GetNumberOfRows() << "." );
+                           "Expected " << ( 2 * m + 1 ) << " or more columns in request but found "
+                           << reqModel->GetNumberOfRows() << "." );
     return false;
     }
 
@@ -162,6 +322,7 @@ bool vtkPCAAssessFunctor::InitializePCA(
       }
       break;
     }
+
   // FIXME: Offer mode to include normalization factors (none,diag,triang)?
   // Could be done here by pre-multiplying this->EigenVectors by factors.
   for ( i = 0; i < this->BasisSize; ++ i )
@@ -176,6 +337,7 @@ bool vtkPCAAssessFunctor::InitializePCA(
   return true;
 }
 
+// ----------------------------------------------------------------------
 void vtkPCAAssessFunctor::operator () ( vtkVariantArray* result, vtkIdType row )
 {
   vtkIdType i;
@@ -334,10 +496,10 @@ int vtkPCAStatistics::FillInputPortInformation( int port, vtkInformation* info )
 }
 
 // ----------------------------------------------------------------------
-static void vtkPCAStatisticsNormalizeSpec( vtkVariantArray* normData, 
+static void vtkPCAStatisticsNormalizeSpec( vtkVariantArray* normData,
                                            ap::real_2d_array& cov,
-                                           vtkTable* normSpec, 
-                                           vtkTable* reqModel, 
+                                           vtkTable* normSpec,
+                                           vtkTable* reqModel,
                                            bool triangle )
 {
   vtkIdType i, j;
@@ -452,7 +614,7 @@ static void vtkPCAStatisticsNormalizeSpec( vtkVariantArray* normData,
 }
 
 // ----------------------------------------------------------------------
-static void vtkPCAStatisticsNormalizeVariance( vtkVariantArray* normData, 
+static void vtkPCAStatisticsNormalizeVariance( vtkVariantArray* normData,
                                                ap::real_2d_array& cov )
 {
   vtkIdType i, j;
@@ -478,15 +640,10 @@ static void vtkPCAStatisticsNormalizeVariance( vtkVariantArray* normData,
 }
 
 // ----------------------------------------------------------------------
-void vtkPCAStatistics::Derive( vtkDataObject* inMetaDO )
+void vtkPCAStatistics::Derive( vtkMultiBlockDataSet* inMeta )
 {
-  vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
   if ( ! inMeta )
     {
-    vtkWarningMacro(
-                    "Expected a vtkMultiBlockDataSet but was given "
-                    << ( inMetaDO ? inMetaDO->GetClassName() : "null pointer" )
-                    << "instead" );
     return;
     }
 
@@ -562,7 +719,7 @@ void vtkPCAStatistics::Derive( vtkDataObject* inMetaDO )
       vtksys_ios::ostringstream pcaCompName;
       pcaCompName << VTK_PCA_COMPCOLUMN << " " << i;
       row->SetValue( 0, pcaCompName.str().c_str() );
-      row->SetValue( 1, s(i) );
+      row->SetValue( 1, s( i ) );
       for ( j = 0; j < m; ++ j )
         {
         // transpose the matrix so basis is row vectors (and thus
@@ -617,23 +774,260 @@ void vtkPCAStatistics::Derive( vtkDataObject* inMetaDO )
 }
 
 // ----------------------------------------------------------------------
-void vtkPCAStatistics::Assess( vtkTable* inData, 
-                               vtkDataObject* inMetaDO, 
+void vtkPCAStatistics::Test( vtkTable* inData,
+                             vtkMultiBlockDataSet* inMeta,
+                             vtkTable* outMeta )
+
+{
+  if ( ! inMeta )
+    {
+    return;
+    }
+
+  if ( ! outMeta )
+    {
+    return;
+    }
+
+  // Prepare columns for the test:
+  // 0: (derived) model block index
+  // 1: multivariate Srivastava skewness
+  // 2: multivariate Srivastava kurtosis
+  // 3: multivariate Jarque-Bera-Srivastava statistic
+  // 4: multivariate Jarque-Bera-Srivastava p-value (calculated only if R is available, filled with -1 otherwise)
+  // 5: number of degrees of freedom of Chi square distribution
+  // NB: These are not added to the output table yet, for they will be filled individually first
+  //     in order that R be invoked only once.
+  vtkIdTypeArray* blockCol = vtkIdTypeArray::New();
+  blockCol->SetName( "Block" );
+
+  vtkDoubleArray* bS1Col = vtkDoubleArray::New();
+  bS1Col->SetName( "Srivastava Skewness" );
+
+  vtkDoubleArray* bS2Col = vtkDoubleArray::New();
+  bS2Col->SetName( "Srivastava Kurtosis" );
+
+  vtkDoubleArray* statCol = vtkDoubleArray::New();
+  statCol->SetName( "Jarque-Bera-Srivastava" );
+
+  vtkIdTypeArray* dimCol = vtkIdTypeArray::New();
+  dimCol->SetName( "d" );
+
+  // Retain data cardinality to check that models are applicable
+  vtkIdType nRowData = inData->GetNumberOfRows();
+
+  // Now iterate over model blocks
+  unsigned int nBlocks = inMeta->GetNumberOfBlocks();
+  for ( unsigned int b = 1; b < nBlocks; ++ b )
+    {
+    vtkTable* derivedTab = vtkTable::SafeDownCast( inMeta->GetBlock( b ) );
+
+    // Silenty ignore empty blocks
+    if ( ! derivedTab )
+      {
+      continue;
+      }
+
+    // Figure out dimensionality; it is assumed that the 2 first columns
+    // are what they should be: namely, Column and Mean.
+    int p = derivedTab->GetNumberOfColumns() - 2;
+
+    // Return informative message when cardinalities do not match.
+    if ( derivedTab->GetValueByName( p, "Mean" ).ToInt() != nRowData )
+      {
+      vtkWarningMacro( "Inconsistent input: input data has "
+                       << nRowData
+                       << " rows but primary model has cardinality "
+                       << derivedTab->GetValueByName( p, "Mean" ).ToInt()
+                       << " for block "
+                       << b
+                       <<". Cannot test." );
+      continue;
+      }
+
+    // Create and fill entries of name and mean vectors
+    vtkStdString *varNameX = new vtkStdString[p];
+    double *mX = new double[p];
+    for ( int i = 0; i < p; ++ i )
+      {
+      varNameX[i] = derivedTab->GetValueByName( i, "Column" ).ToString();
+      mX[i] = derivedTab->GetValueByName( i, "Mean" ).ToDouble();
+      }
+
+    // Create and fill entries of eigenvalue vector and change of basis matrix
+    double *wX = new double[p];
+    double *P = new double[p * p];
+    for ( int i = 0; i < p; ++ i )
+      {
+      // Skip p + 1 (Means and Cholesky) rows and 1 column (Column)
+      wX[i] = derivedTab->GetValue( i + p + 1, 1).ToDouble();
+
+      for ( int j = 0; j < p; ++ j )
+        {
+        // Skip p + 1 (Means and Cholesky) rows and 2 columns (Column and Mean)
+        P[p * i + j] = derivedTab->GetValue( i + p + 1, j + 2).ToDouble();
+        }
+      }
+
+    // Now iterate over all observations
+    double tmp, t;
+    double *x = new double[p];
+    double *sum3 = new double[p];
+    double *sum4 = new double[p];
+    for ( int i = 0; i < p; ++ i )
+      {
+      sum3[i] = 0.;
+      sum4[i] = 0.;
+      }
+    for ( vtkIdType r = 0; r < nRowData; ++ r )
+      {
+      // Read and center observation
+      for ( int i = 0; i < p; ++ i )
+        {
+        x[i] = inData->GetValueByName( r, varNameX[i] ).ToDouble() - mX[i];
+        }
+
+      // Now calculate skewness and kurtosis per component
+      for ( int i = 0; i < p; ++ i )
+        {
+        // Transform coordinate into eigencoordinates
+        t = 0.;
+        for ( int j = 0; j < p; ++ j )
+          {
+          // Pij = P[p*i+j]
+          t += P[p * i + j] * x[j];
+          }
+
+        // Update third and fourth order sums for each eigencoordinate
+        tmp = t * t;
+        sum3[i] += tmp * t;
+        sum4[i] += tmp * tmp;
+        }
+      }
+
+    // Finally calculate moments by normalizing sums with corresponding eigenvalues and powers
+    double bS1 = 0.;
+    double bS2 = 0.;
+    for ( int i = 0; i < p; ++ i )
+      {
+      tmp = wX[i] * wX[i];
+      bS1 += sum3[i] * sum3[i] / ( tmp * wX[i] );
+      bS2 += sum4[i] / tmp;
+      }
+    bS1 /= ( nRowData * nRowData * p );
+    bS2 /= ( nRowData * p );
+
+    // Finally, calculate Jarque-Bera-Srivastava statistic
+    tmp = bS2 - 3.;
+    double jbs = static_cast<double>( nRowData * p ) * ( bS1 / 6. + ( tmp * tmp ) / 24. );
+
+    // Insert variable name and calculated Jarque-Bera-Srivastava statistic
+    blockCol->InsertNextValue( b );
+    bS1Col->InsertNextTuple1( bS1 );
+    bS2Col->InsertNextTuple1( bS2 );
+    statCol->InsertNextTuple1( jbs );
+    dimCol->InsertNextTuple1( p + 1 );
+
+    // Clean up
+    delete [] sum3;
+    delete [] sum4;
+    delete [] x;
+    delete [] P;
+    delete [] wX;
+    delete [] mX;
+    delete [] varNameX;
+    } // b
+
+  // Now, add the already prepared columns to the output table
+  outMeta->AddColumn( blockCol );
+  outMeta->AddColumn( bS1Col );
+  outMeta->AddColumn( bS2Col );
+  outMeta->AddColumn( statCol );
+  outMeta->AddColumn( dimCol );
+
+  // Last phase: compute the p-values or assign invalid value if they cannot be computed
+  vtkDoubleArray* testCol = 0;
+  bool calculatedP = false;
+
+  // If available, use R to obtain the p-values for the Chi square distribution with 2 DOFs
+#ifdef VTK_USE_GNU_R
+  // Prepare VTK - R interface
+  vtkRInterface* ri = vtkRInterface::New();
+
+  // Use the calculated Jarque-Bera-Srivastava statistics as input to the Chi square function
+  ri->AssignVTKDataArrayToRVariable( statCol, "jbs" );
+  ri->AssignVTKDataArrayToRVariable( dimCol, "d" );
+
+  // Calculate the p-values (p+1 degrees of freedom)
+  // Now prepare R script and calculate the p-values (in a single R script evaluation for efficiency)
+  vtksys_ios::ostringstream rs;
+  rs << "p<-c();"
+     << "for(i in 1:"
+     << dimCol->GetNumberOfTuples()
+     << "){"
+     << "p<-c(p,1-pchisq(jbs[i],d[i]));"
+     << "}";
+  ri->EvalRscript( rs.str().c_str() );
+
+  // Retrieve the p-values
+  testCol = vtkDoubleArray::SafeDownCast( ri->AssignRVariableToVTKDataArray( "p" ) );
+  if ( ! testCol || testCol->GetNumberOfTuples() != statCol->GetNumberOfTuples() )
+    {
+    vtkWarningMacro( "Something went wrong with the R calculations. Reported p-values will be invalid." );
+    }
+  else
+    {
+    // Test values have been calculated by R: the test column can be added to the output table
+    outMeta->AddColumn( testCol );
+    calculatedP = true;
+    }
+
+  // Clean up
+  ri->Delete();
+#endif // VTK_USE_GNU_R
+
+  // Use the invalid value of -1 for p-values if R is absent or there was an R error
+  if ( ! calculatedP )
+    {
+    // A column must be created first
+    testCol = vtkDoubleArray::New();
+
+    // Fill this column
+    vtkIdType n = statCol->GetNumberOfTuples();
+    testCol->SetNumberOfTuples( n );
+    for ( vtkIdType r = 0; r < n; ++ r )
+      {
+      testCol->SetTuple1( r, -1 );
+      }
+
+    // Now add the column of invalid values to the output table
+    outMeta->AddColumn( testCol );
+
+    // Clean up
+    testCol->Delete();
+    }
+
+  // The test column name can only be set after the column has been obtained from R
+  testCol->SetName( "P" );
+
+  // Clean up
+  blockCol->Delete();
+  bS1Col->Delete();
+  bS2Col->Delete();
+  statCol->Delete();
+  dimCol->Delete();
+}
+// ----------------------------------------------------------------------
+void vtkPCAStatistics::Assess( vtkTable* inData,
+                               vtkMultiBlockDataSet* inMeta,
                                vtkTable* outData )
 {
-  vtkMultiBlockDataSet* inMeta = vtkMultiBlockDataSet::SafeDownCast( inMetaDO );
-  if ( ! inMeta || ! outData )
+  if ( ! inData )
     {
     return;
     }
 
-  if ( inData->GetNumberOfColumns() <= 0 )
-    {
-    return;
-    }
-
-  vtkIdType nsamples = inData->GetNumberOfRows();
-  if ( nsamples <= 0 )
+  if ( ! inMeta )
     {
     return;
     }
@@ -642,6 +1036,7 @@ void vtkPCAStatistics::Assess( vtkTable* inData,
   // Column names of the metadata and input data are assumed to match (no mapping using AssessNames or AssessParameters is done).
   // The output columns will be named "RelDevSq(A,B,C)" where "A", "B", and "C" are the column names specified in the
   // per-request metadata tables.
+  vtkIdType nRow = inData->GetNumberOfRows();
   int nb = static_cast<int>( inMeta->GetNumberOfBlocks() );
   AssessFunctor* dfunc = 0;
   for ( int req = 1; req < nb; ++ req )
@@ -652,9 +1047,9 @@ void vtkPCAStatistics::Assess( vtkTable* inData,
       continue;
       }
 
-    this->SelectAssessFunctor( inData, 
-                               reqModel, 
-                               0, 
+    this->SelectAssessFunctor( inData,
+                               reqModel,
+                               0,
                                dfunc );
 
     vtkPCAAssessFunctor* pcafunc = static_cast<vtkPCAAssessFunctor*>( dfunc );
@@ -686,7 +1081,7 @@ void vtkPCAStatistics::Assess( vtkTable* inData,
       reqNameStr << "}(" << comp << ")";
       vtkDoubleArray* arr = vtkDoubleArray::New();
       arr->SetName( reqNameStr.str().c_str() );
-      arr->SetNumberOfTuples( nsamples );
+      arr->SetNumberOfTuples( nRow );
       outData->AddColumn( arr );
       arr->Delete();
       assessValues.push_back( arr->GetPointer( 0 ) );
@@ -695,7 +1090,7 @@ void vtkPCAStatistics::Assess( vtkTable* inData,
     // Something to hold assessed values for a single input datum
     vtkVariantArray* singleResult = vtkVariantArray::New();
     // Loop over all the input data and assess each datum:
-    for ( vtkIdType row = 0; row < nsamples; ++ row )
+    for ( vtkIdType row = 0; row < nRow; ++ row )
       {
       (*dfunc)( singleResult, row );
       for ( comp = 0; comp < pcafunc->BasisSize; ++ comp )
@@ -709,9 +1104,9 @@ void vtkPCAStatistics::Assess( vtkTable* inData,
 }
 
 // ----------------------------------------------------------------------
-void vtkPCAStatistics::SelectAssessFunctor( vtkTable* inData, 
+void vtkPCAStatistics::SelectAssessFunctor( vtkTable* inData,
                                             vtkDataObject* inMetaDO,
-                                            vtkStringArray* vtkNotUsed(rowNames), 
+                                            vtkStringArray* vtkNotUsed(rowNames),
                                             AssessFunctor*& dfunc )
 {
   dfunc = 0;
@@ -732,4 +1127,3 @@ void vtkPCAStatistics::SelectAssessFunctor( vtkTable* inData,
 
   dfunc = pcafunc;
 }
-
