@@ -26,6 +26,7 @@
 
 #include "vtkCorrelativeStatistics.h"
 
+class vtkMultiBlockDataSet;
 class vtkMultiProcessController;
 
 class VTK_INFOVIS_EXPORT vtkPCorrelativeStatistics : public vtkCorrelativeStatistics
@@ -44,8 +45,8 @@ public:
   // Description:
   // Execute the parallel calculations required by the Learn option.
   virtual void Learn( vtkTable* inData,
-                             vtkTable* inParameters,
-                             vtkDataObject* outMeta );
+                      vtkTable* inParameters,
+                      vtkMultiBlockDataSet* outMeta );
 
 protected:
   vtkPCorrelativeStatistics();
