@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkDistributedStreamTracer.cxx,v $
+  Module:    vtkDistributedStreamTracer.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,7 @@
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkIntArray.h"
-#include "vtkInterpolatedVelocityField.h"
+#include "vtkAbstractInterpolatedVelocityField.h"
 #include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
@@ -31,7 +31,6 @@
 #include "vtkRungeKutta2.h"
 #include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkDistributedStreamTracer, "$Revision: 1.10 $");
 vtkStandardNewMacro(vtkDistributedStreamTracer);
 
 vtkDistributedStreamTracer::vtkDistributedStreamTracer()
@@ -261,7 +260,7 @@ int vtkDistributedStreamTracer::ProcessTask(double seed[3],
   vtkPolyData* tmpOutput = vtkPolyData::New();
   this->TmpOutputs.push_back(tmpOutput);
 
-  vtkInterpolatedVelocityField* func;
+  vtkAbstractInterpolatedVelocityField* func;
   int maxCellSize = 0;
   this->CheckInputs(func, &maxCellSize);
 
@@ -347,7 +346,7 @@ int vtkDistributedStreamTracer::ProcessTask(double seed[3],
 
   double tmpseed[3];
   memcpy(tmpseed, lastPoint, 3*sizeof(double));
-  this->SimpleIntegrate(tmpseed, lastPoint, this->LastUsedTimeStep, func);
+  this->SimpleIntegrate(tmpseed, lastPoint, this->LastUsedStepSize, func);
   func->Delete();
 
   this->SetIntegrator(ivp);
