@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkMPIController.h,v $
+  Module:    vtkMPIController.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -52,7 +52,7 @@ class VTK_PARALLEL_EXPORT vtkMPIController : public vtkMultiProcessController
 public:
 
   static vtkMPIController *New();
-  vtkTypeRevisionMacro(vtkMPIController,vtkMultiProcessController);
+  vtkTypeMacro(vtkMPIController,vtkMultiProcessController);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -71,6 +71,10 @@ public:
   virtual void Initialize(int* vtkNotUsed(argc), char*** vtkNotUsed(argv),
                           int initializedExternally);
 
+  // Description:
+  // Same as Initialize(0, 0, 1). Mainly for calling from wrapped languages.
+  virtual void Initialize();
+
   // Description:
   // This method is for cleaning up and has to be called before
   // the end of the program if MPI was initialized with
