@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPExtractArraysOverTime.h,v $
+  Module:    vtkPExtractArraysOverTime.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -41,7 +41,7 @@ class VTK_PARALLEL_EXPORT vtkPExtractArraysOverTime : public vtkExtractArraysOve
 {
 public:
   static vtkPExtractArraysOverTime *New();
-  vtkTypeRevisionMacro(vtkPExtractArraysOverTime,vtkExtractArraysOverTime);
+  vtkTypeMacro(vtkPExtractArraysOverTime,vtkExtractArraysOverTime);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
