@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPProbeFilter.h,v $
+  Module:    vtkPProbeFilter.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,7 +25,7 @@ class vtkMultiProcessController;
 class VTK_PARALLEL_EXPORT vtkPProbeFilter : public vtkCompositeDataProbeFilter
 {
 public:
-  vtkTypeRevisionMacro(vtkPProbeFilter,vtkCompositeDataProbeFilter);
+  vtkTypeMacro(vtkPProbeFilter,vtkCompositeDataProbeFilter);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   static vtkPProbeFilter *New();
