@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkSocketCommunicator.h,v $
+  Module:    vtkSocketCommunicator.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -54,7 +54,7 @@ class VTK_PARALLEL_EXPORT vtkSocketCommunicator : public vtkCommunicator
 {
 public:
   static vtkSocketCommunicator *New();
-  vtkTypeRevisionMacro(vtkSocketCommunicator,vtkCommunicator);
+  vtkTypeMacro(vtkSocketCommunicator,vtkCommunicator);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -70,7 +70,7 @@ public:
 
   // Description:
   // Open a connection to host.
-  virtual int ConnectTo( char* hostName, int port);
+  virtual int ConnectTo(const char* hostName, int port);
 
   // Description:
   // Returns 1 if bytes must be swapped in received ints, floats, etc
@@ -190,10 +190,6 @@ public:
   // is invalid if the socket is not connected.
   vtkGetMacro(IsServer, int);
 
-  // Description:
-  // Uniquely identifies the version of this class.  If the versions match,
-  // then the socket communicators should be compatible.
-  static int GetVersion();
 //BTX
 protected:
 
@@ -224,6 +220,7 @@ protected:
   void LogTagged(const char* name, const void* data, int wordSize, int numWords,
                  int tag, const char* logName);
   int CheckForErrorInternal(int id);
+
 private:
   vtkSocketCommunicator(const vtkSocketCommunicator&);  // Not implemented.
   void operator=(const vtkSocketCommunicator&);  // Not implemented.
@@ -241,6 +238,11 @@ private:
   // One may be tempted to change this to a vtkIdType, but really an int is
   // enough since we split messages > VTK_INT_MAX.
   int TagMessageLength;
+
+  // Description:
+  // Uniquely identifies the version of this class.  If the versions match,
+  // then the socket communicators should be compatible.
+  static int GetVersion();
 //ETX
 };
 
