@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCocoaGLView.h,v $
+  Module:    vtkCocoaGLView.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -16,11 +16,17 @@
 //
 // .SECTION Description
 // This class is a subclass of Cocoa's NSView; it uses Objective-C++.
-// This class overrides several NSView methods. It overrides keyDown and
-// keyUp to provide the usual VTK keyboard user interface. It overrides
-// mouseMoved, scrollWheel, mouseDown, rightMouseDown, and otherMouseDown
-// to provide the usual VTK mouse user interface. It overrides drawRect
-// to render and draw onscreen.
+// This class overrides several NSView methods.
+// To provide the usual VTK keyboard user interface, it overrides the
+// following methods from NSResponder: acceptsFirstResponder, keyDown:,
+// keyUp:, and flagsChanged:
+// To provide the usual VTK mouse user interface, it overrides the
+// following methods from NSResponder: mouseMoved:, mouseEntered:,
+// mouseExited: scrollWheel:, mouseDown:, rightMouseDown:,
+// otherMouseDown:, and resetCursorRects.
+// To be able to render and draw onscreen, it overrides drawRect:
+// from NSView.
+
 // Note that this class was previously a subclass of NSOpenGLView,
 // but starting with VTK 5.0 is now a subclass of NSView.
 //
@@ -52,6 +58,8 @@
 {
   @private
   vtkCocoaRenderWindowRef myVTKRenderWindow;
+  NSTrackingRectTag rolloverTrackingRectTag;
+  BOOL rolloverTrackingRectSet;
 }
 
 - (vtkCocoaRenderWindowRef)getVTKRenderWindow;
