@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkCocoaRenderWindow.mm,v $
+Module:    vtkCocoaRenderWindow.mm
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -13,7 +13,9 @@ PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
 
+#import <Cocoa/Cocoa.h>
 #import "vtkCocoaMacOSXSDKCompatibility.h" // Needed to support old SDKs
+
 #import "vtkCocoaRenderWindow.h"
 #import "vtkCommand.h"
 #import "vtkIdList.h"
@@ -23,7 +25,6 @@ PURPOSE.  See the above copyright notice for more information.
 
 #import <vtksys/ios/sstream>
 
-vtkCxxRevisionMacro(vtkCocoaRenderWindow, "$Revision: 1.72 $");
 vtkStandardNewMacro(vtkCocoaRenderWindow);
 
 
@@ -308,16 +309,7 @@ int vtkCocoaRenderWindow::IsDirect()
     {
     return 0;
     }
-
-  NSOpenGLContext* context = (NSOpenGLContext*)this->GetContextId();
-  GLint currentScreen = [context currentVirtualScreen];
-
-  NSOpenGLPixelFormat* pixelFormat = (NSOpenGLPixelFormat*)this->GetPixelFormat();
-  GLint pfd;
-  [pixelFormat getValues: &pfd forAttribute: NSOpenGLPFAFullScreen forVirtualScreen: currentScreen];
-
-  int isDirect = (pfd == 0) ? 0 : 1;
-  return isDirect;
+  return 1;
 }
 
 //----------------------------------------------------------------------------
