@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCocoaRenderWindowInteractor.mm,v $
+  Module:    vtkCocoaRenderWindowInteractor.mm
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -12,16 +12,21 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
+#import <Cocoa/Cocoa.h>
+#import "vtkCocoaMacOSXSDKCompatibility.h" // Needed to support old SDKs
+
 #import "vtkCocoaRenderWindowInteractor.h"
 #import "vtkCocoaRenderWindow.h"
 #import "vtkCommand.h"
 #import "vtkObjectFactory.h"
 
-#import <Cocoa/Cocoa.h>
-#import <OpenGL/gl.h>
+#ifdef VTK_USE_TDX
+#import "vtkTDxMacDevice.h"
+#endif
+
 
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkCocoaRenderWindowInteractor, "$Revision: 1.26 $");
 vtkStandardNewMacro(vtkCocoaRenderWindowInteractor);
 
 //----------------------------------------------------------------------------
@@ -97,7 +102,7 @@ class vtkEarlyCocoaSetup
 // We create a global/static instance of this class to ensure that we have an
 // autorelease pool before main() starts (the C++ constructor for a global
 // object runs before main).  Note: I am unable to find a place to delete this
-// object safely.
+// object safely, but having it around for the lifetime of the process is ok.
 static vtkEarlyCocoaSetup * gEarlyCocoaSetup = new vtkEarlyCocoaSetup();
 
 //----------------------------------------------------------------------------
@@ -207,27 +212,19 @@ static vtkEarlyCocoaSetup * gEarlyCocoaSetup = new vtkEarlyCocoaSetup();
   NSWindow *win = nil;
   if (renWin != NULL)
     {
-    win = reinterpret_cast<NSWindow *>(renWin->GetWindowId());
+    win = reinterpret_cast<NSWindow *>(renWin->GetRootWindow());
   
-  // We don't want to be informed of every window closing, so check for nil.
+    // We don't want to be informed of every window closing, so check for nil.
     if (win != nil)
-    {
+      {
       // Register for the windowWillClose notification in order to stop
       // the run loop if the window closes.
       NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
       [nc addObserver:self selector:@selector(windowWillClose:) 
-                               name:@"NSWindowWillCloseNotification" 
+                               name:NSWindowWillCloseNotification 
                              object:win];
+      }
     }
-    }
-
-  // Now that we are about to begin the standard Cocoa event loop, we can get
-  // rid of the 'pool of last resort' because [NSApp run] will create a new
-  // pool for every event
-  #ifndef __OBJC_GC__
-  delete gEarlyCocoaSetup;
-  gEarlyCocoaSetup = 0;
-  #endif
 
   // Start the NSApplication's run loop
   [NSApp run];
@@ -240,7 +237,7 @@ static vtkEarlyCocoaSetup * gEarlyCocoaSetup = new vtkEarlyCocoaSetup();
   NSWindow  *win = nil;
   if (renWin != NULL)
     {
-    win = reinterpret_cast<NSWindow *>(renWin->GetWindowId());
+    win = reinterpret_cast<NSWindow *>(renWin->GetRootWindow());
     }
   
   // Close the window, removing it from the screen and releasing it
@@ -253,7 +250,7 @@ static vtkEarlyCocoaSetup * gEarlyCocoaSetup = new vtkEarlyCocoaSetup();
   (void)aNotification;
   
   NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
-  [nc removeObserver:self];
+  [nc removeObserver:self name:NSWindowWillCloseNotification object:nil];
   
   if (renWin)
     {
@@ -277,7 +274,7 @@ static vtkEarlyCocoaSetup * gEarlyCocoaSetup = new vtkEarlyCocoaSetup();
       [NSApp postEvent:event atStart:YES];
       
       // The NSWindow is closing, so prevent anyone from accidently using it
-      renWin->SetWindowId(NULL);
+      renWin->SetRootWindow(NULL);
       }
     }
 } 
@@ -297,8 +294,15 @@ vtkCocoaRenderWindowInteractor::vtkCocoaRenderWindowInteractor()
   // init the ivar to null first.
   this->CocoaManager = NULL;
   this->SetCocoaManager(reinterpret_cast<void *>(cocoaManager));
+  [cocoaManager self]; // prevent premature collection.
   
-  this->SetTimerDictionary(reinterpret_cast<void *>([NSMutableDictionary dictionary]));
+  NSMutableDictionary* timerDictionary = [NSMutableDictionary dictionary];
+  this->SetTimerDictionary(reinterpret_cast<void *>(timerDictionary));
+  [timerDictionary self]; // prevent premature collection.
+  
+#ifdef VTK_USE_TDX
+  this->Device=vtkTDxMacDevice::New();
+#endif
 }
 
 //----------------------------------------------------------------------------
@@ -308,6 +312,9 @@ vtkCocoaRenderWindowInteractor::~vtkCocoaRenderWindowInteractor()
   this->SetTimerDictionary(NULL);
   this->SetCocoaServer(NULL);
   this->SetCocoaManager(NULL);
+#ifdef VTK_USE_TDX
+  this->Device->Delete();
+#endif
 }
 
 //----------------------------------------------------------------------------
@@ -378,6 +385,14 @@ void vtkCocoaRenderWindowInteractor::Enable()
   // to handle events from the OS it will either handle them or ignore them
   this->GetRenderWindow()->SetInteractor(this);
 
+#ifdef VTK_USE_TDX
+  if(this->UseTDx)
+    {
+    this->Device->SetInteractor(this);
+    this->Device->Initialize();
+    }
+#endif
+  
   this->Enabled = 1;
   this->Modified();
 }
@@ -390,10 +405,17 @@ void vtkCocoaRenderWindowInteractor::Disable()
     return;
     }
 
+#ifdef VTK_USE_TDX
+  if(this->Device->GetInitialized())
+    {
+      this->Device->Close();
+    }
+#endif
+  
   // Set the RenderWindow's interactor so that when the vtkCocoaGLView tries
   // to handle events from the OS it will either handle them or ignore them
   this->GetRenderWindow()->SetInteractor(NULL);
-
+  
   this->Enabled = 0;
   this->Modified();
 }
