@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCompositePolyDataMapper.cxx,v $
+  Module:    vtkCompositePolyDataMapper.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,7 +28,6 @@
 
 #include <vtkstd/vector>
 
-vtkCxxRevisionMacro(vtkCompositePolyDataMapper, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkCompositePolyDataMapper);
 
 class vtkCompositePolyDataMapperInternals
@@ -94,7 +93,7 @@ void vtkCompositePolyDataMapper::BuildPolyDataMapper()
       // Make a copy of the data to break the pipeline here
       vtkPolyData *newpd = vtkPolyData::New();
       newpd->ShallowCopy(pd);
-      vtkPolyDataMapper *pdmapper = vtkPolyDataMapper::New();
+      vtkPolyDataMapper *pdmapper = this->MakeAMapper();
       pdmapper->Register( this );
       pdmapper->SetInput(newpd);
       this->Internal->Mappers.push_back(pdmapper);
@@ -122,7 +121,7 @@ void vtkCompositePolyDataMapper::BuildPolyDataMapper()
         // Make a copy of the data to break the pipeline here
         vtkPolyData *newpd = vtkPolyData::New();
         newpd->ShallowCopy(pd);
-        vtkPolyDataMapper *pdmapper = vtkPolyDataMapper::New();
+        vtkPolyDataMapper *pdmapper = this->MakeAMapper();
         pdmapper->Register(this);
         pdmapper->SetInput(newpd);
         this->Internal->Mappers.push_back(pdmapper);
@@ -135,7 +134,7 @@ void vtkCompositePolyDataMapper::BuildPolyDataMapper()
         {
         if ( !warnOnce )
           {
-          vtkErrorMacro("All data in the hierachical dataset must be polydata.");
+          vtkErrorMacro("All data in the hierarchical dataset must be polydata.");
           warnOnce = 1;
           }
         }
@@ -306,3 +305,8 @@ void vtkCompositePolyDataMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
 }
+
+vtkPolyDataMapper *vtkCompositePolyDataMapper::MakeAMapper()
+{
+  return vtkPolyDataMapper::New();
+}
