@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkDepthPeelingPass.cxx,v $
+Module:    vtkDepthPeelingPass.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -30,7 +30,6 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkUniformVariables.h"
 #include "vtkTextureUnitManager.h"
 
-vtkCxxRevisionMacro(vtkDepthPeelingPass, "$Revision: 1.7 $");
 vtkStandardNewMacro(vtkDepthPeelingPass);
 vtkCxxSetObjectMacro(vtkDepthPeelingPass,TranslucentPass,vtkRenderPass);
 
@@ -174,9 +173,21 @@ void vtkDepthPeelingPass::Render(const vtkRenderState *s)
   // Depth peeling.
   vtkRenderer *r=s->GetRenderer();
   
-  // get the viewport dimensions
-  r->GetTiledSizeAndOrigin(&this->ViewportWidth,&this->ViewportHeight,
-                           &this->ViewportX,&this->ViewportY);
+  if(s->GetFrameBuffer()==0)
+    {
+    // get the viewport dimensions
+    r->GetTiledSizeAndOrigin(&this->ViewportWidth,&this->ViewportHeight,
+                             &this->ViewportX,&this->ViewportY);
+    }
+  else
+    {
+    int size[2];
+    s->GetWindowSize(size);
+    this->ViewportWidth=size[0];
+    this->ViewportHeight=size[1];
+    this->ViewportX=0;
+    this->ViewportY=0;
+    }
     
   // get z bits
   GLint depthBits;
