@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGenericVertexAttributeMapping.cxx,v $
+  Module:    vtkGenericVertexAttributeMapping.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -37,7 +37,6 @@ public:
 };
 
 vtkStandardNewMacro(vtkGenericVertexAttributeMapping);
-vtkCxxRevisionMacro(vtkGenericVertexAttributeMapping, "$Revision: 1.3 $");
 //----------------------------------------------------------------------------
 vtkGenericVertexAttributeMapping::vtkGenericVertexAttributeMapping()
 {
