@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGraphicsFactory.cxx,v $
+  Module:    vtkGraphicsFactory.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -26,6 +26,7 @@
 #include "vtkOpenGLClipPlanesPainter.h"
 #include "vtkOpenGLCoincidentTopologyResolutionPainter.h"
 #include "vtkOpenGLDisplayListPainter.h"
+#include "vtkOpenGLGlyph3DMapper.h"
 #include "vtkOpenGLImageActor.h"
 #include "vtkOpenGLLight.h"
 #include "vtkOpenGLLightingPainter.h"
@@ -119,7 +120,6 @@ int vtkGraphicsFactory::OffScreenOnlyMode = 1;
 int vtkGraphicsFactory::OffScreenOnlyMode = 0;
 #endif
 
-vtkCxxRevisionMacro(vtkGraphicsFactory, "$Revision: 1.43 $");
 vtkStandardNewMacro(vtkGraphicsFactory);
 
 const char *vtkGraphicsFactory::GetRenderLibrary()
@@ -231,7 +231,7 @@ vtkObject* vtkGraphicsFactory::CreateInstance(const char* vtkclassname )
     }
   if(strcmp(vtkclassname, "vtkRenderWindowInteractor") == 0)
     {
-    return vtkRenderWindowInteractor::New();
+    return 0; // there is no interactor with OSMesa
     }
 #endif
 
@@ -426,6 +426,16 @@ vtkObject* vtkGraphicsFactory::CreateInstance(const char* vtkclassname )
 #endif
       return vtkOpenGLTexture::New();
       }
+    if(strcmp(vtkclassname, "vtkGlyph3DMapper") == 0)
+      {
+#if defined(VTK_USE_MANGLED_MESA)
+      if ( vtkGraphicsFactory::UseMesaClasses )
+        {
+        return NULL;
+        }
+#endif
+      return vtkOpenGLGlyph3DMapper::New();
+      }
     }
 #endif
         
