@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageActor.cxx,v $
+  Module:    vtkImageActor.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -17,10 +17,9 @@
 #include "vtkGraphicsFactory.h"
 #include "vtkImageData.h"
 #include "vtkMath.h"
+#include "vtkMatrix4x4.h"
 #include "vtkRenderer.h"
-#include "vtkTransform.h"
 
-vtkCxxRevisionMacro(vtkImageActor, "$Revision: 1.24 $");
 
 //----------------------------------------------------------------------------
 // Needed when we don't use the vtkStandardNewMacro.
@@ -44,7 +43,7 @@ vtkImageActor::vtkImageActor()
   this->DisplayExtent[2] = 0;
   this->DisplayExtent[3] = 0;
   this->DisplayExtent[4] = 0;
-  this->DisplayExtent[5] = 0;  
+  this->DisplayExtent[5] = 0;
   this->ComputedDisplayExtent[0] = 0;
   this->ComputedDisplayExtent[1] = 0;
   this->ComputedDisplayExtent[2] = 0;
@@ -133,7 +132,7 @@ int vtkImageActor::GetSliceNumberMin()
 void vtkImageActor::SetDisplayExtent(int extent[6])
 {
   int idx, modified = 0;
-  
+
   for (idx = 0; idx < 6; ++idx)
     {
     if (this->DisplayExtent[idx] != extent[idx])
@@ -153,12 +152,12 @@ void vtkImageActor::SetDisplayExtent(int extent[6])
     }
 }
 //----------------------------------------------------------------------------
-void vtkImageActor::SetDisplayExtent(int minX, int maxX, 
+void vtkImageActor::SetDisplayExtent(int minX, int maxX,
                                      int minY, int maxY,
                                      int minZ, int maxZ)
 {
   int extent[6];
-  
+
   extent[0] = minX;  extent[1] = maxX;
   extent[2] = minY;  extent[3] = maxY;
   extent[4] = minZ;  extent[5] = maxZ;
@@ -170,7 +169,7 @@ void vtkImageActor::SetDisplayExtent(int minX, int maxX,
 void vtkImageActor::GetDisplayExtent(int extent[6])
 {
   int idx;
-  
+
   for (idx = 0; idx < 6; ++idx)
     {
     extent[idx] = this->DisplayExtent[idx];
@@ -334,7 +333,7 @@ double *vtkImageActor::GetDisplayBounds()
     this->DisplayBounds[5] =
       this->ComputedDisplayExtent[4]*spacing[2] + origin[2];
     }
-  
+
   return this->DisplayBounds;
 }
 
@@ -353,7 +352,7 @@ double *vtkImageActor::GetBounds()
 {
   int i,n;
   double *bounds, bbox[24], *fptr;
-  
+
   bounds = this->GetDisplayBounds();
   // Check for the special case when the data bounds are unknown
   if (!bounds)
@@ -370,21 +369,22 @@ double *vtkImageActor::GetBounds()
   bbox[15] = bounds[1]; bbox[16] = bounds[2]; bbox[17] = bounds[4];
   bbox[18] = bounds[0]; bbox[19] = bounds[2]; bbox[20] = bounds[4];
   bbox[21] = bounds[0]; bbox[22] = bounds[3]; bbox[23] = bounds[4];
-  
-  // save the old transform
-  this->Transform->Push();
-  this->Transform->SetMatrix(this->GetMatrix());
+
+  // make sure matrix (transform) is up-to-date
+  this->ComputeMatrix();
 
   // and transform into actors coordinates
   fptr = bbox;
-  for (n = 0; n < 8; n++) 
+  for (n = 0; n < 8; n++)
     {
-    this->Transform->TransformPoint(fptr,fptr);
+    double homogeneousPt[4] = {fptr[0], fptr[1], fptr[2], 1.0};
+    this->Matrix->MultiplyPoint(homogeneousPt, homogeneousPt);
+    fptr[0] = homogeneousPt[0] / homogeneousPt[3];
+    fptr[1] = homogeneousPt[1] / homogeneousPt[3];
+    fptr[2] = homogeneousPt[2] / homogeneousPt[3];
     fptr += 3;
     }
-  
-  this->Transform->Pop();  
-  
+
   // now calc the new bounds
   this->Bounds[0] = this->Bounds[2] = this->Bounds[4] = VTK_DOUBLE_MAX;
   this->Bounds[1] = this->Bounds[3] = this->Bounds[5] = -VTK_DOUBLE_MAX;
@@ -414,7 +414,7 @@ void vtkImageActor::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Interpolate: " << (this->Interpolate ? "On\n" : "Off\n");
   os << indent << "Opacity: " << this->Opacity << "\n";
 
-  int idx;  
+  int idx;
   os << indent << "DisplayExtent: (" << this->DisplayExtent[0];
   for (idx = 1; idx < 6; ++idx)
     {
@@ -427,7 +427,7 @@ void vtkImageActor::PrintSelf(ostream& os, vtkIndent indent)
 int vtkImageActor::GetWholeZMin()
 {
   int *extent;
-  
+
   if ( ! this->GetInput())
     {
     return 0;
@@ -441,7 +441,7 @@ int vtkImageActor::GetWholeZMin()
 int vtkImageActor::GetWholeZMax()
 {
   int *extent;
-  
+
   if ( ! this->GetInput())
     {
     return 0;
@@ -453,20 +453,20 @@ int vtkImageActor::GetWholeZMax()
 
 void vtkImageActor::SetInput(vtkImageData *args)
 {
-  vtkDebugMacro(<< this->GetClassName() << " (" << this         
-  << "): setting Input to " << args );     
-  if (this->Input != args)                                       
-    {                                                           
-    if (this->Input != NULL) 
-      { 
-      this->Input->UnRegister(this); 
-      }   
-    this->Input = args;                                          
-    if (this->Input != NULL) 
-      { 
-      this->Input->Register(this); 
-      }     
-    this->Modified();                                           
-    }                                                           
+  vtkDebugMacro(<< this->GetClassName() << " (" << this
+  << "): setting Input to " << args );
+  if (this->Input != args)
+    {
+    if (this->Input != NULL)
+      {
+      this->Input->UnRegister(this);
+      }
+    this->Input = args;
+    if (this->Input != NULL)
+      {
+      this->Input->Register(this);
+      }
+    this->Modified();
+    }
 }
 
