@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkInteractorStyle.cxx,v $
+  Module:    vtkInteractorStyle.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -32,9 +32,10 @@
 #include "vtkRenderer.h"
 #include "vtkTextProperty.h"
 #include "vtkEventForwarderCommand.h"
+#include "vtkTDxInteractorStyleCamera.h"
 
-vtkCxxRevisionMacro(vtkInteractorStyle, "$Revision: 1.103 $");
 vtkStandardNewMacro(vtkInteractorStyle);
+vtkCxxSetObjectMacro(vtkInteractorStyle,TDxStyle,vtkTDxInteractorStyle);
 
 //----------------------------------------------------------------------------
 vtkInteractorStyle::vtkInteractorStyle()
@@ -75,6 +76,8 @@ vtkInteractorStyle::vtkInteractorStyle()
   
   this->TimerDuration = 10;
   this->EventForwarder = vtkEventForwarderCommand::New();
+  
+  this->TDxStyle=vtkTDxInteractorStyleCamera::New();
 }
 
 //----------------------------------------------------------------------------
@@ -103,6 +106,11 @@ vtkInteractorStyle::~vtkInteractorStyle()
 
   this->SetCurrentRenderer(NULL);
   this->EventForwarder->Delete();
+  
+  if(this->TDxStyle!=0)
+    {
+    this->TDxStyle->Delete();
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -238,6 +246,17 @@ void vtkInteractorStyle::SetInteractor(vtkRenderWindowInteractor *i)
     i->AddObserver(vtkCommand::DeleteEvent, 
                    this->EventCallbackCommand, 
                    this->Priority);
+    i->AddObserver(vtkCommand::TDxMotionEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
+    
+    i->AddObserver(vtkCommand::TDxButtonPressEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
+    
+    i->AddObserver(vtkCommand::TDxButtonReleaseEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
     }
   
   this->EventForwarder->SetTarget(this->Interactor);
@@ -326,7 +345,14 @@ void vtkInteractorStyle::HighlightProp3D(vtkProp3D *prop3D)
         {
         this->PickedRenderer->RemoveActor(this->OutlineActor);
         }
-      this->CurrentRenderer->AddActor(this->OutlineActor);
+      if(this->CurrentRenderer!=0)
+        {
+        this->CurrentRenderer->AddActor(this->OutlineActor);
+        }
+      else
+        {
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
+        }
       this->PickedRenderer = this->CurrentRenderer;      
       }
     this->Outline->SetBounds(prop3D->GetBounds());
@@ -344,6 +370,9 @@ void vtkInteractorStyle::HighlightActor2D(vtkActor2D *actor2D)
 
   if ( actor2D )
     {
+    double tmpColor[3];
+    actor2D->GetProperty()->GetColor(tmpColor);
+
     if ( this->PickedActor2D )
       {
       actor2D->GetProperty()->SetColor(
@@ -352,13 +381,13 @@ void vtkInteractorStyle::HighlightActor2D(vtkActor2D *actor2D)
       }
     else
       {
-      double tmpColor[3];
-      actor2D->GetProperty()->GetColor(tmpColor);
       actor2D->GetProperty()->SetColor(this->PickColor);
-      this->PickColor[0] = tmpColor[0];
-      this->PickColor[1] = tmpColor[1];
-      this->PickColor[2] = tmpColor[2];
       }
+
+    this->PickColor[0] = tmpColor[0];
+    this->PickColor[1] = tmpColor[1];
+    this->PickColor[2] = tmpColor[2];
+
     }
   else
     {
@@ -673,24 +702,31 @@ void vtkInteractorStyle::OnChar()
     case 'f' :      
     case 'F' :
       {
-      this->AnimState = VTKIS_ANIM_ON;
-      vtkAssemblyPath *path = NULL;
-      this->FindPokedRenderer(rwi->GetEventPosition()[0],
-                              rwi->GetEventPosition()[1]);
-      rwi->GetPicker()->Pick(rwi->GetEventPosition()[0],
-                             rwi->GetEventPosition()[1], 
-                             0.0, 
-                             this->CurrentRenderer);
-      vtkAbstractPropPicker *picker;
-      if ((picker=vtkAbstractPropPicker::SafeDownCast(rwi->GetPicker())))
+      if(this->CurrentRenderer!=0)
         {
-        path = picker->GetPath();
+        this->AnimState = VTKIS_ANIM_ON;
+        vtkAssemblyPath *path = NULL;
+        this->FindPokedRenderer(rwi->GetEventPosition()[0],
+                                rwi->GetEventPosition()[1]);
+        rwi->GetPicker()->Pick(rwi->GetEventPosition()[0],
+                               rwi->GetEventPosition()[1],
+                               0.0,
+                               this->CurrentRenderer);
+        vtkAbstractPropPicker *picker;
+        if ((picker=vtkAbstractPropPicker::SafeDownCast(rwi->GetPicker())))
+          {
+          path = picker->GetPath();
+          }
+        if (path != NULL)
+          {
+          rwi->FlyTo(this->CurrentRenderer, picker->GetPickPosition());
+          }
+        this->AnimState = VTKIS_ANIM_OFF;
         }
-      if (path != NULL)
+      else
         {
-        rwi->FlyTo(this->CurrentRenderer, picker->GetPickPosition());
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
         }
-      this->AnimState = VTKIS_ANIM_OFF;
       }
       break;
 
@@ -703,7 +739,14 @@ void vtkInteractorStyle::OnChar()
     case 'R' :
       this->FindPokedRenderer(rwi->GetEventPosition()[0], 
                               rwi->GetEventPosition()[1]);
-      this->CurrentRenderer->ResetCamera();
+      if(this->CurrentRenderer!=0)
+        {
+        this->CurrentRenderer->ResetCamera();
+        }
+      else
+        {
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
+        }
       rwi->Render();
       break;
 
@@ -715,16 +758,23 @@ void vtkInteractorStyle::OnChar()
       vtkAssemblyPath *path;
       this->FindPokedRenderer(rwi->GetEventPosition()[0],
                               rwi->GetEventPosition()[1]);
-      ac = this->CurrentRenderer->GetActors();
-      vtkCollectionSimpleIterator ait;
-      for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait)); ) 
+      if(this->CurrentRenderer!=0)
         {
-        for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); ) 
+        ac = this->CurrentRenderer->GetActors();
+        vtkCollectionSimpleIterator ait;
+        for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait)); )
           {
-          aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
-          aPart->GetProperty()->SetRepresentationToWireframe();
+          for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); )
+            {
+            aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
+            aPart->GetProperty()->SetRepresentationToWireframe();
+            }
           }
         }
+      else
+        {
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
+        }
       rwi->Render();
       }
       break;
@@ -737,16 +787,23 @@ void vtkInteractorStyle::OnChar()
       vtkAssemblyPath *path;
       this->FindPokedRenderer(rwi->GetEventPosition()[0],
                               rwi->GetEventPosition()[1]);
-      ac = this->CurrentRenderer->GetActors();
-      vtkCollectionSimpleIterator ait;
-      for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait)); ) 
+      if(this->CurrentRenderer!=0)
         {
-        for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); ) 
+        ac = this->CurrentRenderer->GetActors();
+        vtkCollectionSimpleIterator ait;
+        for (ac->InitTraversal(ait); (anActor = ac->GetNextActor(ait)); )
           {
-          aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
-          aPart->GetProperty()->SetRepresentationToSurface();
+          for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); )
+            {
+            aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
+            aPart->GetProperty()->SetRepresentationToSurface();
+            }
           }
         }
+      else
+        {
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
+        }
       rwi->Render();
       }
       break;
@@ -765,31 +822,38 @@ void vtkInteractorStyle::OnChar()
 
     case 'p' :
     case 'P' :
-      if (this->State == VTKIS_NONE) 
+      if(this->CurrentRenderer!=0)
         {
-        vtkAssemblyPath *path = NULL;
-        int *eventPos = rwi->GetEventPosition();
-        this->FindPokedRenderer(eventPos[0], eventPos[1]);
-        rwi->StartPickCallback();
-        vtkAbstractPropPicker *picker = 
-          vtkAbstractPropPicker::SafeDownCast(rwi->GetPicker());
-        if ( picker != NULL )
+        if (this->State == VTKIS_NONE)
           {
-          picker->Pick(eventPos[0], eventPos[1], 
-                       0.0, this->CurrentRenderer);
-          path = picker->GetPath();
+          vtkAssemblyPath *path = NULL;
+          int *eventPos = rwi->GetEventPosition();
+          this->FindPokedRenderer(eventPos[0], eventPos[1]);
+          rwi->StartPickCallback();
+          vtkAbstractPropPicker *picker =
+            vtkAbstractPropPicker::SafeDownCast(rwi->GetPicker());
+          if ( picker != NULL )
+            {
+            picker->Pick(eventPos[0], eventPos[1],
+                         0.0, this->CurrentRenderer);
+            path = picker->GetPath();
+            }
+          if ( path == NULL )
+            {
+            this->HighlightProp(NULL);
+            this->PropPicked = 0;
+            }
+          else
+            {
+            this->HighlightProp(path->GetFirstNode()->GetViewProp());
+            this->PropPicked = 1;
+            }
+          rwi->EndPickCallback();
           }
-        if ( path == NULL )
-          {
-          this->HighlightProp(NULL);
-          this->PropPicked = 0;
-          }
-        else
-          {
-          this->HighlightProp(path->GetFirstNode()->GetViewProp());
-          this->PropPicked = 1;
-          }
-        rwi->EndPickCallback();
+        }
+      else
+        {
+        vtkWarningMacro(<<"no current renderer on the interactor style.");
         }
       break;
     }
@@ -835,6 +899,26 @@ void vtkInteractorStyle::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "MouseWheelMotionFactor: " << this->MouseWheelMotionFactor << endl;
 
   os << indent << "Timer Duration: " << this->TimerDuration << endl;
+  
+  os << indent << "TDxStyle: ";
+  if(this->TDxStyle==0)
+    {
+    os << "(none)" << endl;
+    }
+  else
+    {
+    this->TDxStyle->PrintSelf(os,indent.GetNextIndent());
+    }
+}
+
+// ----------------------------------------------------------------------------
+void vtkInteractorStyle::DelegateTDxEvent(unsigned long event,
+                                          void *calldata)
+{
+  if(this->TDxStyle!=0)
+    {
+    this->TDxStyle->ProcessEvent(this->CurrentRenderer,event,calldata);
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -1062,6 +1146,11 @@ void vtkInteractorStyle::ProcessEvents(vtkObject* vtkNotUsed(object),
     case vtkCommand::DeleteEvent:
       self->SetInteractor(0);
       break;
+      
+    case vtkCommand::TDxMotionEvent:
+    case vtkCommand::TDxButtonPressEvent:
+    case vtkCommand::TDxButtonReleaseEvent:
+      self->DelegateTDxEvent(event,calldata);
+      break;
     }
 }
-
