@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLabelHierarchyAlgorithm.cxx,v $
+  Module:    vtkLabelHierarchyAlgorithm.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkTrivialProducer.h"
 
-vtkCxxRevisionMacro(vtkLabelHierarchyAlgorithm, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkLabelHierarchyAlgorithm);
 
 //----------------------------------------------------------------------------
