@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLabelPlacer.h,v $
+  Module:    vtkLabelPlacer.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -49,7 +49,7 @@ class VTK_RENDERING_EXPORT vtkLabelPlacer : public vtkPolyDataAlgorithm
 {
 public:
   static vtkLabelPlacer* New();
-  vtkTypeRevisionMacro(vtkLabelPlacer,vtkPolyDataAlgorithm);
+  vtkTypeMacro(vtkLabelPlacer,vtkPolyDataAlgorithm);
   virtual void PrintSelf( ostream& os, vtkIndent indent );
 
   vtkGetObjectMacro(Renderer,vtkRenderer);
