@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLightCollection.cxx,v $
+  Module:    vtkLightCollection.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -19,13 +19,12 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkLightCollection, "$Revision: 1.16 $");
 vtkStandardNewMacro(vtkLightCollection);
 
 // Add a light to the list.
 void vtkLightCollection::AddItem(vtkLight *a) 
 {
-  this->vtkCollection::AddItem((vtkObject *)a);
+  this->vtkCollection::AddItem(a);
 }
 
 // Get the next light in the list. NULL is returned when the collection is 
