@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkMapper.cxx,v $
+  Module:    vtkMapper.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkPointData.h"
 #include "vtkMath.h"
 
-vtkCxxRevisionMacro(vtkMapper, "$Revision: 1.120 $");
 
 // Initialize static member that controls global immediate mode rendering
 static int vtkMapperGlobalImmediateModeRendering = 0;
@@ -32,6 +31,7 @@ static int vtkMapperGlobalResolveCoincidentTopology = VTK_RESOLVE_OFF;
 static double vtkMapperGlobalResolveCoincidentTopologyZShift = 0.01;
 static double vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetFactor = 1.0;
 static double vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetUnits = 1.0;
+static int vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetFaces = 1;
 
 // Construct with initial range (0,1).            
 vtkMapper::vtkMapper()
@@ -63,6 +63,8 @@ vtkMapper::vtkMapper()
   this->InterpolateScalarsBeforeMapping = 0;
   this->ColorCoordinates = 0;
   this->ColorTextureMap = 0;
+
+  this->ForceCompileOnly=0;
 }
 
 vtkMapper::~vtkMapper()
@@ -89,12 +91,10 @@ vtkMapper::~vtkMapper()
 // (Xmin,Xmax,Ymin,Ymax,Zmin,Zmax).
 double *vtkMapper::GetBounds()
 {
-  static double bounds[] = {-1.0,1.0, -1.0,1.0, -1.0,1.0};
-
   vtkDataSet *input = this->GetInput();
   if ( ! input ) 
     {
-    return bounds;
+      vtkMath::UninitializeBounds(this->Bounds);
     }
   else
     {
@@ -103,8 +103,8 @@ double *vtkMapper::GetBounds()
       this->Update();
       }
     input->GetBounds(this->Bounds);
-    return this->Bounds;
     }
+  return this->Bounds;
 }
 
 vtkDataSet *vtkMapper::GetInput()
@@ -117,6 +117,16 @@ vtkDataSet *vtkMapper::GetInput()
     this->GetExecutive()->GetInputData(0, 0));
 }
 
+void vtkMapper::SetForceCompileOnly(int value)
+{
+  if(this->ForceCompileOnly!=value)
+    {
+      this->ForceCompileOnly=value;
+      // make sure we don't call this->Modified();
+      //      this->Modified();
+    }
+}
+
 void vtkMapper::SetGlobalImmediateModeRendering(int val)
 {
   if (val == vtkMapperGlobalImmediateModeRendering)
@@ -183,6 +193,16 @@ void vtkMapper::GetResolveCoincidentTopologyPolygonOffsetParameters(
   units = vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetUnits;
 }
 
+void vtkMapper::SetResolveCoincidentTopologyPolygonOffsetFaces(int faces)
+{
+  vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetFaces = faces;
+}
+
+int vtkMapper::GetResolveCoincidentTopologyPolygonOffsetFaces()
+{
+  return vtkMapperGlobalResolveCoincidentTopologyPolygonOffsetFaces;
+}
+
 // Overload standard modified time function. If lookup table is modified,
 // then this object is modified as well.
 unsigned long vtkMapper::GetMTime()
@@ -280,6 +300,7 @@ vtkUnsignedCharArray *vtkMapper::MapScalars(double alpha)
       }
     this->LookupTable->Build();
     }
+
   if ( !this->UseLookupTableScalarRange )
     {
     this->LookupTable->SetRange(this->ScalarRange);
@@ -337,9 +358,11 @@ vtkUnsignedCharArray *vtkMapper::MapScalars(double alpha)
     }
   
   // map scalars
+  double orig_alpha = this->LookupTable->GetAlpha();
   this->LookupTable->SetAlpha(alpha);
   this->Colors = this->LookupTable->
     MapScalars(scalars, this->ColorMode, this->ArrayComponent);
+  this->LookupTable->SetAlpha(orig_alpha);
   // Consistent register and unregisters
   this->Colors->Register(this);
   this->Colors->Delete();
@@ -505,7 +528,7 @@ void vtkMapperCreateColorTextureCoordinates(T* input, float* output,
       sum = 0;
       for (j = 0; j < numComps; ++j)
         {
-        tmp = (double)(*input);  
+        tmp = static_cast<double>(*input);
         sum += (tmp * tmp);
         ++input;
         }
@@ -525,7 +548,7 @@ void vtkMapperCreateColorTextureCoordinates(T* input, float* output,
     input += component;
     for (i = 0; i < num; ++i)
       {
-      output[i] = k * ((float)(*input) - range[0]);
+      output[i] = k * (static_cast<double>(*input) - range[0]);
       if (output[i] > 1.0)
         {
         output[i] = 1.0;
@@ -546,6 +569,7 @@ void vtkMapperCreateColorTextureCoordinates(T* input, float* output,
 void vtkMapper::MapScalarsToTexture(vtkDataArray* scalars, double alpha)
 {
   double* range = this->LookupTable->GetRange();
+  double orig_alpha = this->LookupTable->GetAlpha();
   
   // Get rid of vertex color array.  Only texture or vertex coloring 
   // can be active at one time.  The existence of the array is the 
@@ -572,13 +596,13 @@ void vtkMapper::MapScalarsToTexture(vtkDataArray* scalars, double alpha)
     // Get the texture map from the lookup table.
     // Create a dummy ramp of scalars.
     // In the future, we could extend vtkScalarsToColors.
-    double k = (range[1]-range[0]) / (double)(ColorTextureMapSize-1);
+    double k = (range[1]-range[0]) / (ColorTextureMapSize-1);
     vtkFloatArray* tmp = vtkFloatArray::New();
     tmp->SetNumberOfTuples(ColorTextureMapSize);
     float* ptr = tmp->GetPointer(0);
     for (int i = 0; i < ColorTextureMapSize; ++i)
       {
-      *ptr = range[0] + ((float)(i)) * k;
+      *ptr = range[0] + i * k;
       ++ptr;
       }
     this->ColorTextureMap = vtkImageData::New();
@@ -588,6 +612,7 @@ void vtkMapper::MapScalarsToTexture(vtkDataArray* scalars, double alpha)
     this->ColorTextureMap->SetScalarTypeToUnsignedChar();
     this->ColorTextureMap->GetPointData()->SetScalars(
          this->LookupTable->MapScalars(tmp, this->ColorMode, 0));
+    this->LookupTable->SetAlpha(orig_alpha);
     // Do we need to delete the scalars?
     this->ColorTextureMap->GetPointData()->GetScalars()->Delete();
     // Consistent register and unregisters
@@ -662,6 +687,10 @@ void vtkMapper::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Immediate Mode Rendering: " 
     << (this->ImmediateModeRendering ? "On\n" : "Off\n");
+
+   os << indent << "Force compile only for display lists: " 
+    << (this->ForceCompileOnly ? "On\n" : "Off\n");
+
   os << indent << "Global Immediate Mode Rendering: " << 
     (vtkMapperGlobalImmediateModeRendering ? "On\n" : "Off\n");
 
