@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkOpenGLProperty.cxx,v $
+  Module:    vtkOpenGLProperty.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -44,7 +44,6 @@
 #include <assert.h>
 
 #ifndef VTK_IMPLEMENT_MESA_CXX
-vtkCxxRevisionMacro(vtkOpenGLProperty, "$Revision: 1.60 $");
 vtkStandardNewMacro(vtkOpenGLProperty);
 #endif
 
@@ -550,7 +549,7 @@ void vtkOpenGLProperty::Render(vtkActor *anActor,
   int numTextures = this->GetNumberOfTextures();
   if (numTextures > 0)
     {
-    if(prog==0) // fixed-pipeline multitexturing
+    if(prog==0) // fixed-pipeline multitexturing or old XML shaders.
       {
       this->LoadMultiTexturingExtensions(ren);
       if (vtkgl::ActiveTexture)
@@ -623,7 +622,7 @@ void vtkOpenGLProperty::PostRender(vtkActor *actor, vtkRenderer *renderer)
   int numTextures = this->GetNumberOfTextures();
   if (numTextures > 0 && vtkgl::ActiveTexture)
     {
-    if(prog==0) // fixed-pipeline multitexturing
+    if(prog==0) // fixed-pipeline multitexturing or old XML shaders.
       {
       GLint numSupportedTextures;
       glGetIntegerv(vtkgl::MAX_TEXTURE_UNITS, &numSupportedTextures);
