@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkOpenGLRenderer.cxx,v $
+Module:    vtkOpenGLRenderer.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -26,6 +26,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkImageImport.h"
 #include "vtkPNGWriter.h"
 #include "vtkOpenGLTexture.h"
+#include "vtkTimerLog.h"
 
 #ifndef VTK_IMPLEMENT_MESA_CXX
 # include "vtkOpenGL.h"
@@ -46,7 +47,6 @@ public:
 };
 
 #ifndef VTK_IMPLEMENT_MESA_CXX
-vtkCxxRevisionMacro(vtkOpenGLRenderer, "$Revision: 1.97 $");
 vtkStandardNewMacro(vtkOpenGLRenderer);
 #endif
 
@@ -226,6 +226,8 @@ int vtkOpenGLRenderer::GetDepthPeelingHigherLayer()
 // Concrete open gl render method.
 void vtkOpenGLRenderer::DeviceRender(void)
 {
+  vtkTimerLog::MarkStartEvent("OpenGL Dev Render");
+
   // Do not remove this MakeCurrent! Due to Start / End methods on
   // some objects which get executed during a pipeline update,
   // other windows might get rendered since the last time
@@ -247,6 +249,8 @@ void vtkOpenGLRenderer::DeviceRender(void)
   // clean up the model view matrix set up by the camera
   glMatrixMode(GL_MODELVIEW);
   glPopMatrix();
+
+  vtkTimerLog::MarkEndEvent("OpenGL Dev Render");
 }
 
 // ----------------------------------------------------------------------------
@@ -1057,6 +1061,8 @@ void vtkOpenGLRenderer::Clear(void)
   if (!this->Transparent() &&
       (this->GradientBackground || this->TexturedBackground))
     {
+    double tile_viewport[4];
+    this->GetRenderWindow()->GetTileViewport(tile_viewport);
     glPushAttrib(GL_ENABLE_BIT | GL_TRANSFORM_BIT);
     glDisable(GL_ALPHA_TEST);
     glDisable(GL_DEPTH_TEST);
@@ -1074,7 +1080,12 @@ void vtkOpenGLRenderer::Clear(void)
       glPushMatrix();
       {
         glLoadIdentity();
-        glOrtho(-1.0,1.0,-1.0,1.0,-1.0,1.0);
+        glOrtho(
+          tile_viewport[0],
+          tile_viewport[2],
+          tile_viewport[1],
+          tile_viewport[3],
+          -1.0, 1.0);
 
         //top vertices
         if(this->TexturedBackground && this->BackgroundTexture)
@@ -1100,10 +1111,10 @@ void vtkOpenGLRenderer::Clear(void)
         glColor4d(this->Background[0],this->Background[1],this->Background[2],
                   0.0);
         glTexCoord2f(0.0, 0.0);
-        glVertex2f(-1.0, -1.0);
+        glVertex2f(0.0, 0.0);
 
         glTexCoord2f(1.0, 0.0);
-        glVertex2f(1.0, -1.0);
+        glVertex2f(1.0, 0);
 
         //bottom vertices
         glColor4d(this->Background2[0],this->Background2[1],
@@ -1112,7 +1123,7 @@ void vtkOpenGLRenderer::Clear(void)
         glVertex2f(1.0, 1.0);
 
         glTexCoord2f(0.0, 1.0);
-        glVertex2f(-1.0, 1.0);
+        glVertex2f(0.0, 1.0);
 
         glEnd();
       }
