@@ -79,6 +79,14 @@ int vtkOpenGLScalarsToColorsPainter::GetPremultiplyColorsWithAlpha(
     this->Superclass::GetPremultiplyColorsWithAlpha(actor);
 }
 
+//-----------------------------------------------------------------------------
+vtkIdType vtkOpenGLScalarsToColorsPainter::GetTextureSizeLimit()
+{
+  GLint textureSize = 0;
+  glGetIntegerv(GL_MAX_TEXTURE_SIZE, &textureSize);
+  return static_cast<vtkIdType>(textureSize);
+}
+
 //-----------------------------------------------------------------------------
 void vtkOpenGLScalarsToColorsPainter::RenderInternal(vtkRenderer *renderer, 
                                                      vtkActor *actor,
