@@ -62,23 +62,27 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkPOVExporter.h"
 
 #include "vtkAssemblyPath.h"
-#include "vtkRenderer.h"
 #include "vtkCamera.h"
-#include "vtkLight.h"
-#include "vtkLightCollection.h"
 #include "vtkCellArray.h"
+#include "vtkCompositeDataGeometryFilter.h"
+#include "vtkCompositeDataSet.h"
 #include "vtkFloatArray.h"
-#include "vtkUnsignedCharArray.h"
-#include "vtkPointData.h"
-#include "vtkPolyData.h"
 #include "vtkGeometryFilter.h"
-#include "vtkProperty.h"
-#include "vtkTexture.h"
+#include "vtkLightCollection.h"
+#include "vtkLight.h"
 #include "vtkMapper.h"
 #include "vtkMatrix4x4.h"
-#include "vtkRenderWindow.h"
+#include "vtkPointData.h"
+#include "vtkPolyData.h"
+#include "vtkProperty.h"
 #include "vtkRendererCollection.h"
+#include "vtkRenderer.h"
+#include "vtkRenderWindow.h"
+#include "vtkSmartPointer.h"
+#include "vtkTexture.h"
 #include "vtkTypeTraits.h"
+#include "vtkUnsignedCharArray.h"
+
 #include <vtksys/ios/sstream>
 
 #include "vtkObjectFactory.h"
@@ -313,7 +317,26 @@ void vtkPOVExporter::WriteActor(vtkActor *actor)
     }
   
   // write geometry, first ask the pipeline to update data
-  vtkDataSet *dataset = actor->GetMapper()->GetInput(); 
+  vtkDataSet *dataset = NULL;
+  vtkSmartPointer<vtkDataSet> tempDS;
+
+  vtkDataObject* dObj = actor->GetMapper()->GetInputDataObject(0, 0);
+  vtkCompositeDataSet* cd = vtkCompositeDataSet::SafeDownCast(dObj);
+  if (cd)
+    {
+    vtkCompositeDataGeometryFilter* gf = vtkCompositeDataGeometryFilter::New();
+    gf->SetInput(cd);
+    gf->Update();
+    tempDS = gf->GetOutput();
+    gf->Delete();
+
+    dataset = tempDS;
+    }
+  else
+    {
+    dataset = actor->GetMapper()->GetInput(); 
+    }
+
   if (dataset == NULL) 
     {
     return;
