@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPainterPolyDataMapper.h,v $
+  Module:    vtkPainterPolyDataMapper.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,7 @@ class VTK_RENDERING_EXPORT vtkPainterPolyDataMapper : public vtkPolyDataMapper
 {
 public:
   static vtkPainterPolyDataMapper* New();
-  vtkTypeRevisionMacro(vtkPainterPolyDataMapper, vtkPolyDataMapper);
+  vtkTypeMacro(vtkPainterPolyDataMapper, vtkPolyDataMapper);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -52,12 +52,6 @@ public:
   // resources to release. Merely propagates the call to the painter.
   void ReleaseGraphicsResources(vtkWindow *);
 
-  // Description:
-  // Re-implement the superclass GetBounds method.
-  virtual void GetBounds(double bounds[6])
-    { this->Superclass::GetBounds(bounds); }
-  virtual double *GetBounds();
-
   // Description:
   // Select a data array from the point/cell data
   // and map it to a generic vertex attribute. 
@@ -101,9 +95,15 @@ protected:
   vtkPainterPolyDataMapper();
   ~vtkPainterPolyDataMapper();
 
+  // Description:
+  // Called in GetBounds(). When this method is called, the consider the input
+  // to be updated depending on whether this->Static is set or not. This method
+  // simply obtains the bounds from the data-object and returns it.
+  virtual void ComputeBounds();
+
   // Description:
   // Called when the PainterInformation becomes obsolete. 
-  // It is called before the Render is initiated on the Painter.
+  // It is called before UpdateBounds or Render is initiated on the Painter
   virtual void UpdatePainterInformation();
 
   // Description:
