@@ -38,6 +38,7 @@
 
 vtkStandardNewMacro(vtkPicker);
 
+//----------------------------------------------------------------------
 // Construct object with initial tolerance of 1/40th of window. There are no
 // pick methods and picking is performed from the renderer's actors.
 vtkPicker::vtkPicker()
@@ -57,6 +58,7 @@ vtkPicker::vtkPicker()
   this->Transform = vtkTransform::New();
 }
 
+//----------------------------------------------------------------------
 vtkPicker::~vtkPicker()
 {
   this->Actors->Delete();
@@ -65,8 +67,9 @@ vtkPicker::~vtkPicker()
   this->Transform->Delete();
 }
 
+//----------------------------------------------------------------------
 // Update state when prop3D is picked.
-void vtkPicker::MarkPicked(vtkAssemblyPath *path, vtkProp3D *prop3D, 
+void vtkPicker::MarkPicked(vtkAssemblyPath *path, vtkProp3D *prop3D,
                            vtkAbstractMapper3D *m,
                            double tMin, double mapperPos[3])
 {
@@ -78,7 +81,7 @@ void vtkPicker::MarkPicked(vtkAssemblyPath *path, vtkProp3D *prop3D,
   this->SetPath(path);
   this->GlobalTMin = tMin;
 
-  for (i=0; i < 3; i++) 
+  for (i=0; i < 3; i++)
     {
     this->MapperPosition[i] = mapperPos[i];
     }
@@ -107,7 +110,8 @@ void vtkPicker::MarkPicked(vtkAssemblyPath *path, vtkProp3D *prop3D,
   this->Transform->TransformPoint(mapperPos,this->PickPosition);
 }
 
-// Perform pick operation with selection point provided. Normally the 
+//----------------------------------------------------------------------
+// Perform pick operation with selection point provided. Normally the
 // first two values for the selection point are x-y pixel coordinate, and
 // the third value is =0. Return non-zero if something was successfully picked.
 int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
@@ -118,7 +122,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
   vtkCamera *camera;
   vtkAbstractMapper3D *mapper = NULL;
   double p1World[4], p2World[4], p1Mapper[4], p2Mapper[4];
-  int *winSize;
+  int winSize[2] = {1, 1};
   double x, y, t;
   double *viewport;
   double cameraPos[4], cameraFP[4];
@@ -132,8 +136,8 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
   double tF, tB;
   double hitPosition[3];
   double cameraDOP[3];
-  
-  bounds[0] = bounds[1] = bounds[2] = bounds[3] = bounds[4] = bounds[5] = 0;  
+
+  bounds[0] = bounds[1] = bounds[2] = bounds[3] = bounds[4] = bounds[5] = 0;
 
   //  Initialize picking process
   this->Initialize();
@@ -151,7 +155,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
     return 0;
     }
 
-  // Get camera focal point and position. Convert to display (screen) 
+  // Get camera focal point and position. Convert to display (screen)
   // coordinates. We need a depth value for z-buffer.
   //
   camera = renderer->GetActiveCamera();
@@ -175,11 +179,11 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
     vtkErrorMacro(<<"Bad homogeneous coordinates");
     return 0;
     }
-  for (i=0; i < 3; i++) 
+  for (i=0; i < 3; i++)
     {
     this->PickPosition[i] = worldCoords[i] / worldCoords[3];
     }
-  
+
   //  Compute the ray endpoints.  The ray is along the line running from
   //  the camera position to the selection point, starting where this line
   //  intersects the front clipping plane, and terminating where this
@@ -195,11 +199,11 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
 
   vtkMath::Normalize(cameraDOP);
 
-  if (( rayLength = vtkMath::Dot(cameraDOP,ray)) == 0.0 ) 
+  if (( rayLength = vtkMath::Dot(cameraDOP,ray)) == 0.0 )
     {
     vtkWarningMacro("Cannot process points");
     return 0;
-    } 
+    }
 
   clipRange = camera->GetClippingRange();
 
@@ -207,7 +211,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
     {
     tF = clipRange[0] - rayLength;
     tB = clipRange[1] - rayLength;
-    for (i=0; i<3; i++) 
+    for (i=0; i<3; i++)
       {
       p1World[i] = this->PickPosition[i] + tF*cameraDOP[i];
       p2World[i] = this->PickPosition[i] + tB*cameraDOP[i];
@@ -217,7 +221,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
     {
     tF = clipRange[0] / rayLength;
     tB = clipRange[1] / rayLength;
-    for (i=0; i<3; i++) 
+    for (i=0; i<3; i++)
       {
       p1World[i] = cameraPos[i] + tF*ray[i];
       p2World[i] = cameraPos[i] + tB*ray[i];
@@ -227,11 +231,19 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
 
   // Compute the tolerance in world coordinates.  Do this by
   // determining the world coordinates of the diagonal points of the
-  // window, computing the width of the window in world coordinates, and 
+  // window, computing the width of the window in world coordinates, and
   // multiplying by the tolerance.
   //
   viewport = renderer->GetViewport();
-  winSize = renderer->GetRenderWindow()->GetSize();
+  if (renderer->GetRenderWindow())
+    {
+    int *winSizePtr = renderer->GetRenderWindow()->GetSize();
+    if (winSizePtr)
+      {
+      winSize[0] = winSizePtr[0];
+      winSize[1] = winSizePtr[1];
+      }
+    }
   x = winSize[0] * viewport[0];
   y = winSize[1] * viewport[1];
   renderer->SetDisplayPoint(x, y, selectionZ);
@@ -244,12 +256,12 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
   renderer->DisplayToWorld();
   renderer->GetWorldPoint(windowUpperRight);
 
-  for (tol=0.0,i=0; i<3; i++) 
+  for (tol=0.0,i=0; i<3; i++)
     {
     tol += (windowUpperRight[i] - windowLowerLeft[i]) *
       (windowUpperRight[i] - windowLowerLeft[i]);
     }
-  
+
   tol = sqrt (tol) * this->Tolerance;
 
   //  Loop over all props.  Transform ray (defined from position of
@@ -259,11 +271,11 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
   //
   vtkPropCollection *props;
   vtkProp *propCandidate;
-  if ( this->PickFromList ) 
+  if ( this->PickFromList )
     {
     props = this->GetPickList();
     }
-  else 
+  else
     {
     props = renderer->GetViewProps();
     }
@@ -300,7 +312,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
           LODId = prop3D->GetPickLODID();
           mapper = prop3D->GetLODMapper(LODId);
 
-          // if the mapper is a vtkMapper (as opposed to a vtkVolumeMapper), 
+          // if the mapper is a vtkMapper (as opposed to a vtkVolumeMapper),
           // then check the transparency to see if the object is pickable
           if ( vtkMapper::SafeDownCast(mapper) != NULL)
             {
@@ -319,7 +331,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
           {
           mapper = 0;
           }
-        else 
+        else
           {
           pickable = 0; //only vtkProp3D's (actors and volumes) can be picked
           }
@@ -327,7 +339,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
 
       //  If actor can be picked, get its composite matrix, invert it, and
       //  use the inverted matrix to transform the ray points into mapper
-      //  coordinates. 
+      //  coordinates.
       if ( pickable )
         {
         vtkMatrix4x4 *lastMatrix = path->GetLastNode()->GetMatrix();
@@ -344,7 +356,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
         this->Transform->TransformPoint(p1World,p1Mapper);
         this->Transform->TransformPoint(p2World,p2Mapper);
 
-        for (i=0; i<3; i++) 
+        for (i=0; i<3; i++)
           {
           ray[i] = p2Mapper[i] - p1Mapper[i];
           }
@@ -366,14 +378,14 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
           imageActor->GetDisplayBounds(bounds);
           }
 
-        bounds[0] -= tol; bounds[1] += tol; 
-        bounds[2] -= tol; bounds[3] += tol; 
-        bounds[4] -= tol; bounds[5] += tol; 
+        bounds[0] -= tol; bounds[1] += tol;
+        bounds[2] -= tol; bounds[3] += tol;
+        bounds[4] -= tol; bounds[5] += tol;
 
         if ( vtkBox::IntersectBox(bounds, p1Mapper, ray, hitPosition, t) )
           {
           t = this->IntersectWithLine(
-            p1Mapper, p2Mapper, tol*0.333*(scale[0]+scale[1]+scale[2]), 
+            p1Mapper, p2Mapper, tol*0.333*(scale[0]+scale[1]+scale[2]),
             path, static_cast<vtkProp3D *>(propCandidate), mapper);
 
           if ( t < VTK_DOUBLE_MAX )
@@ -383,7 +395,7 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
             p[1] = (1.0 - t)*p1World[1] + t*p2World[1];
             p[2] = (1.0 - t)*p1World[2] + t*p2World[2];
 
-            // The IsItemPresent method returns "index+1" 
+            // The IsItemPresent method returns "index+1"
             int prevIndex = this->Prop3Ds->IsItemPresent(prop)-1;
 
             if (prevIndex >= 0)
@@ -431,11 +443,12 @@ int vtkPicker::Pick(double selectionX, double selectionY, double selectionZ,
   return picked;
 }
 
+//----------------------------------------------------------------------
 // Intersect data with specified ray.
-double vtkPicker::IntersectWithLine(double p1[3], double p2[3], 
-                                   double vtkNotUsed(tol), 
-                                   vtkAssemblyPath *path, 
-                                   vtkProp3D *prop3D, 
+double vtkPicker::IntersectWithLine(double p1[3], double p2[3],
+                                   double vtkNotUsed(tol),
+                                   vtkAssemblyPath *path,
+                                   vtkProp3D *prop3D,
                                    vtkAbstractMapper3D *mapper)
 {
   int i;
@@ -475,13 +488,14 @@ double vtkPicker::IntersectWithLine(double p1[3], double p2[3],
   t = (ray[0]*(center[0]-p1[0]) + ray[1]*(center[1]-p1[1])
        + ray[2]*(center[2]-p1[2])) / rayFactor;
 
-  if ( t >= 0.0 && t <= 1.0 && t < this->GlobalTMin ) 
+  if ( t >= 0.0 && t <= 1.0 && t < this->GlobalTMin )
     {
     this->MarkPicked(path, prop3D, mapper, t, center);
     }
   return t;
 }
 
+//----------------------------------------------------------------------
 // Initialize the picking process.
 void vtkPicker::Initialize()
 {
@@ -490,7 +504,7 @@ void vtkPicker::Initialize()
   this->Actors->RemoveAllItems();
   this->Prop3Ds->RemoveAllItems();
   this->PickedPositions->Reset();
-  
+
   this->MapperPosition[0] = 0.0;
   this->MapperPosition[1] = 0.0;
   this->MapperPosition[2] = 0.0;
@@ -501,17 +515,19 @@ void vtkPicker::Initialize()
 }
 
 
-vtkActorCollection *vtkPicker::GetActors() 
+//----------------------------------------------------------------------
+vtkActorCollection *vtkPicker::GetActors()
 {
-  if (this->Actors->GetNumberOfItems() != 
-        this->PickedPositions->GetNumberOfPoints()) 
+  if (this->Actors->GetNumberOfItems() !=
+        this->PickedPositions->GetNumberOfPoints())
     {
     vtkWarningMacro(<<"Not all Prop3Ds are actors, use GetProp3Ds instead");
     }
-  return this->Actors; 
+  return this->Actors;
 }
 
 
+//----------------------------------------------------------------------
 void vtkPicker::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
