@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkRenderWindow.h,v $
+  Module:    vtkRenderWindow.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -94,7 +94,7 @@ class vtkUnsignedCharArray;
 class VTK_RENDERING_EXPORT vtkRenderWindow : public vtkWindow
 {
 public:
-  vtkTypeRevisionMacro(vtkRenderWindow,vtkWindow);
+  vtkTypeMacro(vtkRenderWindow,vtkWindow);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -141,11 +141,16 @@ public:
   // to do things like swapping buffers (if necessary) or similar actions.
   virtual void Frame() = 0;
 
+  // Description:
+  // Block the thread until the actual rendering is finished().
+  // Useful for measurement only.
+  virtual void WaitForCompletion()=0;
+  
   // Description:
   // Performed at the end of the rendering process to generate image.
   // This is typically done right before swapping buffers.
   virtual void CopyResultFrame();
-
+  
   // Description:
   // Create an interactor to control renderers in this window. We need
   // to know what type of interactor to create, because we might be in
@@ -306,7 +311,7 @@ public:
   vtkSetMacro(SwapBuffers,int);
   vtkGetMacro(SwapBuffers,int);
   vtkBooleanMacro(SwapBuffers,int);
-
+  
   // Description:
   // Set/Get the pixel data of an image, transmitted as RGBRGBRGB. The
   // front argument indicates if the front buffer should be used or the back
@@ -471,9 +476,15 @@ public:
   virtual void SetParentInfo(char *) = 0;
 
   // Description:
-  // Make this the current window.
+  // Attempt to make this window the current graphics context for the calling
+  // thread.
   virtual void MakeCurrent() = 0;
 
+  // Description:
+  // Tells if this window is the current graphics context for the calling
+  // thread.
+  virtual bool IsCurrent()=0;
+  
   // Description:
   // If called, allow MakeCurrent() to skip cache-check when called.
   // MakeCurrent() reverts to original behavior of cache-checking
