@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkRenderWindowInteractor.h,v $
+  Module:    vtkRenderWindowInteractor.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -65,7 +65,7 @@ class VTK_RENDERING_EXPORT vtkRenderWindowInteractor : public vtkObject
   //ETX
 public:
   static vtkRenderWindowInteractor *New();
-  vtkTypeRevisionMacro(vtkRenderWindowInteractor,vtkObject);
+  vtkTypeMacro(vtkRenderWindowInteractor,vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -426,6 +426,28 @@ public:
   // it is ignored.
   vtkSetMacro(UseTDx,bool);
   vtkGetMacro(UseTDx,bool);
+
+  // Description:
+  // Fire various events. SetEventInformation should be called just prior
+  // to calling any of these methods. These methods will Invoke the
+  // corresponding vtk event.
+  virtual void MouseMoveEvent();
+  virtual void RightButtonPressEvent();
+  virtual void RightButtonReleaseEvent();
+  virtual void LeftButtonPressEvent();
+  virtual void LeftButtonReleaseEvent();
+  virtual void MiddleButtonPressEvent();
+  virtual void MiddleButtonReleaseEvent();
+  virtual void MouseWheelForwardEvent();
+  virtual void MouseWheelBackwardEvent();
+  virtual void ExposeEvent();
+  virtual void ConfigureEvent();
+  virtual void EnterEvent();
+  virtual void LeaveEvent();
+  virtual void KeyPressEvent();
+  virtual void KeyReleaseEvent();
+  virtual void CharEvent();
+  virtual void ExitEvent();
   
 protected:
   vtkRenderWindowInteractor();
@@ -466,6 +488,7 @@ protected:
   int NumberOfFlyFrames;
   double Dolly;
 
+//BTX
   // Description:
   // These methods allow the interactor to control which events are
   // processed.  When the GrabFocus() method is called, then only events that
@@ -473,20 +496,19 @@ protected:
   // typically used by widgets, i.e., subclasses of vtkInteractorObserver, to
   // grab events once an event sequence begins.) Note that the friend
   // declaration is done here to avoid doing so in the superclass vtkObject.
-  //BTX
   friend class vtkInteractorObserver;
   void GrabFocus(vtkCommand *mouseEvents, vtkCommand *keypressEvents=NULL)
     {this->Superclass::InternalGrabFocus(mouseEvents,keypressEvents);}
   void ReleaseFocus()
     {this->Superclass::InternalReleaseFocus();}
-  //ETX
+//ETX
 
   // Description:
   // Widget mediators are used to resolve contention for cursors and other resources.
   vtkObserverMediator *ObserverMediator;
 
+//BTX
   // Timer related members
-  //BTX
   friend struct vtkTimerStruct;
   vtkTimerIdMap *TimerMap; // An internal, PIMPLd map of timers and associated attributes
   unsigned long  TimerDuration; //in milliseconds
@@ -498,7 +520,7 @@ protected:
   virtual int InternalCreateTimer(int timerId, int timerType, unsigned long duration);
   virtual int InternalDestroyTimer(int platformTimerId);
   int GetCurrentTimerId();
-  //ETX
+//ETX
 
   // Force the interactor to handle the Start() event loop, ignoring any 
   // overrides. (Overrides are registered by observing StartEvent on the 
