@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkRenderer.cxx,v $
+  Module:    vtkRenderer.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -41,7 +41,6 @@
 #include "vtkRenderState.h"
 #include "vtkTexture.h"
 
-vtkCxxRevisionMacro(vtkRenderer, "$Revision: 1.256 $");
 vtkCxxSetObjectMacro(vtkRenderer, Delegate, vtkRendererDelegate);
 vtkCxxSetObjectMacro(vtkRenderer, Pass, vtkRenderPass);
 vtkCxxSetObjectMacro(vtkRenderer, BackgroundTexture, vtkTexture);
@@ -403,6 +402,7 @@ void vtkRenderer::Render(void)
       }
     this->TimeFactor = this->AllocatedRenderTime/this->LastRenderTimeInSeconds;
     }
+  this->InvokeEvent(vtkCommand::EndEvent,NULL);
 }
 
 // ----------------------------------------------------------------------------
@@ -586,7 +586,6 @@ int vtkRenderer::UpdateGeometry()
 
   if ( this->PropArrayCount == 0 )
     {
-    this->InvokeEvent(vtkCommand::EndEvent,NULL);
     return 0;
     }
 
@@ -596,7 +595,6 @@ int vtkRenderer::UpdateGeometry()
     //we are doing a visible polygon selection instead of a normal render
     int ret = this->UpdateGeometryForSelection();
 
-    this->InvokeEvent(vtkCommand::EndEvent,NULL);
     this->RenderTime.Modified();
 
     vtkDebugMacro( << "Rendered " <<
@@ -613,7 +611,6 @@ int vtkRenderer::UpdateGeometry()
     // Delegate the rendering of the props to the selector itself.
     this->NumberOfPropsRendered = this->Selector->Render(this,
       this->PropArray, this->PropArrayCount);
-    this->InvokeEvent(vtkCommand::EndEvent,NULL);
     this->RenderTime.Modified();
     vtkDebugMacro("Rendered " << this->NumberOfPropsRendered << " actors" );
     return this->NumberOfPropsRendered;
@@ -663,7 +660,6 @@ int vtkRenderer::UpdateGeometry()
       this->PropArray[i]->RenderOverlay(this);
     }
 
-  this->InvokeEvent(vtkCommand::EndEvent,NULL);
   this->RenderTime.Modified();
 
   vtkDebugMacro( << "Rendered " <<
@@ -1358,6 +1354,12 @@ void vtkRenderer::WorldToView(double &x, double &y, double &z)
   double     view[4];
 
   // get the perspective transformation from the active camera
+  if (!this->ActiveCamera)
+    {
+    vtkErrorMacro("WorldToView: no active camera, cannot compute world to view, returning 0,0,0");
+    x = y = z = 0.0;
+    return;
+    }
   matrix->DeepCopy(this->ActiveCamera->
                 GetCompositeProjectionTransformMatrix(
                   this->GetTiledAspectRatio(),0,1));
