@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkRenderer.h,v $
+  Module:    vtkRenderer.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -16,11 +16,11 @@
 // .SECTION Description
 // vtkRenderer provides an abstract specification for renderers. A renderer
 // is an object that controls the rendering process for objects. Rendering
-// is the process of converting geometry, a specification for lights, and 
-// a camera view into an image. vtkRenderer also performs coordinate 
+// is the process of converting geometry, a specification for lights, and
+// a camera view into an image. vtkRenderer also performs coordinate
 // transformation between world coordinates, view coordinates (the computer
-// graphics rendering coordinate system), and display coordinates (the 
-// actual screen coordinates on the display device). Certain advanced 
+// graphics rendering coordinate system), and display coordinates (the
+// actual screen coordinates on the display device). Certain advanced
 // rendering features such as two-sided lighting can also be controlled.
 
 // .SECTION See Also
@@ -48,6 +48,7 @@ class vtkIdentColoredPainter;
 class vtkHardwareSelector;
 class vtkRendererDelegate;
 class vtkRenderPass;
+class vtkTexture;
 
 #if !defined(VTK_LEGACY_REMOVE)
 class vtkVisibleCellSelector;
@@ -57,7 +58,7 @@ class vtkVisibleCellSelector;
 class VTK_RENDERING_EXPORT vtkRenderer : public vtkViewport
 {
 public:
-  vtkTypeRevisionMacro(vtkRenderer,vtkViewport);
+  vtkTypeMacro(vtkRenderer,vtkViewport);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -90,21 +91,28 @@ public:
   // Description:
   // Return the collection of lights.
   vtkLightCollection *GetLights();
-  
+
+  // Description:
+  // Set the collection of lights.
+  // We cannot name it SetLights because of TestSetGet
+  // \pre lights_exist: lights!=0
+  // \post lights_set: lights==this->GetLights()
+  void SetLightCollection(vtkLightCollection *lights);
+
   // Description:
   // Create and add a light to renderer.
   void CreateLight(void);
-  
+
   // Description:
   // Create a new Light sutible for use with this type of Renderer.
-  // For example, a vtkMesaRenderer should create a vtkMesaLight 
+  // For example, a vtkMesaRenderer should create a vtkMesaLight
   // in this function.   The default is to just call vtkLight::New.
   virtual vtkLight *MakeLight();
 
   // Description:
   // Turn on/off two-sided lighting of surfaces. If two-sided lighting is
   // off, then only the side of the surface facing the light(s) will be lit,
-  // and the other side dark. If two-sided lighting on, both sides of the 
+  // and the other side dark. If two-sided lighting on, both sides of the
   // surface will be lit.
   vtkGetMacro(TwoSidedLighting,int);
   vtkSetMacro(TwoSidedLighting,int);
@@ -114,7 +122,7 @@ public:
   // Turn on/off the automatic repositioning of lights as the camera moves.
   // If LightFollowCamera is on, lights that are designated as Headlights
   // or CameraLights will be adjusted to move with this renderer's camera.
-  // If LightFollowCamera is off, the lights will not be adjusted.  
+  // If LightFollowCamera is off, the lights will not be adjusted.
   //
   // (Note: In previous versions of vtk, this light-tracking
   // functionality was part of the interactors, not the renderer. For
@@ -139,7 +147,7 @@ public:
 
   // Description:
   // Ask the lights in the scene that are not in world space
-  // (for instance, Headlights or CameraLights that are attached to the 
+  // (for instance, Headlights or CameraLights that are attached to the
   // camera) to update their geometry to match the active camera.
   virtual int UpdateLightsGeometryToFollowCamera(void);
 
@@ -163,7 +171,7 @@ public:
 
   // Description:
   // Create a new Camera sutible for use with this type of Renderer.
-  // For example, a vtkMesaRenderer should create a vtkMesaCamera 
+  // For example, a vtkMesaRenderer should create a vtkMesaCamera
   // in this function.   The default is to just call vtkCamera::New.
   virtual vtkCamera *MakeCamera();
 
@@ -209,14 +217,16 @@ public:
 
   // Description:
   // Get the ratio between allocated time and actual render time.
-  // TimeFactor has been taken out of the render process.  
+  // TimeFactor has been taken out of the render process.
   // It is still computed in case someone finds it useful.
   // It may be taken away in the future.
   virtual double GetTimeFactor();
 
   // Description:
-  // Create an image. This is a superclass method which will in turn 
-  // call the DeviceRender method of Subclasses of vtkRenderer
+  // CALLED BY vtkRenderWindow ONLY. End-user pass your way and call
+  // vtkRenderWindow::Render().
+  // Create an image. This is a superclass method which will in turn
+  // call the DeviceRender method of Subclasses of vtkRenderer.
   virtual void Render();
 
   // Description:
@@ -230,7 +240,7 @@ public:
   // override this method.
   // It updates boolean ivar LastRenderingUsedDepthPeeling.
   virtual void DeviceRenderTranslucentPolygonalGeometry();
-  
+
   // Description:
   // Clear the image to the background color.
   virtual void Clear() {};
@@ -245,11 +255,11 @@ public:
 
   // Description:
   // Compute the bounding box of all the visible props
-  // Used in ResetCamera() and ResetCameraClippingRange() 
+  // Used in ResetCamera() and ResetCameraClippingRange()
   void ComputeVisiblePropBounds( double bounds[6] );
 
   // Description:
-  // Wrapper-friendly version of ComputeVisiblePropBounds 
+  // Wrapper-friendly version of ComputeVisiblePropBounds
   double *ComputeVisiblePropBounds();
 
   // Description:
@@ -261,8 +271,8 @@ public:
   // Reset the camera clipping range based on a bounding box.
   // This method is called from ResetCameraClippingRange()
   void ResetCameraClippingRange( double bounds[6] );
-  void ResetCameraClippingRange( double xmin, double xmax, 
-                                 double ymin, double ymax, 
+  void ResetCameraClippingRange( double xmin, double xmax,
+                                 double ymin, double ymax,
                                  double zmin, double zmax);
 
   // Description:
@@ -275,7 +285,7 @@ public:
   // Description:
   // Automatically set up the camera based on the visible actors.
   // The camera will reposition itself to view the center point of the actors,
-  // and move along its initial view plane normal (i.e., vector defined from 
+  // and move along its initial view plane normal (i.e., vector defined from
   // camera position to focal point) so that all of the actors can be seen.
   void ResetCamera();
 
@@ -283,15 +293,15 @@ public:
   // Automatically set up the camera based on a specified bounding box
   // (xmin,xmax, ymin,ymax, zmin,zmax). Camera will reposition itself so
   // that its focal point is the center of the bounding box, and adjust its
-  // distance and position to preserve its initial view plane normal 
-  // (i.e., vector defined from camera position to focal point). Note: is 
+  // distance and position to preserve its initial view plane normal
+  // (i.e., vector defined from camera position to focal point). Note: is
   // the view plane is parallel to the view up axis, the view up axis will
   // be reset to one of the three coordinate axes.
   void ResetCamera(double bounds[6]);
 
   // Description:
   // Alternative version of ResetCamera(bounds[6]);
-  void ResetCamera(double xmin, double xmax, double ymin, double ymax, 
+  void ResetCamera(double xmin, double xmax, double ymin, double ymax,
                    double zmin, double zmax);
 
   // Description:
@@ -301,7 +311,7 @@ public:
   void SetRenderWindow(vtkRenderWindow *);
   vtkRenderWindow *GetRenderWindow() {return this->RenderWindow;};
   virtual vtkWindow *GetVTKWindow();
-  
+
   // Description:
   // Turn on/off using backing store. This may cause the re-rendering
   // time to be slightly slower when the view changes. But it is
@@ -312,7 +322,7 @@ public:
   vtkBooleanMacro(BackingStore,int);
 
   // Description:
-  // Turn on/off interactive status.  An interactive renderer is one that 
+  // Turn on/off interactive status.  An interactive renderer is one that
   // can receive events from an interactor.  Should only be set if
   // there are multiple renderers in the same section of the viewport.
   vtkSetMacro(Interactive,int);
@@ -371,10 +381,10 @@ public:
   vtkGetMacro( NumberOfPropsRendered, int );
 
   // Description:
-  // Return the prop (via a vtkAssemblyPath) that has the highest z value 
-  // at the given x, y position in the viewport.  Basically, the top most 
+  // Return the prop (via a vtkAssemblyPath) that has the highest z value
+  // at the given x, y position in the viewport.  Basically, the top most
   // prop that renders the pixel at selectionX, selectionY will be returned.
-  // If nothing was picked then NULL is returned.  This method selects from 
+  // If nothing was picked then NULL is returned.  This method selects from
   // the renderers Prop list.
   vtkAssemblyPath* PickProp(double selectionX, double selectionY)
     {
@@ -398,16 +408,17 @@ public:
 
   // Description:
   // This method returns 1 if the ActiveCamera has already been set or
-  // automatically created by the renderer. It returns 0 if the 
+  // automatically created by the renderer. It returns 0 if the
   // ActiveCamera does not yet exist.
-  int IsActiveCameraCreated() 
+  int IsActiveCameraCreated()
     { return (this->ActiveCamera != NULL); }
-  
-  
+
+
   // Description:
   // Turn on/off rendering of translucent material with depth peeling
   // technique. The render window must have alpha bits (ie call
-  // SetAlphaBitPlanes(1)) to support depth peeling.
+  // SetAlphaBitPlanes(1)) and no multisample buffer (ie call
+  // SetMultiSamples(0) ) to support depth peeling.
   // If UseDepthPeeling is on and the GPU supports it, depth peeling is used
   // for rendering translucent materials.
   // If UseDepthPeeling is off, alpha blending is used.
@@ -415,7 +426,7 @@ public:
   vtkSetMacro(UseDepthPeeling,int);
   vtkGetMacro(UseDepthPeeling,int);
   vtkBooleanMacro(UseDepthPeeling,int);
-  
+
   // Description:
   // In case of use of depth peeling technique for rendering translucent
   // material, define the threshold under which the algorithm stops to
@@ -426,20 +437,20 @@ public:
   // may speed-up the rendering with small impact on the quality.
   vtkSetClampMacro(OcclusionRatio,double,0.0,0.5);
   vtkGetMacro(OcclusionRatio,double);
-  
+
   // Description:
   // In case of depth peeling, define the maximum number of peeling layers.
   // Initial value is 4. A special value of 0 means no maximum limit.
   // It has to be a positive value.
   vtkSetMacro(MaximumNumberOfPeels,int);
   vtkGetMacro(MaximumNumberOfPeels,int);
-  
+
   // Description:
   // Tells if the last call to DeviceRenderTranslucentPolygonalGeometry()
   // actually used depth peeling.
   // Initial value is false.
   vtkGetMacro(LastRenderingUsedDepthPeeling,int);
-  
+
   // Description:
   // Set/Get a custom Render call. Allows to hook a Render call from an
   // external project.It will be used in place of vtkRenderer::Render() if it
@@ -448,19 +459,31 @@ public:
   void SetDelegate(vtkRendererDelegate *d);
   vtkGetObjectMacro(Delegate,vtkRendererDelegate);
 
-  //BTX
   // Description:
   // Set/Get a custom render pass.
   // Initial value is NULL.
   void SetPass(vtkRenderPass *p);
   vtkGetObjectMacro(Pass,vtkRenderPass);
-  //ETX
-  
+
   // Description:
   // Get the current hardware selector. If the Selector is set, it implies the
   // current render pass is for selection. Mappers/Properties may choose to
   // behave differently when rendering for hardware selection.
   vtkGetObjectMacro(Selector, vtkHardwareSelector);
+
+  // Description:
+  // Set/Get the texture to be used for the background. If set
+  // and enabled this gets the priority over the gradient background.
+  void SetBackgroundTexture(vtkTexture*);
+  vtkGetObjectMacro(BackgroundTexture, vtkTexture);
+
+  // Description:
+  // Set/Get whether this viewport should have a textured background.
+  // Default is off.
+  vtkSetMacro(TexturedBackground,bool);
+  vtkGetMacro(TexturedBackground,bool);
+  vtkBooleanMacro(TexturedBackground,bool);
+
 //BTX
 protected:
   vtkRenderer();
@@ -469,7 +492,7 @@ protected:
   // internal method for doing a render for picking purposes
   virtual void PickRender(vtkPropCollection *props);
   virtual void PickGeometry();
-  
+
   vtkCamera *ActiveCamera;
   vtkLight  *CreatedLight;
 
@@ -478,8 +501,8 @@ protected:
 
   vtkActorCollection *Actors;
   vtkVolumeCollection *Volumes;
-  
-  double              Ambient[3];  
+
+  double              Ambient[3];
   vtkRenderWindow    *RenderWindow;
   double              AllocatedRenderTime;
   double              TimeFactor;
@@ -557,7 +580,7 @@ protected:
   // It is called once with alpha blending technique. It is called multiple
   // times with depth peeling technique.
   virtual int UpdateTranslucentPolygonalGeometry();
-  
+
   // Description:
   // Ask the active camera to do whatever it needs to do prior to rendering.
   // Creates a camera if none found active.
@@ -572,7 +595,7 @@ protected:
   // Description:
   // Ask all lights to load themselves into rendering pipeline.
   // This method will return the actual number of lights that were on.
-  virtual int UpdateLights(void) {return 0;};
+  virtual int UpdateLights(void) {return 0;}
 
   // Description:
   // Get the current camera and reset it only if it gets created
@@ -586,7 +609,7 @@ protected:
   // If this flag is off, alpha blending is used.
   // Initial value is off.
   int UseDepthPeeling;
-  
+
   // Description:
   // In case of use of depth peeling technique for rendering translucent
   // material, define the threshold under which the algorithm stops to
@@ -596,54 +619,54 @@ protected:
   // Initial value is 0.0, meaning rendering have to be exact. Greater values
   // may speed-up the rendering with small impact on the quality.
   double OcclusionRatio;
-   
+
   // Description:
   // In case of depth peeling, define the maximum number of peeling layers.
   // Initial value is 4. A special value of 0 means no maximum limit.
   // It has to be a positive value.
   int MaximumNumberOfPeels;
-  
+
   // Description:
   // Tells if the last call to DeviceRenderTranslucentPolygonalGeometry()
   // actually used depth peeling.
   // Initial value is false.
   int LastRenderingUsedDepthPeeling;
-  
+
 #if !defined(VTK_LEGACY_REMOVE)
   // VISIBLE CELL SELECTION ----------------------------------------
   friend class vtkVisibleCellSelector;
 
   //Description:
-  // Call to put the Renderer into a mode in which it will color visible 
+  // Call to put the Renderer into a mode in which it will color visible
   // polygons with an enoded index. Later the pixel colors can be retrieved to
-  // determine what objects lie behind each pixel.  
-  enum {NOT_SELECTING = 0, COLOR_BY_PROCESSOR, COLOR_BY_ACTOR, 
+  // determine what objects lie behind each pixel.
+  enum {NOT_SELECTING = 0, COLOR_BY_PROCESSOR, COLOR_BY_ACTOR,
         COLOR_BY_CELL_ID_HIGH, COLOR_BY_CELL_ID_MID, COLOR_BY_CELL_ID_LOW,
-        COLOR_BY_VERTEX};  
+        COLOR_BY_VERTEX};
 
   vtkSetMacro(SelectMode, int);
   vtkSetMacro(SelectConst, unsigned int);
 
    // Description:
   // Allows the use of customized Painters for selection.
-  // If none is supplied with this method, a default will be created 
+  // If none is supplied with this method, a default will be created
   // automatically.
   void SetIdentPainter(vtkIdentColoredPainter*);
-  
+
   // Description:
   // Renders each polygon with a color that represents an selection index.
   virtual int UpdateGeometryForSelection(void);
 
   // Description:
-  // Called by UpdateGeometryForSelection to temporarily swap in a mapper to 
+  // Called by UpdateGeometryForSelection to temporarily swap in a mapper to
   // render a prop in selection mode.
-  vtkPainter* SwapInSelectablePainter(vtkProp *, 
+  vtkPainter* SwapInSelectablePainter(vtkProp *,
                                               int &);
 
   // Description:
   // Called by UpdateGeometryForSelection to restore a prop's original mapper.
   void SwapOutSelectablePainter(vtkProp *,
-                                vtkPainter*, 
+                                vtkPainter*,
                                 int );
 
   // Description:
@@ -675,7 +698,10 @@ protected:
 
   friend class vtkRenderPass;
   vtkRenderPass *Pass;
-  
+
+  bool TexturedBackground;
+  vtkTexture* BackgroundTexture;
+
 private:
   vtkRenderer(const vtkRenderer&);  // Not implemented.
   void operator=(const vtkRenderer&);  // Not implemented.
