@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkScalarBarActor.cxx,v $
+  Module:    vtkScalarBarActor.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -32,7 +32,6 @@
 #include "vtkRenderer.h"
 #include "vtkProperty2D.h"
 
-vtkCxxRevisionMacro(vtkScalarBarActor, "$Revision: 1.65 $");
 vtkStandardNewMacro(vtkScalarBarActor);
 
 vtkCxxSetObjectMacro(vtkScalarBarActor,LookupTable,vtkScalarsToColors);
@@ -56,6 +55,7 @@ vtkScalarBarActor::vtkScalarBarActor()
   this->NumberOfLabelsBuilt = 0;
   this->Orientation = VTK_ORIENT_VERTICAL;
   this->Title = NULL;
+  this->ComponentTitle = NULL;
 
   this->LabelTextProperty = vtkTextProperty::New();
   this->LabelTextProperty->SetFontSize(12);
@@ -209,6 +209,12 @@ vtkScalarBarActor::~vtkScalarBarActor()
     delete [] this->Title;
     this->Title = NULL;
     }
+
+  if ( this->ComponentTitle )
+    {
+    delete [] this->ComponentTitle;
+    this->ComponentTitle = NULL;
+    }
   
   this->SetLookupTable(NULL);
   this->SetLabelTextProperty(NULL);
@@ -381,7 +387,24 @@ int vtkScalarBarActor::RenderOpaqueGeometry(vtkViewport *viewport)
     
     // Update all the composing objects
     this->TitleActor->SetProperty(this->GetProperty());
-    this->TitleMapper->SetInput(this->Title);
+    
+    
+    //update with the proper title
+    if ( this->ComponentTitle && strlen(this->ComponentTitle) > 0 )
+      {
+      //need to account for a space between title & component and null term      
+      char *combinedTitle = new char[ ( strlen(this->Title) + strlen(this->ComponentTitle) + 2) ];
+      strcpy(combinedTitle, this->Title );
+      strcat( combinedTitle, " " );
+      strcat( combinedTitle, this->ComponentTitle );
+      this->TitleMapper->SetInput(combinedTitle);
+      delete [] combinedTitle;
+      }
+    else
+      {
+      this->TitleMapper->SetInput(this->Title);
+      }
+
     if (this->TitleTextProperty->GetMTime() > this->BuildTime)
       {
       // Shallow copy here so that the size of the title prop is not affected
@@ -639,6 +662,7 @@ void vtkScalarBarActor::PrintSelf(ostream& os, vtkIndent indent)
     }
 
   os << indent << "Title: " << (this->Title ? this->Title : "(none)") << "\n";
+  os << indent << "ComponentTitle: " << (this->ComponentTitle ? this->ComponentTitle : "(none)") << "\n";
   os << indent << "Maximum Number Of Colors: " 
      << this->MaximumNumberOfColors << "\n";
   os << indent << "Number Of Labels: " << this->NumberOfLabels << "\n";
