@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkShaderProgram2.cxx,v $
+  Module:    vtkShaderProgram2.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,8 +28,35 @@
 #include <assert.h>
 #include "vtkStdString.h"
 
+GLenum vtkGeometryTypeInVTKToGL[5]={
+  GL_POINTS, // VTK_GEOMETRY_SHADER_IN_TYPE_POINTS=0
+  GL_LINES, // VTK_GEOMETRY_SHADER_IN_TYPE_LINES=1,
+  vtkgl::LINES_ADJACENCY_ARB, // VTK_GEOMETRY_SHADER_IN_TYPE_LINES_ADJACENCY=2
+  GL_TRIANGLES, // VTK_GEOMETRY_SHADER_IN_TYPE_TRIANGLES=3
+  vtkgl::TRIANGLES_ADJACENCY_ARB // VTK_GEOMETRY_SHADER_IN_TYPE_TRIANGLES_ADJACENCY=4
+};
+
+const char *vtkGeometryTypeInAsStringArray[5]={
+  "points",
+  "lines",
+  "lines with adjacency",
+  "triangles",
+  "triangles with adjacency"
+};
+
+GLenum vtkGeometryTypeOutVTKToGL[3]={
+  GL_POINTS, // VTK_GEOMETRY_SHADER_OUT_TYPE_POINTS=0
+  GL_LINE_STRIP, // VTK_GEOMETRY_SHADER_OUT_TYPE_LINE_STRIP=1,
+  GL_TRIANGLE_STRIP, // VTK_GEOMETRY_SHADER_OUT_TYPE_TRIANGLE_STRIP=2
+};
+
+const char *vtkGeometryTypeOutAsStringArray[3]={
+  "points",
+  "line strip",
+  "triangle strip"
+};
+
 vtkStandardNewMacro(vtkShaderProgram2);
-vtkCxxRevisionMacro(vtkShaderProgram2, "$Revision: 1.12 $");
 vtkCxxSetObjectMacro(vtkShaderProgram2,UniformVariables,vtkUniformVariables);
 
 //----------------------------------------------------------------------------
@@ -44,7 +71,11 @@ vtkShaderProgram2::vtkShaderProgram2()
   
   this->LastBuildStatus=VTK_SHADER_PROGRAM2_COMPILE_FAILED;
   
-  // 8 as an initial capcity is nice because the allocation is aligned on
+  this->GeometryTypeIn=VTK_GEOMETRY_SHADER_IN_TYPE_POINTS;
+  this->GeometryTypeOut=VTK_GEOMETRY_SHADER_OUT_TYPE_POINTS;
+  this->GeometryVerticesOut=1;
+
+  // 8 as an initial capacity is nice because the allocation is aligned on
   // 32-bit or 64-bit architecture.
   
   this->LastLinkLogCapacity=8;
@@ -204,17 +235,29 @@ bool vtkShaderProgram2::HasVertexShaders()
 
 // ----------------------------------------------------------------------------
 // Description:
-// Tells if at least one of the shaders is a fragment shader.
-// If yes, it means the fragment processing of the fixed-pipeline is
-// bypassed.
-// If no, it means the fragment processing of the fixed-pipeline is used.
-bool vtkShaderProgram2::HasFragmentShaders()
+// Tells if at least one of the shaders is a tessellation control shader.
+bool vtkShaderProgram2::HasTessellationControlShaders()
 {
   bool result=false;
   
   if(this->Shaders!=0)
     {
-    result=this->Shaders->HasFragmentShaders();
+    result=this->Shaders->HasTessellationControlShaders();
+    }
+  
+  return result;
+}
+
+// ----------------------------------------------------------------------------
+// Description:
+// Tells if at least one of the shaders is a tessellation evaluation shader.
+bool vtkShaderProgram2::HasTessellationEvaluationShaders()
+{
+  bool result=false;
+  
+  if(this->Shaders!=0)
+    {
+    result=this->Shaders->HasTessellationEvaluationShaders();
     }
   
   return result;
@@ -235,11 +278,32 @@ bool vtkShaderProgram2::HasGeometryShaders()
   return result;
 }
 
+// ----------------------------------------------------------------------------
+// Description:
+// Tells if at least one of the shaders is a fragment shader.
+// If yes, it means the fragment processing of the fixed-pipeline is
+// bypassed.
+// If no, it means the fragment processing of the fixed-pipeline is used.
+bool vtkShaderProgram2::HasFragmentShaders()
+{
+  bool result=false;
+  
+  if(this->Shaders!=0)
+    {
+    result=this->Shaders->HasFragmentShaders();
+    }
+  
+  return result;
+}
+
 // ----------------------------------------------------------------------------
 // Description:
 // Tell if the program is the one currently used by OpenGL.
 bool vtkShaderProgram2::IsUsed()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+
   GLint value;
   glGetIntegerv(vtkgl::CURRENT_PROGRAM,&value);
   return static_cast<GLuint>(value)==static_cast<GLuint>(this->Id);
@@ -254,6 +318,9 @@ bool vtkShaderProgram2::IsUsed()
 // useful.
 bool vtkShaderProgram2::DisplayListUnderCreationInCompileMode()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+
   bool result=false;
   GLint value;
   glGetIntegerv(GL_LIST_INDEX,&value);
@@ -287,7 +354,7 @@ void vtkShaderProgram2::Use()
   assert("pre: context_is_set" && this->Context!=0);
   assert("pre: current_context_matches" && this->Context->IsCurrent());
   this->Build();
-  
+
   // We need to know if this call happens in a display list or not because
   // glGetIntegerv(vtkgl::CURRENT_PROGRAM,&value) is executed immediately
   // while vtkgl::UseProgram(id) is just compiled and its execution is
@@ -309,6 +376,11 @@ void vtkShaderProgram2::Use()
       if(static_cast<GLuint>(value)!=progId)
         {
         this->SavedId=static_cast<unsigned int>(value);
+        if(this->SavedId!=0)
+          {
+          vtkWarningMacro(<<"another program was used (id=" << this->SavedId
+                          <<"), our id is" << progId << ".");
+          }
         vtkgl::UseProgram(progId);
         }
       assert("check: in_use" && this->IsUsed());
@@ -322,6 +394,9 @@ void vtkShaderProgram2::Use()
 // Restore the previous shader program (or fixed-pipeline).
 void vtkShaderProgram2::Restore()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+
   if(this->DisplayListUnderCreationInCompileMode())
     {
      vtkgl::UseProgram(0);
@@ -336,6 +411,13 @@ void vtkShaderProgram2::Restore()
       vtkgl::UseProgram(static_cast<GLuint>(this->SavedId));
       this->SavedId=0;
       }
+    else
+      {
+      vtkWarningMacro(<<"cannot restore because the program in use (id="
+                      << value <<
+                      ") is not the id of the vtkShaderProgram2 object (id="
+                      << this->Id << ").");
+      }
     }
 }
 
@@ -346,6 +428,9 @@ void vtkShaderProgram2::Restore()
 // creation.
 void vtkShaderProgram2::RestoreFixedPipeline()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+
   vtkgl::UseProgram(0);
   this->SavedId=0;
 }
@@ -353,6 +438,9 @@ void vtkShaderProgram2::RestoreFixedPipeline()
 // ----------------------------------------------------------------------------
 void vtkShaderProgram2::Build()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+
   if(this->Id==0 || this->LastLinkTime<this->MTime ||
      (this->Shaders!=0 && this->LastLinkTime<this->Shaders->GetMTime()))
     {
@@ -416,6 +504,17 @@ void vtkShaderProgram2::Build()
       {
       this->LastBuildStatus=VTK_SHADER_PROGRAM2_LINK_FAILED;
       
+      // It is required to pass geometry shader parameters before linking.
+      if(this->HasGeometryShaders())
+        {
+        vtkgl::ProgramParameteriARB(progId,vtkgl::GEOMETRY_INPUT_TYPE_ARB,
+                                    static_cast<GLint>(vtkGeometryTypeInVTKToGL[this->GeometryTypeIn]));
+        vtkgl::ProgramParameteriARB(progId,vtkgl::GEOMETRY_OUTPUT_TYPE_ARB,
+                                    static_cast<GLint>(vtkGeometryTypeOutVTKToGL[this->GeometryTypeOut]));
+        vtkgl::ProgramParameteriARB(progId,vtkgl::GEOMETRY_VERTICES_OUT_ARB,
+                                    this->GeometryVerticesOut);
+        }
+
       vtkgl::LinkProgram(progId);
       GLint value;
       vtkgl::GetProgramiv(progId,vtkgl::LINK_STATUS,&value);
@@ -431,7 +530,7 @@ void vtkShaderProgram2::Build()
           {
           delete[] this->LastLinkLog;
           }
-        this->LastLinkLogCapacity=value;
+        this->LastLinkLogCapacity=static_cast<size_t>(value);
         this->LastLinkLog=new char[this->LastLinkLogCapacity];
         }
       vtkgl::GetProgramInfoLog(progId,value,0,this->LastLinkLog);
@@ -447,7 +546,7 @@ void vtkShaderProgram2::Build()
           vtkErrorMacro(<<" the shader program failed to link. Its log is:\n"
                         << this->GetLastLinkLog() << "the shaders are: ");
           size_t i=0;
-          size_t c=this->Shaders->GetNumberOfItems();
+          size_t c=static_cast<size_t>(this->Shaders->GetNumberOfItems());
           this->Shaders->InitTraversal();
           s=this->Shaders->GetNextShader();
           while(s!=0)
@@ -469,6 +568,11 @@ void vtkShaderProgram2::Build()
 // ----------------------------------------------------------------------------
 void vtkShaderProgram2::SendUniforms()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+  assert("pre: built" &&
+         this->GetLastBuildStatus()==VTK_SHADER_PROGRAM2_LINK_SUCCEEDED);
+
   bool needUpdate=this->LastSendUniformsTime<this->LastLinkTime;
   if(!needUpdate)
     {
@@ -555,16 +659,20 @@ void vtkShaderProgram2::PrintActiveUniformVariables(
   ostream &os,
   vtkIndent indent)
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+  assert("pre: built" &&
+         this->GetLastBuildStatus()==VTK_SHADER_PROGRAM2_LINK_SUCCEEDED);
+
   GLint params;
   GLuint progId=static_cast<GLuint>(this->Id);
 
   // info about the list of active uniform variables
   vtkgl::GetProgramiv(progId,vtkgl::ACTIVE_UNIFORMS,&params);
   os<< indent << "There are "<<params<<" active uniform variables."<<endl;
-  int i=0;
-  int c=params;
-  vtkgl::GetProgramiv(progId,vtkgl::OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB,
-                      &params);
+  GLuint i=0;
+  GLuint c=static_cast<GLuint>(params);
+  vtkgl::GetProgramiv(progId,vtkgl::ACTIVE_UNIFORM_MAX_LENGTH,&params);
     
   GLint buffSize=params;
   char *name=new char[buffSize+1];
@@ -572,12 +680,16 @@ void vtkShaderProgram2::PrintActiveUniformVariables(
   GLenum type;
   bool isInt;
   int elementSize;
+  bool isSampler;
+  GLenum textureBinding;
   while(i<c)
     {
     vtkgl::GetActiveUniform(progId,i,buffSize,0,&size,&type,name);
     os << indent << i <<" ";
     os << indent;
     isInt=true;
+    isSampler=false;
+    textureBinding=GL_TEXTURE_BINDING_1D;
     elementSize=1;
     switch(type)
       {
@@ -677,21 +789,43 @@ void vtkShaderProgram2::PrintActiveUniformVariables(
         break;
       case vtkgl::SAMPLER_1D:
         os<<"sampler1D";
+        isSampler=true;
+        textureBinding=GL_TEXTURE_BINDING_1D;
         break;
       case vtkgl::SAMPLER_2D:
         os<<"sampler2D";
+        isSampler=true;
+        textureBinding=GL_TEXTURE_BINDING_2D;
         break;
       case vtkgl::SAMPLER_3D:
         os<<"sampler3D";
+        isSampler=true;
+        textureBinding=vtkgl::TEXTURE_BINDING_3D;
         break;
       case vtkgl::SAMPLER_CUBE:
         os<<"samplerCube";
+        isSampler=true;
+        textureBinding=vtkgl::TEXTURE_BINDING_CUBE_MAP;
         break;
       case vtkgl::SAMPLER_1D_SHADOW:
-        os<<"sampler1Dshadow";
+        os<<"sampler1DShadow";
+        isSampler=true;
+        textureBinding=GL_TEXTURE_BINDING_1D;
         break;
       case vtkgl::SAMPLER_2D_SHADOW:
-        os<<"sampler2Dshadow";
+        os<<"sampler2DShadow";
+        isSampler=true;
+        textureBinding=GL_TEXTURE_BINDING_2D;
+        break;
+      case vtkgl::SAMPLER_2D_RECT_ARB:
+        os<<"sampler2DRect";
+        isSampler=true;
+        textureBinding=vtkgl::TEXTURE_BINDING_RECTANGLE_ARB;
+        break;
+      case vtkgl::SAMPLER_2D_RECT_SHADOW_ARB:
+        os<<"sampler2DRectShadow";
+        isSampler=true;
+        textureBinding=vtkgl::TEXTURE_BINDING_RECTANGLE_ARB;
         break;
       }
     os<<" "<<name;
@@ -732,32 +866,64 @@ void vtkShaderProgram2::PrintActiveUniformVariables(
         {
         os << "{";
         }
-      if(isInt)
+      if(loc==-1)
         {
-        vtkgl::GetUniformiv(progId,loc,ivalues);
-        int j=0;
-        while(j<elementSize)
-          {
-          os << ivalues[j];
-          if(j<(elementSize-1))
-            {
-            os << " ";
-            }
-          ++j;
-          }
+        // this a built-in variable like:
+        // gl_DepthRange.near, gl_DepthRange.far, gl_DepthRange.diff,
+        // gl_ProjectionMatrixInverse, ...
+        // we cannot get the value through vtkgl::GetUniform*()
+        os << "<built-in value>";
         }
       else
         {
-        vtkgl::GetUniformfv(progId,loc,fvalues);
-        int j=0;
-        while(j<elementSize)
+        if(isInt)
           {
-          os << fvalues[j];
-          if(j<(elementSize-1))
+          vtkgl::GetUniformiv(progId,loc,ivalues);
+          int j=0;
+          while(j<elementSize)
             {
-            os << " ";
+            os << ivalues[j];
+            if(j<(elementSize-1))
+              {
+              os << " ";
+              }
+            ++j;
+            }
+          if(isSampler)
+            {
+            os << " (Texture Unit)->";
+            GLint savedActiveTextureUnit;
+            glGetIntegerv(vtkgl::ACTIVE_TEXTURE,&savedActiveTextureUnit);
+            savedActiveTextureUnit=static_cast<GLint>(
+              static_cast<GLenum>(savedActiveTextureUnit)-vtkgl::TEXTURE0);
+            if(savedActiveTextureUnit!=ivalues[0])
+              {
+              vtkgl::ActiveTexture(vtkgl::TEXTURE0+
+                                   static_cast<GLenum>(ivalues[0]));
+              }
+            GLint textureObject;
+            glGetIntegerv(textureBinding,&textureObject);
+            if(savedActiveTextureUnit!=ivalues[0])
+              {
+              vtkgl::ActiveTexture(
+                vtkgl::TEXTURE0+static_cast<GLenum>(savedActiveTextureUnit));
+              }
+            os << textureObject << " (Texture Object)";
+            }
+          }
+        else
+          {
+          vtkgl::GetUniformfv(progId,loc,fvalues);
+          int j=0;
+          while(j<elementSize)
+            {
+            os << fvalues[j];
+            if(j<(elementSize-1))
+              {
+              os << " ";
+              }
+            ++j;
             }
-          ++j;
           }
         }
       if(elementSize>1)
@@ -793,6 +959,10 @@ void vtkShaderProgram2::PrintActiveUniformVariables(
 // Call PrintActiveUniformVariables on cout. Useful for calling inside gdb.
 void vtkShaderProgram2::PrintActiveUniformVariablesOnCout()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+  assert("pre: built" &&
+         this->GetLastBuildStatus()==VTK_SHADER_PROGRAM2_LINK_SUCCEEDED);
   vtkIndent i;
   this->PrintActiveUniformVariables(cout,i);
 }
@@ -802,13 +972,33 @@ void vtkShaderProgram2::PrintActiveUniformVariablesOnCout()
 // Tell if the shader program is valid with the current OpenGL state.
 bool vtkShaderProgram2::IsValid()
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
+  assert("pre: built" &&
+         this->GetLastBuildStatus()==VTK_SHADER_PROGRAM2_LINK_SUCCEEDED);
+
   // this line change the program log.
   GLuint progId=static_cast<GLuint>(this->Id);
   vtkgl::ValidateProgram(progId);
   
   GLint value;
   vtkgl::GetProgramiv(progId,vtkgl::VALIDATE_STATUS,&value);
-  return value==GL_TRUE;
+
+  bool result=value==GL_TRUE;
+
+  vtkgl::GetProgramiv(progId,vtkgl::INFO_LOG_LENGTH,&value);
+  if(static_cast<size_t>(value)>this->LastValidateLogCapacity)
+    {
+    if(this->LastValidateLog!=0)
+      {
+      delete[] this->LastValidateLog;
+      }
+    this->LastValidateLogCapacity=static_cast<size_t>(value);
+    this->LastValidateLog=new char[this->LastValidateLogCapacity];
+    }
+  vtkgl::GetProgramInfoLog(progId,value,0,this->LastValidateLog);
+
+  return result;
 }
 
 //----------------------------------------------------------------------------
@@ -850,6 +1040,8 @@ const char *vtkShaderProgram2::GetLastValidateLog()
 //----------------------------------------------------------------------------
 int vtkShaderProgram2::GetAttributeLocation(const char *name)
 {
+  assert("pre: context_is_set" && this->Context!=0);
+  assert("pre: current_context_matches" && this->Context->IsCurrent());
   assert("pre: name_exists" && name!=0);
   assert("pre: built" &&
          this->LastBuildStatus==VTK_SHADER_PROGRAM2_LINK_SUCCEEDED);
@@ -860,7 +1052,7 @@ int vtkShaderProgram2::GetAttributeLocation(const char *name)
 void vtkShaderProgram2::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  
+
   os << indent << "Context: ";
   if(this->Context!=0)
     {
@@ -870,27 +1062,7 @@ void vtkShaderProgram2::PrintSelf(ostream& os, vtkIndent indent)
     {
     os << "none" << endl;
     }
-  
-  os << indent << "UniformVariables: ";
-  if(this->UniformVariables!=0)
-    {
-    this->UniformVariables->PrintSelf(os,indent);
-    }
-  else
-    {
-    os << "none" << endl;
-    }
-  
-  os << indent << "Shaders: ";
-  if(this->Shaders!=0)
-    {
-    this->Shaders->PrintSelf(os,indent);
-    }
-  else
-    {
-    os << "none" <<  endl;
-    }
-  
+
   os << indent << "PrintErrors: ";
   if(this->PrintErrors)
     {
@@ -900,5 +1072,53 @@ void vtkShaderProgram2::PrintSelf(ostream& os, vtkIndent indent)
     {
     os << "false" << endl;
     }
+
+  os << indent << "LastBuildStatus: ";
+  switch(this->LastBuildStatus)
+    {
+    case VTK_SHADER_PROGRAM2_COMPILE_FAILED:
+      os << "Compile failed";
+      break;
+    case VTK_SHADER_PROGRAM2_LINK_FAILED:
+      os << "Link failed";
+      break;
+    case VTK_SHADER_PROGRAM2_LINK_SUCCEEDED:
+      os << "Link succeeded";
+      break;
+    default:
+      os << "ERROR unknown value!";
+      break;
+    }
+  os << endl;
+
+  os << indent << "OpenGL Id: " << this->Id << endl;
+
+  os << indent << "GeometryTypeIn: " <<
+    vtkGeometryTypeInAsStringArray[this->GeometryTypeIn] << endl;
+
+  os << indent << "GeometryTypeOut: " <<
+    vtkGeometryTypeInAsStringArray[this->GeometryTypeOut] << endl;
+
+  os << indent << "GeometryVerticesOut: " << this->GeometryVerticesOut << endl;
+
+  os << indent << "UniformVariables: ";
+  if(this->UniformVariables!=0)
+    {
+    this->UniformVariables->PrintSelf(os,indent);
+    }
+  else
+    {
+    os << "none" << endl;
+    }
+
+  os << indent << "Shaders: ";
+  if(this->Shaders!=0)
+    {
+    this->Shaders->PrintSelf(os,indent);
+    }
+  else
+    {
+    os << "none" <<  endl;
+    }
 }
 
