@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTesting.cxx,v $
+  Module:    vtkTesting.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -41,8 +41,9 @@
 
 #include <sys/stat.h>
 
+#include <vtksys/SystemTools.hxx>
+
 vtkStandardNewMacro(vtkTesting);
-vtkCxxRevisionMacro(vtkTesting, "$Revision: 1.37 $");
 vtkCxxSetObjectMacro(vtkTesting, RenderWindow, vtkRenderWindow);
 
 using vtkstd::vector;
@@ -188,7 +189,8 @@ const char *vtkTesting::GetDataRoot()
   string dr=vtkTestingGetArgOrEnvOrDefault(
                 "-D",this->Args, "VTK_DATA_ROOT","../../../../VTKData");
 #endif
-  this->SetDataRoot(dr.c_str());
+  this->SetDataRoot(
+     vtksys::SystemTools::CollapseFullPath(dr.c_str()).c_str());
 
   return this->DataRoot;
 }
@@ -197,8 +199,8 @@ const char *vtkTesting::GetTempDirectory()
 {
   string td=vtkTestingGetArgOrEnvOrDefault(
                 "-T",this->Args, "VTK_TEMP_DIR","../../../Testing/Temporary");
-
-  this->SetTempDirectory(td.c_str());
+  this->SetTempDirectory(
+    vtksys::SystemTools::CollapseFullPath(td.c_str()).c_str());
 
   return this->TempDirectory;
 }
