@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTextActor3D.h,v $
+  Module:    vtkTextActor3D.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -43,7 +43,7 @@ class VTK_RENDERING_EXPORT vtkTextActor3D : public vtkProp3D
 {
 public:
   static vtkTextActor3D *New();
-  vtkTypeRevisionMacro(vtkTextActor3D,vtkProp3D);
+  vtkTypeMacro(vtkTextActor3D,vtkProp3D);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
