@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkVisibleCellSelector.h,v $
+  Module:    vtkVisibleCellSelector.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -66,7 +66,7 @@ class vtkIdentColoredPainter;
 class VTK_RENDERING_EXPORT vtkVisibleCellSelector  : public vtkObject
 {
 public:
-  vtkTypeRevisionMacro(vtkVisibleCellSelector, vtkObject);
+  vtkTypeMacro(vtkVisibleCellSelector, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
   static vtkVisibleCellSelector *New();
 
