@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTextAnalysisUtility.h,v $
+  Module:    vtkTextAnalysisUtility.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -18,11 +18,6 @@
   the U.S. Government retains certain rights in this software.
 -------------------------------------------------------------------------*/
 
-#ifndef _vtkTextAnalysisUtility_h
-#define _vtkTextAnalysisUtility_h
-
-#include "vtkSystemIncludes.h"
-
 // .NAME vtkTextAnalysisUtility
 //
 // .SECTION Description
@@ -30,6 +25,11 @@
 // .SECTION Thanks
 // Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories.
 
+#ifndef _vtkTextAnalysisUtility_h
+#define _vtkTextAnalysisUtility_h
+
+#include "vtkSystemIncludes.h"
+
 class VTK_TEXT_ANALYSIS_EXPORT vtkTextAnalysisUtility
 {
 public:
