@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTextExtractionStrategy.cxx,v $
+  Module:    vtkTextExtractionStrategy.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -20,7 +20,6 @@
 
 #include <vtkTextExtractionStrategy.h>
 
-vtkCxxRevisionMacro(vtkTextExtractionStrategy, "$Revision: 1.1 $");
 
 vtkTextExtractionStrategy::vtkTextExtractionStrategy()
 {
