@@ -46,14 +46,14 @@
 *
 * revision history - 
 *
-*  $Id: exerr.c,v 1.3 2009-01-16 14:32:01 utkarsh Exp $
+*  Id
 *
 *****************************************************************************/
 
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include "netcdf.h"
+#include "vtk_netcdf.h"
 #include "exodusII.h"
 #include "exodusII_int.h"
 
