@@ -46,7 +46,7 @@
 *
 * revision history - 
 *
-*  $Id: expcset.c,v 1.4 2009-01-19 18:46:31 utkarsh Exp $
+*  Id
 *
 *****************************************************************************/
 
@@ -64,8 +64,8 @@
  */
 
 int ex_put_concat_sets (int   exoid,
-			ex_entity_type set_type,
-			const struct ex_set_specs* set_specs)
+                        ex_entity_type set_type,
+                        const struct ex_set_specs* set_specs)
 {
   int status;
   int temp;
@@ -85,10 +85,10 @@ int ex_put_concat_sets (int   exoid,
   char errmsg[MAX_ERR_LENGTH];
   char* idsptr;
   char* statptr;
-  char* numdfptr = NULL;
-  char* factptr = NULL;
-  char* elemptr = NULL;
-  char* extraptr = NULL;
+  char* numdfptr;
+  char* factptr;
+  char* elemptr;
+  char* extraptr;
   ex_inquiry ex_inq_val;
   const int *extra_list;   
 
@@ -127,7 +127,7 @@ int ex_put_concat_sets (int   exoid,
   else {
     exerrval = EX_FATAL;
     sprintf(errmsg,
-	    "Error: invalid set type (%d)", set_type);
+            "Error: invalid set type (%d)", set_type);
     ex_err("ex_put_set_param",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -137,13 +137,13 @@ int ex_put_concat_sets (int   exoid,
     if (status == NC_EBADDIM) {
       exerrval = status;
       sprintf(errmsg,
-	      "Error: no %ss defined for file id %d", ex_name_of_object(set_type), exoid);
+              "Error: no %ss defined for file id %d", ex_name_of_object(set_type), exoid);
       ex_err("ex_put_concat_sets",errmsg,exerrval);
     } else {
       exerrval = status;
       sprintf(errmsg,
-	      "Error: failed to locate %ss defined in file id %d",
-	      ex_name_of_object(set_type), exoid);
+              "Error: failed to locate %ss defined in file id %d",
+              ex_name_of_object(set_type), exoid);
       ex_err("ex_put_concat_sets",errmsg,exerrval);
     }
     return (EX_FATAL);
@@ -152,8 +152,8 @@ int ex_put_concat_sets (int   exoid,
   /* inquire how many sets are to be stored */
   if (ex_inquire(exoid, ex_inq_val, &num_sets, &fdum, cdum) != NC_NOERR)  {
     sprintf(errmsg,
-	    "Error: failed to get number of %ss defined for file id %d",
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to get number of %ss defined for file id %d",
+            ex_name_of_object(set_type), exoid);
     /* use error val from inquire */
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
@@ -165,8 +165,8 @@ int ex_put_concat_sets (int   exoid,
   if (!(set_stat= malloc(num_sets*sizeof(int)))) {
     exerrval = EX_MEMFAIL;
     sprintf(errmsg,
-	    "Error: failed to allocate space for %s status array in file id %d",
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to allocate space for %s status array in file id %d",
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -182,8 +182,8 @@ int ex_put_concat_sets (int   exoid,
   if ((status = nc_inq_varid(exoid, statptr, &varid)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to locate %s status in file id %d", 
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to locate %s status in file id %d", 
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -193,8 +193,8 @@ int ex_put_concat_sets (int   exoid,
   if (status != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to store %s status array to file id %d",
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to store %s status array to file id %d",
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_concat_set",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -205,8 +205,8 @@ int ex_put_concat_sets (int   exoid,
   if ((status = nc_redef (exoid)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to put file id %d into define mode",
-	    exoid);
+            "Error: failed to put file id %d into define mode",
+            exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -222,14 +222,14 @@ int ex_put_concat_sets (int   exoid,
     if (cur_num_sets >= num_sets) {
       exerrval = EX_FATAL;
       sprintf(errmsg,
-	      "Error: exceeded number of %ss (%d) defined in file id %d",
-	      ex_name_of_object(set_type), num_sets,exoid);
+              "Error: exceeded number of %ss (%d) defined in file id %d",
+              ex_name_of_object(set_type), num_sets,exoid);
       ex_err("ex_put_concat_sets",errmsg,exerrval);
       goto error_ret;
     }
 
     /*   NOTE: ex_inc_file_item  is used to find the number of sets
-	 for a specific file and returns that value incremented. */
+         for a specific file and returns that value incremented. */
 
     cur_num_sets=ex_inc_file_item(exoid, ex_get_counter_list(set_type));
     set_id_ndx = cur_num_sets + 1;
@@ -272,19 +272,19 @@ int ex_put_concat_sets (int   exoid,
       continue; /* Do not create anything for NULL sets! */
 
     if ((status = nc_def_dim(exoid, ex_dim_num_entries_in_object(set_type, set_id_ndx),
-			     num_entries_per_set[i], &dimid)) != NC_NOERR) {
+                             num_entries_per_set[i], &dimid)) != NC_NOERR) {
       if (status == NC_ENAMEINUSE) {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: %s entry count %d already defined in file id %d",
-		ex_name_of_object(set_type), set_ids[i],exoid);
-	ex_err("ex_put_concat_sets",errmsg,exerrval);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: %s entry count %d already defined in file id %d",
+                ex_name_of_object(set_type), set_ids[i],exoid);
+        ex_err("ex_put_concat_sets",errmsg,exerrval);
       } else {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: failed to define number of entries for %s %d in file id %d",
-		ex_name_of_object(set_type), set_ids[i],exoid);
-	ex_err("ex_put_concat_sets",errmsg,exerrval);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: failed to define number of entries for %s %d in file id %d",
+                ex_name_of_object(set_type), set_ids[i],exoid);
+        ex_err("ex_put_concat_sets",errmsg,exerrval);
       }
       goto error_ret;
     }
@@ -294,17 +294,17 @@ int ex_put_concat_sets (int   exoid,
     dims[0] = dimid;
     if ((status = nc_def_var(exoid,elemptr,NC_INT,1,dims, &temp)) != NC_NOERR) {
       if (status == NC_ENAMEINUSE) {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: element list already exists for %s %d in file id %d",
-		ex_name_of_object(set_type), set_ids[i],exoid);
-	ex_err("ex_put_concat_sets",errmsg,exerrval);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: element list already exists for %s %d in file id %d",
+                ex_name_of_object(set_type), set_ids[i],exoid);
+        ex_err("ex_put_concat_sets",errmsg,exerrval);
       } else {
-	exerrval = status;
-	sprintf(errmsg,
-		"Error: failed to create element list for %s %d in file id %d",
-		ex_name_of_object(set_type), set_ids[i],exoid);
-	ex_err("ex_put_concat_sets",errmsg,exerrval);
+        exerrval = status;
+        sprintf(errmsg,
+                "Error: failed to create element list for %s %d in file id %d",
+                ex_name_of_object(set_type), set_ids[i],exoid);
+        ex_err("ex_put_concat_sets",errmsg,exerrval);
       }
       goto error_ret;            /* exit define mode and return */
     }
@@ -312,20 +312,20 @@ int ex_put_concat_sets (int   exoid,
     /* create extra list variable for set  (only for edge, face and side sets) */
     if (extraptr) {
       if ((status = nc_def_var(exoid,extraptr,NC_INT,1,dims, &temp)) != NC_NOERR) { 
-	if (status == NC_ENAMEINUSE) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: extra list already exists for %s %d in file id %d",
-		  ex_name_of_object(set_type), set_ids[i],exoid);
-	  ex_err("ex_put_concat_sets",errmsg,exerrval);
-	} else {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to create extra list for %s %d in file id %d",
-		  ex_name_of_object(set_type), set_ids[i],exoid);
-	  ex_err("ex_put_concat_sets",errmsg,exerrval);
-	}
-	goto error_ret;         /* exit define mode and return */
+        if (status == NC_ENAMEINUSE) {
+          exerrval = status;
+          sprintf(errmsg,
+                  "Error: extra list already exists for %s %d in file id %d",
+                  ex_name_of_object(set_type), set_ids[i],exoid);
+          ex_err("ex_put_concat_sets",errmsg,exerrval);
+        } else {
+          exerrval = status;
+          sprintf(errmsg,
+                  "Error: failed to create extra list for %s %d in file id %d",
+                  ex_name_of_object(set_type), set_ids[i],exoid);
+          ex_err("ex_put_concat_sets",errmsg,exerrval);
+        }
+        goto error_ret;         /* exit define mode and return */
       }
     }
 
@@ -334,53 +334,53 @@ int ex_put_concat_sets (int   exoid,
     if (num_dist_per_set[i] > 0) {
       
       if (set_type == EX_NODE_SET) {
-	if (num_dist_per_set[i] != num_entries_per_set[i]) {
-	  exerrval = EX_FATAL;
-	  sprintf(errmsg,
-		  "Error: # dist fact (%d) not equal to # nodes (%d) in node set %d file id %d",
-		  num_dist_per_set[i], num_entries_per_set[i], set_ids[i],exoid);
-	  ex_err("ex_put_concat_sets",errmsg,exerrval);
-	  goto error_ret;          /* exit define mode and return */
-	}
+        if (num_dist_per_set[i] != num_entries_per_set[i]) {
+          exerrval = EX_FATAL;
+          sprintf(errmsg,
+                  "Error: # dist fact (%d) not equal to # nodes (%d) in node set %d file id %d",
+                  num_dist_per_set[i], num_entries_per_set[i], set_ids[i],exoid);
+          ex_err("ex_put_concat_sets",errmsg,exerrval);
+          goto error_ret;          /* exit define mode and return */
+        }
 
-	/* resuse dimid from entry lists */
+        /* resuse dimid from entry lists */
       } else  {
-	if ((status = nc_def_dim(exoid, numdfptr,
-				 num_dist_per_set[i], &dimid)) != NC_NOERR) {
-	  if (status == NC_ENAMEINUSE) {
-	    exerrval = status;
-	    sprintf(errmsg,
-		    "Error: %s df count %d already defined in file id %d",
-		    ex_name_of_object(set_type), set_ids[i],exoid);
-	    ex_err("ex_put_concat_sets",errmsg,exerrval);
-	  } else {
-	    exerrval = status;
-	    sprintf(errmsg,
-		    "Error: failed to define %s df count for set %d in file id %d",
-		    ex_name_of_object(set_type), set_ids[i],exoid);
-	    ex_err("ex_put_concat_sets",errmsg,exerrval);
-	  }
-	  goto error_ret;
-	}
+        if ((status = nc_def_dim(exoid, numdfptr,
+                                 num_dist_per_set[i], &dimid)) != NC_NOERR) {
+          if (status == NC_ENAMEINUSE) {
+            exerrval = status;
+            sprintf(errmsg,
+                    "Error: %s df count %d already defined in file id %d",
+                    ex_name_of_object(set_type), set_ids[i],exoid);
+            ex_err("ex_put_concat_sets",errmsg,exerrval);
+          } else {
+            exerrval = status;
+            sprintf(errmsg,
+                    "Error: failed to define %s df count for set %d in file id %d",
+                    ex_name_of_object(set_type), set_ids[i],exoid);
+            ex_err("ex_put_concat_sets",errmsg,exerrval);
+          }
+          goto error_ret;
+        }
       }
 
       /* create distribution factor list variable for set */
       dims[0] = dimid;
       if ((status = nc_def_var(exoid, factptr, nc_flt_code(exoid), 1, dims, &temp)) != NC_NOERR) {
-	if (status == NC_ENAMEINUSE) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: dist factor list already exists for %s %d in file id %d",
-		  ex_name_of_object(set_type), set_ids[i],exoid);
-	  ex_err("ex_put_concat_sets",errmsg,exerrval);
-	} else {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to create dist factor list for %s %d in file id %d",
-		  ex_name_of_object(set_type), set_ids[i],exoid);
-	  ex_err("ex_put_concat_sets",errmsg,exerrval);
-	}
-	goto error_ret;            /* exit define mode and return */
+        if (status == NC_ENAMEINUSE) {
+          exerrval = status;
+          sprintf(errmsg,
+                  "Error: dist factor list already exists for %s %d in file id %d",
+                  ex_name_of_object(set_type), set_ids[i],exoid);
+          ex_err("ex_put_concat_sets",errmsg,exerrval);
+        } else {
+          exerrval = status;
+          sprintf(errmsg,
+                  "Error: failed to create dist factor list for %s %d in file id %d",
+                  ex_name_of_object(set_type), set_ids[i],exoid);
+          ex_err("ex_put_concat_sets",errmsg,exerrval);
+        }
+        goto error_ret;            /* exit define mode and return */
       }
     } /* end define dist factors */
   }
@@ -389,8 +389,8 @@ int ex_put_concat_sets (int   exoid,
   if ((status = nc_enddef (exoid)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to complete definition in file id %d",
-	    exoid);
+            "Error: failed to complete definition in file id %d",
+            exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -401,8 +401,8 @@ int ex_put_concat_sets (int   exoid,
   if ((status = nc_inq_varid(exoid, idsptr, &varid)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to locate %s ids array in file id %d",
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to locate %s ids array in file id %d",
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -413,8 +413,8 @@ int ex_put_concat_sets (int   exoid,
   if (status != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to store %s id array in file id %d",
-	    ex_name_of_object(set_type), exoid);
+            "Error: failed to store %s id array in file id %d",
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_concat_sets",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -430,54 +430,54 @@ int ex_put_concat_sets (int   exoid,
   for (i=0; i<num_sets; i++) {
 
       if (num_entries_per_set[i] == 0) /* Is this a NULL set? */
-	continue; /* Do not create anything for NULL sets! */
+        continue; /* Do not create anything for NULL sets! */
 
       /* set extra list */
       if (set_type == EX_EDGE_SET || set_type == EX_FACE_SET ||
-	  set_type == EX_SIDE_SET)
-	extra_list = &(sets_extra_list[sets_entry_index[i]]);
+          set_type == EX_SIDE_SET)
+        extra_list = &(sets_extra_list[sets_entry_index[i]]);
       else
-	extra_list = NULL;
+        extra_list = NULL;
 
       if (ex_put_set(exoid, set_type, set_ids[i], 
-		     &(sets_entry_list[sets_entry_index[i]]),
-		     extra_list) == -1)
-	return(EX_FATAL); /* error will be reported by subroutine */
+                     &(sets_entry_list[sets_entry_index[i]]),
+                     extra_list) == -1)
+        return(EX_FATAL); /* error will be reported by subroutine */
 
       if (ex_comp_ws(exoid) == sizeof(float)) {
-	flt_dist_fact = sets_dist_fact;
-	if (num_dist_per_set[i] > 0) {     /* store dist factors if required */
-	  if (ex_put_set_dist_fact(exoid, set_type, set_ids[i],
-				   &(flt_dist_fact[sets_dist_index[i]])) == -1) {
-	      sprintf(errmsg,
-		      "Error: failed to store %s %d dist factors for file id %d",
-		      ex_name_of_object(set_type), set_ids[i],exoid);
-	      /* use error val from exodusII routine */
-	      ex_err("ex_put_concat_sets",errmsg,exerrval);
-	      return (EX_FATAL);
-	    }
-	}
+        flt_dist_fact = sets_dist_fact;
+        if (num_dist_per_set[i] > 0) {     /* store dist factors if required */
+          if (ex_put_set_dist_fact(exoid, set_type, set_ids[i],
+                                   &(flt_dist_fact[sets_dist_index[i]])) == -1) {
+              sprintf(errmsg,
+                      "Error: failed to store %s %d dist factors for file id %d",
+                      ex_name_of_object(set_type), set_ids[i],exoid);
+              /* use error val from exodusII routine */
+              ex_err("ex_put_concat_sets",errmsg,exerrval);
+              return (EX_FATAL);
+            }
+        }
       } else if (ex_comp_ws(exoid) == sizeof(double)) {
-	dbl_dist_fact = sets_dist_fact;
-	if (num_dist_per_set[i] > 0) {             /* only store if they exist */
-	  if (ex_put_set_dist_fact(exoid, set_type, set_ids[i],
-				   &(dbl_dist_fact[sets_dist_index[i]])) == -1) {
-	    sprintf(errmsg,
-		    "Error: failed to store %s %d dist factors for file id %d",
-		    ex_name_of_object(set_type), set_ids[i],exoid);
-	    /* use error val from exodusII routine */
-	    ex_err("ex_put_concat_sets",errmsg,exerrval);
-	    return (EX_FATAL);
-	  }
-	}
+        dbl_dist_fact = sets_dist_fact;
+        if (num_dist_per_set[i] > 0) {             /* only store if they exist */
+          if (ex_put_set_dist_fact(exoid, set_type, set_ids[i],
+                                   &(dbl_dist_fact[sets_dist_index[i]])) == -1) {
+            sprintf(errmsg,
+                    "Error: failed to store %s %d dist factors for file id %d",
+                    ex_name_of_object(set_type), set_ids[i],exoid);
+            /* use error val from exodusII routine */
+            ex_err("ex_put_concat_sets",errmsg,exerrval);
+            return (EX_FATAL);
+          }
+        }
       } else {
-	/* unknown floating point word size */
-	exerrval = EX_BADPARAM;
-	sprintf(errmsg,
-		"Error: unsupported floating point word size %d for file id %d",
-		ex_comp_ws(exoid), exoid);
-	ex_err("ex_put_concat_sets", errmsg, exerrval);
-	return (EX_FATAL);
+        /* unknown floating point word size */
+        exerrval = EX_BADPARAM;
+        sprintf(errmsg,
+                "Error: unsupported floating point word size %d for file id %d",
+                ex_comp_ws(exoid), exoid);
+        ex_err("ex_put_concat_sets", errmsg, exerrval);
+        return (EX_FATAL);
       }
   }
   return(EX_NOERR);
@@ -488,8 +488,8 @@ int ex_put_concat_sets (int   exoid,
   if (nc_enddef (exoid) != NC_NOERR)     /* exit define mode */
     {
       sprintf(errmsg,
-	      "Error: failed to complete definition for file id %d",
-	      exoid);
+              "Error: failed to complete definition for file id %d",
+              exoid);
       ex_err("ex_put_concat_sets",errmsg,exerrval);
     }
   return (EX_FATAL);
