@@ -48,7 +48,7 @@
 *
 * revision history - 
 *
-*  $Id: expset.c,v 1.4 2009-01-19 18:46:31 utkarsh Exp $
+*  Id
 *
 *****************************************************************************/
 
@@ -66,16 +66,16 @@
  */
 
 int ex_put_set (int   exoid,
-		ex_entity_type set_type,
-		int   set_id,
-		const int  *set_entry_list,
-		const int  *set_extra_list)
+                ex_entity_type set_type,
+                int   set_id,
+                const int  *set_entry_list,
+                const int  *set_extra_list)
 {
   int dimid, status;
   int entry_list_id, extra_list_id, set_id_ndx;
   char errmsg[MAX_ERR_LENGTH];
-  char* entryptr = NULL;
-  char* extraptr = NULL;
+  char* entryptr;
+  char* extraptr;
 
   exerrval = 0; /* clear error code */
 
@@ -84,7 +84,7 @@ int ex_put_set (int   exoid,
     exerrval = status;
     sprintf(errmsg,
             "Error: no %ss defined in file id %d",
-	    ex_name_of_object(set_type), exoid);
+            ex_name_of_object(set_type), exoid);
     ex_err("ex_put_set",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -95,13 +95,13 @@ int ex_put_set (int   exoid,
     if (exerrval == EX_NULLENTITY) {
       sprintf(errmsg,
               "Warning: no data allowed for NULL %s %d in file id %d",
-	      ex_name_of_object(set_type),set_id,exoid);
+              ex_name_of_object(set_type),set_id,exoid);
       ex_err("ex_put_set",errmsg,EX_MSG);
       return (EX_WARN);
     } else {
       sprintf(errmsg,
-	      "Error: failed to locate %s id %d in VAR_*S_IDS array in file id %d",
-	      ex_name_of_object(set_type), set_id,exoid);
+              "Error: failed to locate %s id %d in VAR_*S_IDS array in file id %d",
+              ex_name_of_object(set_type), set_id,exoid);
       ex_err("ex_put_set",errmsg,exerrval);
       return (EX_FATAL);
     }
@@ -133,8 +133,8 @@ int ex_put_set (int   exoid,
   if ((status = nc_inq_varid(exoid, entryptr, &entry_list_id)) != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to locate entry list for %s %d in file id %d",
-	    ex_name_of_object(set_type), set_id,exoid);
+            "Error: failed to locate entry list for %s %d in file id %d",
+            ex_name_of_object(set_type), set_id,exoid);
     ex_err("ex_put_set",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -144,8 +144,8 @@ int ex_put_set (int   exoid,
     if ((status = nc_inq_varid(exoid, extraptr, &extra_list_id)) != NC_NOERR) {
       exerrval = status;
       sprintf(errmsg,
-	      "Error: failed to locate extra list for %s %d in file id %d",
-	      ex_name_of_object(set_type), set_id,exoid);
+              "Error: failed to locate extra list for %s %d in file id %d",
+              ex_name_of_object(set_type), set_id,exoid);
       ex_err("ex_put_set",errmsg,exerrval);
       return (EX_FATAL);
     }
@@ -158,8 +158,8 @@ int ex_put_set (int   exoid,
   if (status != NC_NOERR) {
     exerrval = status;
     sprintf(errmsg,
-	    "Error: failed to store entry list for %s %d in file id %d",
-	    ex_name_of_object(set_type), set_id,exoid);
+            "Error: failed to store entry list for %s %d in file id %d",
+            ex_name_of_object(set_type), set_id,exoid);
     ex_err("ex_put_set",errmsg,exerrval);
     return (EX_FATAL);
   }
@@ -169,7 +169,7 @@ int ex_put_set (int   exoid,
   if (extraptr) {
     if ( set_extra_list == NULL ) {
       sprintf(errmsg, "Error: extra list NULL for %s %d in file id %d",
-	      ex_name_of_object(set_type), set_id, exoid );
+              ex_name_of_object(set_type), set_id, exoid );
       ex_err("ex_put_set",errmsg,EX_BADPARAM);
       return (EX_FATAL);
     }
@@ -179,8 +179,8 @@ int ex_put_set (int   exoid,
     if (status != NC_NOERR) {
       exerrval = status;
       sprintf(errmsg,
-	      "Error: failed to store extra list for %s %d in file id %d",
-	      ex_name_of_object(set_type), set_id,exoid);
+              "Error: failed to store extra list for %s %d in file id %d",
+              ex_name_of_object(set_type), set_id,exoid);
       ex_err("ex_put_set",errmsg,exerrval);
       return (EX_FATAL);
     }
@@ -190,8 +190,8 @@ int ex_put_set (int   exoid,
   if ((set_type == EX_NODE_SET || set_type == EX_ELEM_SET) &&
       set_extra_list != NULL) {
     sprintf(errmsg,
-	    "Warning: extra list was ignored for %s %d in file id %d",
-	    ex_name_of_object(set_type), set_id, exoid);
+            "Warning: extra list was ignored for %s %d in file id %d",
+            ex_name_of_object(set_type), set_id, exoid);
     ex_err("ex_put_set",errmsg,EX_MSG);
     return(EX_WARN); 
   }
