@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkProjectedTetrahedraMapper.h,v $
+  Module:    vtkProjectedTetrahedraMapper.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -32,7 +32,7 @@
 //
 // .SECTION Bugs
 // This mapper relies highly on the implementation of the OpenGL pipeline.
-// A typically hardware driver has lots of options and some settings can
+// A typical hardware driver has lots of options and some settings can
 // cause this mapper to produce artifacts.
 //
 
@@ -50,7 +50,7 @@ class vtkVolumeProperty;
 class VTK_VOLUMERENDERING_EXPORT vtkProjectedTetrahedraMapper : public vtkUnstructuredGridVolumeMapper
 {
 public:
-  vtkTypeRevisionMacro(vtkProjectedTetrahedraMapper,
+  vtkTypeMacro(vtkProjectedTetrahedraMapper,
                        vtkUnstructuredGridVolumeMapper);
   static vtkProjectedTetrahedraMapper *New();
   virtual void PrintSelf(ostream &os, vtkIndent indent);
