@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkUnstructuredGridLinearRayIntegrator.cxx,v $
+  Module:    vtkUnstructuredGridLinearRayIntegrator.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -221,7 +221,7 @@ void vtkLinearRayIntegratorTransferFunction::GetTransferFunction(
   // Now record control points and colors.
   if (this->ControlPoints) delete[] this->ControlPoints;
   if (this->Colors) delete[] this->Colors;
-  this->NumControlPoints = cpset.size();
+  this->NumControlPoints = static_cast<int>(cpset.size());
   this->ControlPoints = new double[this->NumControlPoints];
   this->Colors = new acolor[this->NumControlPoints];
 
@@ -274,7 +274,7 @@ void vtkLinearRayIntegratorTransferFunction::GetTransferFunction(
   // Now record control points and colors.
   if (this->ControlPoints) delete[] this->ControlPoints;
   if (this->Colors) delete[] this->Colors;
-  this->NumControlPoints = cpset.size();
+  this->NumControlPoints = static_cast<int>(cpset.size());
   this->ControlPoints = new double[this->NumControlPoints];
   this->Colors = new acolor[this->NumControlPoints];
 
@@ -310,7 +310,6 @@ inline void vtkLinearRayIntegratorTransferFunction::GetColor(double x,
 
 //-----------------------------------------------------------------------------
 
-vtkCxxRevisionMacro(vtkUnstructuredGridLinearRayIntegrator, "$Revision: 1.3 $");
 vtkStandardNewMacro(vtkUnstructuredGridLinearRayIntegrator);
 
 vtkUnstructuredGridLinearRayIntegrator::vtkUnstructuredGridLinearRayIntegrator()
