@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkVolumeRenderingFactory.h,v $
+  Module:    vtkVolumeRenderingFactory.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,7 @@ class VTK_VOLUMERENDERING_EXPORT vtkVolumeRenderingFactory : public vtkObject
 {
 public:
   static vtkVolumeRenderingFactory *New();
-  vtkTypeRevisionMacro(vtkVolumeRenderingFactory,vtkObject);
+  vtkTypeMacro(vtkVolumeRenderingFactory,vtkObject);
   virtual void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
