@@ -13,6 +13,7 @@
 
 =========================================================================*/
 #include "vtkBiDimensionalWidget.h"
+#include "vtkBiDimensionalRepresentation.h"
 #include "vtkBiDimensionalRepresentation2D.h"
 #include "vtkCommand.h"
 #include "vtkCallbackCommand.h"
@@ -26,17 +27,16 @@
 #include "vtkWidgetEvent.h"
 #include "vtkRenderWindow.h"
 
-vtkCxxRevisionMacro(vtkBiDimensionalWidget, "1.10");
 vtkStandardNewMacro(vtkBiDimensionalWidget);
 
 
 // The bidimensional widget observes the handles.
-// Here we create the command/observer classes to respond to the 
+// Here we create the command/observer classes to respond to the
 // slider widgets.
 class vtkBiDimensionalWidgetCallback : public vtkCommand
 {
 public:
-  static vtkBiDimensionalWidgetCallback *New() 
+  static vtkBiDimensionalWidgetCallback *New()
     { return new vtkBiDimensionalWidgetCallback; }
   virtual void Execute(vtkObject*, unsigned long eventId, void*)
     {
@@ -94,14 +94,14 @@ vtkBiDimensionalWidget::vtkBiDimensionalWidget()
   // Set up the callbacks on the two handles
   this->BiDimensionalWidgetCallback1 = vtkBiDimensionalWidgetCallback::New();
   this->BiDimensionalWidgetCallback1->BiDimensionalWidget = this;
-  this->Point1Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback1, 
+  this->Point1Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback1,
                                   this->Priority);
   this->Point1Widget->AddObserver(vtkCommand::EndInteractionEvent, this->BiDimensionalWidgetCallback1,
                                   this->Priority);
 
   this->BiDimensionalWidgetCallback2 = vtkBiDimensionalWidgetCallback::New();
   this->BiDimensionalWidgetCallback2->BiDimensionalWidget = this;
-  this->Point2Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback2, 
+  this->Point2Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback2,
                                   this->Priority);
   this->Point2Widget->AddObserver(vtkCommand::EndInteractionEvent, this->BiDimensionalWidgetCallback2,
                                   this->Priority);
@@ -109,7 +109,7 @@ vtkBiDimensionalWidget::vtkBiDimensionalWidget()
 
   this->BiDimensionalWidgetCallback3 = vtkBiDimensionalWidgetCallback::New();
   this->BiDimensionalWidgetCallback3->BiDimensionalWidget = this;
-  this->Point3Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback3, 
+  this->Point3Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback3,
                                   this->Priority);
   this->Point3Widget->AddObserver(vtkCommand::EndInteractionEvent, this->BiDimensionalWidgetCallback3,
                                   this->Priority);
@@ -117,7 +117,7 @@ vtkBiDimensionalWidget::vtkBiDimensionalWidget()
 
   this->BiDimensionalWidgetCallback4 = vtkBiDimensionalWidgetCallback::New();
   this->BiDimensionalWidgetCallback4->BiDimensionalWidget = this;
-  this->Point4Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback4, 
+  this->Point4Widget->AddObserver(vtkCommand::StartInteractionEvent, this->BiDimensionalWidgetCallback4,
                                   this->Priority);
   this->Point4Widget->AddObserver(vtkCommand::EndInteractionEvent, this->BiDimensionalWidgetCallback4,
                                   this->Priority);
@@ -133,6 +133,13 @@ vtkBiDimensionalWidget::vtkBiDimensionalWidget()
   this->CallbackMapper->SetCallbackMethod(vtkCommand::LeftButtonReleaseEvent,
                                           vtkWidgetEvent::EndSelect,
                                           this, vtkBiDimensionalWidget::EndSelectAction);
+  this->Line1InnerSelected = 0;
+  this->Line1OuterSelected = 0;
+  this->Line2InnerSelected = 0;
+  this->Line2OuterSelected = 0;
+  this->HandleLine1Selected = 0;
+  this->HandleLine2Selected = 0;
+  this->CenterSelected = 0;
 }
 
 //----------------------------------------------------------------------
@@ -162,7 +169,7 @@ void vtkBiDimensionalWidget::CreateDefaultRepresentation()
     {
     this->WidgetRep = vtkBiDimensionalRepresentation2D::New();
     }
-  vtkBiDimensionalRepresentation2D::SafeDownCast(this->WidgetRep)->
+  vtkBiDimensionalRepresentation::SafeDownCast(this->WidgetRep)->
     InstantiateHandleRepresentation();
 }
 
@@ -170,16 +177,16 @@ void vtkBiDimensionalWidget::CreateDefaultRepresentation()
 void vtkBiDimensionalWidget::SetEnabled(int enabling)
 {
   // The handle widgets are not actually enabled until they are placed.
-  // The handle widgets take their representation from the vtkBiDimensionalRepresentation2D.
+  // The handle widgets take their representation from the vtkBiDimensionalRepresentation.
   if ( enabling )
     {
     if ( this->WidgetState == vtkBiDimensionalWidget::Start )
       {
       if (this->WidgetRep)
         {
-        vtkBiDimensionalRepresentation2D::SafeDownCast(this->WidgetRep)->
+        vtkBiDimensionalRepresentation::SafeDownCast(this->WidgetRep)->
           Line1VisibilityOff();
-        vtkBiDimensionalRepresentation2D::SafeDownCast(this->WidgetRep)->
+        vtkBiDimensionalRepresentation::SafeDownCast(this->WidgetRep)->
           Line2VisibilityOff();
         }
       }
@@ -187,40 +194,38 @@ void vtkBiDimensionalWidget::SetEnabled(int enabling)
       {
       if (this->WidgetRep)
         {
-        vtkBiDimensionalRepresentation2D::SafeDownCast(this->WidgetRep)->
+        vtkBiDimensionalRepresentation::SafeDownCast(this->WidgetRep)->
           Line1VisibilityOn();
-        vtkBiDimensionalRepresentation2D::SafeDownCast(this->WidgetRep)->
+        vtkBiDimensionalRepresentation::SafeDownCast(this->WidgetRep)->
           Line2VisibilityOn();
         }
-      if (this->Point1Widget)
+
+      // The interactor must be set prior to enabling the widget.
+      if (this->Interactor)
         {
-        this->Point1Widget->SetEnabled(1);
-        }
-      if (this->Point2Widget)
-        {
-        this->Point2Widget->SetEnabled(1);
-        }
-      if (this->Point3Widget)
-        {
-        this->Point3Widget->SetEnabled(1);
-        }
-      if (this->Point4Widget)
-        {
-        this->Point4Widget->SetEnabled(1);
+        this->Point1Widget->SetInteractor(this->Interactor);
+        this->Point2Widget->SetInteractor(this->Interactor);
+        this->Point3Widget->SetInteractor(this->Interactor);
+        this->Point4Widget->SetInteractor(this->Interactor);
         }
+
+      this->Point1Widget->SetEnabled(1);
+      this->Point2Widget->SetEnabled(1);
+      this->Point3Widget->SetEnabled(1);
+      this->Point4Widget->SetEnabled(1);
       }
     }
 
   if ( enabling )
     {
-    // Done in this wierd order to get everything to work right. 
+    // Done in this wierd order to get everything to work right.
     // This invocation creates the default representation.
     this->Superclass::SetEnabled(enabling);
 
       if (this->Point1Widget)
         {
         this->Point1Widget->SetRepresentation(
-          vtkBiDimensionalRepresentation2D::SafeDownCast
+          vtkBiDimensionalRepresentation::SafeDownCast
           (this->WidgetRep)->GetPoint1Representation());
         this->Point1Widget->SetInteractor(this->Interactor);
         this->Point1Widget->GetRepresentation()->SetRenderer(
@@ -229,7 +234,7 @@ void vtkBiDimensionalWidget::SetEnabled(int enabling)
       if (this->Point2Widget)
         {
         this->Point2Widget->SetRepresentation(
-          vtkBiDimensionalRepresentation2D::SafeDownCast
+          vtkBiDimensionalRepresentation::SafeDownCast
           (this->WidgetRep)->GetPoint2Representation());
         this->Point2Widget->SetInteractor(this->Interactor);
         this->Point2Widget->GetRepresentation()->SetRenderer(
@@ -238,7 +243,7 @@ void vtkBiDimensionalWidget::SetEnabled(int enabling)
       if (this->Point3Widget)
         {
         this->Point3Widget->SetRepresentation(
-          vtkBiDimensionalRepresentation2D::SafeDownCast
+          vtkBiDimensionalRepresentation::SafeDownCast
           (this->WidgetRep)->GetPoint3Representation());
         this->Point3Widget->SetInteractor(this->Interactor);
         this->Point3Widget->GetRepresentation()->SetRenderer(
@@ -247,7 +252,7 @@ void vtkBiDimensionalWidget::SetEnabled(int enabling)
       if (this->Point4Widget)
         {
         this->Point4Widget->SetRepresentation(
-          vtkBiDimensionalRepresentation2D::SafeDownCast
+          vtkBiDimensionalRepresentation::SafeDownCast
           (this->WidgetRep)->GetPoint4Representation());
         this->Point4Widget->SetInteractor(this->Interactor);
         this->Point4Widget->GetRepresentation()->SetRenderer(
@@ -274,10 +279,10 @@ void vtkBiDimensionalWidget::SetEnabled(int enabling)
       }
 
     // Done in this wierd order to get everything right. The renderer is
-    // set to null after we disable the sub-widgets. That should give the 
+    // set to null after we disable the sub-widgets. That should give the
     // renderer a chance to remove the representation props before being
     // set to NULL.
-    this->Superclass::SetEnabled(enabling);    
+    this->Superclass::SetEnabled(enabling);
     }
 }
 
@@ -295,7 +300,7 @@ int vtkBiDimensionalWidget::IsMeasureValid()
     }
 }
 
-// The following methods are the callbacks that the bidimensional widget responds to. 
+// The following methods are the callbacks that the bidimensional widget responds to.
 //-------------------------------------------------------------------------
 void vtkBiDimensionalWidget::AddPointAction(vtkAbstractWidget *w)
 {
@@ -312,10 +317,10 @@ void vtkBiDimensionalWidget::AddPointAction(vtkAbstractWidget *w)
     self->GrabFocus(self->EventCallbackCommand);
     self->WidgetState = vtkBiDimensionalWidget::Define;
     self->InvokeEvent(vtkCommand::StartInteractionEvent,NULL);
-    vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->StartWidgetDefinition(e);
+    vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->StartWidgetDefinition(e);
     self->CurrentHandle = 0;
     self->InvokeEvent(vtkCommand::PlacePointEvent,&(self->CurrentHandle));
-    vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->Line1VisibilityOn();
+    vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->Line1VisibilityOn();
     self->Point1Widget->SetEnabled(1);
     self->CurrentHandle++;
     }
@@ -327,24 +332,24 @@ void vtkBiDimensionalWidget::AddPointAction(vtkAbstractWidget *w)
     if ( self->CurrentHandle == 1 )
       {
       self->InvokeEvent(vtkCommand::PlacePointEvent,&(self->CurrentHandle));
-      vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->Point2WidgetInteraction(e);
+      vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->Point2WidgetInteraction(e);
       self->CurrentHandle++;
       self->Point2Widget->SetEnabled(1);
       self->Point3Widget->SetEnabled(1);
       self->Point4Widget->SetEnabled(1);
-      vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->Line2VisibilityOn();
+      vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->Line2VisibilityOn();
       }
     else if ( self->CurrentHandle == 2 )
       {
       self->InvokeEvent(vtkCommand::PlacePointEvent,&(self->CurrentHandle));
-      vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->Point3WidgetInteraction(e);
+      vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->Point3WidgetInteraction(e);
       self->WidgetState = vtkBiDimensionalWidget::Manipulate;
       self->CurrentHandle = (-1);
       self->ReleaseFocus();
-      self->InvokeEvent(vtkCommand::EndInteractionEvent,NULL); 
+      self->InvokeEvent(vtkCommand::EndInteractionEvent,NULL);
       }
     }
-  
+
   // Maybe we are trying to manipulate the widget handles
   else //if ( self->WidgetState == vtkBiDimensionalWidget::Manipulate )
     {
@@ -357,57 +362,57 @@ void vtkBiDimensionalWidget::AddPointAction(vtkAbstractWidget *w)
     self->CenterSelected = 0;
     int modifier = self->Interactor->GetShiftKey() | self->Interactor->GetControlKey();
     int state = self->WidgetRep->ComputeInteractionState(X,Y,modifier);
-    if ( state == vtkBiDimensionalRepresentation2D::Outside )
+    if ( state == vtkBiDimensionalRepresentation::Outside )
       {
       return;
       }
 
     self->GrabFocus(self->EventCallbackCommand);
-    vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->StartWidgetManipulation(e);
-    if ( state == vtkBiDimensionalRepresentation2D::NearP1 ||
-         state == vtkBiDimensionalRepresentation2D::NearP2 )
+    vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->StartWidgetManipulation(e);
+    if ( state == vtkBiDimensionalRepresentation::NearP1 ||
+         state == vtkBiDimensionalRepresentation::NearP2 )
       {
       self->HandleLine1Selected = 1;
       self->InvokeEvent(vtkCommand::LeftButtonPressEvent,NULL);
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::NearP3 ||
-              state == vtkBiDimensionalRepresentation2D::NearP4 )
+    else if ( state == vtkBiDimensionalRepresentation::NearP3 ||
+              state == vtkBiDimensionalRepresentation::NearP4 )
       {
       self->HandleLine2Selected = 1;
       self->InvokeEvent(vtkCommand::LeftButtonPressEvent,NULL);
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL1Inner)
+    else if ( state == vtkBiDimensionalRepresentation::OnL1Inner)
       {
       self->WidgetRep->Highlight(1);
       self->Line1InnerSelected = 1;
       self->StartBiDimensionalInteraction();
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL1Outer)
+    else if ( state == vtkBiDimensionalRepresentation::OnL1Outer)
       {
       self->WidgetRep->Highlight(1);
       self->Line1OuterSelected = 1;
       self->StartBiDimensionalInteraction();
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL2Inner)
+    else if ( state == vtkBiDimensionalRepresentation::OnL2Inner)
       {
       self->WidgetRep->Highlight(1);
       self->Line2InnerSelected = 1;
       self->StartBiDimensionalInteraction();
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL2Outer)
+    else if ( state == vtkBiDimensionalRepresentation::OnL2Outer)
       {
       self->WidgetRep->Highlight(1);
       self->Line2OuterSelected = 1;
       self->StartBiDimensionalInteraction();
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnCenter )
+    else if ( state == vtkBiDimensionalRepresentation::OnCenter )
       {
       self->WidgetRep->Highlight(1);
       self->CenterSelected = 1;
       self->StartBiDimensionalInteraction();
       }
     }
-  
+
   self->EventCallbackCommand->SetAbortFlag(1);
   self->Render();
 }
@@ -435,12 +440,12 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
     {
     if ( self->CurrentHandle == 1 )
       {
-      vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->
+      vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->
         Point2WidgetInteraction(e);
       }
     else
       {
-      vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->
+      vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->
         Point3WidgetInteraction(e);
       }
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
@@ -451,16 +456,16 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
     {
     // moving outer portion of line -- rotating
     self->RequestCursorShape(VTK_CURSOR_HAND);
-    vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->
+    vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
-  
+
   else if ( self->Line1InnerSelected )
     {//must be moving inner portion of line 1 -- line translation
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint1DisplayPosition(p1);
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint2DisplayPosition(p2);
     slope = VTK_DOUBLE_MAX;
     if (p1[0] != p2[0])
@@ -476,16 +481,16 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
       self->RequestCursorShape(VTK_CURSOR_SIZEWE);
       }
 
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
 
   else if ( self->Line2InnerSelected )
     {//must be moving inner portion of line 2 -- line translation
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint3DisplayPosition(p1);
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint4DisplayPosition(p2);
     slope = VTK_DOUBLE_MAX;
     if (p1[0] != p2[0])
@@ -501,16 +506,16 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
       self->RequestCursorShape(VTK_CURSOR_SIZEWE);
       }
 
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
 
   else if ( self->HandleLine1Selected )
     { // moving one of the endpoints of line 1
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint1DisplayPosition(p1);
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint2DisplayPosition(p2);
     slope = VTK_DOUBLE_MAX;
     if (p1[0] != p2[0])
@@ -526,16 +531,16 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
       self->RequestCursorShape(VTK_CURSOR_SIZENS);
       }
 
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
 
   else if ( self->HandleLine2Selected )
     { // moving one of the endpoints of line 2
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint3DisplayPosition(p1);
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       GetPoint4DisplayPosition(p2);
     slope = VTK_DOUBLE_MAX;
     if (p1[0] != p2[0])
@@ -551,7 +556,7 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
       self->RequestCursorShape(VTK_CURSOR_SIZENS);
       }
 
-    reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+    reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
@@ -559,7 +564,7 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
   else if ( self->CenterSelected )
     {//grabbing center intersection point
     self->RequestCursorShape(VTK_CURSOR_SIZEALL);
-    vtkBiDimensionalRepresentation2D::SafeDownCast(self->WidgetRep)->
+    vtkBiDimensionalRepresentation::SafeDownCast(self->WidgetRep)->
       WidgetInteraction(e);
     self->InvokeEvent(vtkCommand::InteractionEvent,NULL);
     }
@@ -567,20 +572,20 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
   else // just moving around, nothing yet selected
     {
     int state = self->WidgetRep->ComputeInteractionState(X,Y);
-    if ( state == vtkBiDimensionalRepresentation2D::Outside )
+    if ( state == vtkBiDimensionalRepresentation::Outside )
       {
       self->RequestCursorShape(VTK_CURSOR_DEFAULT);
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnCenter )
+    else if ( state == vtkBiDimensionalRepresentation::OnCenter )
       {
       self->RequestCursorShape(VTK_CURSOR_SIZEALL);
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::NearP1 ||
-              state == vtkBiDimensionalRepresentation2D::NearP2 )
+    else if ( state == vtkBiDimensionalRepresentation::NearP1 ||
+              state == vtkBiDimensionalRepresentation::NearP2 )
       {
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint1DisplayPosition(p1);
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint2DisplayPosition(p2);
       slope = VTK_DOUBLE_MAX;
       if (p1[0] != p2[0])
@@ -596,12 +601,12 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
         self->RequestCursorShape(VTK_CURSOR_SIZENS);
         }
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::NearP3 ||
-              state == vtkBiDimensionalRepresentation2D::NearP4 )
+    else if ( state == vtkBiDimensionalRepresentation::NearP3 ||
+              state == vtkBiDimensionalRepresentation::NearP4 )
       {
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint3DisplayPosition(p1);
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint4DisplayPosition(p2);
       slope = VTK_DOUBLE_MAX;
       if (p1[0] != p2[0])
@@ -617,11 +622,11 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
         self->RequestCursorShape(VTK_CURSOR_SIZENS);
         }
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL1Inner )
+    else if ( state == vtkBiDimensionalRepresentation::OnL1Inner )
       {
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint1DisplayPosition(p1);
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint2DisplayPosition(p2);
       slope = VTK_DOUBLE_MAX;
       if (p1[0] != p2[0])
@@ -637,11 +642,11 @@ void vtkBiDimensionalWidget::MoveAction(vtkAbstractWidget *w)
         self->RequestCursorShape(VTK_CURSOR_SIZEWE);
         }
       }
-    else if ( state == vtkBiDimensionalRepresentation2D::OnL2Inner )
+    else if ( state == vtkBiDimensionalRepresentation::OnL2Inner )
       {
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint3DisplayPosition(p1);
-      reinterpret_cast<vtkBiDimensionalRepresentation2D*>(self->WidgetRep)->
+      reinterpret_cast<vtkBiDimensionalRepresentation*>(self->WidgetRep)->
         GetPoint4DisplayPosition(p2);
       slope = VTK_DOUBLE_MAX;
       if (p1[0] != p2[0])
@@ -695,10 +700,10 @@ void vtkBiDimensionalWidget::EndSelectAction(vtkAbstractWidget *w)
   self->CurrentHandle = (-1);
   self->WidgetRep->BuildRepresentation();
   int state = self->WidgetRep->GetInteractionState();
-  if ( state == vtkBiDimensionalRepresentation2D::NearP1 ||
-       state == vtkBiDimensionalRepresentation2D::NearP2 ||
-       state == vtkBiDimensionalRepresentation2D::NearP3 ||
-       state == vtkBiDimensionalRepresentation2D::NearP4 )
+  if ( state == vtkBiDimensionalRepresentation::NearP1 ||
+       state == vtkBiDimensionalRepresentation::NearP2 ||
+       state == vtkBiDimensionalRepresentation::NearP3 ||
+       state == vtkBiDimensionalRepresentation::NearP4 )
     {
     self->InvokeEvent(vtkCommand::LeftButtonReleaseEvent,NULL);
     }
@@ -737,6 +742,38 @@ void vtkBiDimensionalWidget::SetProcessEvents(int pe)
   this->Point4Widget->SetProcessEvents(pe);
 }
 
+//----------------------------------------------------------------------
+void vtkBiDimensionalWidget::SetWidgetStateToStart()
+{
+  this->WidgetState = vtkBiDimensionalWidget::Start;
+  this->CurrentHandle = -1;
+  this->HandleLine1Selected = 0;
+  this->HandleLine2Selected = 0;
+  this->Line1InnerSelected = 0;
+  this->Line1OuterSelected = 0;
+  this->Line2InnerSelected = 0;
+  this->Line2OuterSelected = 0;
+  this->CenterSelected = 0;
+  this->SetEnabled(this->GetEnabled()); // show/hide the handles properly
+  this->ReleaseFocus();
+}
+
+//----------------------------------------------------------------------
+void vtkBiDimensionalWidget::SetWidgetStateToManipulate()
+{
+  this->WidgetState = vtkBiDimensionalWidget::Manipulate;
+  this->CurrentHandle = -1;
+  this->HandleLine1Selected = 0;
+  this->HandleLine2Selected = 0;
+  this->Line1InnerSelected = 0;
+  this->Line1OuterSelected = 0;
+  this->Line2InnerSelected = 0;
+  this->Line2OuterSelected = 0;
+  this->CenterSelected = 0;
+  this->SetEnabled(this->GetEnabled()); // show/hide the handles properly
+  this->ReleaseFocus();
+}
+
 //----------------------------------------------------------------------
 void vtkBiDimensionalWidget::PrintSelf(ostream& os, vtkIndent indent)
 {
