@@ -80,6 +80,11 @@ public:
   {this->Superclass::SetWidgetRepresentation
      (reinterpret_cast<vtkWidgetRepresentation*>(r));}
   
+  // Description:
+  // Return the representation as a vtkContinuousValueWidgetRepresentation.
+  vtkContinuousValueWidgetRepresentation *GetContinuousValueWidgetRepresentation()
+    {return reinterpret_cast<vtkContinuousValueWidgetRepresentation*>(this->WidgetRep);}
+
   // Description:
   // Get the value for this widget. 
   double GetValue();
