@@ -20,14 +20,17 @@
 #include "vtkContourLineInterpolator.h"
 #include "vtkCoordinate.h"
 #include "vtkHandleRepresentation.h"
+#include "vtkIncrementalOctreePointLocator.h"
 #include "vtkIntArray.h"
 #include "vtkInteractorObserver.h"
 #include "vtkLine.h"
 #include "vtkMath.h"
+#include "vtkMatrix4x4.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointPlacer.h"
 #include "vtkPolyData.h"
 #include "vtkRenderer.h"
+#include "vtkWindow.h"
 
 #include <vtkstd/set>
 #include <vtkstd/algorithm>
@@ -40,16 +43,20 @@ vtkCxxSetObjectMacro(vtkContourRepresentation, LineInterpolator, vtkContourLineI
 vtkContourRepresentation::vtkContourRepresentation()
 {
   this->Internal = new vtkContourRepresentationInternals;
-  
+
   this->PixelTolerance           = 7;
   this->WorldTolerance           = 0.001;
   this->PointPlacer              = NULL;
   this->LineInterpolator         = NULL;
+  this->Locator                  = NULL;
+  this->RebuildLocator           = false;
   this->ActiveNode               = -1;
   this->NeedToRender             = 0;
   this->ClosedLoop               = 0;
   this->ShowSelectedNodes        = 0;
   this->CurrentOperation         = vtkContourRepresentation::Inactive;
+
+  this->ResetLocator();
 }
 
 //----------------------------------------------------------------------
@@ -58,16 +65,36 @@ vtkContourRepresentation::~vtkContourRepresentation()
   this->SetPointPlacer(NULL);
   this->SetLineInterpolator(NULL);
   this->Internal->ClearNodes();
-  
+
   delete this->Internal;
+
+  if (this->Locator)
+    {
+    this->Locator->Delete();
+    }
+}
+
+//----------------------------------------------------------------------
+void vtkContourRepresentation::ResetLocator()
+{
+  if (this->Locator)
+    {
+    this->Locator->Delete();
+    }
+
+  this->Locator = vtkIncrementalOctreePointLocator::New();
+  this->Locator->SetBuildCubicOctree(1);
+  this->RebuildLocator = true;
 }
 
 //----------------------------------------------------------------------
 void vtkContourRepresentation::ClearAllNodes()
 {
-  this->Internal->ClearNodes(); 
-  
+  this->ResetLocator();
+  this->Internal->ClearNodes();
+
   this->BuildLines();
+  this->BuildLocator();
   this->NeedToRender = 1;
   this->Modified();
 }
@@ -83,26 +110,26 @@ void vtkContourRepresentation::AddNodeAtPositionInternal( double worldPos[3],
   node->WorldPosition[1] = worldPos[1];
   node->WorldPosition[2] = worldPos[2];
   node->Selected = 0;
-  
+
   node->NormalizedDisplayPosition[0] = displayPos[0];
   node->NormalizedDisplayPosition[1] = displayPos[1];
-  this->Renderer->DisplayToNormalizedDisplay( 
+  this->Renderer->DisplayToNormalizedDisplay(
       node->NormalizedDisplayPosition[0],
       node->NormalizedDisplayPosition[1] );
-  
+
   memcpy(node->WorldOrientation, worldOrient, 9*sizeof(double) );
-  
+
   this->Internal->Nodes.push_back(node);
-  
+
   if ( this->LineInterpolator && this->GetNumberOfNodes() > 1 )
     {
-    // Give the line interpolator a chance to update the node. 
-    int didNodeChange = this->LineInterpolator->UpdateNode( 
+    // Give the line interpolator a chance to update the node.
+    int didNodeChange = this->LineInterpolator->UpdateNode(
         this->Renderer, this, node->WorldPosition, this->GetNumberOfNodes()-1 );
 
     // Give the point placer a chance to validate the updated node. If its not
     // valid, discard the LineInterpolator's change.
-    if ( didNodeChange && !this->PointPlacer->ValidateWorldPosition( 
+    if ( didNodeChange && !this->PointPlacer->ValidateWorldPosition(
                 node->WorldPosition, worldOrient ) )
       {
       node->WorldPosition[0] = worldPos[0];
@@ -110,7 +137,7 @@ void vtkContourRepresentation::AddNodeAtPositionInternal( double worldPos[3],
       node->WorldPosition[2] = worldPos[2];
       }
     }
-  
+
   this->UpdateLines( static_cast<int>(this->Internal->Nodes.size())-1);
   this->NeedToRender = 1;
 }
@@ -121,17 +148,17 @@ void vtkContourRepresentation::GetNodePolyData( vtkPolyData* poly )
   poly->Initialize();
   int count = this->GetNumberOfNodes();
 
-  if ( count == 0 ) 
+  if ( count == 0 )
     {
     return;
     }
 
   vtkPoints *points = vtkPoints::New();
   vtkCellArray *lines = vtkCellArray::New();
-  
+
   points->SetNumberOfPoints( count );
   vtkIdType numLines = count;
-  
+
   if ( this->ClosedLoop )
     {
     numLines++;
@@ -149,20 +176,20 @@ void vtkContourRepresentation::GetNodePolyData( vtkPolyData* poly )
     this->GetNthNodeWorldPosition( i, pos );
     points->InsertPoint( index, pos );
     lineIndices[index] = index;
-    index++;      
+    index++;
     }
-    
+
   if ( this->ClosedLoop )
     {
     lineIndices[index] = 0;
     }
-    
+
   lines->InsertNextCell( numLines, lineIndices );
   delete [] lineIndices;
- 
+
   poly->SetPoints( points );
   poly->SetLines( lines );
-  
+
   points->Delete();
   lines->Delete();
 }
@@ -189,7 +216,7 @@ int vtkContourRepresentation::AddNodeAtWorldPosition( double worldPos[3],
     }
 
   double displayPos[2];
-  this->GetRendererComputedDisplayPositionFromWorldPosition( 
+  this->GetRendererComputedDisplayPositionFromWorldPosition(
                           worldPos, worldOrient, displayPos );
   this->AddNodeAtPositionInternal( worldPos, worldOrient, displayPos );
 
@@ -216,9 +243,9 @@ int vtkContourRepresentation::AddNodeAtWorldPosition( double worldPos[3] )
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
                            0.0,0.0,1.0};
-  
+
   double displayPos[2];
-  this->GetRendererComputedDisplayPositionFromWorldPosition( 
+  this->GetRendererComputedDisplayPositionFromWorldPosition(
                           worldPos, worldOrient, displayPos );
   this->AddNodeAtPositionInternal( worldPos, worldOrient, displayPos );
 
@@ -242,8 +269,8 @@ int vtkContourRepresentation::AddNodeAtDisplayPosition(double displayPos[2])
     {
     return 0;
     }
-  
-  this->AddNodeAtPositionInternal( worldPos, worldOrient, displayPos );  
+
+  this->AddNodeAtPositionInternal( worldPos, worldOrient, displayPos );
   return 1;
 }
 //----------------------------------------------------------------------
@@ -253,7 +280,7 @@ int vtkContourRepresentation::AddNodeAtDisplayPosition(int displayPos[2])
   doubleDisplayPos[0] = displayPos[0];
   doubleDisplayPos[1] = displayPos[1];
   return this->AddNodeAtDisplayPosition( doubleDisplayPos );
-  
+
 }
 //----------------------------------------------------------------------
 int vtkContourRepresentation::AddNodeAtDisplayPosition(int X, int Y)
@@ -262,53 +289,31 @@ int vtkContourRepresentation::AddNodeAtDisplayPosition(int X, int Y)
   displayPos[0] = X;
   displayPos[1] = Y;
   return this->AddNodeAtDisplayPosition( displayPos );
-  
+
 }
 
 //----------------------------------------------------------------------
 int vtkContourRepresentation::ActivateNode( double displayPos[2] )
 {
+  this->BuildLocator();
   // Find closest node to this display pos that
   // is within PixelTolerance
-  
-  int closestNode = -1;
+  double dPos[3] = {displayPos[0],displayPos[1],0};
   double closestDistance2 = VTK_DOUBLE_MAX;
-  
-  unsigned int i;
-  double limit = this->PixelTolerance * this->PixelTolerance;
-  
-  for ( i = 0; i < this->Internal->Nodes.size(); i++ )
-    {
-    double currDisplayPos[2];
-    this->GetNthNodeDisplayPosition( i, currDisplayPos );
-    
-    double currDistance2 =
-      (currDisplayPos[0] - displayPos[0])*
-      (currDisplayPos[0] - displayPos[0]) +
-      (currDisplayPos[1] - displayPos[1])*
-      (currDisplayPos[1] - displayPos[1]);
-    
-    if ( currDistance2 < limit &&
-         currDistance2 < closestDistance2 )
-      {
-      closestNode = i;
-      closestDistance2 = currDistance2;
-      }
-    }
-
+  int closestNode = this->Locator->FindClosestPointWithinRadius(
+    this->PixelTolerance,dPos,closestDistance2);
   if ( closestNode != this->ActiveNode )
     {
     this->ActiveNode = closestNode;
     this->NeedToRender = 1;
     }
-
   return ( this->ActiveNode >= 0 );
 }
 //----------------------------------------------------------------------
 int vtkContourRepresentation::ActivateNode( int displayPos[2] )
 {
   double doubleDisplayPos[2];
-  
+
   doubleDisplayPos[0] = displayPos[0];
   doubleDisplayPos[1] = displayPos[1];
   return this->ActivateNode( doubleDisplayPos );
@@ -318,7 +323,7 @@ int vtkContourRepresentation::ActivateNode( int displayPos[2] )
 int vtkContourRepresentation::ActivateNode( int X, int Y )
 {
   double doubleDisplayPos[2];
-  
+
   doubleDisplayPos[0] = X;
   doubleDisplayPos[1] = Y;
   return this->ActivateNode( doubleDisplayPos );
@@ -334,15 +339,15 @@ int vtkContourRepresentation::SetActiveNodeToWorldPosition( double worldPos[3],
     {
     return 0;
     }
-  
+
   // Check if this is a valid location
   if ( !this->PointPlacer->ValidateWorldPosition( worldPos, worldOrient ) )
     {
     return 0;
     }
-  
-  this->SetNthNodeWorldPositionInternal( this->ActiveNode, 
-                                         worldPos, 
+
+  this->SetNthNodeWorldPositionInternal( this->ActiveNode,
+                                         worldPos,
                                          worldOrient );
   return 1;
 }
@@ -355,18 +360,18 @@ int vtkContourRepresentation::SetActiveNodeToWorldPosition( double worldPos[3] )
     {
     return 0;
     }
-  
+
   // Check if this is a valid location
   if ( !this->PointPlacer->ValidateWorldPosition( worldPos ) )
     {
     return 0;
     }
-  
+
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
                            0.0,0.0,1.0};
-  
-  this->SetNthNodeWorldPositionInternal( this->ActiveNode, 
+
+  this->SetNthNodeWorldPositionInternal( this->ActiveNode,
                                          worldPos,
                                          worldOrient );
   return 1;
@@ -380,7 +385,7 @@ int vtkContourRepresentation::SetActiveNodeToDisplayPosition( double displayPos[
     {
     return 0;
     }
-  
+
   double worldPos[3];
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
@@ -395,8 +400,8 @@ int vtkContourRepresentation::SetActiveNodeToDisplayPosition( double displayPos[
     {
     return 0;
     }
-  
-  this->SetNthNodeWorldPositionInternal( this->ActiveNode, 
+
+  this->SetNthNodeWorldPositionInternal( this->ActiveNode,
                                          worldPos,
                                          worldOrient );
   return 1;
@@ -428,8 +433,8 @@ if ( this->ActiveNode < 0 ||
   // Failed to toggle the value
   return 0;
   }
-  
-  this->Internal->Nodes[this->ActiveNode]->Selected = 
+
+  this->Internal->Nodes[this->ActiveNode]->Selected =
     this->Internal->Nodes[this->ActiveNode]->Selected ? 0 : 1;
   this->NeedToRender = 1;
   this->Modified();
@@ -439,20 +444,20 @@ if ( this->ActiveNode < 0 ||
 //----------------------------------------------------------------------
 int vtkContourRepresentation::GetNthNodeSelected(int n)
 {
-  if ( n < 0 || 
+  if ( n < 0 ||
       static_cast<unsigned int>(n) >= this->Internal->Nodes.size() )
     {
     // This case is considered not Selected.
     return 0;
     }
-    
+
   return this->Internal->Nodes[n]->Selected;
 }
 
 //----------------------------------------------------------------------
 int vtkContourRepresentation::SetNthNodeSelected(int n)
 {
-  if ( n < 0 || 
+  if ( n < 0 ||
     static_cast<unsigned int>(n) >= this->Internal->Nodes.size() )
     {
     // Failed.
@@ -467,7 +472,7 @@ int vtkContourRepresentation::SetNthNodeSelected(int n)
     }
   return 1;
 }
-  
+
 //----------------------------------------------------------------------
 int vtkContourRepresentation::GetActiveNodeSelected()
 {
@@ -506,13 +511,13 @@ int vtkContourRepresentation::GetNumberOfIntermediatePoints(int n)
     {
     return 0;
     }
-  
+
   return static_cast<int>(this->Internal->Nodes[n]->Points.size());
 }
 
 //----------------------------------------------------------------------
-int vtkContourRepresentation::GetIntermediatePointWorldPosition(int n, 
-                                                                int idx, 
+int vtkContourRepresentation::GetIntermediatePointWorldPosition(int n,
+                                                                int idx,
                                                                 double point[3])
 {
   if ( n < 0 ||
@@ -520,17 +525,17 @@ int vtkContourRepresentation::GetIntermediatePointWorldPosition(int n,
     {
     return 0;
     }
-  
+
   if ( idx < 0 ||
        static_cast<unsigned int>(idx) >= this->Internal->Nodes[n]->Points.size() )
     {
     return 0;
     }
-  
+
   point[0] = this->Internal->Nodes[n]->Points[idx]->WorldPosition[0];
   point[1] = this->Internal->Nodes[n]->Points[idx]->WorldPosition[1];
   point[2] = this->Internal->Nodes[n]->Points[idx]->WorldPosition[2];
-  
+
   return 1;
 }
 
@@ -538,7 +543,7 @@ int vtkContourRepresentation::GetIntermediatePointWorldPosition(int n,
 // The display position for a given world position must be re-computed
 // from the world positions... It should not be queried from the renderer
 // whose camera position may have changed
-int vtkContourRepresentation::GetNthNodeDisplayPosition( 
+int vtkContourRepresentation::GetNthNodeDisplayPosition(
                            int n, double displayPos[2] )
 {
   if ( n < 0 ||
@@ -546,17 +551,17 @@ int vtkContourRepresentation::GetNthNodeDisplayPosition(
     {
     return 0;
     }
-  
+
   double pos[4];
   pos[0] = this->Internal->Nodes[n]->WorldPosition[0];
   pos[1] = this->Internal->Nodes[n]->WorldPosition[1];
   pos[2] = this->Internal->Nodes[n]->WorldPosition[2];
   pos[3] = 1.0;
-  
+
   this->Renderer->SetWorldPoint( pos );
   this->Renderer->WorldToDisplay();
   this->Renderer->GetDisplayPoint( pos );
-  
+
   displayPos[0] = pos[0];
   displayPos[1] = pos[1];
   return 1;
@@ -570,7 +575,7 @@ int vtkContourRepresentation::GetNthNodeWorldPosition( int n, double worldPos[3]
     {
     return 0;
     }
-  
+
   worldPos[0] = this->Internal->Nodes[n]->WorldPosition[0];
   worldPos[1] = this->Internal->Nodes[n]->WorldPosition[1];
   worldPos[2] = this->Internal->Nodes[n]->WorldPosition[2];
@@ -585,7 +590,7 @@ int vtkContourRepresentation::GetNthNodeWorldOrientation( int n, double worldOri
     {
     return 0;
     }
- 
+
   memcpy( worldOrient, this->Internal->Nodes[n]->WorldOrientation, 9*sizeof(double) );
   return 1;
 }
@@ -597,10 +602,10 @@ void vtkContourRepresentation::SetNthNodeWorldPositionInternal( int n, double wo
   this->Internal->Nodes[n]->WorldPosition[0] = worldPos[0];
   this->Internal->Nodes[n]->WorldPosition[1] = worldPos[1];
   this->Internal->Nodes[n]->WorldPosition[2] = worldPos[2];
-  
-  this->GetRendererComputedDisplayPositionFromWorldPosition( 
+
+  this->GetRendererComputedDisplayPositionFromWorldPosition(
         worldPos, worldOrient, this->Internal->Nodes[n]->NormalizedDisplayPosition );
-  this->Renderer->DisplayToNormalizedDisplay( 
+  this->Renderer->DisplayToNormalizedDisplay(
       this->Internal->Nodes[n]->NormalizedDisplayPosition[0],
       this->Internal->Nodes[n]->NormalizedDisplayPosition[1] );
 
@@ -619,7 +624,7 @@ int vtkContourRepresentation::SetNthNodeWorldPosition( int n, double worldPos[3]
     {
     return 0;
     }
-  
+
   // Check if this is a valid location
   if ( !this->PointPlacer->ValidateWorldPosition( worldPos, worldOrient ) )
     {
@@ -638,13 +643,13 @@ int vtkContourRepresentation::SetNthNodeWorldPosition( int n, double worldPos[3]
     {
     return 0;
     }
-  
+
   // Check if this is a valid location
   if ( !this->PointPlacer->ValidateWorldPosition( worldPos ) )
     {
     return 0;
     }
-  
+
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
                            0.0,0.0,1.0};
@@ -670,7 +675,7 @@ int vtkContourRepresentation::SetNthNodeDisplayPosition( int n, double displayPo
     {
     return 0;
     }
-  
+
   return this->SetNthNodeWorldPosition( n, worldPos, worldOrient );
 }
 
@@ -693,13 +698,13 @@ int vtkContourRepresentation::SetNthNodeDisplayPosition( int n, int X, int Y )
 }
 
 //----------------------------------------------------------------------
-int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y, 
-                                                         double closestWorldPos[3], 
+int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
+                                                         double closestWorldPos[3],
                                                          int *idx )
 {
   // Make a line out of this viewing ray
   double p1[4], p2[4], *p3=NULL, *p4=NULL;
-  
+
   double tmp1[4], tmp2[4];
   tmp1[0] = X;
   tmp1[1] = Y;
@@ -707,7 +712,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
   this->Renderer->SetDisplayPoint( tmp1 );
   this->Renderer->DisplayToWorld();
   this->Renderer->GetWorldPoint(p1);
-  
+
   tmp1[2] = 1.0;
   this->Renderer->SetDisplayPoint( tmp1 );
   this->Renderer->DisplayToWorld();
@@ -724,21 +729,21 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
   this->Renderer->SetWorldPoint(fp);
   this->Renderer->WorldToDisplay();
   this->Renderer->GetDisplayPoint(tmp1);
-  
+
   tmp1[0] = 0;
   tmp1[1] = 0;
   this->Renderer->SetDisplayPoint(tmp1);
   this->Renderer->DisplayToWorld();
   this->Renderer->GetWorldPoint(tmp2);
-  
+
   tmp1[0] = this->PixelTolerance;
   this->Renderer->SetDisplayPoint(tmp1);
   this->Renderer->DisplayToWorld();
   this->Renderer->GetWorldPoint(tmp1);
-  
+
   double wt2 = vtkMath::Distance2BetweenPoints(tmp1, tmp2);
-  
-  // Now loop through all lines and look for closest one within tolerance  
+
+  // Now loop through all lines and look for closest one within tolerance
   for(unsigned int i=0;i<this->Internal->Nodes.size();i++)
     {
     for (unsigned int j=0;j<=this->Internal->Nodes[i]->Points.size();j++)
@@ -758,7 +763,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
             }
           else if ( this->ClosedLoop )
             {
-            p4 = this->Internal->Nodes[0]->WorldPosition;         
+            p4 = this->Internal->Nodes[0]->WorldPosition;
             }
           }
         }
@@ -771,7 +776,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
           }
         else if ( this->ClosedLoop )
           {
-          p4 = this->Internal->Nodes[0]->WorldPosition;         
+          p4 = this->Internal->Nodes[0]->WorldPosition;
           }
         else
           {
@@ -786,10 +791,10 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
         p3 = this->Internal->Nodes[i]->Points[j-1]->WorldPosition;
         p4 = this->Internal->Nodes[i]->Points[j]->WorldPosition;
         }
-      
+
       // Now we have the four points - check closest intersection
       double u, v;
-      
+
       if ( vtkLine::Intersection( p1, p2, p3, p4, u, v ) )
         {
         double p5[3], p6[3];
@@ -800,9 +805,9 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
         p6[0] = p3[0] + v*(p4[0]-p3[0]);
         p6[1] = p3[1] + v*(p4[1]-p3[1]);
         p6[2] = p3[2] + v*(p4[2]-p3[2]);
-        
+
         double d = vtkMath::Distance2BetweenPoints(p5, p6);
-        
+
         if ( d < wt2 && d < closestDistance2 )
           {
           closestWorldPos[0] = p6[0];
@@ -823,7 +828,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
           closestDistance2 = d;
           closestNode = static_cast<int>(i);
           }
-        
+
         d = vtkLine::DistanceToLine( p4, p1, p2 );
         if ( d < wt2 && d < closestDistance2 )
           {
@@ -832,7 +837,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
           closestWorldPos[2] = p4[2];
           closestDistance2 = d;
           closestNode = static_cast<int>(i);
-          }        
+          }
         }
       }
     }
@@ -850,7 +855,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
       return 1;
       }
     }
-  
+
   return 0;
 }
 
@@ -858,7 +863,7 @@ int vtkContourRepresentation::FindClosestPointOnContour( int X, int Y,
 int vtkContourRepresentation::AddNodeOnContour( int X, int Y )
 {
   int idx;
-  
+
   double worldPos[3];
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
@@ -876,39 +881,39 @@ int vtkContourRepresentation::AddNodeOnContour( int X, int Y )
     {
     return 0;
     }
-  
+
   double pos[3];
   if ( !this->FindClosestPointOnContour( X, Y, pos, &idx ) )
     {
     return 0;
     }
-  
+
   if ( !this->PointPlacer->ComputeWorldPosition( this->Renderer,
-                                                 displayPos, 
+                                                 displayPos,
                                                  pos,
                                                  worldPos,
                                                  worldOrient) )
     {
     return 0;
     }
-  
+
   // Add a new point at this position
   vtkContourRepresentationNode *node = new vtkContourRepresentationNode;
   node->WorldPosition[0] = worldPos[0];
   node->WorldPosition[1] = worldPos[1];
   node->WorldPosition[2] = worldPos[2];
   node->Selected = 0;
-  
-  this->GetRendererComputedDisplayPositionFromWorldPosition( 
+
+  this->GetRendererComputedDisplayPositionFromWorldPosition(
           worldPos, worldOrient, node->NormalizedDisplayPosition );
-  this->Renderer->DisplayToNormalizedDisplay( 
+  this->Renderer->DisplayToNormalizedDisplay(
          node->NormalizedDisplayPosition[0],
          node->NormalizedDisplayPosition[1] );
-  
+
   memcpy(node->WorldOrientation, worldOrient, 9*sizeof(double) );
-  
+
   this->Internal->Nodes.insert(this->Internal->Nodes.begin() + idx, node);
-  
+
   this->UpdateLines( idx );
   this->NeedToRender = 1;
 
@@ -923,7 +928,7 @@ int vtkContourRepresentation::DeleteNthNode( int n )
     {
     return 0;
     }
-  
+
   for (unsigned int j=0;j<this->Internal->Nodes[n]->Points.size();j++)
     {
     delete this->Internal->Nodes[n]->Points[j];
@@ -939,7 +944,7 @@ int vtkContourRepresentation::DeleteNthNode( int n )
     {
     this->UpdateLines(this->GetNumberOfNodes()-1);
     }
-  
+
   this->NeedToRender = 1;
   return 1;
 }
@@ -987,7 +992,7 @@ void vtkContourRepresentation::UpdateLines( int index )
       }
     arr->Delete();
     }
-  
+
   // A check to make sure that we have no line segments in
   // the last node if the loop is not closed
   if ( !this->ClosedLoop && this->GetNumberOfNodes() > 0 )
@@ -999,8 +1004,9 @@ void vtkContourRepresentation::UpdateLines( int index )
       }
     this->Internal->Nodes[idx]->Points.clear();
     }
-  
+
   this->BuildLines();
+  this->RebuildLocator = true;
 }
 
 //----------------------------------------------------------------------
@@ -1012,22 +1018,22 @@ int vtkContourRepresentation::AddIntermediatePointWorldPosition( int n,
     {
     return 0;
     }
-  
+
   vtkContourRepresentationPoint *point = new vtkContourRepresentationPoint;
   point->WorldPosition[0] = pos[0];
   point->WorldPosition[1] = pos[1];
   point->WorldPosition[2] = pos[2];
-  
+
   double worldOrient[9] = {1.0,0.0,0.0,
                            0.0,1.0,0.0,
                            0.0,0.0,1.0};
-  
-  this->GetRendererComputedDisplayPositionFromWorldPosition( 
+
+  this->GetRendererComputedDisplayPositionFromWorldPosition(
                           pos, worldOrient, point->NormalizedDisplayPosition );
-  this->Renderer->DisplayToNormalizedDisplay( 
-      point->NormalizedDisplayPosition[0], 
+  this->Renderer->DisplayToNormalizedDisplay(
+      point->NormalizedDisplayPosition[0],
       point->NormalizedDisplayPosition[1] );
-  
+
   this->Internal->Nodes[n]->Points.push_back(point);
   return 1;
 }
@@ -1042,7 +1048,7 @@ int vtkContourRepresentation::GetNthNodeSlope( int n, double slope[3] )
     }
 
   int idx1, idx2;
-  
+
   if ( n == 0 && !this->ClosedLoop )
     {
     idx1 = 0;
@@ -1057,7 +1063,7 @@ int vtkContourRepresentation::GetNthNodeSlope( int n, double slope[3] )
     {
     idx1 = n - 1;
     idx2 = n + 1;
-    
+
     if ( idx1 < 0 )
       {
       idx1 += this->GetNumberOfNodes();
@@ -1067,15 +1073,15 @@ int vtkContourRepresentation::GetNthNodeSlope( int n, double slope[3] )
       idx2 -= this->GetNumberOfNodes();
       }
     }
-  
-  slope[0] = 
-    this->Internal->Nodes[idx2]->WorldPosition[0] - 
+
+  slope[0] =
+    this->Internal->Nodes[idx2]->WorldPosition[0] -
     this->Internal->Nodes[idx1]->WorldPosition[0];
-  slope[1] = 
-    this->Internal->Nodes[idx2]->WorldPosition[1] - 
+  slope[1] =
+    this->Internal->Nodes[idx2]->WorldPosition[1] -
     this->Internal->Nodes[idx1]->WorldPosition[1];
-  slope[2] = 
-    this->Internal->Nodes[idx2]->WorldPosition[2] - 
+  slope[2] =
+    this->Internal->Nodes[idx2]->WorldPosition[2] -
     this->Internal->Nodes[idx1]->WorldPosition[2];
 
   vtkMath::Normalize( slope );
@@ -1089,15 +1095,15 @@ void vtkContourRepresentation::UpdateLine( int idx1, int idx2 )
     {
     return;
     }
-  
+
   // Clear all the points at idx1
   for (unsigned int j=0;j<this->Internal->Nodes[idx1]->Points.size();j++)
     {
     delete this->Internal->Nodes[idx1]->Points[j];
     }
   this->Internal->Nodes[idx1]->Points.clear();
-  
-  this->LineInterpolator->InterpolateLine( this->Renderer, 
+
+  this->LineInterpolator->InterpolateLine( this->Renderer,
                                            this,
                                            idx1, idx2 );
 }
@@ -1113,35 +1119,43 @@ int vtkContourRepresentation::ComputeInteractionState(
 int vtkContourRepresentation::UpdateContour()
 {
   this->PointPlacer->UpdateInternalState();
-  
-  if ( this->ContourBuildTime > this->PointPlacer->GetMTime() )
+
+  //even if just the camera has moved we need to mark the locator
+  //as needing to be rebuilt
+  if ( this->Locator->GetMTime() < this->Renderer->GetActiveCamera()->GetMTime())
+    {
+    this->RebuildLocator = true;
+    }
+
+  if ( this->ContourBuildTime > this->PointPlacer->GetMTime())
     {
     // Contour does not need to be rebuilt
     return 0;
     }
-  
+
   unsigned int i;
   for(i=0; i<this->Internal->Nodes.size(); i++)
     {
     this->PointPlacer->
       UpdateWorldPosition( this->Renderer,
-                           this->Internal->Nodes[i]->WorldPosition,                               
+                           this->Internal->Nodes[i]->WorldPosition,
                            this->Internal->Nodes[i]->WorldOrientation );
     }
-  
+
   for(i=0; (i+1)<this->Internal->Nodes.size(); i++)
     {
     this->UpdateLine(i, i+1);
     }
-  
+
   if ( this->ClosedLoop )
     {
     this->UpdateLine( static_cast<int>(this->Internal->Nodes.size())-1, 0);
     }
   this->BuildLines();
-   
+  this->RebuildLocator = true;
+
   this->ContourBuildTime.Modified();
-  
+
   return 1;
 }
 
@@ -1150,10 +1164,10 @@ void vtkContourRepresentation
 ::GetRendererComputedDisplayPositionFromWorldPosition( double worldPos[3],
                                 double worldOrient[9], int displayPos[2] )
 {
-  double dispPos[2]; 
+  double dispPos[2];
   dispPos[0] = static_cast<double>(displayPos[0]);
   dispPos[1] = static_cast<double>(displayPos[1]);
-  this->GetRendererComputedDisplayPositionFromWorldPosition( worldPos, 
+  this->GetRendererComputedDisplayPositionFromWorldPosition( worldPos,
                                                 worldOrient, dispPos );
   displayPos[0] = static_cast<int>(dispPos[0]);
   displayPos[1] = static_cast<int>(dispPos[1]);
@@ -1169,11 +1183,11 @@ void vtkContourRepresentation
   pos[1] = worldPos[1];
   pos[2] = worldPos[2];
   pos[3] = 1.0;
-  
+
   this->Renderer->SetWorldPoint( pos );
   this->Renderer->WorldToDisplay();
   this->Renderer->GetDisplayPoint( pos );
-  
+
   displayPos[0] = pos[0];
   displayPos[1] = pos[1];
 }
@@ -1200,6 +1214,14 @@ void vtkContourRepresentation::Initialize( vtkPolyData * pd )
     }
   this->Internal->Nodes.clear();
 
+  vtkPolyData *tmpPoints = vtkPolyData::New();
+  tmpPoints->DeepCopy(pd);
+  this->Locator->SetDataSet(tmpPoints);
+  tmpPoints->Delete();
+
+  //reserver space in memory to speed up vector push_back
+  this->Internal->Nodes.reserve(nPoints);
+
   vtkIdList *pointIds = pd->GetCell(0)->GetPointIds();
 
   // Get the worldOrient from the point placer
@@ -1212,12 +1234,49 @@ void vtkContourRepresentation::Initialize( vtkPolyData * pd )
   this->PointPlacer->ComputeWorldPosition(this->Renderer,
                                  displayPos, ref, worldPos, worldOrient );
 
-  // Add nodes
-
+  // Add nodes without calling rebuild lines
+  // to improve performance dramatically(~15x) on large datasets
+  double *pos;
   for ( vtkIdType i=0; i < nPoints; i++ )
     {
-    double *p = points->GetPoint( i );
-    this->AddNodeAtWorldPosition( p, worldOrient );
+    pos = points->GetPoint( i );
+    this->GetRendererComputedDisplayPositionFromWorldPosition(
+                          pos, worldOrient, displayPos );
+
+    // Add a new point at this position
+    vtkContourRepresentationNode *node = new vtkContourRepresentationNode;
+    node->WorldPosition[0] = pos[0];
+    node->WorldPosition[1] = pos[1];
+    node->WorldPosition[2] = pos[2];
+    node->Selected = 0;
+
+    node->NormalizedDisplayPosition[0] = displayPos[0];
+    node->NormalizedDisplayPosition[1] = displayPos[1];
+
+    this->Renderer->DisplayToNormalizedDisplay(
+      node->NormalizedDisplayPosition[0],
+      node->NormalizedDisplayPosition[1] );
+
+    memcpy(node->WorldOrientation, worldOrient, 9*sizeof(double) );
+
+    this->Internal->Nodes.push_back(node);
+
+    if ( this->LineInterpolator && this->GetNumberOfNodes() > 1 )
+      {
+      // Give the line interpolator a chance to update the node.
+      int didNodeChange = this->LineInterpolator->UpdateNode(
+        this->Renderer, this, node->WorldPosition, this->GetNumberOfNodes()-1 );
+
+      // Give the point placer a chance to validate the updated node. If its not
+      // valid, discard the LineInterpolator's change.
+      if ( didNodeChange && !this->PointPlacer->ValidateWorldPosition(
+                node->WorldPosition, worldOrient ) )
+        {
+        node->WorldPosition[0] = worldPos[0];
+        node->WorldPosition[1] = worldPos[1];
+        node->WorldPosition[2] = worldPos[2];
+        }
+      }
     }
 
   if ( pointIds->GetNumberOfIds() > nPoints )
@@ -1226,12 +1285,101 @@ void vtkContourRepresentation::Initialize( vtkPolyData * pd )
     }
 
   // Update the contour representation from the nodes using the line interpolator
+  for (vtkIdType i=1; i <= nPoints; ++i)
+    {
+    this->UpdateLines(i);
+    }
   this->BuildRepresentation();
 
   // Show the contour.
   this->VisibilityOn();
 }
 
+//----------------------------------------------------------------------
+void vtkContourRepresentation::BuildLocator()
+{
+if (!this->RebuildLocator && !this->NeedToRender)
+    {
+    //rebuild if rebuildLocator or needtorender are true
+    return;
+    }
+
+  vtkIdType size = (vtkIdType)this->Internal->Nodes.size();
+  vtkPoints *points = vtkPoints::New();
+  points->SetNumberOfPoints(size);
+
+  //setup up the matrixes needed to transform
+  //world to display. We are going to do this manually
+  // as calling the renderer will create a new matrix for each call
+  vtkMatrix4x4 *matrix = vtkMatrix4x4::New();
+  matrix->DeepCopy(this->Renderer->GetActiveCamera()
+    ->GetCompositeProjectionTransformMatrix(
+    this->Renderer->GetTiledAspectRatio(),0,1));
+
+  //viewport info
+  double viewPortRatio[2];
+  int sizex,sizey;
+
+  /* get physical window dimensions */
+  if ( this->Renderer->GetVTKWindow() )
+    {
+    double *viewPort = this->Renderer->GetViewport();
+    sizex = this->Renderer->GetVTKWindow()->GetSize()[0];
+    sizey = this->Renderer->GetVTKWindow()->GetSize()[1];
+    viewPortRatio[0] = (sizex*(viewPort[2]-viewPort[0])) / 2.0 +
+        sizex*viewPort[0];
+    viewPortRatio[1] = (sizey*(viewPort[3]-viewPort[1])) / 2.0 +
+        sizey*viewPort[1];
+    }
+  else
+    {
+    //can't compute the locator without a vtk window
+    return;
+    }
+
+  double     view[4];
+  double pos[3] = {0,0,0};
+  double *wp;
+  for(vtkIdType i=0; i < size; ++i)
+    {
+    wp = this->Internal->Nodes[i]->WorldPosition;
+    pos[0] = this->Internal->Nodes[i]->WorldPosition[0];
+    pos[1] = this->Internal->Nodes[i]->WorldPosition[1];
+    pos[2] = this->Internal->Nodes[i]->WorldPosition[2];
+
+    //convert from world to view
+    view[0] = wp[0]*matrix->Element[0][0] + wp[1]*matrix->Element[0][1] +
+      wp[2]*matrix->Element[0][2] + matrix->Element[0][3];
+    view[1] = wp[0]*matrix->Element[1][0] + wp[1]*matrix->Element[1][1] +
+      wp[2]*matrix->Element[1][2] + matrix->Element[1][3];
+    view[2] = wp[0]*matrix->Element[2][0] + wp[1]*matrix->Element[2][1] +
+      wp[2]*matrix->Element[2][2] + matrix->Element[2][3];
+    view[3] = wp[0]*matrix->Element[3][0] + wp[1]*matrix->Element[3][1] +
+      wp[2]*matrix->Element[3][2] + matrix->Element[3][3];
+    if (view[3] != 0.0)
+      {
+      pos[0] = view[0]/view[3];
+      pos[1] = view[1]/view[3];
+      }
+
+    //now from view to display
+    pos[0] = (pos[0] + 1.0) * viewPortRatio[0];
+    pos[1] = (pos[1] + 1.0) * viewPortRatio[1];
+    pos[2] = 0;
+
+    points->InsertPoint(i,pos);
+    }
+
+  matrix->Delete();
+  vtkPolyData *tmp = vtkPolyData::New();
+  tmp->SetPoints(points);
+  this->Locator->SetDataSet(tmp);
+  tmp->FastDelete();
+  points->FastDelete();
+
+  //we fully updated the display locator
+  this->RebuildLocator = false;
+}
 //----------------------------------------------------------------------
 void vtkContourRepresentation::SetShowSelectedNodes(int flag )
 {
@@ -1242,18 +1390,21 @@ void vtkContourRepresentation::SetShowSelectedNodes(int flag )
     }
 }
 
+
 //----------------------------------------------------------------------
 void vtkContourRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
   //Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
   this->Superclass::PrintSelf(os,indent);
-  
+
   os << indent << "Pixel Tolerance: " << this->PixelTolerance <<"\n";
   os << indent << "World Tolerance: " << this->WorldTolerance <<"\n";
 
   os << indent << "Closed Loop: " << (this->ClosedLoop ? "On\n" : "Off\n");
   os << indent << "ShowSelectedNodes: " << this->ShowSelectedNodes <<endl;
-  
+  os << indent << "Rebuild Locator: " <<
+     (this->RebuildLocator ? "On" : "Off") << endl;
+
   os << indent << "Current Operation: ";
   if ( this->CurrentOperation == vtkContourRepresentation::Inactive )
     {
@@ -1266,6 +1417,6 @@ void vtkContourRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Line Interpolator: " << this->LineInterpolator << "\n";
   os << indent << "Point Placer: " << this->PointPlacer << "\n";
-  
+
 }
 
