@@ -98,6 +98,11 @@ public:
     {this->Superclass::SetWidgetRepresentation(
       reinterpret_cast<vtkWidgetRepresentation*>(r));}
 
+  // Description:
+  // Return the representation as a vtkDistanceRepresentation.
+  vtkDistanceRepresentation *GetDistanceRepresentation()
+    {return reinterpret_cast<vtkDistanceRepresentation*>(this->WidgetRep);}
+
   // Description:
   // Create the default widget representation if one is not set.
   void CreateDefaultRepresentation();
@@ -107,14 +112,37 @@ public:
   // Overridden to pass the state to component widgets.
   virtual void SetProcessEvents(int);
 
+  // Description:
+  // Description:
+  // Enum defining the state of the widget. By default the widget is in Start mode,
+  // and expects to be interactively placed. While placing the points the widget
+  // transitions to Define state. Once placed, the widget enters the Manipulate state.
+  //BTX
+  enum {Start=0,Define,Manipulate};
+  //ETX
+
+  // Description:
+  // Set the state of the widget. If the state is set to "Manipulate" then it
+  // is assumed that the widget and its representation will be initialized
+  // programmatically and is not interactively placed. Initially the widget
+  // state is set to "Start" which means nothing will appear and the user
+  // must interactively place the widget with repeated mouse selections. Set
+  // the state to "Start" if you want interactive placement. Generally state
+  // changes must be followed by a Render() for things to visually take
+  // effect.
+  virtual void SetWidgetStateToStart();
+  virtual void SetWidgetStateToManipulate();
+
+  // Description:
+  // Return the current widget state.
+  virtual int GetWidgetState()
+    {return this->WidgetState;}
+
 protected:
   vtkDistanceWidget();
   ~vtkDistanceWidget();
 
   // The state of the widget
-//BTX
-  enum {Start=0,Define,Manipulate};
-//ETX
   int WidgetState;
   int CurrentHandle;
 
