@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImagePlaneWidget.h,v $
+  Module:    vtkImagePlaneWidget.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -132,7 +132,7 @@ public:
   // Instantiate the object.
   static vtkImagePlaneWidget *New();
 
-  vtkTypeRevisionMacro(vtkImagePlaneWidget,vtkPolyDataSourceWidget);
+  vtkTypeMacro(vtkImagePlaneWidget,vtkPolyDataSourceWidget);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -387,6 +387,11 @@ public:
   // VTK_DOUBLE_MAX when the data is invalid.
   vtkGetMacro(CurrentImageValue,double);
 
+  // Description:
+  // Get the current reslice class and reslice axes
+  vtkGetObjectMacro( ResliceAxes, vtkMatrix4x4 );
+  vtkGetObjectMacro( Reslice, vtkImageReslice );
+
   // Description:
   // Choose between voxel centered or continuous cursor probing.  With voxel
   // centered probing, the cursor snaps to the nearest voxel and the reported
@@ -403,9 +408,9 @@ public:
   vtkGetMacro(Interaction,int);
   vtkBooleanMacro(Interaction,int);
 
+  //BTX
   // Description:
   // Set action associated to buttons.
-  //BTX
   enum
   {
     VTK_CURSOR_ACTION       = 0,
@@ -420,6 +425,7 @@ public:
   vtkSetClampMacro(RightButtonAction,int, VTK_CURSOR_ACTION, VTK_WINDOW_LEVEL_ACTION);
   vtkGetMacro(RightButtonAction, int);
 
+  //BTX
   // Description:
   // Set the auto-modifiers associated to buttons.
   // This allows users to bind some buttons to actions that are usually
@@ -427,7 +433,6 @@ public:
   // you can bind the left button action to VTK_SLICE_MOTION_ACTION (see above) 
   // and the left button auto modifier to VTK_CONTROL_MODIFIER: you end up with
   // the left button controling panning without pressing a key.
-  //BTX
   enum
   {
     VTK_NO_MODIFIER         = 0,
