@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImplicitPlaneWidget2.h,v $
+  Module:    vtkImplicitPlaneWidget2.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -100,7 +100,7 @@ public:
 
   // Description:
   // Standard vtkObject methods
-  vtkTypeRevisionMacro(vtkImplicitPlaneWidget2,vtkAbstractWidget);
+  vtkTypeMacro(vtkImplicitPlaneWidget2,vtkAbstractWidget);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -110,6 +110,11 @@ public:
   void SetRepresentation(vtkImplicitPlaneRepresentation *r)
     {this->Superclass::SetWidgetRepresentation(reinterpret_cast<vtkWidgetRepresentation*>(r));}
   
+  // Description:
+  // Return the representation as a vtkImplicitPlaneRepresentation.
+  vtkImplicitPlaneRepresentation *GetImplicitPlaneRepresentation()
+    {return reinterpret_cast<vtkImplicitPlaneRepresentation*>(this->WidgetRep);}
+
   // Description:
   // Create the default widget representation if one is not set. 
   void CreateDefaultRepresentation();
