@@ -75,6 +75,11 @@ public:
         reinterpret_cast<vtkWidgetRepresentation*>(r));
     }
   
+  // Description:
+  // Return the representation as a vtkParallelopipedRepresentation.
+  vtkParallelopipedRepresentation *GetParallelopipedRepresentation()
+    {return reinterpret_cast<vtkParallelopipedRepresentation*>(this->WidgetRep);}
+
   // Description:
   // Enable/disable the creation of a chair on this widget. If off,
   // chairs cannot be created.
